(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2212149,      31194]*)
(*NotebookOutlinePosition[   2215362,      31279]*)
(*  CellTagsIndexPosition[   2214857,      31264]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Evolutionary Algorithms Basics", "Title"],

Cell["\<\
Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] May 1998 / February \
2001 \[Copyright]\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Adaptive Systems and Evolution", "Section"],

Cell[CellGroupData[{

Cell["Ex DNA Omnia: Genotypes and Phenotypes", "Subsection"],

Cell[TextData[{
  "In biology, there is the important distinction between the appearance of \
an organism and its genetic constitution.  This difference is referred to as \
the ",
  StyleBox["phenotype",
    FontWeight->"Bold"],
  " and the ",
  StyleBox["genotype",
    FontWeight->"Bold"],
  ", respectively ",
  ButtonBox["(Johannsen 1911).",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Johannsen 1911"},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
Evolution interacts differently with the genotype and the phenotype \
in biological evolution.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Genotype", "Subsubsection"],

Cell["\<\
The genome or genotype of an organism is the information contained \
on the DNA of this organism.\
\>", "Text"],

Cell["\<\
Half of the genome is passed from each parent to the child (except \
for asexually reproducing organisms).\
\>", "Text"],

Cell["\<\
\[Rule] Heredity is passed through the genome.\
\>", "Text"],

Cell["\<\
Genetic changes caused by mutation and recombination are passed \
with the genome from parents to their offspring.\
\>", "Text"],

Cell[TextData[{
  "\[Rule] The genome provides the principal mechanism for variance within a \
population (see the section about ",
  ButtonBox["genome mutations",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ ], "03-GeneticAlgorithms", "GA-Mutation"}, 
        "Mutation-RNA.nb", CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  " for more details)."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Phenotype", "Subsubsection"],

Cell["\<\
The \"phenome\" or \"phenotype\" is the set of observable \
properties of an organism.\
\>", "Text"],

Cell["\<\
\[Rule] The phenotype is the body and the behavior of the organism.\
\
\>", "Text"],

Cell["\<\
Natural selection acts on the phenotype (not on the genotype) \
because the phenotype (body) is necessary for biological reproduction.\
\>", 
  "Text"],

Cell[TextData["\[Rule] The organism must survive to reproduce."], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dualism of Individuals: From Genotype to Phenotype", "Subsubsection"],

Cell["", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006G00016B000`400?l00000o`00003oo`3ooonH
0?ooo`00o`3ooonH0?ooo`00o`3ooonH0?ooo`00o`3ooonH0?ooo`00o`3ooonH0?ooo`00o`3ooonH
0?ooo`00o`3ooonH0?ooo`00o`3ooonH0?ooo`00o`3ooonH0?ooo`00<`3oool2000000D0oooo00<0
00000?ooo`3oool0X`3oool2000000D0oooo00<000000?ooo`3oool0[@3oool003D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0[@3oool003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2U0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0[@3oool00140oooo1@000000103oool0
00000?ooo`3oool3000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2
000000D0oooo0P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000103o
ool300000740oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
00001@3oool2000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000040?oo
o`<00000Y@3oool00100oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000oooo0080
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo0P0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool200000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`2R0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool2000007D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo0P00002Y0?ooo`003`3oool00`00
0000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool2000007D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo0P00002Y0?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool700000700oooo1P00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`L00000Y03oool000l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo00<000000?ooo`3oool0XP3oool000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`00000000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0200000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`2S0?ooo`003`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00800000103oool00`000000oooo00000002000000@0oooo0P000004
0?ooo`<0000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`000000oooo00800000103o
ool200000780oooo00<000000?ooo`3oool00`3oool010000000oooo0000003oool3000000@0oooo
0P0000040?ooo`030000003oool0000000800000103oool2000000@0oooo0`0000000`3oool00000
0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000040?ooo`800000YP3oool00100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000N0?ooo`030000003oool0oooo0;L0oooo
000A0?ooo`D000006P3oool00`000000oooo0?ooo`230?ooo`H000000P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0;L0oooo003o0?oooiP0oooo003o0?oood@0oooo1@1VIVI?0?oo
o`00o`3ooom10?ooo`<0IVIVE03oool00?l0oooo?P3oool306IVIUL0oooo003o0?oooc/0oooo0`1V
IVH00`3oool0IVIV0?ooo`1G0?ooo`00o`3oooli0?ooo`<0IVIV103oool00`1VIVH0oooo0?ooo`1E
0?ooo`00o`3ooolf0?ooo`<0IVIV203oool00`1VIVH0oooo0?ooo`1D0?ooo`00o`3ooold0?ooo`80
IVIV303oool00`1VIVH0oooo0?ooo`1C0?ooo`00o`3ooola0?ooo`<0IVIV3P3oool00`1VIVH0oooo
0?ooo`1C0?ooo`00o`3oool^0?ooo`<0IVIV4P3oool00`1VIVH0oooo0?ooo`1B0?ooo`00o`3oool[
0?ooo`<0IVIV5P3oool00`1VIVH0oooo0?ooo`1A0?ooo`00o`3ooolY0?ooo`80IVIV6P3oool00`1V
IVH0oooo0?ooo`1@0?ooo`00o`3ooolV0?ooo`<0IVIV703oool00`1VIVH0oooo0?ooo`1@0?ooo`00
o`3ooolT0?ooo`80IVIV803oool00`1VIVH0oooo0?ooo`1?0?ooo`00o`3ooolQ0?ooo`<0IVIV8`3o
ool00`1VIVH0oooo0?ooo`1>0?ooo`00o`3ooolN0?ooo`<0IVIV9P3oool00`1VIVH0oooo0?ooo`1>
0?ooo`00o`3ooolK0?ooo`<0IVIV:P3oool00`1VIVH0oooo0?ooo`1=0?ooo`00o`3ooolF0?ooo`D0
IVIV;P3oool206IVITd0oooo003o0?oooa<0oooo0`1VIVH40?ooo`0306IVIP3oool0oooo02d0oooo
00<0IVIV0?ooo`3oool0B`3oool00?l0oooo4@3oool206IVIPL0oooo00<0IVIV0?ooo`3oool0;P3o
ool00`1VIVH0oooo0?ooo`1:0?ooo`00o`3oool>0?ooo`<0IVIV2P3oool00`1VIVH0oooo0?ooo`0^
0?ooo`0306IVIP3oool0oooo00H0oooo0P1VIVI10?ooo`00o`3oool;0?ooo`<0IVIV3P3oool00`1V
IVH0oooo0?ooo`0]0?ooo`0306IVIP3oool0oooo00<0oooo0`1VIVI30?ooo`00o`3oool90?ooo`80
IVIV4P3oool00`1VIVH0oooo0?ooo`0/0?ooo`0306IVIP3oool0oooo00<0IVIVAP3oool00?l0oooo
1P3oool306IVIQ@0oooo00<0IVIV0?ooo`3oool0;03oool306IVITT0oooo003o0?ooo`<0oooo0`1V
IVHH0?ooo`0306IVIP3oool0oooo02T0oooo0`1VIVH00`3oool0IVIV0?ooo`180?ooo`00o`3oool1
0?ooo`80IVIV703oool00`1VIVH0oooo0?ooo`0U0?ooo`<0IVIV1@3oool00`1VIVH0oooo0?ooo`16
0?ooo`00o@3oool306IVIQl0oooo00<0IVIV0?ooo`3oool08@3oool306IVIPP0oooo00<0IVIV0?oo
o`3oool0AP3oool00?X0oooo0`1VIVHS0?ooo`0306IVIP3oool0oooo01d0oooo0`1VIVH<0?ooo`03
06IVIP3oool0oooo04D0oooo003h0?ooo`80IVIV9P3oool00`1VIVH0oooo0?ooo`0J0?ooo`<0IVIV
403oool00`1VIVH0oooo0?ooo`140?ooo`00m@3oool306IVIRT0oooo00<0IVIV0?ooo`3oool05P3o
ool306IVIQ@0oooo00<0IVIV0?ooo`3oool0@`3oool00?80oooo0`1VIVH]0?ooo`0306IVIP3oool0
oooo01<0oooo0`1VIVHF0?ooo`0306IVIP3oool0oooo04<0oooo003_0?ooo`<0IVIV00<0oooo06IV
IP3oool0;P3oool00`1VIVH0oooo0?ooo`0?0?ooo`<0IVIV6P3oool00`1VIVH0oooo0?ooo`120?oo
o`00jP3oool506IVIPD0oooo0P1VIVH^0?ooo`80IVIV2@3oool606IVIQh0oooo00<0IVIV0?ooo`3o
ool0@@3oool00>L0oooo0`1VIVH<0?ooo`0306IVIP3oool0oooo02`0oooo00<0IVIV0?ooo`3oool0
103oool306IVIRD0oooo00<0IVIV0?ooo`3oool0@03oool00>D0oooo0`1VIVH?0?ooo`0306IVIP3o
ool0oooo02`0oooo00@0IVIV00000000000000000P1VIVHY0?ooo`0306IVIP3oool0oooo03l0oooo
003R0?ooo`<0IVIV4`3oool00`1VIVH0oooo0?ooo`0/0?ooo`80<ol000<000000?ooo`3oool0:P3o
ool00`1VIVH0oooo0?ooo`0n0?ooo`00g`3oool306IVIQH0oooo00<0IVIV0?ooo`3oool0:@3oool3
06IVIP<0<ol0;03oool00`1VIVH0oooo0?ooo`0n0?ooo`00g@3oool206IVIQX0oooo00<0IVIV0?oo
o`3oool09@3oool306IVIP@0oooo0P0co`0]0?ooo`0306IVIP3oool0oooo03d0oooo003J0?ooo`<0
IVIV7@3oool00`1VIVH0oooo0?ooo`0Q0?ooo`<0IVIV1`3oool203?o02h0oooo00<0IVIV0?ooo`3o
ool0?03oool00=L0oooo0`1VIVHQ0?ooo`0306IVIP3oool0oooo01d0oooo0`1VIVH;0?ooo`<0<ol0
;@3oool00`1VIVH0oooo0?ooo`040?ooo`<0IVIV=03oool00=D0oooo0P1VIVHU0?ooo`0306IVIP3o
ool0oooo01X0oooo0P1VIVH>0?ooo`@0<ol0;03oool0101VIVH0oooo0?ooo`3oool306IVISL0oooo
003B0?ooo`<0IVIV:03oool00`1VIVH0oooo0?ooo`0F0?ooo`<0IVIV4P3oool303?o02`0oooo0`1V
IVHj0?ooo`00c`3oool306IVIR/0oooo00<0IVIV0?ooo`3oool04`3oool306IVIQH0oooo0`0co`0Y
0?ooo`@0IVIV>`3oool00<`0oooo0`1VIVH20?ooo`0306IVIP3oool0oooo02X0oooo00<0IVIV0?oo
o`3oool03`3oool306IVIQX0oooo0`0co`0U0?ooo`<0IVIV0`3oool00`1VIVH0oooo0?ooo`0i0?oo
o`00bP3oool206IVIPH0oooo00<0IVIV0?ooo`3oool0:P3oool00`1VIVH0oooo0?ooo`0;0?ooo`<0
IVIV7@3oool00`1VIVH0<ol003?o00050?ooo`<000006P3oool306IVIPH0oooo00<0IVIV0?ooo`3o
ool0>@3oool00<L0oooo0`1VIVH90?ooo`0306IVIP3oool0oooo02X0oooo00<0IVIV0?ooo`3oool0
1`3oool306IVIR40oooo0`0co`020?ooo`80000000<0I/co06K<c00000005`3oool306IVIPX0oooo
00<0IVIV0?ooo`3oool0>03oool00<D0oooo0P1VIVH=0?ooo`0306IVIP3oool0oooo02X0oooo00<0
IVIV0?ooo`3oool0103oool206IVIRD0oooo0`0co`001`3oool0000009VIo`2IVL`0VIWo09VIc000
00004`3oool306IVIPh0oooo00<0IVIV0?ooo`3oool0=`3oool00<80oooo0`1VIVH@0?ooo`0306IV
IP3oool0oooo02X0oooo00<0IVIV0?ooo`3oool00`1VIVHX0?ooo`<0<ol000H0000006K<c01Vc?l0
I/c<06K<o`00000A0?ooo`80IVIV4P3oool00`1VIVH0oooo0?ooo`0f0?ooo`00_03oool606IVIQ@0
oooo00<0IVIV0?ooo`3oool09P3oool606IVIR80oooo0`0000070?ooo`<0<ol000@0000006K<o`1V
c<`0I/co0P00000:0?ooo`H0IVIV503oool206IVISL0oooo002j0?ooo`80IVIV6`3oool00`1VIVH0
oooo0?ooo`0R0?ooo`<0IVIV1P3oool00`1VIVH0oooo0?ooo`0L0?ooo`<0000000<0VIWo06K<c01V
c<`01@0000030?ooo`0806IVIP3oool0000009VIc02IVOl0VIW<09VIo`0000070?ooo`<0IVIV703o
ool00`1VIVH0oooo0?ooo`0d0?ooo`00]`3oool306IVIQh0oooo00<0IVIV0?ooo`3oool07P3oool3
06IVIPX0oooo00<0IVIV0?ooo`3oool06`3oool3000000P0Z_oo10000000201VIVH0000006K<o`1V
c<`0I/co06K<c01Vc?l000000`3oool306IVIQl0oooo00<0IVIV0?ooo`3oool0=03oool00;D0oooo
0P1VIVHR0?ooo`0306IVIP3oool0oooo01/0oooo0P1VIVH>0?ooo`0306IVIP3oool0oooo01d0oooo
0`0000002@2IVOl0I/c<09VIo`1Vc<`0VIWo06K<c02IVOl0I/c<09VIo`030000000509VIo`2IVL`0
VIWo09VIc00000000`1VIVHS0?ooo`0306IVIP3oool0oooo03<0oooo002b0?ooo`<0IVIV9@3oool0
0`1VIVH0oooo0?ooo`0G0?ooo`<0IVIV403oool00`1VIVH0oooo0?ooo`0O0?ooo`<000002P2Zool0
1@000000I/co06K<c01Vc?l0000002L0oooo00<0IVIV0?ooo`3oool0<P3oool00:l0oooo0`1VIVHY
0?ooo`0306IVIP3oool0oooo01<0oooo0`1VIVHD0?ooo`0306IVIP3oool0oooo0240oooo0P000000
302IVOl0I/c<09VIo`1Vc<`0VIWo06K<c02IVOl0I/c<09VIo`1Vc<`0VIWo000002T0oooo00<0IVIV
0?ooo`3oool0<@3oool00:`0oooo1@1VIVH[0?ooo`0306IVIP3oool0oooo00l0oooo0`1VIVHG0?oo
o`0306IVIP3oool0oooo02L0oooo0P0000040:[oo`80<ol01P00000S0?ooo`0306IVIP3oool0oooo
0340oooo002Y0?ooo`<0IVIV1@3oool00`1VIVH0oooo0?ooo`0Y0?ooo`0306IVIP3oool0oooo00/0
oooo0`1VIVHK0?ooo`0306IVIP3oool0oooo02<0oooo0`1VIVH50?ooo`0906IVIP0co`00<ol003?o
002m_Kd0VIW<0;fm_@2IVL`0_Kfm00<000008@3oool00`1VIVH0oooo0?ooo`0`0?ooo`00Z03oool0
0`1VIVH0oooo0?ooo`070?ooo`0306IVIP3oool0oooo02T0oooo00<0IVIV0?ooo`3oool01`3oool3
06IVIQl0oooo00<0IVIV0?ooo`3oool07`3oool306IVIPP0oooo1@0co`070:ZZo`<000007`3oool0
0`1VIVH0oooo0?ooo`040?ooo`<0IVIV:03oool00;<0oooo00<0IVIV0?ooo`3oool0:@3oool00`1V
IVH0oooo0?ooo`040?ooo`80IVIV8`3oool00`1VIVH0oooo0?ooo`0K0?ooo`<0IVIV2P3oool703?o
00090;fm_@2IVL`0_Kfm09VIc02m_Kd0VIW<0;fm_@2IVL`0_Kfm008000007P3oool0101VIVH0oooo
0?ooo`3oool306IVIRX0oooo000F0?ooo`<0003D0P3oool50000e1`0oooo1@00001c0?ooo`0306IV
IP3oool0oooo02T0oooo00<0IVIV0?ooo`3oool00`1VIVHV0?ooo`0306IVIP3oool0oooo01P0oooo
0`1VIVH<0?ooo`@0<ol000<0ZZ[o03?o000co`000P0000090:ZZo`800000703oool406IVIRd0oooo
000F0?ooo`80003D0`3oool30000e1d0oooo0P0000020?ooo`800000M03oool00`1VIVH0oooo0?oo
o`0X0?ooo`<0IVIV:P3oool00`1VIVH0oooo0?ooo`0D0?ooo`<0IVIV3P3oool503?o00050:ZZo`0c
o`00<ol003?o003oool00P0000002@2m_Kd0VIW<0;fm_@2IVL`0_Kfm09VIc02m_Kd0VIW<0;fm_@02
000001P0oooo101VIVH_0?ooo`005@3oool20000e0<0oooo0P000=@M0?ooo`<000000P3oool20000
07D0oooo00<0IVIV0?ooo`3oool09@3oool306IVIP80oooo00<0IVIV0?ooo`3oool0:@3oool00`1V
IVH0oooo0?ooo`0@0?ooo`<0IVIV4@3oool203?o00030?ooo`0co`00<ol00080ZZ[o0`0co`020?oo
o`@000001`2ZZ_l2000001<0oooo0`1VIVH40?ooo`0306IVIP3oool0oooo02`0oooo000E0?ooo`80
003D00@0oooo0000e0000=@0003D703oool400000080oooo0`00001f0?ooo`0306IVIP3oool0oooo
0240oooo0`1VIVH60?ooo`0306IVIP3oool0oooo02T0oooo00<0IVIV0?ooo`3oool0303oool306IV
IQ<0oooo0`0co`001P3oool0<ol003?o002ZZ_l0c<c<000000<0<ol01@3oool500000080VIW<00@0
_Kfm09VIc000000000003@3oool406IVIPP0oooo00<0IVIV0?ooo`3oool0:`3oool001@0oooo0P00
0=@00`3oool0003D0000e00L0?ooo`<0000000<0oooo0000000000000P3oool2000007P0oooo00<0
IVIV0?ooo`3oool07@3oool306IVIPX0oooo00<0IVIV0?ooo`3oool0:@3oool00`1VIVH0oooo0?oo
o`080?ooo`<0IVIV5@3oool303?o0080oooo0P0co`020:ZZo`030;fm_@000000<ol00080<ol02@3o
ool400000080ZZ[o0P0000090?ooo`80IVIV303oool00`1VIVH0oooo0?ooo`0[0?ooo`00503oool4
0000e1/0oooo0`0000030?ooo`80000000<0oooo000000000000>@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0=P3oool00`1VIVH0oooo0?ooo`0J0?ooo`80IVIV3P3o
ool00`1VIVH0oooo0?ooo`0Y0?ooo`0306IVIP3oool0oooo00D0oooo0P1VIVHH0?ooo`80<ol00`3o
ool203?o00050:ZZo`3<c<`0ZZ[o0000003oool00P0co`0=0?ooo`<0000000<0VIW<0000003oool0
103oool306IVIPl0oooo00<0IVIV0?ooo`3oool0:P3oool001<0oooo10000=@I0?ooo`<000001P3o
ool4000007`0oooo0`1VIVHC0?ooo`H0IVIV4@3oool206IVIRT0oooo201VIVHI0?ooo`<0<ol00`3o
ool203?o00030000002ZZ_l0ZZ[o008000001@0co`0=0?ooo`@000000`1VIVHC0?ooo`80IVIV:P3o
ool001<0oooo0P000=@H0?ooo`D000001`3oool300000800oooo00<0IVIV0?ooo`3oool03@3oool3
06IVIQP0oooo00<0IVIV0?ooo`3oool09@3oool306IVIP030?ooo`1VIVH0oooo01d0oooo0P0co`04
0?ooo`80<ol000H000000:ZZo`2m_Kd0ZZ[o0000001VIVH20?ooo`<0<ol02P3oool306IVIQX0oooo
00<0IVIV0?ooo`3oool0:03oool001<0oooo0`000=@F0?ooo`8000000P3oool2000000H0oooo0`00
00220?ooo`0306IVIP3oool0oooo00T0oooo0`1VIVHL0?ooo`0306IVIP3oool0oooo0240oooo0`1V
IVH50?ooo`0306IVIP3oool0oooo01/0oooo0P0co`040?ooo`80<ol000L000000<c<c02ZZ_l0c<c<
0000003oool0IVIV0080oooo0P0co`060?ooo`@0IVIV7@3oool00`1VIVH0oooo0?ooo`0X0?ooo`00
4`3oool40000e1<0oooo0`0000030?ooo`8000001@3oool4000008<0oooo00<0IVIV0?ooo`3oool0
1@3oool306IVIR00oooo00<0IVIV0?ooo`3oool07@3oool306IVIPT0oooo00<0IVIV0?ooo`3oool0
6@3oool303?o00@0oooo0P0co`001@3oool000000;fm_@2ZZ_l000000080oooo00<0IVIV0?ooo`0c
o`000`0co`020?ooo`<0IVIV8@3oool00`1VIVH0oooo0?ooo`0W0?ooo`00503oool40000e0l0oooo
0`0000060?ooo`8000000`3oool3000000030?ooo`000000000008@0oooo00<0IVIV0?ooo`3oool0
0P3oool306IVIR<0oooo00<0IVIV0?ooo`3oool06P3oool206IVIPd0oooo00<0IVIV0?ooo`3oool0
5`3oool303?o00D0oooo0P0co`001@3oool000000:ZZo`3<c<`0000000<0oooo00<0IVIV0?ooo`0c
o`000`0co`000`1VIVH0oooo0?ooo`0R0?ooo`0306IVIP3oool0oooo02L0oooo000E0?ooo`@0003D
303oool3000000P0oooo0P0000020?ooo`800000RP3oool406IVIRL0oooo00<0IVIV0?ooo`3oool0
5P3oool306IVIQ00oooo00<0IVIV0?ooo`3oool05P3oool203?o00H0oooo0P0co`020?ooo`040000
002ZZ_l0_Kfm000000<0oooo0`1VIVH303?o00<000008P3oool00`1VIVH0oooo0?ooo`0V0?ooo`00
5@3oool20000e0030?ooo`000=@0003D00T0oooo100000090?ooo`@00000RP3oool406IVIRX0oooo
00<0IVIV0?ooo`3oool04P3oool306IVIQ@0oooo00<0IVIV0?ooo`3oool05@3oool203?o00H0oooo
0P0co`020?ooo`040000003<c<`0ZZ[o000000@0IVIV0`3oool203?o00030000001EEOl0000002<0
oooo00<0IVIV0?ooo`3oool09@3oool001D0oooo0P000=@20?ooo`<0003D1@3oool3000000030?oo
o`000000000000T0oooo0`0000280?ooo`<0IVIV103oool00`1VIVH0oooo0?ooo`0X0?ooo`0306IV
IP3oool0oooo00h0oooo0`1VIVHH0?ooo`0306IVIP3oool0oooo01<0oooo0`0co`060?ooo`80<ol0
0P3oool0101VIVH000000;fm_@0000040?ooo`0306IVIP3oool0oooo00<0<ol000@0VIW<00000000
000000008P3oool00`1VIVH0oooo0?ooo`0T0?ooo`005P3oool20000e0<0oooo0`000=@20?ooo`80
00000`3oool2000000H0oooo1@0000280?ooo`0306IVIP3oool0oooo00H0oooo00<0IVIV0?ooo`3o
ool0:03oool00`1VIVH0oooo0?ooo`0:0?ooo`<0IVIV6`3oool00`1VIVH0oooo0?ooo`0C0?ooo`80
<ol01`3oool203?o0080IVIV00@0oooo0000002ZZ_l000001@3oool3000000<0<ol00`00000R0?oo
o`0306IVIP3oool0oooo02@0oooo000F0?ooo`80003D1@3oool30000e0030000003oool0oooo0080
oooo0P0000030?ooo`@000000P3oool200000980oooo00<0IVIV0?ooo`3oool0:03oool00`1VIVH0
oooo0?ooo`060?ooo`<0IVIV7`3oool00`1VIVH0oooo0?ooo`0A0?ooo`<0<ol01P3oool00`1VIVH0
<ol003?o00040?ooo`8000001P3oool00`1VIVH000000000000203?o00<000008`3oool00`1VIVH0
oooo0?ooo`050?ooo`<0IVIV6`3oool001L0oooo0P000=@30?ooo`03000000000=@0003D00<0003D
0`3oool2000000040?ooo`0000000000000009X0oooo0P1VIVHY0?ooo`0306IVIP3oool0oooo00<0
oooo0`1VIVHR0?ooo`0306IVIP3oool0oooo00l0oooo0`0co`040?ooo`<0IVIV00<0oooo03?o000c
o`00103oool2000000H0oooo0P0000001P3<oiT00000000000000000VIW<000002@0oooo00@0IVIV
0?ooo`3oool0oooo0`1VIVHN0?ooo`00603oool20000e080oooo00<000000000e0000=@00P3oool3
0000e0030?ooo`000000000009l0oooo00<0IVIV0?ooo`3oool0:03oool00`1VIVH0oooo06IVIP02
06IVIRD0oooo00<0IVIV0?ooo`3oool03`3oool203?o0080oooo0`1VIVH40?ooo`80<ol01@3oool0
0`000000oooo0?ooo`030?ooo`@0000000D0olc<000000000000VIVI0000000T0?ooo`@0IVIV8@3o
ool001P0oooo0`000=@200000080003D103oool40000e440oooo0`00000D0?ooo`@00000A03oool0
0`1VIVH0oooo0?ooo`0U0?ooo`@0IVIV:@3oool00`1VIVH0oooo0?ooo`0>0?ooo`80<ol00P1VIVH7
0?ooo`80<ol02`3oool01@000000oooo0?ooo`1VIVH000000080oooo0P00000Q0?ooo`<0IVIV9@3o
ool001T0oooo0`000=@00`000000003D0000e0070?ooo`@0003D?`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool00`1VIVH0oooo0?ooo`0Q
0?ooo`<0IVIV103oool00`1VIVH0oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo00X0oooo0P1VIVH3
03?o00T0oooo0P0co`0?0?ooo`0306IVIP3oool0oooo0200oooo0`1VIVHX0?ooo`00603oool20000
00D0003D103oool4000000030?ooo`000=@0003D03l0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo00<0IVIV0?ooo`3oool07@3oool306IV
IPP0oooo00<0IVIV0?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`070?ooo`80IVIV0P3oool203?o
00X0oooo0P0co`0@0?ooo`0306IVIP3oool0oooo01`0oooo101VIVHZ0?ooo`00603oool200000003
0?ooo`000=@0003D0080003D0P3oool3000000<0oooo10000=@U0?ooo`<000000P3oool00`000000
oooo0?ooo`03000000<0oooo0P0000030?ooo`<000000`3oool3000000@0oooo1P0000030?ooo`80
0000103oool5000000@0oooo0`0000000`3oool0000000000004000000@0oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`00000R0?ooo`80IVIV603oool506IVIP`0oooo0P1VIVHX0?ooo`80
IVIV00<0oooo06IVIP1VIVH0101VIVH30?ooo`<0<ol02P3oool203?o0140oooo00<0IVIV0?ooo`3o
ool0503oool706IVIRh0oooo000G0?ooo`8000000`3oool00`000000003D0000e002000000L0oooo
1P000=@S0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo000002<0oooo00<0IVIV0?ooo`3oool04P3oool306IVIQ<0oooo00<0IVIV0?oo
o`3oool09@3oool306IVIPT0oooo0P0co`0;0?ooo`80<ol04@3oool00`1VIVH0oooo0?ooo`0A0?oo
o`<0IVIV=@3oool001H0oooo0P0000040?ooo`8000000P000=@80?ooo`80003D0`3oool30000e003
0?ooo`000=@0003D01h0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0280oooo
00<0IVIV0?ooo`3oool03P3oool306IVIQL0oooo00<0IVIV0?ooo`3oool0803oool406IVIP<0oooo
00<0IVIV0?ooo`3oool01P3oool203?o00/0oooo0P0co`0B0?ooo`0306IVIP3oool0oooo00d0oooo
0`1VIVHh0?ooo`005P3oool2000000<0oooo0P0000020?ooo`<0003D1P3oool20000e0D0oooo1000
0=@N0?ooo`060000003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00D0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P00000V0?ooo`0306IVIP3oool0
oooo00X0oooo0`1VIVHJ0?ooo`0306IVIP3oool0oooo01h0oooo0P1VIVH80?ooo`0306IVIP3oool0
oooo00@0oooo0`0co`0;0?ooo`80<ol04`3oool00`1VIVH0oooo0?ooo`090?ooo`<0IVIV>`3oool0
01D0oooo0P0000020?ooo`<000001@3oool30000e0@0oooo0P000=@70?ooo`<0003D7@3oool01000
0000oooo0000000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`3oool6000000050?ooo`000000oooo0?ooo`0000000`3oool6000000030?ooo`00
0000oooo00@0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`80IVIV1`3oool306IVIQh0oooo
00<0IVIV0?ooo`3oool06P3oool306IVIP/0oooo00<0IVIV0?ooo`3oool00`3oool203?o00`0oooo
0`0co`0C0?ooo`0306IVIP3oool0oooo00D0oooo0`1VIVHn0?ooo`005@3oool2000000030?ooo`00
0000000000T0oooo0`000=@20?ooo`80003D1`3oool50000e1/0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`040000003oool0oooo00000080oooo0`0000020?ooo`<00000
00<0oooo0000003oool00`3oool2000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool0oooo100000000`3o
ool000000?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003o
ool00000000000<0oooo00@000000?ooo`3oool00000:03oool00`1VIVH0oooo0?ooo`020?ooo`80
IVIV8P3oool00`1VIVH0oooo0?ooo`0F0?ooo`<0IVIV3`3oool0101VIVH0oooo0?ooo`3oool303?o
00d0oooo0P0co`0D0?ooo`0306IVIP3oool0oooo00@0IVIV@@3oool001D0oooo1000000<0?ooo`D0
003D1`3oool20000e080oooo0`000=@I0?ooo`030000003oool0000000<0oooo00<000000?ooo`00
0000103oool2000000@0oooo00P000000?ooo`00000000000?ooo`000000oooo000000D0oooo00<0
00000?ooo`0000001@3oool2000000D0oooo0P0000060?ooo`<000000P3oool00`000000oooo0000
00060?ooo`<000000`3oool300000080oooo00<000000?ooo`3oool00P3oool3000002T0oooo101V
IVHU0?ooo`0306IVIP3oool0oooo0180oooo0`1VIVHB0?ooo`0406IVIP3oool0oooo0?ooo`80<ol0
3P3oool203?o01@0oooo0`1VIVI50?ooo`00503oool300000100oooo0`000=@70?ooo`80003D103o
ool20000e080oooo0P000=@D0?ooo`8000001@3oool2000001L0oooo00<000000?ooo`3oool0G03o
ool406IVIRP0oooo00<0IVIV0?ooo`3oool03P3oool306IVIQH0oooo00<0IVIV0?ooo`3oool00P0c
o`0>0?ooo`80<ol04@3oool306IVITP0oooo000D0?ooo`8000004`3oool40000e0@0oooo0P000=@5
0?ooo`80003D00<0oooo0000e0000=@0503oool2000000D0oooo0P00000F0?ooo`800000F`3oool3
06IVIP@0oooo00<0IVIV0?ooo`3oool09P3oool00`1VIVH0oooo0?ooo`090?ooo`@0IVIV6P3oool0
101VIVH0oooo03?o000co`0>0?ooo`80<ol03P3oool306IVIT/0oooo000D0?ooo`8000005P3oool2
0000e0<0oooo0P000=@60?ooo`@0003D4`3oool2000000L0oooo0P00000F0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool09`3oool206IVIPP0oooo00<0IVIV0?ooo`3oool09P3oool0
0`1VIVH0oooo0?ooo`060?ooo`80IVIV7`3oool00`1VIVH0<ol00?ooo`0>0?ooo`80<ol02`3oool3
06IVITh0oooo000D0?ooo`8000005`3oool60000e0L0oooo0`000=BI0?ooo`0306IVIP3oool0oooo
02H0oooo00<0IVIV0?ooo`3oool00P3oool306IVIR80oooo00<0<ol00?ooo`3oool03@3oool203?o
00L0oooo101VIVIA0?ooo`005@3oool2000001T0oooo10000=@70?ooo`<0003DV03oool00`1VIVH0
oooo0?ooo`0W0?ooo`@0IVIV903oool203?o00l0oooo0P0co`040?ooo`<0IVIVE@3oool001D0oooo
0`00000K0?ooo`<0003D1@3oool40000e9P0oooo00<0IVIV0?ooo`3oool0903oool406IVIRH0oooo
0P0co`000`1VIVH0oooo0?ooo`0<0?ooo`80<ol000@0oooo06IVIP1VIVH0IVIVF03oool001D0oooo
1000000L0?ooo`<0003D0`3oool40000e9T0oooo00<0IVIV0?ooo`3oool07`3oool406IVIP@0oooo
00<0IVIV0?ooo`3oool08P3oool303?o00030?ooo`1VIVH0oooo00`0oooo0P0co`000`1VIVH0oooo
0?ooo`1I0?ooo`005P3oool5000001`0oooo0`000=@0103oool0003D0000e03oool20000e9T0oooo
00<0IVIV0?ooo`3oool0703oool206IVIPT0oooo00<0IVIV0?ooo`3oool08@3oool203?o00<0oooo
00<0IVIV0?ooo`3oool01`3oool306IVIP80<ol0G03oool001H0oooo0P0000020?ooo`8000000`3o
ool2000001P0oooo0`000=@30?ooo`80003DV@3oool206IVIQT0oooo0`1VIVH<0?ooo`0306IVIP3o
ool0oooo01l0oooo0`0co`040?ooo`0306IVIP3oool0oooo0080oooo101VIVH30?ooo`80<ol0G03o
ool001L0oooo0P0000020?ooo`<0000000<0oooo0000000000006P3oool30000e0030?ooo`000=@0
003D01`0oooo0`0000030?ooo`<000000`3oool;000000<0oooo0`0000020?ooo`<000000P3oool5
00000080oooo1@0000030?ooo`800000103oool600000400oooo0P1VIVHA0?ooo`H0IVIV403oool2
06IVIQl0oooo0P0co`040?ooo`H0IVIV203oool00`0co`00oooo0?ooo`1J0?ooo`00603oool20000
00<0oooo1000000L0?ooo`80003D00<0oooo0000e0000=@0703oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000@`3oool00`1VIVH0oooo0?ooo`0;0?ooo`<0IVIV603o
ool00`1VIVH0oooo0?ooo`0L0?ooo`80<ol000@0oooo06IVIP1VIVH0IVIV3P3oool00`0co`00oooo
0?ooo`1J0?ooo`00603oool3000000@0oooo0`00000L0?ooo`@0003D703oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0@P3oool00`1VIVH0oooo0?ooo`060?ooo`@0IVIV
703oool00`1VIVH0oooo0?ooo`0J0?ooo`<0<ol000<0IVIV0?ooo`3oool03`3oool2000005/0oooo
000I0?ooo`<000000`3oool5000000@0oooo0P00000E0?ooo`<0003D703oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`040000003oool0oooo000000D0oooo
0P0000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`130?ooo`0306IVIP3oool0oooo00<0oooo0P1VIVHP0?ooo`0306IVIP3oool0oooo
01L0oooo0`1VIVH203?o01<0oooo00<0EJ[o0000003oool0FP3oool001X0oooo0`0000020?ooo`80
00000`3oool3000000030?ooo`000000000001H0oooo0`000=@K0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0A03oool00`1VIVH0oooo06IVIP0206IVIR<0oooo00<0IVIV0?ooo`3oool0
4`3oool206IVIP@000000P0co`0C0?ooo`030000002IVOl0000005X0oooo000L0?ooo`80000000<0
oooo0000000000001P3oool3000001L0oooo0P000=@K0?ooo`030000003oool0oooo0080oooo0`00
00020?ooo`060000003oool0oooo0?ooo`000000oooo0`0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00
00020?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`<0000000<0oooo0000003oool0
A03oool306IVIRL0oooo00<0IVIV0?ooo`3oool03`3oool306IVIP80oooo00<0000003?<c01EZ_l0
0`0co`0<0?ooo`P0000000<0<ol00000003oool0F@3oool001d0oooo100000070?ooo`@000005@3o
ool20000e1/0oooo00<000000?ooo`3oool00`3oool01@000000oooo000000000000oooo00<00000
0`3oool00`000000oooo000000060?ooo`<000000P3oool010000000oooo0?ooo`3oool300000080
oooo0`0000020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0000004<0
oooo0`1VIVH30?ooo`0306IVIP3oool0oooo02D0oooo00<0IVIV0?ooo`3oool02`3oool306IVIPH0
oooo00D0000003?<o`0co`00<ol00000000;0?ooo`080000001Eool0`<3005Goo`30`<00EOoo0<30
`01Eool203?o00030;fm_@000000000005P0oooo000N0?ooo`<000001`3oool2000000030?ooo`00
00000000008000000P3oool2000000d0oooo0`000=@H0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo
0P1VIVH70?ooo`0306IVIP3oool0oooo02D0oooo00<0IVIV0?ooo`3oool01`3oool306IVIPX0oooo
0`0co`000`34a<@000000?ooo`0>0?ooo`80000000<0oooo03?o000co`000P0000000`2IVL`00000
0000001F0?ooo`00803oool2000000H0oooo0P0000040?ooo`D00000303oool40000e1P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0H0?ooo`8000002@3oool00`000000oooo
0?ooo`1K0?ooo`80IVIV9P3oool00`1VIVH0oooo0?ooo`020?ooo`@0IVIV303oool403?o00030:ZZ
o`00000000000100oooo0`0co`000`000000oooo00000004000005@0oooo000Q0?ooo`<00000103o
ool2000000H0oooo0`00000;0?ooo`@0003D6@3oool7000001/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1I0?ooo`0306IVIP3oool0oooo02@0oooo101VIVH>0?ooo`H0<ol000<0
a<C40;fm_@0000003`3oool403?o00030?o<o`000000oooo00<0oooo0`00001B0?ooo`008`3oool3
00000080oooo0P0000070?ooo`@000001`3oool30000e0030?ooo`000=@0003D0:D0oooo00<0IVIV
0?ooo`3oool08P3oool406IVIPl0oooo1P0co`000`3oool000000<bIc002000000h0oooo100co`00
0`2m_Kd000000?ooo`060?ooo`030000003oool0oooo04l0oooo000U0?ooo`D000001`3oool20000
00040?ooo`000000000000000080oooo10000=@20?ooo`80003DY`3oool00`1VIVH0oooo0?ooo`0M
0?ooo`@0IVIV4P3oool703?o0080oooo00<000000<C4a00000003@3oool503?o00030000003oool0
oooo05P0oooo000W0?ooo`<000001`3oool2000000<0oooo0`0000030000e0<0oooo0P000=BX0?oo
o`0306IVIP3oool0oooo01X0oooo0`1VIVHD0?ooo`P0<ol00`3oool2000000d0oooo1@0co`000`00
0000oooo0?ooo`1H0?ooo`00:03oool5000000@0oooo0P0000040?ooo`@0003D0`3oool20000e:X0
oooo00<0IVIV0?ooo`3oool05@3oool406IVIQH0oooo0`0co`000`3oool0<ol003?o000303?o00@0
oooo00<000000?ooo`3oool02P3oool703?o05X0oooo000/0?ooo`8000000`3oool200000080oooo
0`000=@00`3oool0003D0000e002000000<0003DZ`3oool00`1VIVH0oooo0?ooo`0A0?ooo`<0IVIV
6@3oool303?o00030?ooo`0co`00<ol000<0<ol04P3oool203?o00030?ooo`0co`00<ol00080<ol0
FP3oool002d0oooo1P0000030000e0<0oooo0P000=@200000080003D[@3oool206IVIPX0oooo1`1V
IVHJ0?ooo`@0<ol000D0oooo03?o000co`00<ol00?ooo`0203?o0100oooo2@0co`1J0?ooo`00<03o
ool30000e0H0oooo0P000=@00`3oool0003D0000e01U0?ooo`<0g@P6B03oool00`1VIVH0oooo0?oo
o`050?ooo`<0IVIV7`3oool303?o0080oooo0`0co`00103oool0<ol003?o000co`0@0?ooo`80<ol0
0P3oool203?o00040?ooo`0co`00<ol003?o05T0oooo000]0?ooo`@0003D0P3oool3000000<0oooo
10000=@2000006@0oooo1`3M20I50?ooo`0306IVIP3oool0oooo00@0IVIV8@3oool303?o00<0oooo
0P0co`020?ooo`80<ol0403oool303?o0080oooo0P0co`020?ooo`80<ol0F@3oool002`0oooo0P00
0=@00`3oool0003D0000e0040?ooo`<0000000@0oooo0000e0000=@0003D1000001S0?ooo`X0g@P6
@P3oool306IVIR<0oooo100co`030?ooo`<0<ol00P3oool203?o00l0oooo0`0co`020?ooo`<0<ol0
0P3oool203?o05T0oooo000Y0?ooo`@0003D0P3oool20000e0H0oooo00D000000000e0000=@0003D
0?ooo`0500000680oooo3P3M20Hk0?ooo`<0IVIV9@3oool403?o00<0oooo0`0co`030?ooo`80<ol0
3P3oool303?o00<0oooo0P0co`030?ooo`80<ol0F@3oool002L0oooo0`000=@50?ooo`80003D1P3o
ool20000e0<000000`3oool200000680oooo4P3M20He0?ooo`80IVIV9P3oool403?o00@0oooo0`0c
o`030?ooo`<0<ol03P3oool203?o00@0oooo0P0co`030?ooo`80<ol0F@3oool002@0oooo0`000=@8
0?ooo`80003D103oool30000e0<0oooo0P0000030?ooo`800000H@3ooolF0=d81UP0oooo100co`05
0?ooo`80<ol0103oool203?o00h0oooo0`0co`030?ooo`<0<ol00`3oool203?o05T0oooo000S0?oo
o`@0003D203oool20000e0<0oooo0P000=@60?ooo`<0000000<0oooo0000000000002`3ooom_0=d8
1U@0oooo0`0co`060?ooo`<0<ol0103oool203?o00h0oooo0P0co`040?ooo`80<ol0103oool203?o
05T0oooo000Q0?ooo`80003D0P3oool20000e0P0oooo0P000=@00`3oool0003D0000e00:0?ooo`80
000000<0oooo0000000000002P3ooomc0=d81Tl0oooo0`0co`070?ooo`80<ol0103oool303?o00h0
oooo0P0co`040?ooo`80<ol0103oool203?o05T0oooo000O0?ooo`<0003D0`3oool20000e0P0oooo
10000=@<0?ooo`@000002P3ooomb0=d81Tl0oooo0`0co`080?ooo`80<ol0103oool203?o00h0oooo
0`0co`040?ooo`80<ol0103oool303?o05P0oooo000N0?ooo`80003D1@3oool20000e0H0oooo0`00
0=@@0?ooo`@000002@3ooom_0=d81U40oooo0`0co`090?ooo`80<ol0103oool203?o00h0oooo0P0c
o`050?ooo`80<ol01@3oool203?o05P0oooo000L0?ooo`<0003D1P3oool20000e0<0oooo10000=@D
0?ooo`8000002@3ooom/0=d81U80oooo100co`090?ooo`80<ol01@3oool203?o00d0oooo0`0co`04
0?ooo`<0<ol01@3oool203?o05P0oooo000K0?ooo`<0003D1`3oool20000e0040?ooo`000=@0003D
0000e1L0oooo0P00001O0?oooa80g@P6E@3oool403?o00T0oooo0`0co`050?ooo`80<ol0303oool3
03?o00D0oooo0P0co`060?ooo`80<ol0F03oool001X0oooo10000=@80?ooo`@0003D5`3oool30000
05l0oooo3`3M20IG0?ooo`<0<ol02P3oool303?o00H0oooo0P0co`0<0?ooo`80<ol01P3oool203?o
00H0oooo0`0co`1G0?ooo`006@3oool20000e0030?ooo`000=@0003D00D0oooo10000=@H0?ooo`D0
0000G`3oool<0=d81UT0oooo0`0co`0;0?ooo`80<ol01`3oool203?o00/0oooo0`0co`050?ooo`<0
<ol01`3oool00`0co`00000000000002000005@0oooo000H0?ooo`80003D0P3oool20000e0<0oooo
0`000=@J0?ooo`D00000H03oool80=d81Ud0oooo0P0co`0;0?ooo`<0<ol01`3oool203?o00X0oooo
0`0co`060?ooo`80<ol0203oool01@0co`00000005EEo`0cI/`0EEGo00800000DP3oool001L0oooo
0`000=@20?ooo`80003D00@0oooo0000e0000=@0003D6`3oool200000080oooo0P00001P0?ooo`D0
g@P6G@3oool403?o00/0oooo0`0co`070?ooo`<0<ol02@3oool303?o00H0oooo0`0co`080?ooo`03
03?o00000000<fK<00@0<fK<0P00001@0?ooo`005`3oool20000e0@0oooo0`000=@K0?ooo`<00000
0P3oool200000640oooo0P3M20IO0?ooo`@0<ol02`3oool303?o00P0oooo0P0co`090?ooo`<0<ol0
1`3oool203?o00X0oooo200cI/`00`000000oooo0?ooo`1=0?ooo`005P3oool20000e0<0oooo0`00
0=@L0?ooo`800000103oool200000<40oooo0`0co`0=0?ooo`80<ol01P3oool300000080<ol02@3o
ool203?o00P0oooo0P0co`0:0?ooo`0:03=Vc01EEOl0<fK<05EEo`0cI/`0EEGo03=Vc01EEOl0<fK<
000004h0oooo000F0?ooo`80003D00@0oooo0000e0000=@0003D703oool3000000@0oooo0P00002I
0?ooo`<000000`3oool4000001h0oooo0`0co`0>0?ooo`80<ol01P3oool01@000000<fK<03=Vo`00
0000<ol000T0oooo0P0co`080?ooo`80<ol02P3oool00`0co`00<fK<03=Vc00603=Vc0030000003o
ool0oooo04`0oooo000E0?ooo`80003D00<0oooo0000e0000=@06`3oool3000000030?ooo`000000
000000<0oooo0`00002I0?ooo`030000001Vc?l0VIWo0080000000D0oooo000000000000<fKo05FZ
o`02000001/0oooo0`0co`0>0?ooo`<0<ol01P3oool010000000<fK<03=Vc00cI/`2000000P0oooo
00<0<ol00?ooo`3oool01`3oool203?o00X0oooo00/0<ol005EEo`0cI/`0EEGo03=Vc01EEOl0<fK<
05EEo`0cI/`0EEGo0000001=0?ooo`005@3oool40000e1X0oooo0`0000030?ooo`8000000`3oool2
000009`0oooo00<0EJ[o0:ZZo`1EZ_l00P0000001@3oool0<lco03=Vc00cc?l0<fK<00800000603o
ool303?o00l0oooo0P0co`070?ooo`0703=Vo`0cI/`0<fKo03=Vc00cI_l0<fK<000000060?ooo`80
<ol0203oool303?o00X0oooo00<0<ol003=Vc00cI/`0200cI/`00`000000oooo0?ooo`1:0?ooo`00
503oool40000e1P0oooo100000050?ooo`8000000P3oool2000009l0oooo00<0VIWo06K<o`2IVOl0
0P0000001@1EZ_l0<fKo05FZo`0cI_l0000001L0oooo0`0co`0?0?ooo`<0<ol0203oool603=Vc003
0000003oool0oooo00<0oooo0P0co`080?ooo`80<ol02`3oool03@0co`00EEGo03=Vc01EEOl0<fK<
05EEo`0cI/`0EEGo03=Vc01EEOl0<fK<05EEo`000000B`3oool001@0oooo0`000=@F0?ooo`D00000
1`3oool2000000030?ooo`00000000000:80oooo00P0EJ[o0:ZZo`1EZ_l0ZZ[o0000000cI/`0<lco
03=Vc0800000503oool303?o00l0oooo0`0co`090?ooo`0803=Vc00cI_l0<fK<03=Vo`0cI/`0<fKo
03=Vc00000030?ooo`<0<ol0203oool203?o00d0oooo1P0cI/`6000004X0oooo000D0?ooo`80003D
5P3oool3000000030?ooo`000000000000L0oooo1000002T0?ooo`060000002IVOl0I/co09VIo`00
0000<fKo0P1EZ_l00`0cI_l000000?ooo`0A0?ooo`<0<ol0403oool203?o00X0oooo1P0cI/`30000
0080oooo0P0co`090?ooo`80<ol0303oool70000000403=Vc01EEOl0<fK<05EEo`80<fK<00<00000
0?ooo`3oool0A`3oool001@0oooo0P000=@C0?ooo`@000000`3oool2000000L0oooo0`00002W0?oo
o`040000001EZ_l0ZZ[o00000080<fK<00<0<lco03=Vc00000003`3oool403?o0100oooo0`0co`02
0?ooo`D00000103oool00`0cI_l0<fK<000000020000000403=Vc00cI_l0<fK<000000<0<ol0203o
ool700000080oooo1@1E000010000000E@000000001VIYT2000000T0<fK<0`0000160?ooo`00503o
ool30000e100oooo0`0000060?ooo`8000001P3oool200000:/0oooo00L0000009VIo`000000EJ[o
03=Vo`1EZ_l0<fKo00800000303oool403?o0100oooo0`0co`040?ooo`030000002Z0000ZP0000<0
ZP001000000603=Vc0<0<ol0203oool02P000000E@000:X0001E0000ZP0005D0002Z0000E@000:X0
001E00020:X00080000000<0E@000:X0000000000P000000202IVL`00000000000000000<fK<05EE
o`0cI/`0EEGo0P0cI/`0101EEOl0<fK<0000002IVL`400000480oooo000D0?ooo`@0003D3@3oool3
000000P0oooo0P0000040?ooo`<00000C03oool3000005h0oooo0P0000001@0cI/`0<lco03=Vc00c
c?l0<fK<008000002P3oool303?o0180oooo0P0co`070?ooo`D0000000<0E@000000002I<iT00P00
0000100cI_l0<fK<03=Vo`0cI/`203?o00030000003oool0oooo00H0oooo00<0000005D0001E0000
1`1E0002000000D0E@0000D000000<bIc0000000IVJI05EEo`03000000L0<fK<00H0000006IVV@1E
EOl0IVJI05EEo`0000110?ooo`005@3oool40000e0X0oooo100000090?ooo`8000000P3oool30000
04l0oooo00<000000?ooo`3oool0GP3oool20000000503=Vo`1EZ_l0<fKo05FZo`0cI_l00`000007
0?ooo`<0<ol04P3oool303?o00P0oooo0P0000000`2Z00000000000000020000000409VIc0000000
0000000000@0<fK<00<000000?ooo`3oool01`3oool020000000ZP0005D0002Z0000E@000:X0001E
0000ZP000P0000002@2Z0000E@000:X0001E0000ZP0005D000000000ofJI0000000309VIc0040000
002IVL`0000005EEo`80<fK<00D0EEGo03=Vc01EEOl0<fK<0000000409VIc0030000003oool0oooo
03h0oooo000E0?ooo`80003D00@0oooo0000e0000=@0003D1P3oool3000000030?ooo`0000000000
00T0oooo0P0000000`3oool000000000001A0?ooo`030000003oool0oooo05l0oooo0P000000200c
I/`0<lco03=Vc00cc?l0<fK<03?<o`0cI/`000001P3oool203?o01<0oooo0P0co`080?ooo`800000
00@0c?oo0000003oool0oooo0P0000000`1nOWh0VC>I000000030000000403=Vo`0cI/`000000000
00P0oooo00@0<ol00000001E000000000P1E0002000000P0E@000P0000001@3<VL`0000005EEo`1V
IYT0EEGo00@000001P0cI/`01@000000IVJI05EEo`1VIYT000000400oooo000E0?ooo`80003D0`3o
ool20000e0<0oooo0`0000030?ooo`8000002@3oool3000002@0oooo0`0000030?ooo`<000000`3o
ool;000000<0oooo0`0000040?ooo`<0000000@0oooo00000000000000000P3oool300000080oooo
0`0000050?ooo`D00000103oool2000000<0oooo1P0000150?ooo`<0<ol000T0000003=Vo`1EZ_l0
<fKo05FZo`0cI_l0EJ[o03=Vo`0000000`3oool303?o01<0oooo0`0co`060?ooo`8000000P3<ol`0
1@000000oooo0?ooo`000000ojZZ00<000000P2IVL`00`000000VIW<00000003000000P0oooo0P0c
o`020?ooo`80000000<0E@000:X0001E00000P2Z00001@1E0000ZP0005D0002Z0000E@0000800000
00<0/K6a0?mVV@000000102IVL`30000000705EEo`0cI/`0EEGo03=Vc01EEOl0<fK<0000000309VI
c0030000003oool0oooo03d0oooo000F0?ooo`80003D0`3oool40000e0030000003oool0oooo00<0
oooo0P0000070?ooo`@000009P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000160?ooo`H0<ol0
00P0000003=Vc00cc?l0<fK<03?<o`0cI/`000000?ooo`@0<ol04`3oool203?o00H0oooo00H00000
0<coo`2Zool0c?oo0:[oo`0000020?ooo`0;0000003oc9T000000000003oool0OWin09TcV@1nOWh0
000007inOP2I<iT00`0000070?ooo`80<ol0103oool00`000000E@0005D0000705D0008000000P3<
VL`020000000IVJI05EEo`1VIYT0EEGo06IVV@000000EEGo0P00000403=Vc0060000001EEOl0IVJI
05EEo`1VIYT00000?P3oool001H0oooo0P000=@40?ooo`04000000000=@0003D0000e0D0oooo0P00
00040?ooo`@00000:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`180?ooo`@0<ol00P0000000`0cI_l0<ol003?o000203?o00030000
003oool0oooo0180oooo0`0co`030?ooo`<000000`3<ol`2000000<0oooo00<000000?nZZP000000
0P0000000`2IVL`0VC>I00000004000000P0oooo0`0co`050?ooo`T0000000D0/K6a0000002a/K40
c9W<0;6a/@020000000406IVV@1EEOl0IVJI05EEo`T0000000<0IVJI05EEo`1VIYT00P00000m0?oo
o`005`3oool20000e080oooo0P0000050000e0<0oooo0P0000020?ooo`<00000;03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`040000003oool0oooo0000
00D0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1:0?ooo`03
00000034a<@0<ol000D0<ol000@0ZZ[o0;fm_@00000000004@3oool303?o00<0oooo00<000000<co
c03<ol`00`3<ol`50?ooo`040000002Ic9T0ojZZ00000080oooo0P0co`00101EZ_l0IVJI00000000
00090?ooo`80<ol0203oool03P000000oonZ0;Vi^@3oojX000000;6a/@3oIYT0/K6a0000002a/K40
ofJI0;6a/@3oIYT000001`2IVL`00`000000VIW<09VIc00709VIc0030000003oool0oooo03/0oooo
000H0?ooo`80003D0`0000020000e080oooo0`000=@30?ooo`<00000;P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo04T0oooo1`0co`020?ooo`040000003<VOl0b<S80:ZZo`8000003`3oool203?o00<0oooo
1P0000060?ooo`0300000030`<0000000080oooo0`0co`00100cI_l0VIW<0000000000090?ooo`80
<ol0203oool00`000000olbI0?ooZP02000000<0c9W<00<000000<bIc03<VL`00`3<VL`00`000000
EEGo06IVV@0205EEo`0306IVV@1EEOl0IVJI0080000000T0EEGo06IVV@1EEOl0IVJI05EEo`1VIYT0
EEGo06IVV@000000?03oool001P0oooo0`000=@0103oool000000000e0000=@50?ooo`<0003D<@3o
ool00`000000oooo0?ooo`020?ooo`<000000P3oool01P000000oooo0?ooo`3oool000000?ooo`<0
000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
0?ooo`@000000P3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo00800000103oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo0000003oool0A`3o
ool903?o00<0oooo00L000000<S8b02ZZ_l000000;fm_@1Vc?l0000000<0oooo0P0000080?ooo`<0
<ol03`3oool2000000<0oooo0P0co`000`1VIYT0EJ[o0000000209VIc0030000003oool0oooo00H0
oooo0P0co`070?ooo`0A0000002i^KT0oonZ0;Vi^@000000ofJI0;6a/@3oIYT0/K6a0?mVV@000000
ofJI0;6a/@3oIYT0/K6a0?mVV@000000202IVL`00`000000VIW<09VIc00509VIc0030000003oool0
oooo03X0oooo000H0?ooo`05000000000=@0003D0000e00000000P000=@20?ooo`<000000`3oool2
0000e2l0oooo00<000000?ooo`3oool00`3oool01@000000oooo000000000000oooo00<000000`3o
ool00`000000oooo000000060?ooo`<000000`3oool300000080oooo00H000000?ooo`0000000000
0?ooo`0000030?ooo`030000003oool0000000<0oooo0`0000020?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`030000003oool0000004L0oooo1P0co`001@3oool0<ol003?o000co`00oooo
00<0000000L0oooo00000038b<P0b<S80000002ZZ_l0olco0080000000@0oooo05FZo`1EZ_l00000
1P3oool303?o01@0oooo00T0000009VIc00cI_l0oooo03=Vo`000000OWin09TcV@000000203oool2
03?o00L0oooo00<0oonZ0?o<V@3oc9T00P0000050<bIc0030000003<VL`0c9W<00<0c9W<01800000
06IVV@1EEOl0EEGo06IVV@1EEOl0IVJI05EEo`1VIYT0EEGo0000001EEOl0IVJI05EEo`1VIYT0EEGo
06IVV@00000l0?ooo`005`3oool3000000D0003D0`0000050?ooo`@0003D:P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0E03oool603?o0080
oooo100co`030?ooo`030000001Vc?l000000080000000X0ZZ[o0<S8b0000000_Kfm06K<o`2m_Kd0
000005FZo`1VIYT000001P3oool400000180oooo00H0000005FZo`1VIYT0EJ[o06IVV@1EZ_l30000
00T0oooo0P0co`060?ooo`040000002i^KT0^KVi0?ooZP80000000d0ofJI0;6a/@3oIYT0/K6a0?mV
V@000000ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K40000000T0VIW<0P00000309VIc0030000003oool0
oooo03/0oooo000G0?ooo`8000000P3oool40000e0030000003oool0oooo00D0oooo0P000=@0103o
ool0003D0000e0000=@X0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1>0?ooo`X0<ol00P3oool503?o00D0oooo00`0000009VIo`1Vc?l0VIWo
0000003<VOl0b<S80000002ZZ_l0olco0:ZZo`00000205FZo`030000003oool0oooo00<0000000@0
EJ[o06K<c01EZ_l0I/c<1@00000<0?ooo`070000002IVL`0<fKo09VIc00cI_l0VIW<0000000<0?oo
o`80<ol01@3oool010000000olbI0?ooZP3oc9T2000000H0c9W<00<000000<bIc03<VL`01@3<VL`0
3P000000EEGo06IVV@1EEOl0IVJI05EEo`1VIYT0EEGo06IVV@1EEOl0IVJI0000001VIYT00000?P3o
ool001H0oooo0P0000030?ooo`8000000P000=@80?ooo`80003D103oool30000e2D0oooo1`00000V
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A`3oool:03?o00@0oooo100co`09
0?ooo`<0I/co100000001`2m_Kd0I/co0;fm_@000000EJ[o06IVV@0000000`3oool02P0co`000:[o
05FZZP00Z_l0EJZZ002Zo`1EZZX00:[o05FZZP00Z_l5000000L0oooo00D0EJ[o06IVV@1EZ_l0IVJI
05FZo`02000000`0oooo0P0co`040?ooo`0F0000002i^KT0oonZ0;Vi^@000000oooo0000002a/K40
ofJI0;6a/@3oIYT0/K6a0?mVV@000000ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K40ofJI000000/0VIW<
00<000000?ooo`3oool0?@3oool001H0oooo0P0000020?ooo`8000000P3oool20000e0L0oooo0P00
0=@60?ooo`@0003DT@3oool300000180oooo1P0co`090?ooo`<0<ol03@3oool206K<o`0709VIo`1V
c?l000000000002ZZ_l0olco0000000305FZo`030000003oool0oooo0080<ol01@3oool020000000
I/c<05FZo`1Vc<`0EJ[o06K<c01EZ_l0I/c<100000020?ooo`060000000cI_l0VIW<03=Vo`2IVL`0
00003@3oool303?o00@0oooo00<000000?ooZP3oc9T00P0000000`3oool000000<bIc0050<bIc003
0000003<VL`0c9W<00D0c9W<00d0000005EEo`1VIYT0EEGo06IVV@1EEOl0IVJI05EEo`1VIYT0EEGo
06IVV@1EEOl0000003l0oooo000E0?ooo`80000000@0oooo0000000000000000103oool30000e0D0
oooo0P000=@80?ooo`<0003DT03oool00`000000<lco00000002000000/0oooo200co`0;0?ooo`<0
<ol03P3oool2000000@0I/co0`0000001@1EZ_l0IVJI05FZo`1VIYT0000000<0<ol0203oool30000
0004002Zo`1EZZX00:[o05FZZP800:[o0`000000101EZ_l0IVJI00000000000>0?ooo`80<ol01@3o
ool00`000000^KVi000000020?ooo`0B0000003oIYT0/K6a0?mVV@2a/K40ofJI0;6a/@3oIYT00000
0?mVV@2a/K40ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K4000002P2IVL`00`000000oooo0?ooo`0m0?oo
o`005@3oool4000000P0oooo0`000=@30?ooo`80003D203oool50000e8L0oooo2@000000100cI/`0
<fKo03=Vc00000070?ooo`T0<ol0303oool303?o00l0oooo10000000102IVOl0I/co09VIo`1Vc?l2
000000@0EJ[o0P0co`0<0?ooo`040000001Vc<`0EJ[o06K<c080EJ[o00@0I/c<03?o000co`00<ol0
0`00000>0?ooo`80<ol01@3oool00`000000oooo0?ooo`020?ooo`030000003<VL`0c9W<00H0c9W<
00<000000<bIc03<VL`01P3<VL`02`000000EEGo06IVV@1EEOl0IVJI05EEo`1VIYT0EEGo06IVV@1E
EOl0000003l0oooo000D0?ooo`@000002`3oool30000e0030?ooo`000=@0003D00P0oooo0P000=@2
0?ooo`80003DR`3oool00`1EZZX0I/co05FZZP06000000X0<ol03`3oool403?o0180oooo00<00000
0<S8b00000000`1Vc?l01@000000EJ[o0000001EZ_l0IVJI00<0<ol04@3oool503?o00030000002m
_Kd0/K6a00<000002`3oool203?o00X0oooo010000000?mVV@2a/K40ofJI0;6a/@3oIYT0/K6a0?mV
V@2a/K4000000;6a/@3oIYT0/K6a0?mVV@2a/K40ofJI0P2a/K400`3oIYT0000009VIc00709VIc003
0000003oool0oooo03d0oooo000D0?ooo`<000003P3oool40000e0P0oooo0P000=@30?ooo`<0003D
S03oool4000000T0<ol04@3oool403?o01@0oooo00X000000<S8b03<VOl0000006K<o`2IVOl00000
05FZo`000000EJ[o0P0co`000`000000oooo0?ooo`0?0?ooo`D0<ol00P000000102ZZ_l0c9W<0:ZZ
o`3<VL`2000000P0oooo0`0co`0:0?ooo`030000003<VL`0c9W<00H0c9W<00<000000<bIc03<VL`0
203<VL`20000000706IVV@1EEOl0IVJI05EEo`1VIYT0EEGo0000000o0?ooo`00503oool200000140
oooo0`000=@70?ooo`80003D1@3oool20000e0030?ooo`000=@0003D0840oooo2P0co`00103oool0
<ol003?o000co`0300000180oooo100co`0G0?ooo`0400000038b<P0ZZ[o0<S8b0@0000000D0IVJI
03?o000co`00_Kfm0000000?0?ooo`D0<ol000<0f=SH0000003oool00P000000102a/K40_Kfm0;6a
/@2m_Kd2000000H0oooo0P0co`0:0?ooo`0A0000002a/K40ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K40
ofJI0;6a/@000000/K6a0?mVV@2a/K40ofJI0;6a/@3oIYT00P2a/K401@3oIYT0/K6a0000003oool0
000000D0VIW<00<000000?ooo`3oool0?@3oool001@0oooo0P00000C0?ooo`@0003D103oool20000
e0H0oooo10000=B10?ooo`T0<ol00P3oool01P000000ZZ[o000000000000VIWo0<bIc08000003`3o
ool403?o01T0oooo00H000000<S8b03<VOl0b<S80<bIo`00000303?o00<000003P3oool603?o0003
0<c<c0000000oooo0080oooo0P000000102ZZ_l0c9W<0:ZZo`3<VL`2000000@0oooo0P0co`0:0?oo
o`030000003<VL`0c9W<00L0c9W<00<000000<bIc03<VL`01`3<VL`010000000oooo0?ooo`3oool5
00000400oooo000D0?ooo`8000005P3oool20000e0<0oooo0P000=@70?ooo`<0003DP@3oool203?o
00T0oooo0P0000000`3@d=00ZZ[o00000007000000T0oooo100co`0K0?ooo`T0<ol000<000000;fm
_@0000000`0000090?ooo`@0<ol000@0000003?o000co`00ZZ[o0P0000050?ooo`P000000P3oool2
03?o00X0oooo014000000;6a/@3<VL`0/K6a0<bIc02a/K40c9W<0;6a/@3<VL`0/K6a0000002a/K40
c9W<0;6a/@3<VL`0/K6a0<bIc0020;6a/@800000B03oool001@0oooo0`00000F0?ooo`@0003D2P3o
ool30000e8d0oooo00@000000<C4a03@d=0000000`3oool010000000]KFe0;fm_@0000060?ooo`@0
<ol06`3oool:03?o00030<c<c03<ool000000080c9Wo00<0_Kfm0<bIo`0000001P3oool603?o0005
0000000co`00<ol00:ZZo`0000001P3oool:00000080<ol02P3oool04`000000/K6a0?mVV@2a/K40
ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K40ofJI0000003oIYT0/K6a0?mVV@2a/K40ofJI0;6a/@000000
BP3oool001D0oooo1000000G0?ooo`@0003D1`3oool40000e8d0oooo00<000000<bIc00000001@3o
ool2000000<0oooo00<0000003?o000co`000`0co`0K0?ooo`@0<ol000<0oooo03?o000co`00100c
o`000`2ZZ_l0c<c<000000020:ZZo`040:[oo`2ZZ_l0Z_oo000000<0oooo1`0co`001P3oool00000
03?o003<c<`0c?oo000000T0oooo0P0000001@00VOl0<fK<002Io`0cI/`009Wo0080<ol000<00000
0?ooo`3oool01`3oool00`000000c9W<0<bIc0080<bIc0030000003<VL`0c9W<00<0c9W<00<00000
0?ooo`3oool0B@3oool001D0oooo0P0000000`3oool000000000000I0?ooo`<0003D1@3oool40000
e8h0oooo00<000000<C4a00000001P3oool00`000000oooo0?ooo`0403?o01T0oooo1P0co`000`3o
ool0<ol003?o000203?o000>0?ooo`0co`00<ol00000003<c<`0c?oo0<c<c0000000c9Wo0;fm_@3<
VOl0_Kfm0<bIo`00000503?o00030?ooo`0co`00<ol00080oooo00D0000003?o003Hf=P0ZZ[o0000
000;0?ooo`@000000`0co`00102m_Kd000000000000000060?ooo`0>0000002a/K40ofJI0;6a/@3o
IYT0/K6a0?mVV@2a/K40ofJI0;6a/@3oIYT000000?mVV@2a/K44000004/0oooo000E0?ooo`800000
0P3oool3000001X0oooo0`000=@20?ooo`80003D00<0oooo0000e0000=@0SP3oool2000000H0oooo
00<0000005D0000000000P0co`001@1VIYT0EEFZ06IVV@1EEJX0IVJI00<0oooo0P00000@0?ooo`H0
<ol000<0oooo03?o000co`000P0co`00203oool0<ol003?o000co`0000000:ZZo`3<c<`0ZZ[o0P00
0000102Zool0ZZ[o0:[oo`2ZZ_l403?o0080oooo0`0co`001P3oool0000003?o000co`00c<c<0000
00l0oooo100co`000`000000VIWo0;^k^`02000000D0oooo00<000000<bIc03<VL`0203<VL`30000
04l0oooo000F0?ooo`8000000`3oool2000001/0oooo0`000=@40?ooo`80003DS03oool300000003
0?ooo`1E0000E@000080E@000`0000003@1E000000000:YE00000000ZUGo0000002ZEOl0VIW<0:YE
o`2IVL`0ZUGo09VIc02ZEOl00P00000:0?ooo`H0<ol0103oool303?o0080oooo0`0co`001`3oool0
00000<c<c03<ool0c<c<0000003oool00P0000001@2m_Kd0<ol003?o000co`0000000080oooo0`0c
o`020?ooo`040000000co`00ZZ[o000000l0oooo1@0co`02000000030;fm_@2a/K40000000800000
0`3oool02`000000/K6a0?mVV@2a/K40ofJI0;6a/@3oIYT0/K6a0?mVV@2a/K4000000580oooo000F
0?ooo`800000103oool3000001/0oooo0P000=@30?ooo`80003DR@3oool3000000D0E@000P000002
05D000030000001E0000000000@0000000/0IVJI000000000000EEFZ06IVV@1EEJX0IVJI05EEZP1V
IYT0EEFZ000000060?ooo`P0<ol0103oool303?o0080oooo0`0co`020?ooo`050000002ZZ_l0c<c<
0:ZZo`0000000P3oool503?o00030:[oo`000000<ol00080<ol00`3oool203?o00030<coo`000000
oooo00h0oooo100co`020?ooo`D0000000D0c9W<0000003oool0oooo000000080<bIc0030000003o
ool0oooo0540oooo000G0?ooo`800000103oool4000001X0oooo0`000=@20?ooo`80003DQ03oool4
000000@0E@000`00000505D00080000000<0oooo0000000000000P0000002@2IVL`0ZUGo09VIc000
0000VIW<0:YEo`2IVL`0ZUGo09VIc0020:YEo`040000003oool0oooo0?ooo`H0<ol01`3oool303?o
00<0oooo0P0co`040?ooo`040000003<ool0c<c<000000D0<ol000<000000<bIo`2m_Kd00`0co`04
0?ooo`80<ol000<000000?ooo`3oool03@3oool503?o00@0oooo1P0000020?ooo`80000000H0/K6a
0?mVV@2a/K40ofJI0;6a/@00001D0?ooo`00603oool2000000<0oooo0P0000020?ooo`<000006@3o
ool20000e0030?ooo`000=@0003D08@0oooo00<0000005D0001E00000P1E0003000000P0E@0000<0
00000?ooo`0000000P0000003P3oIS<000000000001EEJX0IVJI05EEZP000000EEFZ06IVV@1EEJX0
IVJI05EEZP1VIYT000001P0co`090?ooo`<0<ol00`3oool303?o00@0oooo00<000000<c<c02ZZ_l0
1@0co`020?ooo`050000000co`00<ol003?o000000000`3oool303?o00030000003oool0oooo00`0
oooo1P0co`060?ooo`80000000<0ZZ[o0000000000000`3oool3000000030<bIc0000000oooo05@0
oooo000H0?ooo`<000000P3oool2000000@0oooo1000000G0?ooo`@0003DQ03oool6000000P0E@00
10000000100cI/`009Wo0000003oV@030000000309VIc02ZEOl0VIW<0080000000@0ZUGo09VIc02Z
EOl0ZUGo1@0co`0;0?ooo`80<ol0103oool203?o00H0oooo00<000000<c<c00co`000P0co`040?oo
o`<0<ol000<000000<bIo`0000000P3oool203?o00030000003oool0oooo00d0oooo1P0co`080?oo
o`@000001@3oool00`000000oooo0?ooo`1D0?ooo`006@3oool3000000030?ooo`000000000000L0
oooo1000000F0?ooo`<0003DR@3oool8000000030:[oZP000000oooo0080oooo00l000000?nZZP00
000000000?nZZP000000IVJI05EEZP1VIYT0EEFZ06IVV@000000IVJI05EEZP1VIYT00P0co`0=0?oo
o`80<ol0103oool303?o00D0oooo0P0co`000`2ZZ_l0<ol00?ooo`040?ooo`<0<ol00P3oool20000
00050?ooo`0co`00<ol003?o000000003P3oool203?o00030?ooo`0co`00<ol00080<ol02P3oool2
000005`0oooo000J0?ooo`D000002@3oool4000001D0oooo0P000=B?0?ooo`030000002ZojX0oooo
00<0oooo00h0c9VI0000003<VIT000000:YE00000000c9VI0000002ZEOl0VIW<0:YEo`2IVL`0ZUGo
00000080ZUGo00<0VIW<0:YEo`0000002`3oool303?o00@0oooo0P0co`040?ooo`@0<ol00P000004
0?ooo`<0<ol01@3oool01@000000<ol003?o003Hf=P0000000h0oooo0P0co`000`3oool0<ol003?o
000203?o06P0oooo000L0?ooo`<000002@3oool2000000040?ooo`0000000000000001<0oooo0P00
0=B>0?ooo`030000002ZojX0oooo00@0oooo00H000000?ooo`3oZZX0ojZZ0<bI<`0000020?nZZP07
0000001VIYT0EEFZ06IVV@1EEJX0IVJI0000000206IVV@0305EEZP000000oooo00P0oooo100co`04
0?ooo`<0<ol00`3oool503?o00030000002ZZ_l000000080oooo0`0co`060?ooo`<0<ol000<00000
0?ooo`3oool0303oool803?o06P0oooo000M0?ooo`8000002@3oool2000000@0oooo0`00000@0?oo
o`80003DS03oool2000000040:[oZP3oool0oooo0?ooo`<0<ol000@0000003?o003<VIT0_Kfm0P00
00003P3<VIT0_Kfm0000002IVL`0ZUGo09VIc02ZEOl0VIW<0:YEo`000000VIW<0:YEo`2IVL`00000
1`3oool403?o00D0oooo0P0co`030?ooo`<0<ol0103oool2000000040?ooo`0co`00<ol003?o00L0
oooo0P0co`000`000000oooo0?ooo`0;0?ooo`L0<ol000<0oooo03?o000co`00J03oool001h0oooo
0`0000070?ooo`8000001P3oool3000000d0oooo0P000=B80?ooo`050000003oool0oooo0?ooo`00
00000P2ZojX703?o00070000000co`00ojZZ0?nZZP000000ofHc000000020?nZZP0;0000001EEJX0
IVJI05EEZP1VIYT0EEFZ06IVV@000000EEFZ06IVV@0000001P3oool303?o00H0oooo0`0co`020?oo
o`<0<ol01@3oool2000000<0<ol01`3oool303?o00d0oooo100co`000`3oool0<ol003?o00020?oo
o`80<ol0J03oool00200oooo0P0000060?ooo`8000001`3oool4000000X0oooo0`000=B40?ooo`@0
00000P0co`020000000309W<V@2ZojX0<ol000D0<ol000/0oooo0;fm_@000000oooo0<bIV@2m_Kd0
00000?nI00000000_Kfm0<bIV@020000000309VIc02ZEOl0VIW<0080ZUGo00<0VIW<000000000000
1P3oool303?o00030000003oool0oooo00@0oooo0P0co`000`3oool0<ol003?o000203?o00H0oooo
00@000000?ooo`0co`00<ol0203oool203?o00d0oooo0`0co`030?ooo`80<ol00P3oool203?o06P0
oooo000Q0?ooo`<00000103oool2000000L0oooo0P000000103oool000000000000000070?ooo`@0
003DQ@3oool6000000040:[oZP000000000003?o00H0oooo00<000000?nZZP3oZZX00P3oZZX80000
00070:YEo`1VIYT0ZUGo0:YEo`1VIYT0ZUGo000000040?ooo`040000000co`00<ol0002Io`H00000
200co`070?ooo`040000000co`00<ol003?o00L0oooo0`0co`0<0?ooo`<0<ol0103oool203?o0080
oooo0P0co`1X0?ooo`008`3oool300000080oooo0P0000070?ooo`8000000`3oool2000000@0oooo
1@000=B70?ooo`80000000H0Z_nZ000000000000000006Hcc00000070?ooo`H0ojZZ00<000000<bI
<`0000000`3oool20000000606IVV@1EEJX0IVJI06IVV@1EEJX000000P3oool403?o0080oooo00@0
000005FZZP00VL`0EJZZ0P00000303?o00`0oooo0P0co`090?ooo`80<ol0303oool303?o00D0oooo
00@0<ol00?ooo`3oool0oooo0P0co`1X0?ooo`009@3oool5000000L0oooo0P0000040?ooo`040000
00000=@0003D0?ooo`80003D0P3oool20000e8D0oooo0`000000202ZojX000000000002i^KT0SHf=
0000002=SHd000001P3oool0102m_Kd0c9VI0;fm_@3<VIT3000000030?ooo`000000oooo0080oooo
00<0_Kfm0000000000000P2ZEOl0102IVL`0ZUGo0000003oool403?o00@0oooo1000000403?o00/0
oooo0P0co`0:0?ooo`80<ol0303oool203?o00D0oooo0P0co`030?ooo`80<ol0J03oool002L0oooo
0`0000070?ooo`8000001@3oool40000e080oooo0P000=B60?ooo`060000003ool`000000000003<
VIT0c9W<0P0000000`1V<l`00000000000050?ooo`D0ojZZ00D0I/co09VIo`000000oooo00000004
0?ooo`@0000000<0IVJI05EEZP0co`000`0co`070?ooo`0403?o00000000VIWo00000080<ol000<0
00000?ooo`3oool0203oool303?o00X0oooo0P0co`0;0?ooo`<0<ol01@3oool203?o00<0oooo0P0c
o`1X0?ooo`00:P3oool3000000@0oooo0P0000040?ooo`<0003D0`0000020000e8H0oooo0P000002
0?ooo`050000002i^KT0ofK<0000003oI/`00`0000050?ooo`080<bIV@2m_Kd0c9VI0;fm_@3<VIT0
EJ[o06K<c00000070?ooo`@00000100co`050?ooo`8000000P0co`000`1Vc?l0<fK<03?o000203?o
00030<S8b0000000oooo00L0oooo0`0co`0:0?ooo`<0<ol02P3oool303?o00H0oooo0P0co`030?oo
o`80<ol0J03oool002`0oooo0P0000030?ooo`8000000P3oool50000e0030?ooo`000000003D0080
003DQP3oool02`000000oooo0?ooo`3oool000000<bIV@3<VL`000000<bIc03<VIT0000000H0oooo
0P3oZZX01`3oool0ojZZ0?nZZP000000VIWo06K<o`000000203oool010000000<ol003?o000co`07
0?ooo`0300000000VOl000000080000000L0VIWo05FZo`0co`00ZZ[o0<bIc02ZZ_l0000000H0oooo
0`0co`0:0?ooo`<0<ol02P3oool303?o00H0oooo0`0co`020?ooo`<0<ol0J03oool002d0oooo1000
00020?ooo`<0003D0P3oool20000e0050?ooo`000=@0003D0000e0000000R@3oool010000000ofK<
0;Vi^@3oI/`6000000@0oooo00X000000;fm_@3oool0_Kfm0<bIV@000000I/c<05FZo`1Vc<`00000
1`3oool303?o00H0oooo0P0co`0010000000EJZZ05FZo`1EZZX200000080<ol00P0000000`2m_Kd0
0000000000040?ooo`<0<ol02`3oool203?o00T0oooo100co`070?ooo`80<ol00`3oool203?o06T0
oooo000`0?ooo`<0003D1@3oool50000e0<00000R03oool2000000080<bIV@3<VL`000000?ooo`0c
c<`0<fKo03?<c00cI_l3000000030?ooo`000000ojZZ00<0ojZZ0P000000101Vc?l0VIWo06K<o`00
00060?ooo`80<ol0103oool603?o00080000001EZ_l0oooo05FZo`000000<ol005FZo`2IVOl20000
00030<bIc02ZZ_l000000080oooo0`0co`0<0?ooo`80<ol0203oool403?o00P0oooo0P0co`030?oo
o`80<ol0J@3oool002d0oooo10000=@20?ooo`<000000P3oool30000e0030?ooo`00000000000080
0000RP3oool2000000D0oooo00@0<fK<03?<o`0cI/`0<lco0P0000002P2m_Kd0c9VI000000000000
oooo0000001EZ_l0I/c<05FZo`0000050?ooo`80<ol00`3oool603?o00<0oooo00<0000005FZZP1E
Z_l00P0co`000`1Vc?l0<fK<00000003000000030;fm_@000000<ol00080<ol000<0oooo00000000
00000`0000060?ooo`<0<ol01`3oool303?o00T0oooo0`0co`030?ooo`80<ol0J@3oool002/0oooo
0`000=@00`3oool0003D0000e0040?ooo`<000000P000=@20?ooo`80000000<0oooo000000000000
TP3oool00`000000<lc<03=Vo`03000000<0oooo00H0000006K<o`2IVOl0I/co09VIo`0000030?oo
o`<0<ol000<0oooo03?o000co`000`0co`070?ooo`040000001EZ_l0<ol003?o0080000000D0EJ[o
000000000000ZZ[o0000000203?o00<0000000H0ZUFZ096AT@2ZEJX0ZUFZ096AT@0000020?ooo`80
000000<0oooo03?o000co`00203oool203?o00X0oooo0P0co`040?ooo`80<ol0J@3oool002P0oooo
10000=@30?ooo`80003D1@3oool40000e080oooo0P0000020?ooo`800000T`3oool010000000<fK<
03?<o`0cI/`2000000090?ooo`000000EJ[o06K<c01EZ_l0I/c<05FZo`000000oooo00P0<ol02P3o
ool203?o000505FZZP1EZ_l0EJZZ0000000cI/`00P00000203?o000709VIc03oEJX0VIW<0?mEZP2I
VL`0oeFZ09VIc0020?mEZP030000003oool0oooo0080000000<0oooo03?o000co`001`3oool303?o
00T0oooo0`0co`040?ooo`80<ol0J@3oool002H0oooo0`000=@60?ooo`80003D103oool20000e080
oooo0`0000040?ooo`800000U03oool01@000000<lc<03=Vo`0cc<`0<fKo00<0000000D0VIWo06K<
o`2IVOl0I/co0000000703?o00`0oooo0P0co`0205FZo`0=002Io`1EZ_l000000000002ATI40ZUFZ
03?o002ZEJX0TI6A0:YEZP2ATI40ZUFZ096AT@020:YEZP04096AT@2ZEJX000000?ooo`8005FZ0`0c
o`070?ooo`80<ol02P3oool203?o00D0oooo0P0co`1Y0?ooo`00903oool30000e0P0oooo0P000=@2
0?ooo`<0003D1@3oool2000000@0oooo0P00002D0?ooo`070000000cI/`0<lco03=Vc00cc?l0<fK<
03?<o`020000000306K<c01EZ_l0<ol000@0<ol000<000000?ooo`3oool0303oool203?o00080000
001EZ_l0EJZZ09VIc03oEJX0VIW<0?mEZP2IVL`30000000509VIc03oEJX0VIW<0?mEZP2IVL`00P3o
EJX01@2IVL`000000?ooo`3oool0002Z0080<ol00P0000030?ooo`8000000P0co`0;0?ooo`80<ol0
1@3oool203?o06T0oooo000R0?ooo`80003D00<0oooo0000e0000=@0203oool50000e0P0oooo0`00
00020?ooo`800000V03oool01P0cc<`0<fKo03?<c00cI_l0<lc<000000@0<ol000<0c6K<00000000
0000303oool03P000000<ol003?o000co`00oooo0:YEZP2ATI40ZUFZ096AT@2ZEJX0TI6A0:YEZP2A
TI40ZUFZ100000001P2ATI40ZUFZ0:YEZP2ATI40ZUFZ00000080oooo0`0000001P00EJX0000007in
OP1VIYT0OWin06IVV@<0<ol02P3oool303?o00D0oooo0P0co`1Y0?ooo`00803oool30000e080oooo
0P000=@80?ooo`<0003D303oool2000000030?ooo`000000000009X0oooo1P0co`02000000030:6Q
X@2IVL`0000000`0oooo00<0000003?o000co`000P3oEJX03@2IVL`0oeFZ09VIc03oEJX0VIW<0?mE
ZP2IVL`0oeFZ09VIc03oEJX0000003?<o`1EZ_l00P0000020?mEZP0509VIc03oEJX000000000002I
<fH010000000102IVL`0ZUFZ09VIc02ZEJX203?o00030000003oool0oooo00P0oooo0P0co`060?oo
o`80<ol0J@3oool001h0oooo0`000=@40?ooo`80003D1P3oool40000e0h0oooo0P0000000`3oool0
00000000002C0?ooo`T0<ol000<0000003?o000000001@0000080?ooo`D0000000<0ZZX000000000
00000P0000002P3oEJX0ZUFZ0000002ZEJX0oeFZ0:YEZP3oEJX0ZUFZ0?mEZP2ZEJX20000000303?<
o`1EZ_l0000000@0000000H0ZUEE06HcIP000000ZUFZ0000001VIYT20000000409VIc01VIYT0VIW<
06IVV@8000002@3oool203?o00H0oooo0P0co`1Y0?ooo`007@3oool20000e0H0oooo0P000=@30?oo
o`<0003D0P3oool20000e0l0oooo1000002@0?ooo`H0<ol000P0oooo03?o000co`00<ol00?ooo`00
0000ZZ[o0<coo`80000000@0c<c<0:ZZo`3<c<`000001`3oool01@1E0000ZP1E05D000000000E@00
0080000000@0ZUD00000002ZEJX0ZUFZ0P0000004@2ATI40ZUFZ096AT@2ZEJX000000:YEZP2ATI40
ZUFZ096AT@2ZEJX0000003=Vc02ZEJX0000006HcIP2I<c<0IS=V00D0000000<0IVJI07inOP00EJX0
0P000000101nOWh0IVJI06IVV@0000080?ooo`<0<ol01P3oool203?o06T0oooo000K0?ooo`<0003D
1`3oool20000e0040?ooo`000=@0003D0000e1L0oooo0P0000240?ooo`L000002@0co`020?ooo`<0
<ol000T0oooo000000000000d=3@0<c<c03@d=0000000<bIo`2m_Kd00P3<VOl300000080<ol00`1E
00000`000000E@0005D00003000000060?mV00000000000009VIc03oEJX0VIW<0P0000006P3oEJX0
VIW<0?mEZP2IVL`0oeFZ09VIc03oEJX0oooo0?mEZP000000oeFZ0:YEE@2I<fH0ZUEE0000002ZEED0
VC=V0000002ZEJX0VIW<0000002IVL`0ZUFZ001Eo`000:X000000P2ZEJX00`000000oooo0?ooo`06
0?ooo`80<ol01`3oool203?o06T0oooo000J0?ooo`<0003D203oool20000e1X0oooo0`0000230?oo
o`L0000000<0<fK<03?o000co`00100co`040?ooo`<0<ol00`3oool02@000000ZZ[o0<coo`2ZZ_l0
c?oo0000002ZZ_l0c<c<0:ZZo`020000000:0:X0E@1E0000ZP1E05D0002Z05D000000:X0E@1E0000
ZP1E05D00080000000P0ZUD0000000000000ZUFZ096AT@2ZEJX0TI6A0:YEZP80000000H0TI6A0:YE
ZP2ATI40ZUFZ096AT@2ZEJX20000000>06HcIP2I<c<0IS=V09Tc<`1V<fH0VC<c0000002YZJT00000
07inOP000000OWin06IVV@1nOWh2001EZP030000001VIYT0000000P0oooo0P0co`070?ooo`80<ol0
J@3oool001T0oooo10000=@90?ooo`<0003D5`3oool3000008<0oooo00D0000003?<c000ZZX0oooo
03?o000200000080<ol000@0oooo000000000000VIW<0P0000030?ooo`<0<ol0103oool02@000000
d=3@0<c<c03@d=00c<c<0=3@d0000000c9Wo0000000505D0008000001@1E000030000000ojYE0000
002ZZP00000009VIc03oEJX0VIW<0?mEZP2IVL`0oeFZ09VIc080000000H0oeFZ09VIc00000000000
0:YEE@2I<fH20:YEE@0309TcIP000000VC=V0080000000d0ZJVY0000002IVL`0ZUFZ0000002ZEJX0
VIW<0:YEZP000000002Z0000002IVL`0000000H0oooo0`0co`070?ooo`80<ol0J@3oool001P0oooo
0P000=@00`3oool0003D0000e0060?ooo`@0003D603oool4000008l0oooo1@00000303?o00030000
003oool0oooo0080<ol000H000000:ZZo`3<ool0ZZ[o0<coo`2ZZ_l200000080ZP1E00X0E@000:X0
E@1E0000000005D0002Z05D0E@000:X0E@1E0000ZP1E0P0000003@3<VL`000000<bI00000000ZUFZ
096AT@2ZEJX0TI6A0:YEZP2ATI40ZUFZ096AT@2ZZ_l00P0000000`2I<c<0IS=V09Tc<`0206HcIP0?
09Tc<`1V<fH0VC<c06HcIP2I<c<000000:VYZ@000000OWin06IVV@1nOWh0000007inOP1VIYT0OWin
0080000000<0OWin0000003oool0103oool303?o00P0oooo0P0co`000`000000oooo0?ooo`1V0?oo
o`005`3oool20000e080oooo0P000=@40?ooo`<0003D6P3oool4000009<0oooo0P00000903?o0004
0000003<c<`0d=3@0<c<c08000001@1E00000`000000E@0005D0000405D000050000002ZZ_l00000
0?nZE@2m_Kd00`0000003P3oEJX0VIW<0?mEZP2IVL`0oeFZ09VIc03oEJX0VIW<0000002I<fH0ZUEE
09TcIP2ZEED0VC=V0P2ZEED01P000000ZUEE09TcIP2ZEED000000:VYZ@80000000X0ZUFZ09VIc000
0000VIW<0:YEZP2IVL`0ZUFZ0000002IVL`000001@3oool203?o00T0oooo0`0cI/`00`000000oooo
0?ooo`1U0?ooo`005P3oool30000e080oooo0P000=@0103oool0003D0000e0000=@K0?ooo`<00000
00<0oooo000000000000U03oool203?o00030<coV@0co`00<ol000<0<ol00`3oool01P000000ZZ[o
0000001E0000ZP1E05D00080ZP1E0P0000001P1E0000ZP1E05D0002Z05D000000:X0E@<0000000<0
ojZZ0<bIc03oZZX00`0000003@2ATI40ZUFZ096AT@2ZEJX0TI6A0:YEZP2ATI40ZUFZ0000001V<fH0
VC<c06HcIP2I<c<00P1V<fH040000000IS=V09Tc<`000000VC<c0000002YZJT000000:VYZ@1VIYT0
OWin06IVV@000000IVJI07inOP1VIYT20000000306IVV@000000oooo00<0oooo0P0co`0:0?ooo`04
03=Vc0000<`0<fK<000006H0oooo000F0?ooo`80003D103oool30000e1`0oooo0P0000030?ooo`80
0000T`3oool203?o00H00000103oool00`000000d=3@0000000405D000030000001E0000E@0000D0
E@0000P000000?ooo`0co`0000000;fm_@3oZUD0_Kfm0?nZE@<0000000d0VIW<0?mEZP2IVL`0oeFZ
09VIc03oEJX000000:YEE@2I<fH0ZUEE09TcIP2ZEED0VC=V0080ZUEE00h0VC=V0:YEE@2I<fH0ZUEE
0000002YZJT000000:VYZ@2ZEJX0VIW<0:YEZP2IVL`0000009VIc080ZUFZ00<0VIW<0:YEZP000000
0`3oool303?o00X0oooo1P00001T0?ooo`005@3oool20000e0@0oooo0P000=@L0?ooo`<000000`3o
ool200000980oooo0`0co`0010000000oooo0000003oI/`2000000H0oooo00d000000:X0E@1E0000
ZP1E05D000000000ZP1E05D0002Z05D0E@000:X0E@1E0000ZP1E008000000P0co`001@000000ojZZ
0<bIc03oZZX0c9W<0080000000D0c9W<0000002ATI40ZUFZ096AT@030000000<09Tc<`1V<fH0VC<c
06HcIP2I<c<0IS=V0000002I<c<0IS=V09Tc<`1V<fH000000P2YZJT020000000ZJVY0000001nOWh0
IVJI07inOP000000OWin0P1VIYT00`1nOWh0IVJI000000030?ooo`80<ol02P3oool00`2I<c<00000
000000020000000303=Vc0000000000006<0oooo000E0?ooo`80003D0P3oool30000e1/0oooo1000
00040?ooo`800000T@3oool403?o0080oooo00<000000;fm_@0000001`3oool6000000D0E@000P00
000303?o00080000003oZUD0_Kfm0?nZE@2m_Kd0ojYE0000003oIP020000000<0?mEZP2IVL`00000
0?ooc03<c<`000000:YEE@2I<fH0ZUEE09TcIP2ZEED0VC=V0P2ZEED01`2I<fH0ZUEE09TcIP000000
ojZZ0:VYZ@3Hf=P00P0000001@2IVL`0ZUFZ09VIc02ZEJX000000080ZUFZ00<0VIW<0:YEZP000000
0`3oool203?o00L0oooo00<0000009Tc<`2Z05D010000000102ATI40000003=Vc000001S0?ooo`00
503oool20000e080oooo0P000=@K0?ooo`<0000000<0oooo0000000000000`3oool200000940oooo
0`0co`040?ooo`8000002@3oool00`000000ZZ[o000000020?ooo`D0000000<0oooo03?o000co`00
0P0co`001P000000c9W<0?nZZP3<VL`0ojZZ0<bIc0<0000000<0ojZZ0000000000000`3@d=003@00
0000VC<c06HcIP2I<c<0IS=V09Tc<`1V<fH0000009Tc<`1V<fH0VC<c06HcIP0000000`2YZJT20000
000507inOP1VIYT0OWin06IVV@0000000P1VIYT00`1nOWh0IVJI000000020?ooo`<0<ol01P3oool0
1@000000VC<c09Tc<`000000VC<c0080000000<0VC?<0000002I<l`00`00001R0?ooo`00503oool5
0000e1X0oooo0`0000030?ooo`8000000P3oool2000008d0oooo0P0000020?ooo`<0<ol00`3oool6
000000P0oooo0P0000030?ooo`03000000030`<0000A008000000P0co`020?ooo`060000003oZUD0
_Kfm0?nZE@2m_Kd0ojYE0P0000003P2ZZP00_Kfm0000003ool`0c<c<0?ooc03<c<`000000:YEE@2I
<fH0ZUEE09TcIP2ZEED000000P2ZEED04`2I<fH0ZUEE09TcIP000000ojZZ0:VYZ@3oZZX000000?nZ
ZP000000ZUFZ09VIc02ZEJX0VIW<0000002ZEJX0VIW<0:YEZP0000000P3oool203?o00L0oooo00@0
000009Tc<`000000ZP1E0P0000001`2ATI400000096AT@000000TI6A0<aVc0000000HP3oool001<0
oooo1@000=@H0?ooo`<000001P3oool2000000040?ooo`0000000000000008h0oooo00<000000?oo
o`0co`000P0co`030?ooo`0809VIc02I<iT0VC>I09VIc02I<iT0VIW<09TcV@0000070?ooo`800000
0`3oool00`000000000A0000000403?o00080?ooo`000000ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`2
000000030<bI00000000d=3@00@0d=3@00H0000009Tc<`1V<fH0VC<c06HcIP2I<c<206HcIP0509Tc
<`1V<fH0VC<c06HcIP0000000`2YZJT030000000ZJVY0000001VIYT0OWin06IVV@1nOWh0IVJI0000
001nOWh0IVJI00000080oooo0P0co`070?ooo`D0000000P0c9W<000000000000VIW<09Tcc0000000
VC?<00000680oooo000C0?ooo`<0003D5`3oool4000000P0oooo1@00002@0?ooo`<0<ol000@0TI6A
09VIc02ATI40VIW<0P2ATI401`2IVL`0TI6A09VIc02ATI40VIW<096AT@0000001`3oool01`000000
oooo0?ooo`000000000A0000000009T00`0co`020?ooo`070000002m_Kd0ojYE0;fm_@3oZUD0_Kfm
0?nZE@03000000090?ooc03<c<`0ooo<0<c<c03ool`0c<c<0000002ZEED0VC=V00X000000100ojZZ
0:VYZ@3oZZX000000?nZZP000000ZUFZ09VIc02ZEJX0VIW<0:YEZP000000VIW<0:YEZP000000oooo
0`0co`080?ooo`050000003oool000000;6a/@3<VFH00P000000102ATI40c6K<096AT@00001S0?oo
o`004`3oool20000e1L0oooo0P0000000`3oool00000000000080?ooo`@00000S`3oool200000080
<ol000H0VC>I09VIc02I<iT0VIW<09TcV@2IVL`209TcV@0609VIc02I<iT0VIW<09TcV@2IVL`00000
1@3oool3000000030?ooo`000000000A00D0000000d0002I0000002IVL`000000?nZZP3<VL`0ojZZ
0<bIc03oZZX0c9W<0000003@d=00000000H0d=3@0`0000030=3@d080ZUFZ00<0TI6A0:YEZP000000
1@2YZJT03@000000ZJVY0:VYZ@1VIYT0OWin06IVV@1nOWh0IVJI0000001nOWh0IVJI0000003oool0
0P0co`080?ooo`080000002Ic6H0oooo0000003<I/`0c9W<0000002I<l`500000680oooo00370?oo
o`@0000000<0VC=V09Tc<`2I<fH00`0000000`2ATI40VC>I0000000200000008096AT@2I<iT0TI6A
09TcV@2ATI40VC>I096AT@2I<iTD000000040?nZZP3oZUD0ojZZ0?nZE@8000000`3@d=0A000000D0
ZJVY00P000000:VYZ@2YZJT0000009VIc01VIYT0VIW<06IVV@<0000000@0oooo03?o000co`00<ol0
1`3oool200000080oooo2000001T0?ooo`00aP3oool20000000609Tc<`2I<fH0000009TcIP2I<c<0
VC=V0P0000003`3oZZX0VC<009VIc02ATI40VIW<096AT@000000VIW<096AT@2IVL`0TI6A09VIc02A
TI40VIW<000000060?ooo`@000000P3oool20000000K06Hcc0000000002I0000003oZUD0_Kfm0?nZ
E@2m_Kd0ojYE0;fm_@000000c<c<0?ooc03<c<`0ooo<0:ZZ00000000c<c<0?ooc03<c<`0<lco05FZ
ZP0cc?l0EJZZ03?<o`1EZZX0<lco0080EJZZ00<0<lco0000000000001@0000001P3oZZX0ZJVY0?nZ
ZP2IVL`0ZUFZ09VIc080ZUFZ00<0VIW<0000000000000P0co`1h0?ooo`00aP3oool01`000000E@1E
09TcIP000000VC=V05D0E@2I<fH00`0000001`2IVL`0YJFU09Tc002IVL`0VC>I09VIc02I<iT00P00
00001`2I<iT0VIW<09TcV@2IVL`0VC>I09VIc00000000`3oool2000000030:[oZP3<ol`0000000<0
oooo0`0000002P2IVL`000000000003<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP0000030=3@d0h00000
00<0EJ[o0000000000000P0000000`1Vc<`0EJ[o06K<c0050000000406IVV@1nOWh0IVJI06IVV@80
000000<0_Kfm03?o000co`00N03oool00<H0oooo00l0000009TcIP000000VC=V09Tc<`2I<fH0VC<c
0000003oZZX000000?nZZP2EUID0ojZZ09Tc002IVL`00P2ATI402P2IVL`0TI6A000000000000VIW<
096AT@2IVL`0TI6A0000003oool2000000040:[oo`1Vc<`00000000000<0oooo00h000000?o<V@2i
^KT0000008f=S@000000_Kfm0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0?nZE@<0000000h0I/co03?<
o`1Vc?l0000006K<o`0cc?l0I/co03?<o`1Vc?l0<lco06K<o`0cc?l0I/co03?<o`<000000P0cc?l8
000000030:YEZP000000000000<000000`0co`1h0?ooo`00aP3oool20000000409TcIP1E05D0VC=V
05D0E@80000000D0VIW<0:FUY@000000YJFU09VIc0020000000909VIc02I<iT0VC>I09VIc02I<iT0
VIW<0000002IVL`0VC>I00<0000000@0Z_nZ0<coc02ZojX000001@3oool00`000000c9W<0?mVV@03
000000090?nZZP3<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0000000/0d=3@1`0000000`2YZJT0
0000000000070000000505FZo`00000000000000000cc<`00P00000203?o00<00000MP3oool00<L0
oooo00<0000009Tc<`0000000P0000001`3oool000000?nZZP2EUID0000009FEU@3oZZX00`000000
1P2ATI40VIW<096AT@2IVL`0TI6A09VIc080000000D0I/c<0:[oo`1Vc<`0Z_oo000000070?ooo`03
0000003oc9T0^KVi00<0000001P0_Kfm0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0?nZE@000000ooo<
0<c<c03ool`0c<c<0?ooc03<c<`0ooo<0<c<c03ool`0c<c<0000003oEJX0VIW<0?mEZP2IVL`20?mE
ZP080000002YZJT0ojZZ0:VYZ@3oZZX0ZJVY0?nZZP2YZJT8000000040?ooo`0co`00<ol003?o00P0
0000L@3oool00<P0oooo00/000000?ooo`3oool0oooo0000002UYJD0VIW<0:FUY@000000YJFU09VI
c0020000000909VIc0000000VC>I09VIc02I<iT0VIW<0000003<ol`0Z_nZ008000002@3oool01000
0000ofJI0<bIc03oIYT20000000:0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ0<bIc03oZZX0c9W<0000
00X0d=3@0P0000001P2ZEJX0TI6A0:YEZP2ZEJX0TI6A000000L0ZJVY00D000000:VYZ@2YZJT0ZJVY
000000030?ooo`@0<ol00P3oool2000000030:ZZo`000000000000D00000K@3oool00<`0oooo00L0
000009FEU@3oZZX0UIFE0000002EUID000000080oooo0P0000000`2IVL`0TI6A09VIc00300000003
09VIc0000000oooo00X0oooo01/000000?o<V@000000oooo0000003oZUD0_Kfm0?nZE@2m_Kd0ojYE
0;fm_@3oZUD0_Kfm0?nZE@000000ooo<0<c<c03ool`0c<c<0?ooc03<c<`0ooo<0<c<c03ool`00000
0;fm_@3oZUD00P0000000`2IVL`0oeFZ00000004000000080?nZZP2YZJT0ojZZ0:VYZ@000000ZJVY
0?nZZP0000030?ooo`@0<ol0103oool4000000030;fm_@000000000000H00000J@3oool00<`0oooo
00@000000:FUY@2IVL`0YJFU0P0000040?ooo`090000002I<iT0VIW<09TcV@2IVL`0VC>I09VIc02I
<iT0000000/0oooo0P0000020?ooo`0;0000003<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ
0<bIc0000000203@d=001@000000c9W<0?nZZP3<VL`0ojZZ00@00000103oool3000000040:VYZ@00
0000ZJVY000000<0oooo1@0co`060?ooo`P0000000<0ZZ[o09VIo`2ZZ_l00`00001V0?ooo`00c03o
ool01@000000UIFE0?nZZP2EUID0000000D0oooo00T0TI6A09VIc02ATI40VIW<096AT@2IVL`0TI6A
09VIc00000003P3oool02P000000_Kfm0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0?nZE@2m_Kd20?nZ
E@060000003<c<`0ooo<0<c<c03ool`0c<c<0P0000002P2m_Kd0ojYE0;fm_@3oZUD0_Kfm0000002=
SHd0000005EEo`0000060?ooo`<000000P3oool703?o00P0oooo00D000000;fm_@2m_Kd0_Kfm0000
00020;fm_@80000000<0_Kfm09VIo`2m_Kd01000001R0?ooo`00c03oool01@000000YJFU09VIc02U
YJD0000000H0oooo00P0VC>I09VIc02I<iT0VIW<09TcV@2IVL`0VC>I000000h0oooo00/000000?nZ
ZP3<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ0<bIc0020?nZZP030000003@d=00d=3@0080
000000T0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0000006Hcc02IVOl00P1V<l`00`000000oooo0?oo
o`080?ooo`L0<ol02P3oool2000000H0ZZ[o100000000`2IVOl0ZZ[o09VIo`04000005h0oooo003<
0?ooo`040000002EUID0ojZZ000000P0oooo00L0TI6A09VIc02ATI40VIW<096AT@2IVL`0000000h0
oooo00X000000;fm_@3oZUD0_Kfm0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0P3oZUD03`2m_Kd00000
0?ooc0000000_Kfm0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0?nZE@000000EEGo08f=S@0205EEo`03
08f=S@000000oooo00H0oooo2@0co`0<0?ooo`8000001`2m_Kd5000000030;fm_@2IVOl0_Kfm0080
0000G03oool00<`0oooo00<000000:FUY@0000002P3oool01P000000VIW<09TcV@2IVL`0VC>I0000
00h0oooo00/000000?nZZP3<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ0<bIc0020?nZZP80
000000`0c9W<0?nZZP3<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP000000oooo0000002IVOl206Hcc003
09VIo`000000oooo00D0oooo2@0co`0?0?ooo`D00000102ZZ_l3000000@0oooo00@0ZZ[o00000000
00000000F@3oool00<`0oooo0P00000=0?ooo`<000003P3oool02`000000ojYE0;fm_@3oZUD0_Kfm
0?nZE@2m_Kd0ojYE0;fm_@3oZUD0_Kfm0080ojYE01<0_Kfm0000002m_Kd0ojYE0;fm_@3oZUD0_Kfm
0?nZE@2m_Kd0ojYE0;fm_@000000SHf=0?ooo`000000EEGo0?ooo`2=SHd000000080oooo0`000007
03?o00030?ooo`0co`00<ol001@0oooo100000030;fm_@<000000`3oool00`2IVOl0_Kfm00000002
000005H0oooo003/0?ooo`0<0000003<VL`0ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ0<bIc03o
ZZX0c9W<0P3oZZX020000000ojZZ0<bIc03oZZX0c9W<0?nZZP3<VL`0ojZZ0P0000000`1V<l`0VIWo
06Hcc008000000@0<ol000<0000003?o000co`000`3oool00`0co`00oooo0?ooo`0G0?ooo`D00000
00<0ZZ[o0000000000001@3oool00`2ZZ_l000000?ooo`1D0?ooo`00k03oool5000000060?nZE@2m
_Kd0ojYE0;fm_@3oZUD0_Kfm0P3oZUD01`2m_Kd000000;fm_@3oZUD0_Kfm0?nZE@2m_Kd00P000000
2P3oool0000005EEo`3oool0EEGo08f=S@000000EEGo08f=S@1EEOl2000000@0<ol000@0000003?o
000co`00<ol00`3oool00`0co`00oooo0?ooo`0L0?ooo`D00000FP3oool00?40oooo1`0000020?nZ
ZP030?nZE@000000000000<00000103oool010000000SHf=05EEo`2=SHd20000000308f=S@000000
<ol00080<ol00P00000403?o00<000000P0co`0Q0?ooo`@00000F03oool00?00oooo00<000000<co
c03<ol`00P0000030?ooo`80000000D0c9W<000000000000ojYE000000060?ooo`030000001V<l`0
oooo0080IS?<00@0000003?o000co`00oooo100co`000`000000oooo0?ooo`020?ooo`<00000O@3o
ool00?00oooo0P0000080?ooo`040000003oool00000000000H0oooo00@0<ol00000000co`00SHf=
0P1EEOl00`000000oooo03?o000403?o00800000Q03oool00?00oooo00<000000?ooo`3oool0203o
ool4000000@0oooo0`0co`001@000000VIWo06Hcc01V<l`0000000@0<ol00P3oool2000008@0oooo
003g0?ooo`@0000000@006K<002ZZP00I/`00:ZZ1000000303?o00050000000co`00EEGo05EEo`2=
SHd00P0co`050?ooo`030000003oool0oooo0880oooo003e0?ooo`8000000P1EZ_l0100cc<`0EJ[o
03?<c01EZ_l400000003001EZP00VIT005FZ00D0000000<0IS?<09VIo`000000R`3oool00?/0oooo
1@0000000`1EZZX0000000000004000000<0<ol000<000000?ooo`3oool0RP3oool00?l0oooo0@3o
ool20000000305FZo`0cc<`0EJ[o008000000P0co`06000008P0oooo003o0?ooo`40oooo200co`00
0`3oool00000000000020000000309VIc02m_Kd0000000800000Q@3oool00?l0oooo0@3oool503?o
00D0oooo00<000000:ZZo`0000000P0000000`2ZZ_l0VIWo0:ZZo`0300000880oooo003o0?ooo``0
oooo00<000000;fm_@2m_Kd00`000000102IVL`0_Kfm09VIc02m_Kd200000800oooo003o0?ooo`d0
oooo00D000000:ZZo`3<VL`0ZZ[o0<bIc002000000040:ZZo`2IVOl0ZZ[o09VIo`<00000O@3oool0
0?l0oooo3`3oool50;fm_@050000003oool0oooo0?ooo`2IVL`00P00001m0?ooo`00o`3ooolA0?oo
o`050<bIc02ZZ_l0c9W<0:ZZo`000000PP3oool00?l0oooo4`3oool300000880oooo003o0?oooiP0
oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0
oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0
oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0
oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0
oooo003o0?oooiP0oooo003o0?oooiP0oooo003o0?oooiP0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{407, 281.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Mapping from genotype to phenotype through transcription, translation, and \
morphogenetic processes. (Figure from C. Jacob, ",
  StyleBox["Principia Evolvica",
    FontWeight->"Bold"],
  ". dpunkt, Heidelberg, Germany. Chapter 3.2.3.)"
}], "NumberedFigure"],

Cell[TextData[{
  "More information about ",
  ButtonBox["transcription and translation",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ ], "03-GeneticAlgorithms", "GA-Mutation"}, 
        "Mutation-RNA.nb", CharacterEncoding -> "MacintoshRoman"], 
      "TranscriptionTranslation"},
    ButtonStyle->"Hyperlink"],
  " \[Ellipsis]"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutations", "Subsection",
  CellTags->"Mutations"],

Cell[CellGroupData[{

Cell["Mutations Cause Genotypic Variation", "Subsubsection"],

Cell["Heredity is passed through the genome.", "Text"],

Cell["\<\
Genetic changes caused by mutation and recombination are passed \
with the genome from parents to their offspring.\
\>", "Text"],

Cell["\<\
\[Rule] The genome provides the principal mechanism for variation \
within a population.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples of Mutation Effects", "Subsubsection"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008J0001iR000`400?l00000o`00003oo`3ooooo
0?oooa`0oooo003o0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00o`3ooooo0?oooa`0oooo
003o0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00o`3ooooo0?oooa`0oooo003o0?ooof@0
oooo00<0IVIV0?ooo`3oool0]03oool00?l0ooooI@3oool00`1VIVH0oooo0?ooo`2c0?ooo`00o`3o
oomV0?ooo`0306IVIP3oool0oooo0;80oooo003o0?ooofL0oooo0`1VIVJa0?ooo`00o`3ooomS0?oo
o`@0IVIV00<0oooo06IVIP1VIVH0/@3oool00?l0ooooG03oool706IVIPH0oooo0P1VIVJ`0?ooo`00
o`3ooomI0?ooo`@0IVIV3P3oool00`1VIVH0oooo0?ooo`2]0?ooo`00o`3ooom90?ooo`80IVIV2P3o
ool406IVIQ<0oooo00<0IVIV0?ooo`3oool0[03oool00?l0ooooBP3oool206IVIP@0oooo1@1VIVHH
0?ooo`80IVIV[03oool00?l0ooooB`3oool606IVIQ`0oooo101VIVJZ0?ooo`00o`3ooom70?ooo`P0
IVIV603oool706IVIP030?ooo`1VIVH0IVIV0:X0oooo003o0?oood80oooo1@1VIVH80?ooo`0306IV
IP3oool0oooo0140oooo1@1VIVH90?ooo`0306IVIP3oool0oooo0:L0oooo003o0?ooocl0oooo101V
IVH<0?ooo`80IVIV3P3oool506IVIPh0oooo00<0IVIV0?ooo`3oool0YP3oool00?l0oooo;`3oool2
06IVIPX0oooo101VIVHB0?ooo`80IVIV203oool406IVIQ@0oooo0P1VIVJV0?ooo`00o`3oool`0?oo
o`80IVIV1@3oool406IVIQL0oooo0P1VIVH20?ooo`D0IVIV6@3oool406IVIZ<0oooo003o0?oooc40
oooo1P1VIVHI0?ooo`L0IVIV6@3oool706IVIZ@0oooo003o0?ooobd0oooo101VIVH30?ooo`80IVIV
5P3oool406IVIP<0oooo0P0co`0206IVIQ@0oooo1@1VIVH70?ooo`0306IVIP3oool0oooo0:40oooo
003o0?ooobT0oooo101VIVH80?ooo`0306IVIP3oool0oooo0100oooo101VIVH70?ooo`80<ol000<0
oooo06IVIP1VIVH03`3oool506IVIP`0oooo00<0IVIV0?ooo`3oool0X03oool00?l0oooo9@3oool4
06IVIPd0oooo0P1VIVH;0?ooo`D0IVIV2`3oool203?o0080oooo0P1VIVH:0?ooo`D0IVIV4@3oool2
06IVIZ00oooo003o0?ooob40oooo101VIVHB0?ooo`80IVIV1P3oool506IVIPl0oooo0P0co`040?oo
o`0306IVIP3oool0oooo0080oooo1P1VIVHF0?ooo`@0IVIVW@3oool00?l0oooo7P3oool306IVIQP0
oooo00<0IVIV0?ooo`1VIVH0101VIVHC0?ooo`80<ol01@3oool506IVIQT0oooo1@1VIVJN0?ooo`00
o`3ooole0?ooo`L0IVIV5`3oool203?o00P0IVIV503oool706IVIP@0oooo0P1VIVJM0?ooo`00o`3o
oola0?ooo`D0IVIV1P3oool00`1VIVH0oooo0?ooo`0@0?ooo`@0IVIV0P0co`080?ooo`0306IVIP3o
ool0oooo00d0oooo1@1VIVJY0?ooo`00o`3oool]0?ooo`@0IVIV303oool206IVIP`0oooo1@1VIVH3
0?ooo`80<ol02@3oool206IVIPT0oooo1@1VIVJ]0?ooo`00o`3ooolX0?ooo`D0IVIV4@3oool206IV
IPL0oooo1@1VIVH70?ooo`80<ol02P3oool206IVIP@0oooo1@1VIVJa0?ooo`00o`3ooolU0?ooo`@0
IVIV5`3oool00`1VIVH0oooo0?ooo`0506IVIP/0oooo0P0co`0;0?ooo`D0IVIV]P3oool00?l0oooo
?03oool706IVIQ00oooo0P0co`060?ooo`H0IVIV00<0oooo06IVIP1VIVH0]`3oool00?l0oooo>03o
ool506IVIPD0oooo0P1VIVH>0?ooo`<0<ol000<0oooo06IVIP1VIVH00`1VIVK00?ooo`00o`3ooold
0?ooo`D0IVIV2`3oool206IVIP`0oooo0P0co`0306IVI/@0oooo003o0?oooc00oooo1@1VIVH@0?oo
o`80IVIV1`3oool406IVIP80<ol0a`3oool00?l0oooo;@3oool306IVIQL0oooo00<0IVIV0?ooo`1V
IVH0101VIVH40?ooo`80<ol0a`3oool00?l0oooo@`3oool706IVIPP0oooo0P0co`370?ooo`00o`3o
oolo0?ooo`D0IVIV1@3oool00`1VIVH0oooo0?ooo`050?ooo`<0<ol0a`3oool00?l0oooo1@3oool7
000002l0oooo1@1VIVHA0?ooo`80<ol0b03oool00?l0oooo0`3oool;000002T0oooo1@1VIVHE0?oo
o`80<ol0b03oool00?l0oooo0@3oool4000000L0oooo1000000T0?ooo`<0IVIV6P3oool203?o0<P0
oooo003o0?ooo`<000001P3oool2000000<0oooo0`00000o0?ooo`<0<ol0b03oool00?h0oooo0`00
00070?ooo`800000103oool3000003d0oooo00<0000003?o000co`00b@3oool00?d0oooo0`000008
0?ooo`8000001@3oool3000003`0oooo00@0000003?o000000000000b03oool00?d0oooo0P000004
0?ooo`T00000103oool2000003`0oooo0`0co`000`000000oooo0?ooo`360?ooo`00o03oool20000
00D0oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P00000j0?ooo`@0<ol000<000000?oo
o`3oool0aP3oool00?`0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000001`3oool20000
03X0oooo1@0co`380?ooo`00n`3oool2000000L0oooo00@000000?ooo`3oool0oooo0P0000080?oo
o`800000=`3oool703?o0<P0oooo003k0?ooo`800000203oool00`000000oooo0?ooo`02000000P0
oooo0P00000g0?ooo`@0<ol000@0oooo03?o000co`00<ol0a`3oool00?/0oooo0P0000090?ooo`04
0000003oool00000000000P0oooo0P00000c0?ooo`D000000`0co`020?ooo`80<ol0a`3oool00?/0
oooo0P0000090?ooo`040000003oool00000000000P0oooo0P00000c0?ooo`040000001EZZX0EJZZ
05FZZP@000000P3oool203?o0<L0oooo003k0?ooo`8000002P3oool3000000P0oooo0P00000d0?oo
o`030000001EZZX0EJZZ00<0EJZZ0P000000103oool0<ol003?o000co`360?ooo`00n`3oool20000
00X0oooo0`0000080?ooo`800000=03oool805FZZP8000000P0co`360?ooo`00n`3oool2000000/0
oooo0P0000080?ooo`800000<`3oool00`0co`00EJZZ05FZZP0705FZZP<0000000<0<ol00?ooo`3o
ool0``3oool00?`0oooo0P00000C0?ooo`800000<`3oool203?o00T0EJZZ200000310?ooo`00o03o
ool2000001<0oooo0P00000c0?ooo`80<ol000<0oooo05FZZP1EZZX00`1EZZX4000000<0EJZZ0P00
00020:YEZP800000_`3oool00?d0oooo0P00000A0?ooo`8000009@3oool8000000D0oooo100co`00
103oool0EJZZ05FZZP1EZZX3000000P0EJZZ0P0000000`2ZEJX000000000002n0?ooo`00o@3oool3
000000l0oooo0`00000X0?ooo``0000000<04@000000000000000`00000=05FZZP030000002ZEJX0
00000;h0oooo003n0?ooo`<000003@3oool300000340oooo00<0<ol00000000000003@00000805FZ
ZP<00000_@3oool00?l0oooo0`00000;0?ooo`<00000<@3oool403?o00040?ooo`00000000000?oo
o`@0000000<0ZUFZ0000000000001P00000505FZZP800000_@3oool00?l0oooo0@3oool4000000L0
oooo1000000b0?ooo`<0<ol000@0oooo000000000000oooo0`0000000`2a/K400000000000030:YE
ZP<0000000<0ZUFZ03?o000000001P00002m0?ooo`00o`3oool30?ooo`/00000<`3oool303?o0080
00000`3oool01P000000/K6a0;6a/@000000/K6a000000D0ZUFZ0`00000203?o00@0ZUFZ00<00000
0?ooo`3oool0^`3oool00?l0oooo1@3oool7000003@0oooo0`0co`02000000@0oooo00@000000;6a
/@2a/K4000000P2a/K400`000000ZUFZ0:YEZP040:YEZP030000000co`00<ol000@0ZUFZ00<00000
0?ooo`3oool0^`3oool00?l0oooo503oool00`3M20H0oooo0?ooo`0W0?ooo`<0<ol00`0000040?oo
o`8000000P2a/K400`000000/K6a0;6a/@02000000H0ZUFZ1P00002n0?ooo`00o`3ooolC0?ooo`80
g@P6:@3oool0100co`0000000000000000060?ooo`050000002a/K40/K6a0;6a/@0000000`2a/K42
000000D0ZUFZ00H0000006K<c000000000000:YEZP00002n0?ooo`00o`3ooolB0?ooo`<0g@P6803o
ool300000080oooo0P000000103oool0<ol00000000000080?ooo`040000002a/K40/K6a0;6a/@80
00000P2a/K490000000403?o00000000ZUFZ00000;h0oooo003o0?oooa40oooo0`3M20HR0?ooo`D0
000000@0EJ[o00000000000000002@3oool00`000000/K6a0;6a/@020;6a/@030000002a/K400000
0080000000P0I/c<000000000000000005FZZP1Vc<`0000003?o00@00000_@3oool00?l0oooo403o
ool40=d81R<0oooo100000000`1EZ_l00000000000090?ooo`800000102a/K401P000000/K6a0;6a
/@2a/K4000000?ooo`8000000`2ZEJX00`000000<ol003?o000600000;X0oooo003o0?ooo`l0oooo
1@3M20HT0?ooo`D0<ol00P0000080?ooo`030000002a/K40/K6a00<0/K6a00@000000;6a/@000000
00000`3oool200000080ZUFZ00@0000003?o000co`00<ol01`00002h0?ooo`00o`3oool>0?ooo`D0
g@P68P3oool703?o00D000001P3oool00`000000/K6a0;6a/@020;6a/@<000001P3oool200000080
ZUFZ00@0000003?o000co`0000001@3oool00`000000oooo0?ooo`2f0?ooo`00o`3oool<0?ooo`L0
g@P6803oool903?o0080ZZ[o1@0000040?ooo`<0000000<0/K6a0000003oool02@3oool4000000@0
<ol0_@3oool00?l0oooo2`3oool80=d81Ql0oooo0`0co`02000000D0<ol00P0000020?ooo`<00000
1P3oool2000000h0oooo00<0000003?o000co`000P0co`2m0?ooo`00o`3oool:0?ooo`T0g@P67@3o
ool503?o00030?ooo`0co`00<ol000@0<ol00P0000040?ooo`030000003oool0oooo01D0oooo1@0c
o`2l0?ooo`00o`3oool90?ooo`T0g@P6703oool503?o0080oooo0`0co`001P3oool0<ol003?o000c
o`00oooo000001d0oooo100co`2l0?ooo`00o`3oool80?ooo`X0g@P6703oool403?o0080oooo0`0c
o`00103oool0<ol003?o000co`0P0?ooo`D0<ol0^`3oool00?l0oooo1`3oool;0=d81R40oooo0`0c
o`020?ooo`80<ol08P3oool503?o0;X0oooo003o0?ooo`H0oooo303M20HP0?ooo`<0<ol00`3oool2
03?o0280oooo1@0co`2j0?ooo`00o`3oool50?ooo``0g@P6803oool303?o00<0oooo0`0co`0R0?oo
o`H0<ol0^@3oool00?l0oooo1P3oool;0=d81Ql0oooo0`0co`040?ooo`80<ol08`3oool603?o0;T0
oooo003o0?ooo`L0oooo2P3M20HN0?ooo`<0<ol0103oool303?o02@0oooo1P0co`2h0?ooo`00o`3o
ool80?ooo`P0g@P67@3oool200000080<ol00P3oool40000000303?o003oool0oooo0280oooo0P00
000503?o0;P0oooo003o0?ooo`T0oooo1`3M20HH0?ooo`040000003oool0oooo0?ooo`80E@1E0P00
000606IVV@800000903oool4000000<0<ol01@00002c0?ooo`00o`3oool80?ooo`P0g@P65@3oool3
000000<0DU9B2000000406IVV@030000003oool0oooo01/0oooo0P0000000`3oool0ZP000:X00002
0:X000@000000P0co`000`000000IVJI06IVV@0306IVV@030000003oool0oooo0;00oooo003o0?oo
o`L0oooo0`3M20H30?ooo`<0g@P65@3oool00`000000DU9B059BDP03000000<0DU9B0`000000101V
IYT0000000000000000306IVV@030000003oool0oooo01L0oooo100000030:X0E@P0000000@0<ol0
00000000000000000`1VIYT00`000000oooo0?ooo`2`0?ooo`00o`3oool70?ooo`80g@P6703oool4
000000@0DU9B00@000000?nZZP00000000000`1VIYT200000080IVJI00<000000?ooo`3oool05`3o
ool3000000070:X0E@00000000000000002Z05D0000003?<c00500000080<ol01@0000000`1VIYT0
00000?ooo`2`0?ooo`00o`3oool60?ooo`<0g@P66P3oool;000000040?nZZP000000ojZZ000000<0
IVJI1000000L0?ooo`P000000P2k^k/010000000<ol003?o000co`0700000;40oooo003o0?ooo`D0
oooo0`3M20HJ0?ooo`800000203oool01P000000ojZZ0?nZZP3oZZX000000?nZZP8000000`1VIYT0
0`000000oooo0?ooo`0L0?ooo`800000103oool010000000^k^k0;^k^`00000203?o00030000000c
o`00<ol00080IVJI1@00002_0?ooo`00o`3oool50?ooo`80g@P6903oool2000000<0ojZZ00<00000
0?nZZP3oZZX00P00000206IVV@030000003oool0oooo01/0oooo0P0000040?ooo`030000002k^k/0
^k^k0080^k^k00@0000003?o0000000000000P0co`0206IVV@050000003oool0oooo0?ooo`000000
[P3oool00?l0oooo103oool30=d81R@0oooo00<000000?nZZP3oZZX00P3oZZX30000000503?o0000
0000000006IVV@0000008P3oool2000000@0^k^k0P0co`0300000080<ol000<0IVJI0000003oool0
/@3oool00?l0oooo0`3oool30=d81RD0oooo00H000000?nZZP3oZZX0ojZZ0000003oool303?o0004
0?ooo`000000000000000280oooo00<000000;^k^`2k^k/00`2k^k/00`0co`00^k^k0;^k^`020;^k
^`80<ol000<0IVJI0000003oool0/@3oool00?l0oooo0`3oool20=d81RH0oooo100000020?ooo`<0
<ol09@3oool2000000D0^k^k00<0<ol00;^k^`2k^k/00P2k^k/010000000<ol000000000002b0?oo
o`00o`3oool20?ooo`<0g@P6:`3oool303?o02H0oooo00<000000;^k^`2k^k/00`2k^k/203?o00@0
000000@0oooo03?o000co`00<ol0/P3oool00?l0oooo0@3oool30=d81R`0oooo0P0co`0W0?ooo`80
0000102k^k/00`000000<ol00?ooo`040?ooo`@0<ol0/@3oool00?l0oooo0@3oool20=d81R`0oooo
0`0co`0X0?ooo`D00000203oool303?o00<0oooo0P00002/0?ooo`00o`3oool30=d81R/0oooo0`0c
o`0f0?ooo`80<ol00P0000000`3<I/`000000:6QX@0200000:/0oooo003n0?ooo`<0g@P6;03oool2
03?o03P0oooo00@0<ol000000000000000000`2QXJ400`000000oooo0?ooo`2Y0?ooo`00oP3oool2
0=d81R`0oooo0`0co`0e0?ooo`/00000Z`3oool00?d0oooo0`3M20H/0?ooo`80<ol0=P3oool20000
0080VC<c100000000`0007L000000000002[0?ooo`00o03oool30=d81R`0oooo0`0co`0f0?ooo`P0
000000@0XJ6Q0000000000000000E03oool00`1VIVH0oooo0?ooo`1C0?ooo`00n`3oool30=d81R`0
oooo00<0000003?o000co`00=P3oool01P000000VLbI0?ooo`3oool000000?nZZPD0000000<0oooo
0000003oool0D`3oool00`1VIVH0oooo0?ooo`1C0?ooo`00n`3oool20=d81R`0oooo1@00000d0?oo
o`030000002Ic9T0oooo0080oooo1`00001G0?ooo`0306IVIP3oool0oooo00H0oooo0P1VIVI:0?oo
o`00nP3oool30=d81RX0oooo1`00000c0?ooo`8000001@3oool5000005T0oooo0P1VIVH00`3oool0
IVIV06IVIP0306IVIT`0oooo003i0?ooo`<0g@P6;03oool6000003X0oooo0P00001<0?ooo`0306IV
IP3oool0oooo00d0oooo101VIVI@0?ooo`00n@3oool20=d81Rh0oooo00<000000?ooo`3oool0RP3o
ool00`1VIVH0oooo0?ooo`0:0?ooo`@0IVIV00<0oooo06IVIP3oool0D03oool00?P0oooo0`3M20Jk
0?ooo`80IVIV203oool406IVIPD0oooo00<0IVIV0?ooo`3oool0CP3oool00?L0oooo0`3M20Jm0?oo
o`80IVIV103oool406IVIPT0oooo00<0IVIV0?ooo`3oool0C@3oool00?L0oooo0P3M20J_0?ooo`03
06IVIP3oool0oooo00d0oooo1@1VIVH>0?ooo`80IVIVC@3oool00?H0oooo0`3M20J`0?ooo`0306IV
IP3oool0oooo00T0oooo101VIVH00`3oool0IVIV0?ooo`0@0?ooo`0306IVIP3oool0oooo04/0oooo
003e0?ooo`<0g@P6/P3oool00`1VIVH0oooo0?ooo`050?ooo`@0IVIV1@3oool00`1VIVH0oooo0?oo
o`0?0?ooo`0306IVIP3oool0oooo00@0oooo0`1VIVI30?ooo`00m@3oool20=d81[<0oooo0P1VIVH3
0?ooo`@0IVIV203oool206IVIQ00oooo0P1VIVH20?ooo`<0IVIVAP3oool00?@0oooo0`3M20Jd0?oo
o`D0IVIV303oool206IVIPl0oooo101VIVI90?ooo`00l`3oool30=d81Z@0oooo0P1VIVH;0?ooo`L0
IVIV3`3oool206IVIPT0oooo1P1VIVH00`3oool0IVIV06IVIP190?ooo`00l`3oool20=d81ZL0oooo
00<0IVIV0?ooo`3oool01@3oool406IVIPH0oooo00<0IVIV0?ooo`3oool03P3oool00`1VIVH0oooo
0?ooo`030?ooo`@0IVIV203oool00`1VIVH0oooo0?ooo`160?ooo`00lP3oool30=d81ZP0oooo00@0
IVIV0?ooo`3oool0oooo101VIVH:0?ooo`0306IVIP3oool0oooo00h0oooo1P1VIVH<0?ooo`0306IV
IP3oool0oooo04D0oooo003a0?ooo`<0g@P6ZP3oool406IVIPh0oooo00<0IVIV0?ooo`3oool02`3o
ool406IVIQ40oooo00<0IVIV0?ooo`3oool0A03oool00?40oooo0P3M20JJ0?ooo`80IVIV303oool5
06IVIQ00oooo0P1VIVH90?ooo`@0IVIV0P3oool206IVIQ00oooo0P1VIVH70?ooo`80IVIV?03oool0
0?l0ooooS`3oool206IVIPP0oooo0`1VIVH50?ooo`0306IVIP3oool0oooo00h0oooo0P1VIVH50?oo
o`@0IVIV1P3oool206IVIQ00oooo0P1VIVH30?ooo`<0IVIV?P3oool00?l0ooooT03oool306IVIP03
0?ooo`1VIVH0IVIV00@0IVIV203oool206IVIPl0oooo1P1VIVH;0?ooo`80IVIV3P3oool606IVIT40
oooo003o0?oooi40oooo0`1VIVH@0?ooo`0306IVIP3oool0oooo00X0oooo0`1VIVH00`3oool0IVIV
06IVIP0?0?ooo`0306IVIP3oool0oooo00P0oooo101VIVH20?ooo`80IVIV@P3oool00=d0oooo0P00
0=@00`3oool0003D0000e0020000e0030000003oool0000000@00000XP3oool406IVIP030?ooo`1V
IVH0oooo0100oooo00<0IVIV0?ooo`3oool01@3oool406IVIPD0oooo0P1VIVH?0?ooo`0306IVIP3o
ool0oooo00@0oooo0`1VIVH70?ooo`80IVIV@@3oool00=d0oooo1@000=@200000080oooo1000002Q
0?ooo`80IVIV1P3oool206IVIPl0oooo0P1VIVH30?ooo`@0IVIV2@3oool00`1VIVH0oooo0?ooo`0>
0?ooo`0306IVIP3oool0IVIV00<0IVIV2`3oool206IVIT00oooo003M0?ooo`D0003D1`00002[0?oo
o`80IVIV403oool406IVIPd0oooo00<0IVIV0?ooo`3oool0303oool406IVIPl0oooo00<0IVIV0?oo
o`3oool0?P3oool00=h0oooo10000=@600000:d0oooo0`1VIVH90?ooo`D0IVIV00<0oooo06IVIP1V
IVH03`3oool206IVIPL0oooo1@1VIVH20?ooo`80IVIV403oool206IVIP@0oooo101VIVHf0?ooo`00
g`3oool50000e0030000003oool0oooo0;00oooo0P1VIVH50?ooo`<0IVIV1`3oool206IVIPl0oooo
0P1VIVH20?ooo`@0IVIV2@3oool00`1VIVH0oooo0?ooo`0>0?ooo`H0IVIV>@3oool00=l0oooo00<0
00000000e0000=@00`000=Bc0?ooo`H0IVIV303oool00`1VIVH0oooo0?ooo`0=0?ooo`8000000P1V
IVH=0?ooo`0306IVIP3oool0oooo00`0oooo101VIVHl0?ooo`00g`3oool2000000L0003D[`3oool4
06IVIPl0oooo0P1VIVH:0?ooo`@0IVIV00<0EOl00000003oool03`3oool00`1VIVH0oooo0?ooo`07
0?ooo`@0IVIV0`3oool00`1VIVH0oooo0?ooo`0j0?ooo`00gP3oool4000000H0003D[03oool406IV
IP80oooo0P1VIVH?0?ooo`80IVIV1P3oool406IVIP<0oooo0P1Eo`000`1VIVH0oooo0?ooo`0>0?oo
o`0306IVIP3oool0oooo00<0oooo101VIVH70?ooo`0306IVIP3oool0oooo03T0oooo003N0?ooo`@0
0000103oool40000e:T0oooo00<0IVIV0?ooo`3oool01@3oool306IVIPh0oooo201VIVH60?ooo`80
EOl000<0oooo06IVIP1VIVH03P3oool706IVIP/0oooo00<0IVIV0?ooo`3oool0>03oool00=h0oooo
10000000103oool0003D0000e03oool40000e;<0oooo0P1VIVH<0?ooo`D0IVIV2P3oool205Go0080
oooo0P1VIVH:0?ooo`@0IVIV00<0oooo06IVIP3oool03`3oool00`1VIVH0oooo0?ooo`0g0?ooo`00
gP3oool4000000T0003D/`3oool206IVIPL0oooo101VIVH40?ooo`80IVIV2@3oool205Go00<0oooo
0P1VIVH60?ooo`@0IVIV1@3oool00`1VIVH0oooo0?ooo`0>0?ooo`0306IVIP3oool0oooo0080oooo
101VIVH`0?ooo`00g`3oool6000000L0003D/`3oool206IVIP<0oooo101VIVH80?ooo`80IVIV203o
ool205Go00D0oooo00<0IVIV0?ooo`1VIVH0101VIVH90?ooo`0306IVIP3oool0oooo00h0oooo1@1V
IVHc0?ooo`00g`3oool3000000030?ooo`0000000000008000001@000=Bd0?ooo`D0IVIV303oool2
06IVIPL0oooo00<0EOl00?ooo`3oool00`3oool406IVIPh0oooo00<0IVIV0?ooo`3oool02P3oool5
06IVISH0oooo003P0?ooo`P000000P3oool20000e;40oooo1P1VIVH?0?ooo`80IVIV1P3oool00`1E
o`00oooo0?ooo`0406IVIP030?ooo`1VIVH0IVIV00l0oooo00<0IVIV0?ooo`3oool01@3oool506IV
IP@0oooo00<0IVIV0?ooo`3oool0<`3oool00>40oooo1P0000050000e:l0oooo0`1VIVH50?ooo`80
IVIV3P3oool306IVIP030?ooo`1VIVH0IVIV0080EOl00P1VIVH60?ooo`80IVIV3P3oool206IVIP03
0?ooo`1VIVH0IVIV00@0IVIV2@3oool00`1VIVH0oooo0?ooo`0b0?ooo`006P3oool7000000D0oooo
0`000000103oool000000000000000020?ooo`D000000`3oool2000000@0oooo1000000;0?ooo`D0
00000P3oool00`000000oooo0?ooo`020?ooo`@00000103oool2000000<0oooo0P0000040?ooo`@0
0000103oool2000000<0oooo0P0000030?ooo`800000103oool4000005`0oooo0P0000060000e003
0000003oool0oooo0;H0oooo0P1VIVH>0?ooo`@0IVIV00<0oooo05Go001Eo`002P3oool00`1VIVH0
oooo0?ooo`0;0?ooo`@0IVIV@`3oool001X0oooo0P0000040?ooo`8000000`3oool200000080oooo
0`0000020?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000P3oool2000000T0oooo
0P0000030?ooo`@000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80
00000`3oool200000080oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`80
00000`3oool00`000000oooo0?ooo`1H0?ooo`P0003D0P00002i0?ooo`80IVIV2P3oool406IVIP04
0?ooo`1VIVH0oooo0?ooo`80EOl02`3oool00`1VIVH0oooo0?ooo`060?ooo`@0IVIV0`3oool00`1V
IVH0oooo0?ooo`110?ooo`006P3oool2000000D0oooo0P0000020?ooo`8000000`3oool200000080
oooo0P0000030?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000001`3oool2000000D0
oooo0`0000020?ooo`800000103oool200000080oooo0P0000030?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`800000103oool2000005T0
oooo20000=@200000;X0oooo0P1VIVH50?ooo`@0IVIV1P3oool00`1VIVH0000005Go000=0?ooo`04
06IVIP3oool0oooo0?ooo`@0IVIV203oool00`1VIVH0oooo0?ooo`100?ooo`006P3oool2000000D0
oooo0P0000020?ooo`8000000`3oool2000000L0oooo0P0000020?ooo`8000000P3oool2000000`0
oooo0P0000070?ooo`8000000P3oool2000000P0oooo0P0000030?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`800000GP3oool70000e003
0?ooo`00000000000;`0oooo0P1VIVH00`3oool0IVIV06IVIP0206IVIPP0oooo1@00000<0?ooo`D0
IVIV303oool00`1VIVH0oooo0?ooo`0o0?ooo`006P3oool2000000D0oooo0P0000020?ooo`800000
0`3oool2000000D0oooo0`0000030?ooo`8000000P3oool2000000`0oooo0P0000070?ooo`800000
0P3oool2000000P0oooo0P0000030?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000
0`3oool2000000<0oooo0P0000020?ooo`800000G@3oool50000e0@0000000<0oooo000000000000
^@3oool606IVIPd0oooo00@0EOl000000000000000001P3oool806IVIU00oooo000J0?ooo`800000
1@3oool2000000@0oooo1@0000030?ooo`@00000103oool200000080oooo0P00000<0?ooo`800000
1`3oool200000080oooo200000020?ooo`8000000`3oool200000080oooo0P0000040?ooo`800000
0P3oool2000000<0oooo0P0000030?ooo`8000000P3oool8000005L0oooo10000=@30?ooo`D00000
]P3oool306IVIPD0oooo0P1VIVH;0?ooo`@0EOl000<000000?ooo`3oool0101VIVH80?ooo`0306IV
IP3oool0oooo04d0oooo000J0?ooo`800000103oool2000000P0oooo0P0000020?ooo`8000001`3o
ool200000080oooo0P00000<0?ooo`800000103oool500000080oooo0P0000040?ooo`8000000P3o
ool2000000<0oooo0P0000020?ooo`800000103oool200000080oooo0P0000030?ooo`8000000`3o
ool200000080oooo0P0000040?ooo`800000EP3oool60000e0L00000_`3oool206IVIPT0oooo1@1E
o`0406IVIP`0oooo00<0IVIV0?ooo`3oool0C03oool001X0oooo1P0000050?ooo`8000000`3oool2
00000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3oool00P3oool2
000000H0oooo0P00000<0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000`3oool2
00000080oooo0P0000040?ooo`8000000P3oool2000000<0oooo0P0000030?ooo`8000000`3oool0
0`000000oooo0?ooo`020?ooo`800000EP3oool50000e0P00000`03oool206IVIPP0oooo0`1Eo`00
1@1VIVH0EOl00?ooo`3oool0IVIV05`0oooo000J0?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P000002
0?ooo`8000001`3oool2000000`0oooo0P0000020?ooo`8000000`3oool300000080oooo0P000003
0?ooo`8000000P3oool2000000<0oooo0`0000020?ooo`<000000P3oool2000000<0oooo0P000002
0?ooo`800000EP3oool40000e0<0000000<0oooo0000000000000`0000330?ooo`0306IVIP3oool0
oooo00<0oooo00<0IVIV05Go001Eo`000P1Eo`000`3oool0EOl00?ooo`020?ooo`0306IVIP3oool0
oooo05T0oooo000J0?ooo`800000103oool2000000@0oooo1@0000040?ooo`D000000`3oool20000
00@0oooo100000090?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`@00000103oool20000
00040?ooo`0000000000000000D0oooo100000040?ooo`80000000D0oooo00000000000000000?oo
o`04000000D0oooo1000001G0?ooo`80003D0P3oool200000080oooo100000350?ooo`D0IVIV00<0
0?l005Go001Eo`000P1Eo`000`3oool0EOl005Go00030?ooo`0306IVIP3oool0oooo05P0oooo000J
0?ooo`800000103oool2000002P0oooo0P0000050?ooo`800000RP3oool50000e0L00000`@3oool8
06IVIP80oooo101Eo`00103oool000000000001Eo`1N0?ooo`006P3oool2000000@0oooo0P00000E
0?ooo`8000004P3oool2000000<0oooo0P00002;0?ooo`D0003D1P0000320?ooo`0306IVIP3oool0
oooo00@0oooo00<0IVIV00000000000010000002002Ic003003o001Eo`00oooo05d0oooo000J0?oo
o`L000005P3oool2000001<0oooo1@00002=0?ooo`H0003D00<000000?ooo`3oool0b`3oool205Go
0080oooo1@0000000`1Eo`00oooo0?ooo`1L0?ooo`00g`3oool60000e<d0oooo00<0EOl0003o003o
ool010000002002Ic00305Go003oool0oooo05`0oooo003O0?ooo`03000000000=@0003D00H0003D
b@3oool205Go00030?ooo`00000000000080000000@0oooo0000000000000000GP3oool00=h0oooo
100000060000e<P0oooo0P1Eo`020?ooo`@000000`3oool2000005d0oooo003N0?ooo`@000000P3o
ool00`000=@0oooo0000e0030000e<H0oooo0P1Eo`040?ooo`050000003oool0oooo0?ooo`00o`00
0P1Eo`1M0?ooo`00gP3oool4000000040?ooo`000=@0003D0?ooo`@0003Da@3oool205Go00T0oooo
0`1Eo`1M0?ooo`00gP3oool4000000T0003Da03oool00`1Eo`0000000?ooo`070?ooo`@0EOl000<0
0?l00?ooo`3oool0FP3oool00=l0oooo1@0000000`3oool0003D0000e0050000e<80oooo00<00?l0
05Go000000001`3oool00`00o`00EOl005Go000305Go05`0oooo003P0?ooo`<0000000@0oooo0000
0000000000001@000=C00?ooo`@0EOl0103oool2000000040?ooo`000000000005Go0080oooo0P1E
o`020?ooo`800000F03oool00>00oooo200000040000e;l0oooo1@1Eo`050?ooo`@000000P2Z0002
0000000305Go0000o`00ZUFZ0080ZUGo00<000000?ooo`3oool0E@3oool00>80oooo1@0000050000
e;h0oooo1@1Eo`060?ooo`80EOl0100000001@2Z000000000000002ZEOl000000080ZUGo00<00000
0?ooo`3oool0E@3oool00>D0oooo1`000=Bn0?ooo`0305Go0000o`00EOl00080EOl00P3oool30000
000305Go0000000000000080000000<0oooo0000000000001@0000000`2ZEOl000000?ooo`1F0?oo
o`00hP3oool90000e0030000003oool0oooo0;/0oooo1P1Eo`020?ooo`0300000000ZZX00:ZZ00H0
000000@0oooo000000000000ojZZ0P0000000`2ZEOl000000000001G0?ooo`00hP3oool30000e003
000000000=@0003D0080003D00<000000?ooo`3oool0T@3oool50=d81R@0oooo1@1Eo`001@3oool0
EOl005Go003oool0000000<00:ZZ100000000`3oool000000?ooo`02000000040?nZZP0000000000
0:YEo`<00000EP3oool00=P0oooo00<000000?ooo`3oool01P3oool40000e003000000000=@0003D
0080003D00<000000?ooo`3oool0QP3oool?0=d81R@0oooo0P1Eo`002@00o`00oooo05Go001Eo`00
oooo05Go003oool000000?nZZP07000000<0oooo0P0000001@3oZZX00000000000000000ZUGo0080
0000EP3oool00=L0oooo0P0000060?ooo`T0003D100000210?oooa@0g@P6903oool205Go0080oooo
0`0000000`00o`00EOl00?ooo`0900000080oooo0P0000020?nZZP050000003oZZX000000:YEo`00
0000E`3oool00=H0oooo0P0000060?ooo`T0003D0`3oool200000880oooo4@3M20HU0?ooo`80EOl0
0P3oool40000000305Go0000000000000080000000@0ojZZ000000000000EJ[o100000000`3oool0
0000000000020?nZZP030000003oZZX0ojZZ00800000E`3oool00=D0oooo0`0000060?ooo`L0003D
0`3oool400000880oooo403M20HS0?ooo`040000003oool0EOl005Go00H0oooo0`00000205Go00D0
000000@0EJ[o000000000000oooo3000001E0?ooo`00e03oool4000000D0oooo0P000=@00`3oool0
003D0000e0020000e0<0oooo1@0000220?ooo`l0g@P6903oool00`000000EOl005Go00060?ooo`80
00000`1Eo`00103oool000000?nZZP3oZZX200000080EJ[o00D000000?ooo`000000oooo00000003
0?nZZP0300000000ZZX000000080EOl00`00001C0?ooo`00d`3oool5000000D0oooo1@000=@20000
00030?ooo`000000000000@00000P`3oool=0=d81R40oooo1@0000000`1Eo`000000000000020000
00<0oooo0P00000305Go0080oooo00<000000?nZZP3oZZX01@0000020?ooo`8000000P3oZZX20000
00030?ooo`000000EOl00080EOl00`00001B0?ooo`00dP3oool5000000H0oooo0P000=@30?ooo`P0
0000P@3oool?0=d81R<0oooo101Eo`000`00o`00000000000003000000<0oooo00<0EOl0003o001E
o`000`3oool3000000L0oooo00D000000?nZZP3oZZX0ojZZ000000020?ooo`8000001@1Eo`1B0?oo
o`00d@3oool600000940oooo403M20HT0?ooo`@0EOl000<00?l00000003oool00`3oool300000080
EOl000<0oooo05Go003oool00P3oool2000000P0oooo00@000000?nZZP00000000000`3oool0101E
o`00000005Go001Eo`020?ooo`80EOl0D@3oool00=00oooo1`00002>0?ooo`L0g@P6103oool70=d8
1R<0oooo1P1Eo`000`3oool000000?ooo`020?ooo`050000001EZZX0EJZZ0000001Eo`000`00000=
0?ooo`<00000103oool205Go00050?ooo`1Eo`00EOl00?ooo`00o`000`1Eo`1?0?ooo`00<`3oool2
0000e0<0oooo10000=@>0?ooo`@000000P3oool2000007d0oooo2000002;0?ooo`L0g@P61`3oool6
0=d81R80oooo1`1Eo`080?ooo`<0EOl01000000C0?ooo`80EOl000<0oooo05Go001Eo`000`3oool0
1000o`00EOl000000000001=0?ooo`00<P3oool20000e080oooo10000=@>0?ooo`H0000000@0oooo
0000000000000000O03oool8000008T0oooo1`3M20H:0?ooo`@0g@P68P3oool2000000@0EOl000<0
0?l005Go0000o`001P3oool01P00o`00EOl005Go001Eo`000?l00?ooo`@000004P3oool0101Eo`00
0?l00?ooo`3oool205Go00030000003oool0oooo00<0000000<0EOl00?ooo`3oool0BP3oool00380
oooo0P000=@0103oool0003D0000e0000=@=0?ooo`D000000P3oool5000007`0oooo2@0000260?oo
o`L0g@P63P3oool20=d81R80oooo0P1Eo`00100007L0000005Go003oool305Go00L0oooo0P1Eo`00
103oool0000000000000o`0205Go0003003o00000000oooo01@0oooo0P00000205Go0080000000<0
oooo0000003oool00P1Eo`000`00o`00oooo0?ooo`180?ooo`00<@3oool20000e0040?ooo`000=@0
003D0000e0d0oooo100000040?ooo`@00000O03oool:000008<0oooo1`3M20HA0?ooo`030=d81P3o
ool0oooo0200oooo0P000000101EE@0000000000001EEOl3000000L0oooo0P1Eo`00103oool0EOl0
05Go003oool405Go01H0oooo00<0000005IFEP000000100000030?ooo`80EOl000<00?l00?ooo`3o
ool0A`3oool00340oooo10000=@A0?ooo`8000000`3oool3000007d0oooo2P0000210?ooo`L0g@P6
=P3oool700000080EOl000<000000?ooo`3oool0103oool01000o`00EOl00?ooo`3oool205Go0003
0?ooo`1Eo`00EOl00080EOl05`3oool7000000<0oooo0`1Eo`000`00o`00oooo0?ooo`150?ooo`00
<@3oool60000e0P0oooo0P0000001@3oool00000000000000000oooo0080000000<0oooo00000000
00000`00001l0?ooo`/00000OP3oool70=d81SP0oooo0P0000030?ooo`80000000D0EOl000000000
0000ZZ[o000000040?ooo`03003o001Eo`00EOl00080oooo00<0EOl00?ooo`00o`00101Eo`0G0?oo
o`P00000103oool305Go04H0oooo000c0?ooo`D0003D1`3oool6000000030?ooo`000000000000<0
0000OP3oool<000007`0oooo1P3M20I00?ooo`L000000P3oool200000080EOl00P3oool205Go0003
0?ooo`1Eo`00EOl000<0EOl05P3oool3000000050?nZZP00000000000000003oool00P0000050?oo
o`<0EOl000<000000?ooo`3oool0@@3oool003@0oooo1`000=@30?ooo`D000000P3oool500000800
oooo2`00001i0?ooo`H0g@P6@P3oool010000000EOl00000002UYJD4000000030?ooo`0000000000
00<000000P3oool905Go01@0oooo0P0000001034a<@000000000003oool2000000P0oooo1@000012
0?ooo`00=03oool20000e080oooo10000=@5000000030?ooo`000000000000@00000Q@3oool70000
07L0oooo1`3M20I40?ooo`030000001Eo`00000000/00000103oool205Go00030000001Eo`00oooo
0080EOl09P3oool2000004<0oooo000e0?ooo`80003D0P3oool50000e0030?ooo`000000000000@0
0000Q`3oool800000440oooo2P000=@700000280oooo1`3M20I60?ooo`0305Go00000000YJFU0080
00001P3oool500000080oooo0P1Eo`00103oool0000005Go0000000205Go06/0oooo000e0?ooo`<0
003D00@0oooo0000e0000=@000001P000=B:0?ooo`8000000P3oool400000440oooo1@000=@20?oo
o`T00000803oool70=d81TP0oooo1@0000070?ooo`030000003oool0000000@0oooo0P1Eo`020?oo
o`8005Go00<0000005Go003oool0JP3oool003H0oooo1@000=@30?ooo`D0003DR03oool3000000@0
oooo0P0000100?ooo`D0003D0P3oool:000001d0oooo1`3M20I:0?ooo`@000003@3oool400000003
003o00000000000000<0000000<0EOl005FZZP0000001000001U0?ooo`00=`3oool40000e0@0oooo
0P0000020000e8P0oooo0P0000170?ooo`D0003D00<0oooo0000000000001@0000020?ooo`800000
6P3oool70=d81Td0oooo1000000=0?ooo`030000000A0000000000X000000`1EZ_l2000006@0oooo
000f0?ooo`8000000`000=@00`3oool000000000000300000080003D0`3oool20000e880oooo0`00
00180?ooo`D0003D00<000000000e0000=@00P00000M0?ooo`L0g@P6H`3oool205Go0080000000<0
oooo0000000000000P0000000`00o`0000000000000305FZo`030000003oool0oooo0680oooo000e
0?ooo`<0000000@0oooo0000e0000=@0003D0`0000000`3oool0003D0000e0030000e0030?ooo`00
0=@0003D0880oooo0P00001:0?ooo`P0003D6`3oool70=d81VD0oooo00D0EOl0000000000000VLbI
0?ooo`050000000305Go000000000000008000000P1EZ_l00`000000oooo0?ooo`1Q0?ooo`00=@3o
ool2000000030?ooo`000000000000@0003D0`3oool70000e840oooo0`00001:0?ooo`0300000000
0=@0003D00@0003D00@000000?ooo`000=@0003D5`3oool50=d81SL0oooo1`00000Y0?ooo`<00000
0`3oool01P000000ojZZ000000000000oooo05Go008000000P1EZ_l2000006@0oooo000d0?ooo`80
000000@0oooo00000000000000000P3oool40000e0030?ooo`000=@0003D0080oooo1@000=Ao0?oo
o`800000BP3oool4000000P0003D5`3oool20=d81SP0oooo2`00000V0?ooo`80000000<0EOl00000
000000000P3oool00`000000ojZZ000000020000000405Go00000000000000000080EJ[o00<00000
0?ooo`3oool0HP3oool003@0oooo100000060?ooo`D0003D0`3oool50000e0<0oooo0P000=Ah0?oo
o`<00000B@3oool3000000<0oooo1`000=@20?ooo`80003DB`3oool4000000L0oooo1000000S0?oo
o`80000000<0EOl00000000000000P0000002@3oool00000000000000000<oo<0000001Eo`000?l0
05FZZP0305FZo`030000003oool0oooo0680oooo000c0?ooo`@000002@3oool50000e0040?ooo`00
0=@0003D0?ooo`@0003D00<0oooo0000e0000=@0M`3oool3000004X0oooo0`0000060?ooo`P0003D
BP3oool3000000/0oooo0`00000T0?ooo`80EOl000<000000?ooo`0000001P3oool7000006@0oooo
000c0?ooo`<00000303oool20000e080oooo0P000=@30?ooo`D0003DM`3oool2000004`0oooo1@00
00000`3oool000000000e0080000e4T0oooo0`00000=0?ooo`<00000;P3oool205Go00800000I`3o
ool003<0oooo1000000;0?ooo`H0003D1@3oool30000e7H0oooo0`00001=0?ooo`L00000103oool5
0000e4L0oooo0`0000050?ooo`@000001P3oool3000002`0oooo0`1Eo`000`3oool000000000001V
0?ooo`00<`3oool5000000`0oooo1P000=@40?ooo`<0003DGP3ooolD000000<0oooo0P00001?0?oo
o`H000000P3oool2000000<0oooo0`000=A60?ooo`8000001@3oool200000080oooo0P0000060?oo
o`800000;03oool305Go00030000003oool0oooo06H0oooo000d0?ooo`H000003@3oool50000e080
oooo10000=AG0?ooob000000CP3oool2000000030?ooo`00000000000080000000<0oooo00000000
00001P000=A50?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000:`3oool505Go06L0
oooo000d0?ooo`8000000P3oool4000000h0oooo10000=@20?ooo`80003DDP3oool;000001@0oooo
2`00001<0?ooo`8000002@000=A70?ooo`8000001@3oool2000000@0oooo0P0000060?ooo`800000
:P3oool00`00o`00EOl00?ooo`0305Go06L0oooo000e0?ooo`8000000P3oool5000000h0oooo0`00
0=@20?ooo`80003DC@3oool900000200oooo2@0000170?ooo`80003D0P0000080000e4H0oooo0P00
000<0?ooo`8000001`3oool2000002T0oooo0P1Eo`001@3oool0EOl0003o001Eo`000?l006H0oooo
000e0?ooo`<0000000@0oooo000000000000oooo1P00000;0?ooo`H0003DBP3oool7000002X0oooo
1`00000P0?oooaH000003P3oool80000e08000000P000=A60?ooo`8000002`3oool2000000P0oooo
0P00000Y0?ooo`80EOl000<0oooo05Go001Eo`000P1Eo`1V0?ooo`00=P3oool5000000<0oooo1@00
000<0?ooo`D0003DAP3oool600000380oooo1P00000M0?oooaD00000303oool20000e0030?ooo`00
0=@0003D00<0003D0`3oool5000004D0oooo0P0000090?ooo`<000002@3oool2000002T0oooo0P1E
o`000`3oool0EOl005Go001X0?ooo`00=`3oool4000000H0oooo0P00000?0?ooo`80003DA03oool5
000003P0oooo1@00000L0?oooa8000003P3oool20000e0030?ooo`000=@0003D00@0003D1@3oool3
000004@0oooo0P00000:0?ooo`8000002@3oool2000002L0oooo100000000`3oool0EOl005Go001X
0?ooo`00>03oool3000000D0oooo100000040?ooo`800000203oool20000e480oooo1@00000l0?oo
o`D000006P3ooolA000000l0oooo2@000=@8000004@0oooo0P0000060?ooo`8000000`3oool20000
00P0oooo0P00000X0?ooo`0305Go00000000000000P00000H`3oool003T0oooo0`0000050?ooo`H0
000000<0oooo0000000000001P3oool40000e400oooo100000120?ooo`@00000603oool?00000140
oooo10000=@20?ooo`X00000A@3oool2000000H0oooo0P0000030?ooo`800000203oool2000002L0
oooo0P1Eo`000`3oool0000000000005000000030:ZZo`00000000000680oooo000k0?ooo`<00000
0`3oool2000000030?ooo`000000000000@000001@3oool40000e3l0oooo100000160?ooo`@00000
5@3oool?00000140oooo0P000=@40?ooo`H000000P3oool3000004D0oooo0P0000060?ooo`800000
0`3oool2000000P0oooo0P00000W0?ooo`80EOl00P0000000`1EojX0000000000002000000040:ZZ
o`000000000000000680oooo000l0?ooo`@0000000<0oooo000000000000103oool400000080oooo
1P000=@n0?ooo`<00000BP3oool300000140oooo4000000B0?ooo`<0003D103oool3000000030?oo
o`000000000000@00000A`3oool2000000H0oooo0P000000103oool000000000000000070?ooo`80
00009`3oool205Go00060?ooo`000000oooo0?ooo`000000ojZZ0`0000000`2ZZ_l000000?ooo`1R
0?ooo`00?P3oool5000000D0oooo100000030000e003000000000=@0003D03d0oooo1000001<0?oo
o`@00000303oool7000000030?ooo`000000000000P000004`3oool60000e003000000000=@0003D
00H00000B@3oool2000000L0oooo100000080?ooo`8000009`3oool205Go00@0oooo00L000000?nZ
ZP000000ojZZ0000002ZZ_l0000006<0oooo00100?ooo`H000000P3oool2000000@0003D00@00000
0000e0000=@0003D?03oool300000500oooo0`0000070?ooo`P000001@3oool8000001D0oooo2@00
0=@3000004`0oooo0P00000A0?ooo`800000:03oool00`1Eo`000?l00?ooo`030?ooo`030000003o
ZZX0000000@00000H`3oool004<0oooo0P0000000`3oool0003D0000e0090000e3/0oooo1000001B
0?ooo`@000000P3oool8000000P0oooo1P00000G0?ooo`@0003D00H000000000e0000=@0003D0000
003oool20000e4`0oooo0`00000?0?ooo`<00000:03oool00`1Eo`00oooo0?ooo`030?ooo`<00000
I`3oool004<0oooo00<000000000e0000=@010000=@20?ooo`@0003D>`3oool3000005H0oooo2000
000<0?ooo`D00000603oool00`000000003D0000e0020000e0050?ooo`000=@0003D0000e03oool0
0P000=A=0?ooo`<000003@3oool3000002P0oooo00<0000005Go003oool0KP3oool004<0oooo1@00
0=@2000000040?ooo`000=@0003D0000e0<00000>@3oool3000005P0oooo1000000@0?ooo`800000
6@3oool3000000030?ooo`000=@0003D00L0003D0P3oool20000e4X0oooo0`00000;0?ooo`<00000
:@3oool2000006l0oooo00120?ooo`<0003D00@0oooo0000e0000=@000001@000=@4000003L0oooo
0`00001J0?ooo`<00000403oool00`000000oooo0?ooo`0G0?ooo`<00000103oool;0000e4/0oooo
100000070?ooo`@00000:@3oool4000006h0oooo000o0?ooo`H0003D00<0oooo0000e0000=@00`00
0=@300000080oooo0P00000f0?ooo`<00000G03oool3000002X0oooo1@0000030?ooo`T0003DC@3o
ool;000009d0oooo000n0?ooo`D0003D0P3oool50000e080oooo100000000`3oool000000000000d
0?ooo`<00000GP3oool3000002X0oooo200000040?ooo`D0003DCP3oool7000009l0oooo000l0?oo
o`D0003D00<0oooo0000e0000=@010000=@60?ooo`D00000<`3oool300000600oooo0`00000Z0?oo
o`<0000000@0oooo00000000000000000P3oool2000000<0oooo0`000=Cc0?ooo`00>P3oool40000
e0030?ooo`000=@0003D00@0003D00<0oooo0000e0000=@0203oool400000380oooo0P00001R0?oo
o`800000:`3oool7000000030?ooo`000000000000H0003Dl`3oool003L0oooo1@000=@30?ooo`80
003D4@3oool200000340oooo0P00001T0?ooo`800000;03oool3000000L0003D0P0000020000e?<0
oooo000g0?ooo`@0003D103oool20000e0l0oooo1000000`0?ooo`<00000I03oool3000002/0oooo
0P000=@2000000<0003D00@000000000e0000=@000000P000=Cd0?ooo`00=`3oool30000e1D0oooo
1@00000`0?ooo`800000IP3oool2000002/0oooo0P000=@20?ooo`80003D0P3oool40000e?D0oooo
000f0?ooo`<0003D1@3oool50000e0T0oooo1`00000`0?ooo`8000002P3oool5000000@0oooo00@0
00000?ooo`3oool0oooo1P0000030?ooo`@000001@3oool300000080oooo0`000000103oool00000
0000000000030?ooo`<000000P3oool4000000<0oooo1@0000040?ooo`P000000P3oool6000000/0
oooo0P00000W0?ooo`80003D00@0oooo0000e0000=@0oooo20000=@200000?@0oooo000e0?ooo`@0
003D0`3oool60000e0T0oooo100000020?ooo`800000<03oool2000000`0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo0P0000040?ooo`8000000P3oool300000080oooo0P0000020?ooo`<0
00000P3oool3000000030?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`02000000<0
oooo0P0000030?ooo`800000103oool200000080oooo0P0000030?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`8000009`3oool20000e0030?ooo`000=@0003D00H0003D0`0000000`3oool0
00000000003c0?ooo`00=@3oool20000e0<0oooo10000=@;0?ooo`D000000P3oool200000300oooo
0P00000=0?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`800000103oool200000080oooo
0P0000030?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`8000001@3oool2000000<0oooo
0P0000040?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000`3oool00`000000oooo
0?ooo`020?ooo`8000002`3oool2000002H0oooo20000=@40?ooo`D00000l`3oool003@0oooo0P00
0=@20?ooo`@0003D2@3oool6000000040?ooo`00000000000?ooo`<00000<03oool2000000d0oooo
00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo00<0oooo0P0000040?ooo`800000
0P3oool2000000<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000050?ooo`800000
0P3oool2000000D0oooo0P0000030?ooo`8000000P3oool2000000L0oooo0`00000;0?ooo`800000
9P3oool30000e0040?ooo`000=@0003D0000e0X00000l`3oool003@0oooo1P000=@:0?ooo`D00000
0`3oool5000001P0oooo0`00000F0?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`800000
00<0oooo0000003oool00`3oool2000000@0oooo0P0000020?ooo`8000000`3oool2000000D0oooo
0P0000000`3oool00000000000030?ooo`8000001@3oool200000080oooo0P0000050?ooo`800000
0`3oool200000080oooo0P0000060?ooo`<00000303oool2000002D0oooo2P000=@200000080oooo
0`00003d0?ooo`00<`3oool50000e0h0oooo0P0000040?ooo`@000006@3oool600000180oooo0`00
000=0?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000@0
oooo0P0000020?ooo`8000000`3oool2000000L0oooo0`0000030?ooo`8000001@3oool200000080
oooo0P0000050?ooo`8000000`3oool200000080oooo0P0000040?ooo`@000003@3oool3000002<0
oooo1@000=@2000000@0oooo0P000000103oool0000000000000003e0?ooo`00<`3oool40000e0P0
oooo0P0000050?ooo`800000103oool3000001X0oooo2@00000?0?ooo`8000003P3oool010000000
oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`8000000P3oool2
000000<0oooo0P0000080?ooo`8000000`3oool2000000D0oooo0P0000020?ooo`8000001@3oool2
000000<0oooo0P0000020?ooo`8000000`3oool300000100oooo0P00003o0?ooobX0oooo000c0?oo
o`<0003D2@3oool2000000030?ooo`000000000000@000000`3oool3000001/0oooo3@00000;0?oo
o`8000003P3oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`3oool00P0000040?oo
o`8000000P3oool2000000<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000050?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool200000080oooo0P0000030?oo
o`800000103oool00`000000oooo0?ooo`0:0?ooo`800000o`3ooolZ0?ooo`00<`3oool40000e0P0
oooo1P000000103oool000000000003oool3000001<0oooo6P0000080?ooo`8000003P3oool00`00
0000oooo0?ooo`02000000D0oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool20000
00<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000040?ooo`<000000`3oool20000
00<0oooo0P0000030?ooo`@0000000<0oooo0000000000000`3oool2000000<0oooo0P00000<0?oo
o`800000o`3ooolZ0?ooo`00=03oool40000e0D0oooo1@0000040?ooo`D00000503ooolM000000D0
oooo0P00000>0?ooo`030000003oool00000008000001P3oool010000000oooo0000000000030?oo
o`<0000000@0oooo00000000000000000P3oool500000080oooo1@0000030?ooo`D00000103oool0
0`000000oooo0?ooo`020?ooo`D000001@3oool2000000030?ooo`000000000000D0oooo10000000
0`3oool000000?ooo`0;0?ooo`800000o`3ooolZ0?ooo`00=03oool20000e0030?ooo`000=@0003D
0080003D00<0oooo0000000000000`0000030?ooo`D00000803ooolB000000H0oooo0P00000>0?oo
o`040000003oool00000000000L0oooo00@000000?ooo`00000000003@3oool2000000d0oooo0P00
000a0?ooo`800000o`3ooolZ0?ooo`00=@3oool20000e0030?ooo`000=@0003D0080003D0P000000
0`3oool000000000000700000240oooo3`0000090?ooo`8000003P3oool4000000P0oooo0`00000>
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;`3oool200000?l0oooo:P3oool0
03D0oooo0`000=@00`3oool0003D0000e0040000e0D000009@3oool<000000`0oooo0P00000>0?oo
o`<000002@3oool3000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?oo
o`800000o`3ooolZ0?ooo`00=P3oool50000e0030?ooo`000=@0003D00@0003D00<000000?ooo`3o
ool0903oool800000100oooo0P00000>0?ooo`<000002@3oool3000002<0oooo0P00000Z0?ooo`80
0000o`3ooolZ0?ooo`00=P3oool00`000000003D0000e0020000e080oooo0P0000040000e2H0oooo
1@00000C0?ooo`<000002`3oool4000000/0oooo1000000Q0?ooo`800000:@3oool300000?l0oooo
:P3oool003D0oooo0`0000030000e0@0000000<0oooo0000e0000=@00P000=@U0?ooo`8000005`3o
ool2000006X0oooo0P00003o0?ooob/0oooo000e0?ooo`8000000P3oool30000e0030000003oool0
oooo0080oooo1`000=@j0?ooo`800000JP3oool200000?l0oooo:`3oool003@0oooo0P0000000`3o
ool00000000000050000e0<0oooo0P000=@00`3oool0003D0000e0030000e3T0oooo0P00001Z0?oo
o`800000o`3oool[0?ooo`00=03oool5000000<0oooo10000=@00`3oool0003D0000e0030?ooo`D0
003D>03oool2000006P0oooo0P00003o0?ooob`0oooo000c0?ooo`@000001`3oool50000e0<0oooo
0P000=@0103oool0003D0000e0000=@20?ooo`80003D<`3oool2000006P0oooo0P00003o0?ooob`0
oooo000c0?ooo`8000002`3oool50000e0030?ooo`000=@0003D00<0oooo1@000=@d0?ooo`800000
IP3oool200000?l0oooo;@3oool003<0oooo0P00000=0?ooo`80003D0P3oool20000e0@0oooo1000
0=@d0?ooo`<00000I03oool300000?l0oooo;@3oool003<0oooo0`00000<0?ooo`H0003D1@3oool3
0000e3D0oooo0P00001T0?ooo`800000o`3oool^0?ooo`00<`3oool4000000d0oooo1P000=@40?oo
o`<0003D=@3oool200000680oooo0P00000a0?ooo`L0003D0`000000103oool0000000000000003_
0?ooo`00=03oool5000000h0oooo1@000=@20?ooo`@0003D=03oool300000600oooo0`00000a0?oo
o`<0003D0`3oool800000>l0oooo000d0?ooo`80000000<0oooo0000000000000P00000?0?ooo`@0
003D0P3oool20000e3D0oooo0`00001N0?ooo`<00000<P3oool40000e08000000P000=@300000?80
oooo000e0?ooo`8000000P3oool4000000l0oooo0`000=@20?ooo`80003D=@3oool3000005`0oooo
0`00000c0?ooo`P0003D0P00003c0?ooo`00=@3oool3000000030?ooo`000000000000@000000P3o
ool2000000X0oooo1P000=@f0?ooo`<00000FP3oool3000003D0oooo00<000000000e0000=@01P00
0=Cc0?ooo`00=P3oool500000080oooo1P00000<0?ooo`D0003D=P3oool3000005P0oooo1P00000b
0?ooo`80000020000=Cc0?ooo`00=`3oool4000000@0oooo1000000?0?ooo`80003D=`3oool30000
05H0oooo2P00000;0?ooo`8000008P3oool4000000H0003D0P3oool20000e>l0oooo000h0?ooo`<0
00001@3oool4000000h0oooo0P000=@h0?ooo`@00000DP3oool4000000@0oooo1`0000080?ooo`@0
00007`3oool300000080oooo0P0000050000e0030?ooo`000=@0003D0>l0oooo000i0?ooo`<00000
1@3oool7000000P0oooo10000=@j0?ooo`<00000D03oool3000000T0oooo1`0000040?ooo`H00000
7`3oool7000000H0003Dl03oool003/0oooo0`0000030?ooo`80000000<0oooo0000000000000`00
00060?ooo`D0003D>`3oool4000004`0oooo1000000=0?ooo`L0000000<0oooo0000000000001P00
000O0?ooo`H000000P3oool00`000000003D0000e0350?ooo`<0IVIV:03oool003`0oooo10000000
0`3oool00000000000030?ooo`D0000000<0oooo0000e0000=@01@000=@n0?ooo`<00000BP3oool3
00000180oooo3`00000N0?ooo`@000001`000=C20?ooo`<0IVIV:P3oool003h0oooo1@0000030?oo
o`80000000@0oooo00000000000000000`000=@010000000oooo0000e0000=@o0?ooo`@00000AP3o
ool4000001H0oooo3P00000M0?ooo`80000020000=Bo0?ooo`D0IVIV:`3oool00400oooo20000002
0?ooo`@0003D0P0000020000e480oooo100000120?ooo`@000006@3oool>000001d0oooo1P000=@0
0`3oool0003D0000e02m0?ooo`<0IVIV0`3oool206IVIRX0oooo00130?ooo`04000000000=@0003D
0?ooo`L0003D00@000000000e0000=@0003DA03oool5000003`0oooo1@00000K0?oooa000000603o
ool80000e0800000_03oool306IVIPL0oooo00<0IVIV0?ooo`3oool0:03oool004@0oooo1P000=@2
0?ooo`D0003DA`3oool5000003P0oooo1@00000L0?oooa<000005P3oool80000e0<00000]`3oool4
06IVIPX0oooo0P1VIVHY0?ooo`00@`3oool40000e08000000`3oool40000e0030000003oool0oooo
04L0oooo1P00000b0?ooo`H000007P3ooolD000001D0oooo1@000=@00`3oool00000000000040000
0;@0oooo0P1VIVH?0?ooo`80IVIV:03oool00440oooo0P000=@00`3oool0003D0000e005000000<0
003D1000001;0?ooo`L00000:P3oool800000200oooo5P00000A0?ooo`@0003D0P3oool800000;40
oooo0`1VIVHB0?ooo`0306IVIP3oool0oooo02H0oooo000n0?ooo`P0003D0`3oool40000e0<0oooo
0P00001>0?ooo`T00000803oool=000004L0oooo10000=@20?ooo`D0000000<0oooo000000000000
[P3oool306IVIQH0oooo00<0IVIV0?ooo`3oool09@3oool003`0oooo1@000=@30?ooo`80003D00<0
oooo0000e0000=@00P000=@400000080oooo0P00001A0?ooo`/00000503oool;000000<0oooo1P00
00160?ooo`H0003D100000020?ooo`800000[03oool306IVIP030?ooo`1VIVH0oooo01D0oooo0P1V
IVHV0?ooo`00>P3oool40000e0030?ooo`000=@0003D00<0oooo1P000=@30?ooo`H00000EP3ooolP
000000P0oooo1`0000150?ooo`X0003D[03oool406IVIPD0oooo0P1VIVHE0?ooo`H0IVIV8@3oool0
03P0oooo10000=@30?ooo`80003D00<0oooo0000e0000=@00`000=@80?ooo`D00000F`3ooolD0000
00d0oooo200000160?ooo`T0003DZ@3oool306IVIPX0oooo00<0IVIV0?ooo`3oool04P3oool406IV
IR@0oooo000g0?ooo`<0003D1@3oool60000e0/0oooo1000001k0?ooo`X00000A@3oool00`000000
003D0000e0060000e080oooo0P000=BS0?ooo`80IVIV3P3oool00`1VIVH0oooo0?ooo`0>0?ooo`@0
IVIV0P3oool00`1VIVH0oooo0?ooo`0R0?ooo`00=P3oool30000e0H0oooo10000=@<0?ooo`D00000
NP3oool;000004@0oooo0`0000080000e0030?ooo`000=@0003D0:00oooo0`1VIVHA0?ooo`0306IV
IP3oool0oooo00/0oooo0`1VIVH50?ooo`80IVIV8`3oool003D0oooo10000=@30?ooo`H0003D303o
ool3000000030?ooo`000000000007/0oooo2`0000120?ooo`@0000000D0oooo000000000000003D
000000020?ooo`@0003DW@3oool306IVIQ@0oooo00<0IVIV0?ooo`3oool0203oool306IVIPT0oooo
00<0IVIV0?ooo`3oool08@3oool003@0oooo0P000=@0103oool0003D0000e03oool50000e0d0oooo
100000000`3oool000000000001n0?ooo`X00000@P3oool6000000@0003D00@0oooo0000e0000=@0
003DV@3oool706IVIQD0oooo0P1VIVH40?ooo`D0IVIV303oool00`1VIVH0oooo0?ooo`0P0?ooo`00
<`3oool20000e080oooo1@000=@>0?ooo`@000000`3oool2000007l0oooo2@0000130?ooo`H00000
1P000=@>0?ooo`@0g@P6QP3oool306IVIPD0oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH00000
0000000206IVIQ80oooo00<0IVIV0?ooo`3oool07`3oool00380oooo0`000=@20?ooo`<0003D3P3o
ool600000080oooo0P0000220?ooo`P00000A03oool7000000030?ooo`000=@0003D00h0oooo1`3M
20J00?ooo`<0IVIV2@3oool00`1VIVH0oooo0?ooo`0B0?ooo`80IVIV00<0<ol00000003oool0503o
ool00`1VIVH0oooo0?ooo`0N0?ooo`00<P3oool20000e0030?ooo`000=@0003D0080003D303oool5
00000080oooo0P000000103oool000000000000000240?ooo`H00000A@3oool4000000H0003D403o
ool70=d81W/0oooo0`1VIVH<0?ooo`0306IVIP3oool0oooo00l0oooo0`1VIVH0103oool0<ol003?o
000co`0D0?ooo`80IVIV7`3oool00340oooo1P000=@<0?ooo`D00000103oool5000008L0oooo1@00
00160?ooo`P0003D4`3oool70=d81WD0oooo0`1VIVH@0?ooo`0306IVIP3oool0oooo00/0oooo0`1V
IVH50?ooo`80<ol05@3oool00`1VIVH0oooo06IVIP0306IVIQX0oooo000a0?ooo`80003D0P3oool0
0`000=@0oooo0?ooo`0<0?ooo`040000003oool00000000000@0oooo100000290?ooo`@00000@P3o
ool80000e0800000603oool70=d81Vl0oooo0`1VIVHD0?ooo`0306IVIP3oool0oooo00L0oooo0`1V
IVH90?ooo`80<ol0503oool306IVIQd0oooo000a0?ooo`80003D303oool2000000D0oooo0P000004
0?ooo`<00000S03oool300000440oooo20000=@4000001T0oooo1`3M20IY0?ooo`H0IVIV503oool2
06IVIP@0oooo1@1VIVH<0?ooo`<0<ol03@3oool506IVIP030?ooo`1VIVH0IVIV01d0oooo003M0?oo
o`800000@03oool60000e0H00000703oool80=d81V80oooo0`1VIVH50?ooo`80IVIV503oool606IV
IQ40oooo0`0co`0:0?ooo`<0IVIV1P3oool206IVIQ`0oooo003N0?ooo`030000003oool0oooo06T0
oooo203M20IL0?ooo`<0IVIV2@3oool206IVIQ<0oooo0`1VIVHE0?ooo`80<ol01`3oool306IVIPX0
oooo00<0IVIV0?ooo`3oool06P3oool00?l0ooooC`3oool70=d81UL0oooo0`1VIVH<0?ooo`80IVIV
3`3oool306IVIP80oooo0P1VIVHD0?ooo`0306IVIP0co`00<ol00080000000@0oooo06IVIP1VIVH0
IVIV3P3oool00`1VIVH0oooo0?ooo`0I0?ooo`00o`3ooomB0?ooo`L0g@P6D@3oool306IVIQ00oooo
0P1VIVH;0?ooo`<0IVIV1P3oool00`1VIVH0oooo0?ooo`0A0?ooo`H000000P1VIVH@0?ooo`80IVIV
6P3oool00?l0ooooE@3oool70=d81TX0oooo1@1VIVHC0?ooo`80IVIV1P3oool506IVIPT0oooo0P1V
IVHA0?ooo`0306IVIP000000000000@000004P3oool00`1VIVH0oooo0?ooo`0H0?ooo`00j`3oool6
0000e0D00000H@3oool70=d81TH0oooo00<0IVIV0?ooo`3oool00P3oool00`1VIVH0oooo0?ooo`0C
0?ooo`0306IVIP3oool0oooo00<0IVIV3`3oool00`1VIVH0oooo0?ooo`0<0?ooo`<0IVIV0`3oool2
03?o00@000004@3oool00`1VIVH0oooo06IVIP0306IVIQ@0oooo003Z0?ooo`@0003D2000001T0?oo
o`L0g@P6B@3oool00`1VIVH0oooo0?ooo`0B0?ooo`@0IVIV4P3oool00`1VIVH0oooo0?ooo`080?oo
o`@0IVIV103oool203?o00050000000co`00<ol00?ooo`000000403oool406IVIQL0oooo003Z0?oo
o`@0003D1`00001X0?ooo`P0g@P6AP3oool00`1VIVH0oooo0?ooo`0?0?ooo`D0IVIV503oool00`1V
IVH0oooo0?ooo`050?ooo`<0IVIV1`3oool303?o000306IVIP0co`00<ol000h0oooo101VIVH00`3o
ool0IVIV06IVIP0G0?ooo`00jP3oool70000e0800000K@3oool80=d81T@0oooo00<0IVIV0?ooo`3o
ool02`3oool306IVIP@0oooo0P1VIVHD0?ooo`0406IVIP3oool0oooo0?ooo`<0IVIV2@3oool203?o
00030?ooo`0co`00oooo0080<ol0303oool306IVIPD0oooo00<0IVIV0?ooo`3oool05@3oool00>/0
oooo20000=Aa0?ooo`L0g@P6@P3oool206IVIPL0oooo101VIVH80?ooo`80IVIV4P3oool506IVIP`0
oooo0P0co`00103oool0<ol00?ooo`3oool303?o00@0000000<0oooo06IVIP1VIVH00`1VIVH90?oo
o`0306IVIP3oool0oooo01@0oooo003[0?ooo`<0003D00<000000000e0000=@00P000=Ad0?ooo`L0
g@P6@@3oool0101VIVH0oooo0?ooo`3oool306IVIPh0oooo00<0IVIV0?ooo`3oool03@3oool306IV
IP80oooo00<0IVIV0?ooo`3oool02P3oool203?o0080oooo00@0<ol00?ooo`3oool0oooo0P0co`00
0`000000<fJI03=VV@05000000`0oooo00<0IVIV0?ooo`3oool04`3oool00>X0oooo0P0000070000
e080oooo0P000=Ac0?ooo`L0g@P6?P3oool506IVIQ00oooo0P1VIVH;0?ooo`<0IVIV1P3oool00`1V
IVH0oooo0?ooo`090?ooo`80<ol00P3oool00`0co`00oooo0?ooo`020?ooo`80<ol00`0cIYT20000
00030:6QX@000000oooo00/0oooo0P1VIVHD0?ooo`00jP3oool4000000T0003DMP3oool70=d81SX0
oooo101VIVHC0?ooo`80IVIV1`3oool306IVIPT0oooo0P1VIVH90?ooo`80<ol00`3oool00`0co`00
oooo06IVIP0206IVIP80<ol00`0cIYT200000080XJ6Q00<000000?ooo`3oool02P3oool00`1VIVH0
oooo0?ooo`0B0?ooo`00jP3oool400000080oooo00<0003D0?ooo`3oool010000=Ai0?ooo`P0g@P6
=@3oool0101VIVH0oooo0?ooo`3oool206IVIQ<0oooo0P1VIVH30?ooo`@0IVIV303oool206IVIPP0
oooo0P0co`030?ooo`0403?o001VIVH0IVIV0?ooo`8000000P0co`0400000080XJ6Q00<000000?oo
o`3oool02P3oool206IVIP<0oooo00<0IVIV0?ooo`3oool03@3oool00>T0oooo1@0000020?ooo`<0
003D00@0oooo0000e0000=@0003DO03oool80=d81SL0oooo0P1VIVHC0?ooo`D0IVIV403oool00`1V
IVH0oooo0?ooo`050?ooo`80<ol000D0oooo06IVIP1VIVH0IVIV03?o00020?ooo`8000000P2ZEED6
000000030:6QX@000000oooo00`0oooo101VIVH@0?ooo`00j`3oool300000080oooo1`000=B00?oo
o`L0g@P6=P3oool00`1VIVH0oooo0?ooo`0=0?ooo`H0IVIV4`3oool206IVIP<0oooo0P1VIVH203?o
000506IVIP3oool0oooo0?ooo`0co`00200000000`2QXJ40000000000003000000T0oooo1@1VIVHC
0?ooo`00k03oool600000080oooo0`000=B30?ooo`L0g@P6=03oool00`1VIVH0oooo0?ooo`090?oo
o`@0IVIV1@3oool00`1VIVH0oooo0?ooo`0A0?ooo`D0IVIV00<0oooo03?o003oool00`3oool30000
0080d=3@0P000000102ZEED000000?nZZP0000020:6QX@<000001P3oool306IVIQP0oooo00110?oo
o`80003DZ`3oool5000000@0003DQP3oool70=d81PL0oooo0P3M20HY0?ooo`0306IVIP3oool0oooo
00H0oooo0`1VIVH80?ooo`80IVIV403oool406IVIP<0oooo0P0co`020?ooo`<000000`3@d=030000
00040:YEE@0000000000000000@0XJ6Q00@000000?ooo`3oool0oooo0`1VIVHK0?ooo`00@@3oool2
0000e:/0oooo0P000=@00`000000003D0000e0040000e8T0oooo1`3M20H40?ooo`<0g@P6:@3oool2
06IVIP<0oooo0`1VIVH<0?ooo`80IVIV3@3oool306IVIP<0oooo00<0IVIV0?ooo`3oool00P0co`00
0`3oool00000000000020=3@d00403?o003@d=00000000000080oooo0`0000000`3oZZX000000:6Q
X@020:6QX@040000001VIVH0IVIV06IVIQh0oooo00110?ooo`80003DZ`3oool80000e0030000003o
ool0oooo08X0oooo1`3M20H00`3oool0g@P60=d81P030=d81RP0oooo101VIVH@0?ooo`80IVIV2@3o
ool306IVIPL0oooo00<0IVIV03?o000co`000P3oool3000000030=3@d00co`00000000@0oooo00D0
00000?nZZP000000ojZZ000000030:6QX@030000003oool0oooo01l0oooo00110?ooo`80003DZ@3o
ool90000e0030000003oool0oooo08h0oooo2`3M20HT0?ooo`H0IVIV4P3oool206IVIP<0oooo1@1V
IVH:0?ooo`0306IVIP0co`00<ol00080oooo00<000000?ooo`0000000P0000050?ooo`040000003o
ZZX000000?nZZP80000000<0XJ6Q0000000000008@3oool00440oooo0P000=BY0?ooo`L0003D1000
002B0?ooo`X0g@P69`3oool206IVIQ<0oooo101VIVH>0?ooo`80<ol000<0IVIV0?ooo`3oool0103o
ool203?o0080oooo0P1VIVH01@000000ojZZ000000000000oooo00<000008P3oool00440oooo0P00
0=BY0?ooo`D0003D0P3oool4000009<0oooo2P3M20HW0?ooo`80IVIV3`3oool506IVIQ00oooo0P0c
o`000`3oool0IVIV0?ooo`040?ooo`80<ol00P1VIVH20?ooo`040000003oZZX00000000002H0oooo
00110?ooo`80003DZ@3oool40000e0<0oooo1000002C0?ooo``0g@P69P3oool206IVIP`0oooo0`1V
IVH30?ooo`80IVIV3`3oool203?o00040?ooo`1VIVH0IVIV0?ooo`<0IVIV0P0co`040?ooo`030000
003oZZX0000002L0oooo00110?ooo`80003DZ03oool60000e0H00000TP3oool>0=d81RL0oooo00<0
IVIV0?ooo`3oool01P3oool306IVIPL0oooo0P1VIVH80?ooo`030000003oool0oooo00<0oooo00<0
<ol00?ooo`3oool0101VIVH20?ooo`030000000co`00000000<0oooo0P3oZZX00`000000oooo0?oo
o`0U0?ooo`00@@3oool20000e:L0oooo10000=@20?ooo`H00000T`3oool?0=d81RL0oooo00<0IVIV
0?ooo`3oool00P3oool306IVIP/0oooo0P1VIVH60?ooo`030000001EZ_l0000000<0oooo0P0co`03
06IVIPD0oooo00@0000003?o0000000000000P3oool3000002L0oooo00110?ooo`80003DY`3oool4
0000e080oooo1@00002D0?oooa40g@P69@3oool506IVIPl0oooo0P1VIVH00`3oool0000000000004
0000000405FZo`000000000006IVIP80<ol0203oool4000002`0oooo00110?ooo`80003DY`3oool4
0000e0L00000T`3ooolC0=d81R80oooo0`1VIVH00`3oool0IVIV0?ooo`0A0?ooo`80IVIV0P3oool6
0000000305FZo`000000<ol000T0oooo0P0co`000`000000oooo0?ooo`0[0?ooo`00@@3oool20000
e:L0oooo10000=@200000080003DW@3oool>0=d81RD0oooo0P1VIVHA0?ooo`D0IVIV0P0000001@1E
Z_l00000000000000000<ol000T0oooo0P0co`02000002`0oooo00110?ooo`80003DZ03oool70000
e:P0oooo103M20HU0?ooo`80IVIV3P3oool406IVIPH0oooo00<0000003?<o`0co`000P0000080?oo
o`80<ol00P00000/0?ooo`00@@3oool20000e:P0oooo00<000000000e0000=@01@000=CA0?ooo`03
06IVIP3oool0oooo00T0oooo101VIVH80?ooo`<0<ol01@0000050?ooo`<0<ol000<0ZZ[o0000003o
ool0:`3oool00440oooo0P000=BW0?ooo`@000001@000=CB0?ooo`80IVIV103oool506IVIP/0oooo
100co`04000000040:ZZo`00000000000?ooo`<0<ol01000000/0?ooo`00>`3oool;0000e:@0oooo
0P0000020?ooo`D0003D0P3oool20000e<l0oooo1P1VIVH>0?ooo`H0<ol00P0000000`2ZZ_l00000
00000002000000H0<ol0;@3oool003/0oooo2`000=BS0?ooo`@000000`3oool70000e<h0oooo101V
IVH?0?ooo`P0<ol000@0oooo000000000000ZZ[o0P0000000`0co`0000000000000403?o02d0oooo
000l0?ooo`X0003DY@3oool3000000030?ooo`000=@0003D00D0003D3@3oool20=d81[l0oooo0P1V
IVH@0?ooo`@0<ol000<0oooo03?o000co`000P0co`030?ooo`<000000P0co`020000000403?o003o
ool0oooo03?o02d0oooo000l0?ooo`T0003DY`3oool6000000030?ooo`000=@0003D0080003D303o
ool30=d81/l0oooo0`0co`020?ooo`80<ol000<0oooo03?o000co`00103oool200000080<ol000H0
oooo0000000co`0000000?ooo`0co`0]0?ooo`00?03oool90000e:L0oooo1`0000020?ooo`80003D
3@3oool30=d81XH0oooo2000000n0?ooo`@0<ol00`3oool403?o00H0oooo0P0000020?ooo`80<ol0
00<000000?ooo`0co`00;@3oool003d0oooo20000=BW0?ooo`80000000<0oooo0000000000001P00
0=@>0?ooo`<0g@P6P`3oool<000003/0oooo0`0co`040?ooo`80<ol000<0oooo03?o000co`001@3o
ool203?o00030000003oool0oooo0080<ol00P3oool00`0co`00oooo0?ooo`0[0?ooo`00?@3oool8
0000e:T0oooo00<000000000e0000=@01@000=@00`000000oooo0?ooo`0=0?ooo`<0g@P6P03oool5
000000H0oooo1@00000g0?ooo`<0<ol01@3oool203?o008000000P0co`040?ooo`<0<ol00`3oool0
100co`00oooo0?ooo`3oool203?o02`0oooo000m0?ooo`L0003DZP3oool70000e0800000403oool3
0=d81Wh0oooo0`00000<0?ooo`<00000=@3oool303?o00H0oooo0P0co`00100000000:[o00000000
00040?ooo`80<ol00`3oool203?o00<0oooo0P0co`0/0?ooo`00?@3oool70000e:X0oooo1`000=@2
00000140oooo0`3M20Il0?ooo`<000003P3oool3000003<0oooo0P0co`070?ooo`80<ol000@0oooo
00000000Z_l00:[o0P0000020?ooo`80<ol0103oool203?o00<0oooo0P0co`0/0?ooo`00?P3oool6
0000e:P0oooo1`000=@400000180oooo0`3M20Ij0?ooo`<000001@3oool8000000<0oooo0`00000`
0?ooo`@0<ol01P3oool303?o00030?ooo`00Z_l00:[o00800:[o0P00000203?o00D0oooo0P0co`04
0?ooo`0303?o003oool0oooo02X0oooo000n0?ooo`H0003DZ03oool40000e0D0oooo0P00000C0?oo
o`<0g@P6N@3oool2000000H0oooo0P00000:0?ooo`800000:03oool3000000<0oooo100co`070?oo
o`<0<ol00P3oool00`0cI/`00:[o002Zo`02002Zo`030000000co`00<ol000@0oooo0P0co`050?oo
o`0303?o00000000oooo02X0oooo000n0?ooo`D0003DZ03oool60000e0H00000503oool30=d81WL0
oooo0P0000080?ooo`8000002P3oool2000002H0oooo1P00000303?o00T0oooo0`0000020?ooo`03
03=Vc000Z_l0000000D00000103oool203?o00D0oooo00<0<ol0000000000000:P3oool003l0oooo
10000=BX0?ooo`<0003D00<0oooo0000000000001P00000E0?ooo`<0g@P6MP3oool2000000T0oooo
0P0000090?ooo`8000009`3oool400000080<ol000<000000?ooo`3oool01`3oool00`0co`000000
0:YEE@030:YEE@<000001@00Z_l200000080oooo0P0co`040?ooo`D00000:@3oool003l0oooo1000
0=C:0?ooo`<0g@P6M03oool3000000X0oooo0P0000080?ooo`<00000:03oool303?o00@000001`3o
ool00`0co`0000000:YEE@020:YEE@L000001000Z_l010000000oooo03?o000co`040?ooo`D00000
:@3oool003l0oooo10000=C;0?ooo`<0g@P6L`3oool2000000`0oooo0P0000080?ooo`8000009P3o
ool303?o0080oooo1P0000040?ooo`80<ol00`0000020:YEE@@0000000@0IS?<0000000000000000
0P00Z_l200000080<ol0103oool5000002T0oooo000o0?ooo`@0003Dc03oool30=d81W80oooo0P00
000=0?ooo`8000001`3oool2000002@0oooo100co`040?ooo`H000000P3oool303?o00@0000000<0
ZUEE0000000000002P0000000`0co`00oooo0?ooo`020?ooo`80000000<0oj[o000000000000:P3o
ool00400oooo0P000=C>0?ooo`<0g@P6L@3oool2000000h0oooo0P0000060?ooo`8000008@3oool5
03?o00030?ooo`0000000000008000000`3oool2000000<0oooo0`0co`030?ooo`0:0000002ZEED0
ZUEE0000002k^k/0<ol00000001V<l`0000005FZo`8000000P3oool00`000000<ol00?ooo`040?oo
o`800000;03oool00400oooo0P000=C?0?ooo`<0g@P6L03oool2000000P0oooo0P0000040?ooo`80
00001P3oool2000001h0oooo0P00000303?o00D0oooo00<0I/co0000000000000P0000060?ooo`80
<ol00`3oool200000080ZUEE00H000000;^k^`0co`00000006Hcc000000205FZo`80000000<0oooo
03?o000co`00<`3oool00400oooo0P000=C@0?ooo`<0g@P6K`3oool2000000P0oooo0P0000040?oo
o`8000001P3oool2000001h0oooo00@0000003?o000000000000203ooolC0000000603?o00000000
^k^k0000001V<l`000000P1EZ_l00`000000oooo03?o000d0?ooo`00@@3oool00`000=@0oooo0?oo
o`3?0?ooo`<0g@P6KP3oool2000000P0oooo0P0000040?ooo`8000001P3oool2000001/0oooo1P00
00000`1VIYT000000?ooo`080?ooo`030000001EZ_l00000008000000P0cI_l303=Vc0L000000`2k
^k/010000000IS?<00000000000205FZo`030000000co`00oooo03<0oooo003o0?oooaD0oooo0`3M
20I]0?ooo`<00000203oool200000080oooo0P0000060?ooo`<000006`3oool9000000P0oooo1P00
00000`0co`00oooo03=Vo`0B0000000303?o003oool0oooo0380oooo003o0?oooaH0oooo0`3M20I]
0?ooo`8000002@3oool4000000L0oooo0P00000M0?ooo`D0000000<0IVJI0000003oool0303oool2
03?o00@0000000@0VLbI0?ooo`3oool000000`2k^k/3000000@0EJ[o1@00000c0?ooo`00o`3ooolG
0?ooo`<0g@P6K03oool2000001@0oooo0P00000M0?ooo`L00000303oool303?o00<0000000D0VLbI
0?ooo`3oool0<ol0000000050;^k^`80000000<0^k^k0000000000000P0000000`0co`0000000000
000200000340oooo003o0?oooaP0oooo0`3M20I/0?ooo`8000004P3oool200000200oooo00<00000
0?ooo`3oool0303oool503?o00D000000P0co`060;^k^`050000002k^k/0^k^k0;^k^`0000000`0c
o`03000000040:ZZo`0000000000000002h0oooo003o0?oooaT0oooo0`3M20I[0?ooo`<00000403o
ool3000002h0oooo1@0co`001`3oool00000000000000000gMgM0000000co`000P0000050;^k^`03
0000002k^k/00000008000000`0co`000`000000ZZ[o00000002000000040:ZZo`00000000000000
02`0oooo003o0?oooaX0oooo0`3M20I[0?ooo`<000003P3oool3000002h0oooo0P0co`00103oool0
<ol003?o003oool2000000030?ooo`00000000000080000000<0<ol00;^k^`2k^k/00`2k^k/40000
00@0<ol00P0000020:ZZo`@0000000@0ZZ[o0000000000000000:P3oool007H0oooo0`0000060?oo
o`800000V@3oool30=d81V/0oooo0`00000<0?ooo`<00000;@3oool703?o008000000P3oool203?o
0080000000@0<ol0000000000000^k^k100000000`3oool0<ol003?o000403?o008000000P2ZZ_l0
0`000000oooo00000007000002L0oooo001h0?ooo`8000001@3oool2000009X0oooo0`3M20H50?oo
o`030=d81P3oool0oooo06<0oooo1@0000060?ooo`D00000:`3oool200000080<ol00P3oool303?o
00@0oooo0`0co`000`3oool0<ol003?o0005000000030<c<c0000000<ol000H0<ol00P3oool01000
0000ZZ[o0:ZZo`0000040?ooo`H000009@3oool007T0oooo00<000000?ooo`3oool00`3oool20000
09/0oooo0`3M20H30?ooo`80g@P6I`3oool<000002X0oooo0`00000303?o00<0oooo0P0co`040?oo
o`<0<ol000@0oooo03?o000co`00oooo0P0000030?ooo`8000000P0co`000`3oool0<ol003?o0002
03?o00<0oooo00<000000:ZZo`0000001`3oool4000002@0oooo001h0?ooo`<00000103oool20000
09`0oooo0`3M20H00`3oool0g@P60=d81P020=d81VP0oooo2000000[0?ooo`030000000cI_l0<fKo
00D000000P3oool0100co`00oooo0?ooo`3oool200000080<ol00P3oool203?o0080oooo00<00000
0?ooo`3oool00`0000001P0co`00oooo03?o000co`00oooo03?o00D0oooo0P00000:0?ooo`030000
003oool0oooo0280oooo000A0?ooo`L000001@3oool3000000040?ooo`0000000000000000<0oooo
1@0000030?ooo`8000000`3oool4000000P0oooo0P0000090?ooo`8000000`3oool2000000D0oooo
100000030?ooo`8000000`3oool2000000D0oooo100000040?ooo`800000103oool3000000@0oooo
0P000000103oool000000000000000050?ooo`@00000T03oool70=d81Y`0oooo0`0co`0500000080
<ol0100000000`2ZZ_l00000000000020?ooo`0303?o003oool0oooo00@0oooo0P0000000`0co`00
oooo0?ooo`0203?o00030?ooo`0co`00oooo00D0oooo0P00000^0?ooo`004@3oool2000000@0oooo
0P0000030?ooo`8000000P3oool3000000<0oooo0P0000030?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000001`3oool2000000T0oooo0P0000030?ooo`800000103oool2000000<0oooo
00<000000?ooo`3oool00P0000030?ooo`800000103oool200000080oooo0P0000020?ooo`800000
1@3oool3000000@0oooo0`0000020?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool0
SP3oool70=d81YT0oooo100co`001@3oool000000000003oool000000080<ol000D0oooo0;6a/@00
000000000;6a/@050000000303?o003oool0oooo00<0oooo00D0<ol000000000000000000?ooo`02
03?o0080oooo00<0<ol00?ooo`3oool0103oool2000002h0oooo000A0?ooo`8000001@3oool20000
0080oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`80000000<0oooo0000
00000000103oool2000000H0oooo0P0000090?ooo`8000000`3oool2000000<0oooo0P0000040?oo
o`80000000<0oooo0000000000000`3oool2000000<0oooo0P0000040?ooo`80000000<0oooo0000
00000000103oool2000000030?ooo`000000000000<0oooo0P0000040?ooo`80000000<0oooo0000
00000000103oool2000008l0oooo1`3M20JG0?ooo`<0<ol0103oool01P000000oooo0?ooo`00I/`0
<ol0000000D0/K6a0P000000103oool0<ol003?o000co`030?ooo`<0<ol00`000000103oool0<ol0
0?ooo`3oool203?o00L0oooo00<000000?ooo`3oool0;03oool00140oooo0P0000050?ooo`800000
0P3oool2000000<0oooo0P0000080?ooo`8000000P3oool2000000030?ooo`000000000000`0oooo
0P0000090?ooo`8000000`3oool2000000<0oooo0P0000070?ooo`8000000`3oool2000000<0oooo
0P0000040?ooo`80000000<0oooo000000000000103oool2000000030?ooo`000000000000<0oooo
0P0000040?ooo`80000000<0oooo000000000000U03oool90=d81YD0oooo0`0co`070?ooo`P00000
00<0ZUFZ0000000000000P000000100co`00000000000000000303?o00040?ooo`00000000000?oo
o`80<ol00P3oool203?o03H0oooo000A0?ooo`8000001@3oool200000080oooo0P0000030?ooo`80
00001P3oool3000000<0oooo0P0000000`3oool000000000000<0?ooo`8000002@3oool2000000<0
oooo0P0000030?ooo`8000001`3oool2000000<0oooo0P0000030?ooo`800000103oool200000003
0?ooo`000000000000@0oooo0P0000000`3oool00000000000030?ooo`800000103oool200000003
0?ooo`000000000009<0oooo2P3M20JC0?ooo`@0<ol01@3oool6000000030;6a/@000000000000T0
000000@0IVJI0000000co`00<ol01@3oool203?o0080oooo0P0co`0f0?ooo`004@3oool2000000D0
oooo0P0000040?ooo`D00000103oool4000000@0oooo0P0000000`3oool000000000000<0?ooo`80
00002@3oool2000000<0oooo0P0000030?ooo`P0000000<0oooo0000000000000`3oool2000000<0
oooo0P0000040?ooo`80000000<0oooo0000000000000`3oool2000000<0oooo0P0000020?ooo`80
0000103oool2000000030?ooo`000000000000H00000S03oool<0=d81Y40oooo100000050?ooo`@0
000000D0ZP1E000000000000VIW<0;6a/@06000000030<c<c000000000000080000000<0IVJI0000
003oool0103oool203?o00<0oooo00<0<ol00?ooo`3oool0=@3oool00140oooo0P0000040?ooo`80
0000203oool2000000<0oooo0P0000070?ooo`80000000<0oooo000000000000303oool7000000@0
oooo0P0000030?ooo`8000000`3oool2000000@0oooo0P0000000`3oool00000000000030?ooo`80
00000`3oool2000000@0oooo0P0000000`3oool00000000000030?ooo`8000000`3oool200000080
oooo0P0000040?ooo`80000000<0oooo000000000000103oool2000008d0oooo303M20J@0?ooo`@0
0000103oool8000000030;Fe]@000000/K6a008000000P3<c<`00`000000oooo00000005000000D0
oooo0P0co`020?ooo`80<ol0=`3oool00140oooo1P0000050?ooo`8000000`3oool2000000<0oooo
0P0000030?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool2000000H0oooo
0P0000040?ooo`8000000`3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0P0000000`3oool00000000000030?ooo`8000000`3oool2000000@0oooo0P0000000`3oool00000
000000030?ooo`8000000`3oool200000080oooo0P0000040?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`800000S`3oool:0=d81YH0oooo0P0000030>CTi0<0000000<0]KFe0000002e]KD0
0P0000030<c<c0030000003oool0000000<0000000@0IVJI00000000000000000`3oool203?o00<0
oooo0P0co`0g0?ooo`004@3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo
0P0000030?ooo`8000000`3oool200000080oooo0P0000020?ooo`8000000P3oool2000000L0oooo
0P0000050?ooo`8000000P3oool300000080oooo0P0000040?ooo`8000000P3oool200000080oooo
0`0000020?ooo`800000103oool200000080oooo0P0000020?ooo`8000000`3oool2000000<0oooo
0P0000020?ooo`<000000P3oool2000000<0oooo0P0000020?ooo`800000T@3oool:0=d81YD0oooo
200000020;Fe]@<000000P3<c<`2000000030?ooo`000000000000<0000000<0IVJI0000003oool0
0P3oool203?o00@0oooo00<0<ol00000003oool0=P3oool00140oooo0P0000040?ooo`800000103o
ool5000000D0oooo1@0000030?ooo`8000000`3oool4000000P0oooo0P0000050?ooo`8000000P3o
ool2000000040?ooo`0000000000000000H0oooo100000030?ooo`80000000@0oooo000000000000
00001P3oool400000080oooo100000000`3oool00000000000050?ooo`80000000@0oooo00000000
0000oooo0`0000050?ooo`@00000U03oool80=d81YL0oooo00@000000?ooo`3oool0oooo0P000000
0`2e]KD0000000000006000000030?ooo`000000ojZZ0080000000<0oooo0000003oool00`3oool2
03?o00<0oooo00@0ZP000000000co`0000000`1V<l`00`3oool000000000000`0?ooo`004@3oool2
000000@0oooo0P00000W0?ooo`8000001@3oool200000080oooo0P00000T0?ooo`800000/@3oool7
0=d81YX0oooo100000080?ooo`030000003oZZX0000000<0oooo0`00000203?o00<0oooo00H0VC<c
000000000000ZUD005EEo`00000405EEo`<00000;P3oool00140oooo0P0000040?ooo`8000005P3o
ool2000000l0oooo0P0000040?ooo`8000000`3oool2000002@0oooo0P00002c0?ooo`D0g@P6YP3o
ool3000000<0oooo10000000100co`0000000000002I<c<4000000030:YE001EEOl0000000D0EEGo
0P00000]0?ooo`004@3oool7000001L0oooo0P00000?0?ooo`L00000103oool2000002@0oooo0P00
002d0?ooo`D0g@P6Y@3oool90000000303?o00000000VC<c0080VC<c00<0000009Tc<`0000001P00
000405EEo`800000;03oool00?l0oooo:P3oool30=d81ZT0oooo10000000100co`00000009Tc<`2I
<c<:0000000305EEo`000000000000<0EEGo0P00000[0?ooo`00o`3oool/0?ooo`80g@P6ZP3oool0
0`000000<ol000000005000000060?ooo`000000c9W<0<bIc0000000c9W<0`0000000`1EEOl00000
0000000305EEo`030000003oool0oooo02T0oooo003o0?ooobd0oooo00<0g@P60?ooo`3oool0YP3o
ool203?o00040000000co`0000000:ZZo`D000000`3<VL`010000000c9W<0<bIc000000305EEo`80
000000<0EEGo000000000000:`3oool00?l0ooooeP3oool203?o00030000000co`00000000800000
00@0oooo00000000000000000`3<VL`00`000000c9W<0<bIc002000000<0EEGo0P00000]0?ooo`00
o`3ooooG0?ooo`<0<ol000<0oooo0000000000000`3oool010000000c9W<0<bIc03<VL`600000003
05EEo`000000000002h0oooo003o0?oooed0oooo0P1VIVIg0?ooo`80<ol0103oool01@000000oooo
0?ooo`3oool000000080c9W<0P0000050?ooo`030000003oool0oooo02h0oooo003o0?oooeh0oooo
101VIVId0?ooo`80<ol0103oool010000000oooo0?ooo`3oool4000003L0oooo003o0?ooodh0oooo
0`1VIVH@0?ooo`<0IVIVLP3oool00`0co`00oooo0?ooo`120?ooo`00o`3ooom@0?ooo`<0IVIV403o
ool306IVIVl0oooo0P0co`000`3oool000000?ooo`110?ooo`00o`3ooom00?ooo`80IVIV403oool2
06IVIQ40oooo0P1VIVIZ0?ooo`8000000P3oool01@0co`00ZUFZ0000002a/K4000000440oooo003o
0?oood80oooo0P1VIVH@0?ooo`80IVIV4@3oool206IVIPD0oooo0P1VIVIQ0?ooo`L000000P2a/K40
0`000000oooo0?ooo`0n0?ooo`00o`3ooom40?ooo`80IVIV403oool206IVIPl0oooo1`1VIVIT0?oo
o`D0000000<0/K6a000000000000@@3oool00?l0ooooAP3oool206IVIQ00oooo0P1VIVH60?ooo`P0
IVIV0P3oool306IVIVD0oooo1P0000000`2a/K4000000?ooo`100?ooo`00F03oool306IVI^`0oooo
0P1VIVH@0?ooo`L0IVIV2`3oool306IVIV80oooo0P0000000`3oool000000:YEZP02000000030;6a
/@000000oooo0400oooo001F0?ooo`<0IVIVa03oool8000002@0oooo0P1VIVH70?ooo`L0IVIV0P3o
ool206IVIQ00oooo0`1VIVIO0?ooo`040000002Ic9T0oooo0?ooo`<0000000<0oooo0000003oool0
@@3oool005<0oooo1@1VIVK30?ooo``00000903oool706IVIPX0oooo0`1VIVH@0?ooo`<0IVIVG03o
ool2000000<0oooo0`0000140?ooo`00D@3oool306IVIP<0oooo0P1VIVK00?ooo`D000001P3oool5
000001`0oooo1`1VIVH00`3oool0IVIV06IVIP0?0?ooo`<0IVIV403oool206IVIU/0oooo00<00000
0?ooo`3oool00P3oool2000004D0oooo001>0?ooo`<0IVIV1`3oool00`1VIVH0oooo0?ooo`2m0?oo
o`<000001P3oool2000000@0oooo0`00000F0?ooo`D0IVIV2P3oool306IVIPh0oooo101VIVH?0?oo
o`<0IVIVY03oool004/0oooo0`1VIVH:0?ooo`80IVIV_@3oool3000000L0oooo0P0000050?ooo`<0
00009`3oool206IVIPl0oooo0`1VIVH?0?ooo`<0IVIVXP3oool004P0oooo101VIVH=0?ooo`80IVIV
^`3oool3000000P0oooo0P0000060?ooo`<00000:03oool206IVIPl0oooo0`1VIVH?0?ooo`<0IVIV
X03oool004D0oooo0`1VIVHB0?ooo`0306IVIP3oool0oooo0;P0oooo0`0000090?ooo`8000001`3o
ool3000002T0oooo0P1VIVH?0?ooo`<0IVIV3`3oool806IVIYT0oooo00120?ooo`<0IVIV5P3oool0
0`1VIVH0oooo0?ooo`2g0?ooo`8000002P3oool2000000P0oooo0P00000[0?ooo`80IVIV3`3oool3
06IVIPP0oooo2@1VIVJM0?ooo`00@03oool306IVIP030?ooo`1VIVH0oooo01D0oooo0P1VIVJh0?oo
o`8000002P3oool2000000P0oooo0P00000]0?ooo`80IVIV3`3oool:06IVIPH0oooo0P00000206IV
IY/0oooo000m0?ooo`<0IVIV1@3oool00`1VIVH0oooo0?ooo`0D0?ooo`80IVIV00@0oooo06IVIP1V
IVH0IVIV/P3oool2000000/0oooo0P0000090?ooo`800000;P3oool206IVIPP0oooo2P1VIVH;0?oo
o`8000000P3oool206IVIYT0oooo000j0?ooo`@0IVIV203oool00`1VIVH0oooo0?ooo`0D0?ooo`<0
IVIV]03oool2000000/0oooo0P0000090?ooo`800000;`3oool:06IVIPP0oooo0`1VIVH90?ooo`03
03?o003oool0oooo00<0oooo0P1VIVJG0?ooo`00>03oool306IVIP/0oooo0P1VIVHB0?ooo`<0IVIV
00<0oooo06IVIP3oool0]03oool2000000/0oooo0P0000090?ooo`800000:`3oool906IVIPl0oooo
0P1VIVH80?ooo`0303?o003oool0oooo00D0oooo0P1VIVJE0?ooo`00=03oool506IVIPh0oooo0P1V
IVH=0?ooo`@0IVIV103oool206IVI[@0oooo0P00000;0?ooo`8000002@3oool2000002D0oooo1P1V
IVH90?ooo`80IVIV3`3oool206IVIPH0oooo00<0<ol00?ooo`3oool01P3oool306IVIY<0oooo000a
0?ooo`<0IVIV503oool00`1VIVH0oooo0?ooo`080?ooo`<0IVIV2@3oool00`1VIVH0oooo0?ooo`2b
0?ooo`8000002@3oool4000000T0oooo0P00000f0?ooo`<0IVIV3P3oool306IVIP<0oooo00<0<ol0
0?ooo`3oool0203oool306IVIY40oooo000_0?ooo`@0IVIV5P3oool00`1VIVH0oooo0?ooo`040?oo
o`@0IVIV303oool00`1VIVH0oooo0?ooo`2a0?ooo`8000002`3oool2000000T0oooo0P00000h0?oo
o`<0IVIV3`3oool206IVIP0303?o003oool0oooo00`0oooo0P1VIVJ?0?ooo`00;03oool306IVIP@0
oooo00<0IVIV0?ooo`3oool0503oool00`1VIVH0oooo0?ooo`0406IVIPl0oooo0P1VIVJc0?ooo`80
00002P3oool2000000P0oooo0P00000k0?ooo`<0IVIV3P3oool00`000000<ol006IVIP0?0?ooo`03
06IVIP3oool0oooo08`0oooo000Y0?ooo`@0IVIV1P3oool206IVIQD0oooo00@0IVIV000000000000
IVIV4`3oool206IVI[80oooo0P00000D0?ooo`800000?P3oool206IVIP/0oooo0`0000000`3oool0
IVIV06IVIP2L0?ooo`009`3oool306IVIPX0oooo0P1VIVHB0?ooo`<0IVIV0P0co`0E0?ooo`0306IV
IP3oool0oooo0;00oooo0`00000B0?ooo`<00000@03oool206IVIPX0oooo00D0<ol0000000000000
oooo06IVIP2L0?ooo`008`3oool506IVIPd0oooo0P1VIVH=0?ooo`D0IVIV0`3oool203?o01D0oooo
00<0IVIV0?ooo`1VIVH00`1VIVJ]0?ooo`<00000403oool3000004<0oooo0P1VIVH70?ooo`80<ol0
X03oool00200oooo0`1VIVHD0?ooo`0306IVIP3oool0oooo00L0oooo0`1VIVH90?ooo`80<ol0503o
ool306IVI[40oooo0`00000>0?ooo`<00000C@3oool00`0co`00oooo0?ooo`2O0?ooo`007P3oool5
06IVIQ@0oooo0P1VIVH50?ooo`@0IVIV303oool203?o0100oooo0`1VIVH00`3oool0IVIV0?ooo`2b
0?ooo`<00000303oool3000004d0oooo00<0<ol00?ooo`3oool0X03oool001/0oooo0`1VIVH40?oo
o`0306IVIP3oool0oooo01<0oooo00@0IVIV0?ooo`3oool0oooo0`1VIVH?0?ooo`<0<ol0303oool3
06IVIPD0oooo00<0IVIV0?ooo`3oool0/@3oool5000000H0oooo1@00001=0?ooo`80<ol0XP3oool0
01P0oooo101VIVH70?ooo`0306IVIP3oool0oooo01<0oooo0`1VIVHC0?ooo`0306IVIP0co`00<ol0
00P0oooo101VIVH80?ooo`0306IVIP3oool0oooo0;80oooo3000001>0?ooo`80<ol0X`3oool001H0
oooo0`1VIVH;0?ooo`0306IVIP3oool0oooo00l0oooo0`1VIVH00`3oool0IVIV0?ooo`0D0?ooo`<0
<ol00P0000030?ooo`<0IVIV2`3oool206IVI[D0oooo2000001?0?ooo`80<ol0Y03oool001<0oooo
101VIVH>0?ooo`0306IVIP3oool0oooo00/0oooo101VIVH40?ooo`0306IVIP3oool0oooo01<0oooo
0P0co`02000000<0IVIV3`3oool00`1VIVH0oooo0?ooo`3o0?ooo`T0oooo1@00002S0?ooo`003`3o
ool506IVIQ80oooo0P1VIVH70?ooo`D0IVIV1`3oool206IVIQ80oooo1P00000C0?ooo`0306IVIP3o
ool0oooo0?l0oooo2@3oool203?o0:D0oooo000=0?ooo`<0IVIV0P3oool00`1VIVH0oooo0?ooo`0B
0?ooo`80IVIV103oool306IVIPd0oooo00<0IVIV0?ooo`3oool03@3oool406IVIP030?ooo`0co`00
<ol000<000004@3oool206IVIP<0oooo0P1VIVKo0?ooo`@0oooo00<0<ol00?ooo`0co`00Y@3oool0
0180oooo0P1VIVHD0?ooo`0306IVIP3oool0IVIV0080IVIV403oool206IVIP`0oooo0`1VIVH40?oo
o`0303?o00000000<ol000<000004@3oool406IVI_l0oooo1@3oool0100co`00oooo0?ooo`0co`2U
0?ooo`004`3oool206IVIQ80oooo0`1VIVHD0?ooo`80IVIV203oool306IVIPH0oooo0P0co`000`00
0000<ol003?o000A0?ooo`@0IVIVo`3oool70?ooo`0403?o003oool0oooo03?o0:D0oooo000D0?oo
o`80IVIV3P3oool406IVIP80oooo00<0IVIV0?ooo`3oool04P3oool206IVIP@0oooo101VIVH80?oo
o`<0<ol000<0oooo03?o000co`003@3oool406IVIP<0oooo00<0IVIV0?ooo`3oool0o`3oool30?oo
o`80<ol00P3oool00`0co`00oooo0?ooo`2S0?ooo`005@3oool206IVIP/0oooo0`1VIVH60?ooo`03
06IVIP3oool0oooo0180oooo00<0IVIV0?ooo`1VIVH00`1VIVH:0?ooo`80<ol000<0oooo03?o003o
ool00`0co`090?ooo`<0IVIV1`3oool206IVI_l0oooo103oool00`0co`00oooo0?ooo`0200000003
03?o003oool0oooo0:80oooo000G0?ooo`0306IVIP3oool0oooo00D0oooo0`1VIVH:0?ooo`0306IV
IP3oool0oooo0100oooo101VIVH=0?ooo`80<ol000@0oooo03?o003oool0oooo0`0co`0400000003
0?ooo`1VIVH0IVIV0080IVIV2P3oool00`1VIVH0oooo0?ooo`3o0?ooo`40oooo00@0<ol00?ooo`3o
ool0oooo0`00002T0?ooo`00603oool00`1VIVH0oooo0?ooo`0406IVIPh0oooo00<0IVIV0?ooo`3o
ool02`3oool506IVIP80oooo0P1VIVH;0?ooo`80<ol00P3oool0100co`00oooo0?ooo`3oool203?o
00030000000cIYT0<fJI00D00000303oool00`1VIVH0oooo0?ooo`3o0?ooo`0303?o003oool0oooo
00<0oooo0P00002S0?ooo`00603oool306IVIQ<0oooo00<0IVIV0?ooo`3oool01`3oool406IVIPL0
oooo00<0IVIV0?ooo`3oool02@3oool01@0co`00oooo0?ooo`3oool0<ol000<0oooo00<0IVIV03?o
000co`000`0cIYT00`000000XJ6Q0:6QX@02000000`0oooo00<0IVIV0?ooo`3oool0n03oool90000
00<0oooo00<0<ol0000000000000XP3oool001H0oooo0`1VIVH00`3oool0IVIV0?ooo`0C0?ooo`03
06IVIP3oool0oooo00@0oooo0`1VIVH;0?ooo`0306IVIP3oool0oooo00L0oooo0P0co`030?ooo`03
03?o001VIVH0IVIV0080IVIV00<0oooo03?o000cIYT00`0cIYT010000000XJ6Q0:6QX@00000<0?oo
o`0306IVIP3oool0oooo0?/0oooo1`0000020?ooo`80<ol0X`3oool001/0oooo0P1VIVHC0?ooo`03
06IVIP3oool0oooo00<0IVIV3`3oool00`1VIVH0oooo0?ooo`060?ooo`80<ol000@0oooo06IVIP1V
IVH0<ol00`3oool200000080<ol0100000020:6QX@030000003oool0oooo00/0oooo00<0IVIV0?oo
o`1VIVH00P1VIVKf0?ooo`T000000`3oool00`0co`00oooo0?ooo`2Q0?ooo`00703oool206IVIQ80
oooo101VIVHA0?ooo`80IVIV1P3oool203?o00<0IVIV00D0oooo03?o003oool0oooo000000020:YE
E@L0000000<0XJ6Q0000003oool02`3oool406IVI_H0oooo0`0co`030?ooo`0303?o003oool0oooo
00D0oooo00<0<ol00?ooo`3oool0X@3oool001d0oooo00<0IVIV0?ooo`3oool03@3oool306IVIP80
oooo00<0IVIV0?ooo`3oool04@3oool206IVIP<0oooo0P1VIVH00`0co`00IVIV0?ooo`030?ooo`03
03?o00000000000000H000000P2QXJ44000000T0oooo101VIVKh0?ooo`80<ol0103oool203?o00P0
oooo00<0<ol00?ooo`3oool0X03oool001h0oooo0P1VIVH90?ooo`D0IVIV1@3oool00`1VIVH0oooo
0?ooo`0A0?ooo`D0IVIV00<0oooo03?o003oool00P3oool400000080d=3@0P000000102ZEED00000
0000000000020:6QX@<00000103oool506IVI_/0oooo0P0co`050?ooo`0303?o003oool0oooo00L0
oooo00<0<ol00?ooo`3oool0X03oool001l0oooo0P1VIVH50?ooo`<0IVIV2`3oool00`1VIVH0oooo
0?ooo`0=0?ooo`H0IVIV0P3oool203?o00060?ooo`00000000000000003@d=00<ol00P3@d=000`00
0000oooo00000005000000<0XJ6Q00<000000?ooo`1VIVH00`1VIVKm0?ooo`<0<ol0103oool40000
00P0oooo0P0co`2Q0?ooo`00803oool206IVIP030?ooo`1VIVH0IVIV0080IVIV3P3oool00`1VIVH0
oooo0?ooo`090?ooo`<0IVIV1@3oool206IVIP050?ooo`0co`00oooo0?ooo`0000000`3@d=000`0c
o`000000000000030?ooo`050000003oZZX000000?nZZP0000000`2QXJ400`000000IVIV06IVIP3o
0?ooo`0403?o003oool0oooo0?ooo`<0000000<0oooo0000000000000P0cI_l>000009d0oooo000Q
0?ooo`<0IVIV4P3oool00`1VIVH0oooo0?ooo`050?ooo`@0IVIV203oool00`1VIVH0<ol003?o0002
0?ooo`H00000103oool010000000ojZZ0000003oZZX200000080XJ6Q00<000000?ooo`3oool0o@3o
ool203?o00D0oooo1@0000000`0co`0000000000000600000080oooo00<0<ol00000000000000`00
002L0?ooo`007P3oool306IVIP030?ooo`1VIVH0IVIV01<0oooo00@0IVIV0?ooo`3oool0oooo101V
IVH<0?ooo`80<ol0103oool20000000303?o003oool0oooo00<0oooo00@000000?nZZP000000ojZZ
0P0000000`2QXJ4000000?ooo`3m0?ooo`<0<ol0103oool4000000030>c/k00co`00000000H00000
00D0<fK<0000000cI/`000000?ooo`0203?o0:00oooo000S0?ooo`80IVIV4`3oool406IVIPh0oooo
0P0co`000`1VIVH0oooo0?ooo`040?ooo`80<ol00P3oool206IVIP050000003oZZX000000000003o
ool00`00003m0?ooo`80<ol00`3oool70000000803?o00000000<ol00000003oool0<ol00000000c
I/`600000080<ol0X03oool002@0oooo0P1VIVH?0?ooo`D0IVIV403oool203?o00030?ooo`1VIVH0
oooo00@0oooo0P0co`0206IVIP80oooo00@000000?nZZP0000000000o`3oool203?o00D0oooo1000
000203?o0080oooo0`0000020?ooo`0303?o00000000000000@0000000@0oooo000000000000<ol0
W`3oool002D0oooo0`1VIVH90?ooo`D0IVIV0`3oool206IVIPl0oooo0P0co`000`3oool0IVIV06IV
IP0406IVIP80<ol0103oool00`000000ojZZ0000001f0?ooo`8000001@3oool3000000040?ooo`00
0000000000000080oooo0P0000030?ooo`8000000`3oool3000000040?ooo`000000000000000080
oooo0P0000030?ooo`8000000`3oool2000000<0oooo1@00001A0?ooo`<0<ol0103oool300000003
0?ooo`0co`00<ol000@0oooo1000000209VIc080000000H0VIW<00000000000000000?ooo`000002
03?o09l0oooo000W0?ooo`80IVIV1@3oool406IVIPT0oooo00<0IVIV0?ooo`3oool01@3oool30000
00<0oooo0P0co`000`3oool0IVIV06IVIP0206IVIP<0oooo00@0000003?o0000000000000P3oool0
0`000000ojZZ0000001e0?ooo`<00000103oool200000080oooo0`0000030?ooo`8000000`3oool2
00000080oooo0P0000020?ooo`<000000`3oool2000000<0oooo0P0000020?ooo`8000000`3oool2
000000<0oooo0P00001>0?ooo`<0<ol01`3ooolE00000080oooo0`0co`2N0?ooo`00:03oool00`1V
IVH0oooo0?ooo`0406IVIPd0oooo00<0IVIV0?ooo`3oool00`0000000`3oool0000005FZo`020000
00050?ooo`1VIVH0<ol003?o001VIVH01`3oool400000080oooo0P00001f0?ooo`<00000103oool2
000000<0oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000`3oool2
000000<0oooo0P0000020?ooo`8000000`3oool2000000<0oooo0P00001<0?ooo`80<ol02@3oool2
03?o00040?ooo`0000000000000000<0oooo00D000000?nZo`3oZ_l000000?nZo`030000000409VI
c00co`00<ol0000000@0oooo0P0co`2N0?ooo`00:03oool406IVIQ40oooo00<0IVIV0?ooo`000000
1@00000205FZo`040000001VIVH0<ol003?o00P0oooo1000001j0?ooo`@000000`3oool2000000<0
oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000`3oool2000000<0
oooo0P0000020?ooo`800000203oool2000004/0oooo0P0co`090?ooo`80<ol01@3oool01@000000
oooo000000000000oj[o00<000000`3oool30000000403?o003oool0oooo0?ooo`<00000WP3oool0
02H0oooo0`1VIVH00`3oool0IVIV0?ooo`0A0?ooo`80IVIV0P3oool60000000305FZo`000000<ol0
00T0oooo0P0co`000`000000oooo0?ooo`1h0?ooo`80000000<0oooo0000000000000`3oool20000
00<0oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000`3oool20000
00<0oooo0P0000020?ooo`8000001P3oool3000004X0oooo0P0co`070?ooo`040000003oool0<ol0
03?o00T0oooo100000090?ooo`0303?o003oool0oooo0080oooo0P00002M0?ooo`00:`3oool206IV
IQ40oooo1@1VIVH20000000505FZo`00000000000000000co`002@3oool203?o00800000N@3oool2
000000030?ooo`000000000000D0oooo1@0000030?ooo`8000000`3oool2000000@0oooo1@000003
0?ooo`8000000`3oool200000080oooo0P0000040?ooo`@00000BP3oool00`0co`00oooo0?ooo`06
0?ooo`<000006@3oool0100co`00oooo0?ooo`3oool5000009X0oooo000/0?ooo`80IVIV3@3oool5
06IVIPH0oooo00<0000003?<o`0co`000`0000060?ooo`<0<ol00P00001i0?ooo`80000000<0oooo
000000000000203oool2000000<0oooo0P0000030?ooo`8000001`3oool2000000<0oooo0P000003
0?ooo`8000000P3oool2000000<0oooo0P00001E0?ooo`80<ol00P00000H0?ooo`d00000U`3oool0
02d0oooo0P1VIVH90?ooo`<0IVIV2P3oool303?o00<0000000<0ZZ[o0000000000000`3oool303?o
00<00000N03oool2000000<0oooo0P0000020?ooo`8000000`3oool2000000<0oooo0`0000020?oo
o`8000000P3oool2000000<0oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?oo
o`8000000`3oool2000004l0oooo0`0co`02000001/0oooo3000002E0?ooo`00;P3oool206IVIP@0
oooo101VIVH<0?ooo`D0<ol000@000000:ZZo`000000ZZ[o0P000000103oool0<ol003?o000co`02
0000000303?o00000000oooo07L0oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P000003
0?ooo`@0000000<0oooo0000000000000P3oool2000000<0oooo0P0000030?ooo`<000000P3oool2
00000080oooo0P0000030?ooo`8000000`3oool2000004d0oooo0`0co`0N0?ooo`X0000000@0oooo
05EEZP0000000000U03oool002l0oooo1P1VIVH>0?ooo`H0<ol00P0000000`2ZZ_l0000000000002
000000H0<ol0N@3oool2000000<0oooo0P0000030?ooo`D00000103oool2000000030?ooo`000000
oooo008000000`3oool5000000@0oooo0P000000103oool000000000000000020?ooo`@000000`3o
ool5000004`0oooo00<0<ol00000000co`007`3oool00`000000oooo0?ooo`0200000080<ol000@0
000005FZZP0000000000V03oool002h0oooo101VIVH?0?ooo`P0<ol000@0oooo000000000000ZZ[o
0P0000000`0co`0000000000000403?o07P0oooo0P0000050?ooo`8000009`3oool200000540oooo
0P000000103oool0<ol003?o0000000S0?ooo`030000003oZZX0ojZZ00@00000V@3oool002d0oooo
0P1VIVH@0?ooo`@0<ol000<0oooo03?o000co`000P0co`030?ooo`<000000P0co`020000000403?o
003oool0oooo03?o07P0oooo0P0000050?ooo`800000403oool2000001D0oooo0P00001A0?ooo`@0
0000903oool400000080<ol0V`3oool003h0oooo0`0co`020?ooo`80<ol000<0oooo03?o000co`00
103oool200000080<ol000H0oooo0000000co`0000000?ooo`0co`1h0?ooo`8000001@3oool20000
0100oooo0P00000E0?ooo`800000CP3oool403?o00<000009P3oool203?o00040?ooo`0co`00<ol0
03?o09T0oooo000l0?ooo`@0<ol00`3oool403?o00H0oooo0P0000020?ooo`80<ol000<000000?oo
o`0co`00mP3oool400000080oooo00<0<ol00?ooo`0000009P3oool203?o00030?ooo`0co`00oooo
0080<ol0V03oool003/0oooo0`0co`040?ooo`80<ol000<0oooo03?o000co`001@3oool203?o0003
0000003oool0oooo0080<ol00P3oool00`0co`00oooo0?ooo`3_0?ooo`<000001@0co`0300000003
03?o003oool0oooo02D0oooo1`00000203?o09L0oooo000i0?ooo`<0<ol01@3oool203?o00800000
0P0co`040?ooo`<0<ol00`3oool0100co`00oooo0?ooo`3oool203?o0?00oooo1`0000040;6a/@03
0000003oool0oooo0280oooo3@0000000`0co`00oooo0?ooo`2C0?ooo`00>03oool303?o00H0oooo
0P0co`00100000000:[o0000000000040?ooo`80<ol00`3oool203?o00<0oooo0P0co`3Y0?oooa<0
00009P3oool00`000000ojZZ03?o0004000000@0oooo00<0<ol00?ooo`3oool0T`3oool003L0oooo
0P0co`070?ooo`80<ol000@0oooo00000000Z_l00:[o0P0000020?ooo`80<ol0103oool203?o00<0
oooo0P0co`3X0?ooo`030000000c0000000000/0000000H0/K6a0000002a/K40/K6a0000000co`0U
0?ooo`P000001@3oool203?o09<0oooo000e0?ooo`@0<ol01P3oool303?o00030?ooo`00Z_l00:[o
00800:[o0P00000203?o00D0oooo0P0co`040?ooo`0303?o003oool0oooo0>L0oooo0`00000203?o
00030?ooo`000000000000P000000P2a/K400`000000oooo0?ooo`0R0?ooo`@0<ol0103oool203?o
00D0oooo0P0co`2B0?ooo`00;@3oool3000000<0oooo100co`070?ooo`<0<ol00P3oool00`0cI/`0
0:[o002Zo`02002Zo`030000000co`00<ol000@0oooo0P0co`050?ooo`0303?o00000000oooo09l0
oooo0`0000060?ooo`800000?P3oool203?o00030?ooo`000000000000P000000P1V<l`300000003
03?o003oool0oooo0200oooo00@0<ol00?ooo`3oool0<ol00P0000000`3oool00000000000030000
00D0oooo0P0co`2A0?ooo`00;03oool6000000<0<ol02@3oool300000080oooo00<0<fK<002Zo`00
00001@0000040?ooo`80<ol01@3oool00`0co`0000000000002Q0?ooo`8000001@3oool2000003`0
oooo0P0co`030?ooo`<0000000@0<ol00000003oZZX0ojZZ0`00000206Hcc080000000<0oooo03?o
003oool0803oool203?o00H0000000<0TI6A0000000000000P0000060?ooo`80<ol0T03oool002d0
oooo1000000203?o00030000003oool0oooo00L0oooo00<0<ol00000002ZEED00`2ZEED3000000D0
0:[o0P0000020?ooo`80<ol0103oool500000:40oooo00<000000?ooo`3oool00`3oool2000003/0
oooo0P0co`060?ooo`80<ol00`0000030?ooo`<000008`3oool203?o00/00000203oool203?o08l0
oooo000_0?ooo`<0<ol0100000070?ooo`0303?o00000000ZUEE0080ZUEE1`000004002Zo`040000
003oool0<ol003?o00@0oooo1@00002P0?ooo`<00000103oool2000003P0oooo4@00000X0?ooo`04
03?o003oool0oooo03?o00@0000000<0oooo0000000000000P00002I0?ooo`00;@3oool303?o0080
oooo1P0000040?ooo`80<ol00`0000020:YEE@@0000000@0IS?<00000000000000000P00Z_l20000
0080<ol0103oool5000006P0oooo0P0000090?ooo`8000000`3oool2000000D0oooo100000030?oo
o`8000000`3oool2000000D0oooo100000050?ooo`8000000`3oool3000000@0oooo0P000000103o
ool000000000000000030?ooo`800000103oool4000002H0oooo0P0co`0200000080oooo1P000000
0`2IVL`0EEFZ05EEZP03000002L0oooo00@0<ol00?ooo`3oool0<ol0X`3oool002`0oooo0`0co`04
0?ooo`H000000`3oool203?o00@0000000<0ZUEE000000000000200000000`00Z_l0000003?o0004
0?ooo`80000000<0oj[o000000000000J@3oool2000000T0oooo0P0000030?ooo`800000103oool2
000000<0oooo00<000000?ooo`3oool00P0000030?ooo`800000103oool200000080oooo0P000003
0?ooo`800000103oool3000000@0oooo0`0000020?ooo`8000000P3oool2000000<0oooo0P000002
0?ooo`8000008`3oool303?o00@0oooo00<0000006K<V@3oool00P3oool01@000000c9VI00000000
0000VIW<00<0000000<0<ol00?ooo`3oool0903oool0100co`00oooo03?o000co`2S0?ooo`00:@3o
ool403?o0080oooo00<000000?ooo`3oool00`3oool2000000040?ooo`000000oooo0?ooo`80<ol0
0P3oool3000000040:YEE@000000000003?o00H0000000@0oooo000000000000<ol0103oool50000
06T0oooo0P0000090?ooo`8000000`3oool2000000<0oooo0P0000040?ooo`80000000<0oooo0000
000000000`3oool2000000<0oooo0P0000040?ooo`8000000P3oool2000000<0oooo0P0000000`3o
ool00000000000030?ooo`800000103oool2000000030?ooo`00000000000080oooo0P0000040?oo
o`800000803oool3000000T0oooo0P0co`04000000@0oooo00<0<ol00000003oool09P3oool00`0c
o`00oooo0?ooo`2R0?ooo`009@3oool2000000D0<ol00P3oool600000080oooo00@000000?ooo`3o
ool0oooo0P0co`030?ooo`8000000P2ZEED01`000000^k^k03?o00000000IS?<0000001EZ_l00`00
00000`3oool0<ol003?o001b0?ooo`8000002@3oool2000000<0oooo0P0000030?ooo`8000001`3o
ool2000000<0oooo0P0000030?ooo`800000103oool200000080oooo0P0000030?ooo`80000000<0
oooo0000000000000`3oool2000000@0oooo0P0000000`3oool00000000000020?ooo`8000009@3o
ool5000000L0oooo0P0co`090?ooo`800000903oool300000:D0oooo000U0?ooo`040000000co`00
0000000000P0oooo4`0000001P0co`0000000;^k^`000000IS?<00000080EJ[o00<000000?ooo`0c
o`00L`3oool2000000T0oooo0P0000030?ooo`8000000`3oool2000000L0oooo0P0000030?ooo`80
00000`3oool2000000@0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`000000000000<0
oooo0P0000040?ooo`80000000<0oooo0000000000000P3oool2000002L0oooo00<000000?ooo`3o
ool01P3oool203?o00X0oooo1P00000Q0?ooo`0303?o0000000000000:@0oooo000R0?ooo`H00000
00<0IVJI0000003oool0203oool00`000000EJ[o0000000200000080<fKo0`0cI/`7000000<0^k^k
00@0000006Hcc000000000000P1EZ_l00`000000<ol00?ooo`1b0?ooo`8000002@3oool2000000<0
oooo0P0000030?ooo`P0000000<0oooo0000000000000`3oool2000000<0oooo0P0000040?ooo`80
00000P3oool200000080oooo0P0000030?ooo`8000000P3oool2000000@0oooo0P0000000`3oool0
0000000000020?ooo`800000;`3oool203?o00D0oooo100000030?ooo`<0EJ[o1000000N0?ooo`03
03?o003oool0oooo0:D0oooo000R0?ooo`T00000203oool60000000303?o003oool0<fKo00d00000
00H0IS?<000000000000EJ[o0000000co`1c0?ooo`L00000103oool2000000<0oooo0P0000030?oo
o`800000103oool2000000030?ooo`000000000000<0oooo0P0000030?ooo`800000103oool20000
0080oooo0P0000020?ooo`8000000`3oool200000080oooo0P0000040?ooo`80000000<0oooo0000
000000000P3oool2000002d0oooo0P0co`070?ooo`8000000P2I<c<>000001P0oooo0`00002W0?oo
o`008`3oool50000000306IVV@000000000000/0oooo0P000000100co`0000000?ooo`3oool20000
0080oooo00<000000<bIc00000000`00000205FZo`H0000000<0<ol00?ooo`3oool0L@3oool20000
00@0oooo0P0000030?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool20000
00030?ooo`000000000000<0oooo0P0000030?ooo`800000103oool200000080oooo0P0000020?oo
o`8000000`3oool200000080oooo0P0000040?ooo`80000000<0oooo0000000000000`3oool00`00
0000oooo0?ooo`020?ooo`8000009P3oool203?o00X0oooo100000000`2I<c<00000000000050000
000305FZo`0000000000008000005@3oool00`000000oooo0000000700000:80oooo000S0?ooo`80
000000<0/K6a0000000000000P00000<0?ooo`<0<ol010000000102Ic9T0oooo0?ooo`0000040;^k
^`<000000`1EZ_l20000000405FZo`000000000000000740oooo0P0000050?ooo`8000000P3oool3
00000080oooo0P0000040?ooo`8000000P3oool200000080oooo0`0000020?ooo`800000103oool2
00000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`<000000P3oool2
00000080oooo0P0000030?ooo`8000000P3oool2000002D0oooo0`0co`090?ooo`<0000000<0c?nI
0000000000000P000000100co`00VIW<09VIc000000206IVV@<0000000<0IVJI0000003oool0403o
ool6000000030:YEZP000000000000H00000X@3oool002@0oooo0`0000000`3oool000000000000:
0?ooo`D0<ol01@00000203?o00H0^k^k00<000000;^k^`2k^k/00`00000203?o00L00000K@3oool2
000000D0oooo0P0000020?ooo`80000000@0oooo00000000000000001P3oool4000000<0oooo0P00
0000103oool000000000000000060?ooo`@000000`3oool6000000D0oooo0P000000103oool00000
0000003oool3000000<0oooo0P0000040?ooo`@000009@3oool203?o00T0oooo1P0000020?ooo`05
0000002IVL`0000003?o002IVL`01000000206IVV@030000003oool0oooo00h0oooo0`0000000`2Z
ojX0000000000004000000<0^k^k0P2ZEJX00`000000oooo0?ooo`2P0?ooo`00<`3oool503?o0007
0?ooo`00000000000000003MgMd0000003?o0002000000D0^k^k00<000000;^k^`0000000P000003
03?o00030000002ZZ_l000000080000000@0ZZ[o0000000000000000J`3oool2000000D0oooo0P00
00020?ooo`8000009@3oool2000004<0oooo00<0<ol00?ooo`3oool01P3oool5000000@0oooo0P00
00000`2IVL`000000000000200000080oooo1000000?0?ooo`040000003<ol`000000<coc0<0oooo
1@0000000`2k^k/000000000000200000:80oooo000b0?ooo`80<ol000@0oooo03?o000co`00oooo
0P0000000`3oool00000000000020000000303?o002k^k/0^k^k00<0^k^k1000000403?o00800000
0P2ZZ_l4000000040:ZZo`0000000000000006T0oooo0P0000040?ooo`8000000`3oool2000002D0
oooo0P00000D0?ooo`800000@03oool30000000303?o003oool0oooo01`0oooo00<0<ol00;^k^`2k
^k/01000002U0?ooo`00<03oool703?o00030?ooo`000000oooo0080oooo00D0<ol0000000000000
<ol0000000030;^k^`<000000P3oool503?o008000000P2ZZ_l00`000000oooo00000006000006L0
oooo1`0000040?ooo`8000009@3oool2000001@0oooo0P0000120?ooo`0303?o003oool0oooo01d0
oooo00@0<ol00000000000000000Z03oool002l0oooo0`0co`020?ooo`80<ol000<0oooo0000003o
ool00P3oool203?o00030?ooo`000000<ol000D0000000<0c<c<0000003oool01P0co`00103oool0
00000000002ZZ_l2000000<0oooo1P00003]0?ooo`L00000703oool00`0co`00oooo0?ooo`2Z0?oo
o`00;@3oool200000080<ol00P3oool203?o00D0oooo0P0co`00103oool0<ol003?o000co`020000
0080oooo0`00000203?o00030?ooo`0co`00<ol00080<ol00P3oool2000000030:ZZo`000000oooo
00D0oooo1000003[0?ooo`0300000000VL`009W<00L000006P3oool00`0co`00oooo0?ooo`2Z0?oo
o`00:@3oool40000000303?o00000000000000<0oooo0P0co`030?ooo`<0<ol00P3oool203?o0003
0?ooo`3oc?l000000080oooo0`0000001@0co`00oooo03?o000co`00oooo0080<ol00`3oool30000
00T0oooo0P00003_0?ooo`0503?o003oool0oooo0?ooo`0000006@3oool00`0co`00oooo0?ooo`2[
0?ooo`00:P3oool303?o00D000000P0co`0700000080oooo00<0<ol00?ooo`3oool0103oool20000
0080<ol000D0oooo03?o000co`00oooo03?o00050?ooo`<00000n03oool00`0co`00oooo0?ooo`0K
0?ooo`800000[@3oool002P0oooo100co`000`3oool00000000000020?ooo`80<ol00P3oool20000
000303?o00000000000000<0000000<0<ol00?ooo`3oool00`3oool203?o0080000000<0oooo03?o
000co`000P3oool00`0co`00oooo0?ooo`040?ooo`800000n03oool00`0co`00oooo0?ooo`0I0?oo
o`D00000[03oool002L0oooo0`0co`030?ooo`040000003oool0oooo00000080<ol000<0ZUFZ0;6a
/@2a/K400P2a/K4200000080oooo0P0co`040?ooo`80<ol00`000000103oool0<ol003?o003oool2
03?o00L0oooo00<000000?ooo`3oool0m@3oool3000001X0oooo1@00002/0?ooo`009P3oool303?o
00L0oooo1`0000000`2a/K400000000000020000000303?o003oool0oooo0080oooo0`0co`030000
00040?ooo`0co`00oooo0?ooo`80<ol0o`3oool3000001/0oooo00<0<ol00?ooo`3oool0[@3oool0
02<0oooo100co`060?ooo`h0000000<0<ol00000000000000P00000203?o00D0oooo0P0co`020?oo
o`80<ol0o`3ooolN0?ooo`0303?o003oool0oooo0:d0oooo000R0?ooo`040000000co`0000000000
00H0oooo1P0000020;6a/@d000001@3oool303?o0080oooo0P0co`3o0?oooad0oooo00<0<ol00?oo
o`3oool0[P3oool00280oooo100000040?ooo`P0000000<0]KFe0000002a/K400`0000000`3<c<`0
00000<coc006000000D0oooo0P0co`020?ooo`80<ol0o`3ooolM0?ooo`<00000[`3oool002P0oooo
0P0000030>CTi0<0000000<0]KFe0000002e]KD00P0000030<c<c0030000003oool0000000<00000
00@0IVJI00000000000000000`3oool203?o00<0oooo0P0co`3o0?oooa`0oooo1000002_0?ooo`00
:03oool010000000i>CT0>CTi03Ti>@2000000030?ooo`000000]KFe00<00000103<c<`00`000000
oooo000000030000000306IVV@000000000000@0oooo0P0co`030?ooo`80<ol0o`3oooo?0?ooo`00
:03oool5000000030?ooo`00000000000080]KFe1`0000000`3oool000000?nZZP05000000<0oooo
0P0co`040?ooo`80000000<0EEGo0?ooo`3oool0o`3oooo<0?ooo`00;P3oool2000000030;Fe]@00
0000oooo00@0oooo00D000000?ooo`3oool000000?nZZP0200000080oooo0P0000000`3oool0<ol0
03?o00030?ooo`80E@1E00@0000006Hcc000000000000`1EEOl300000?l0ooooa`3oool002l0oooo
0`0000080?ooo`030000003oZZX0000000<0oooo00<0000005FZo`0000000P0co`00103oool00000
05D0E@2I<c<2000000040:YE001V<l`00000000000@0EEGo0P00003o0?ooolH0oooo000j0?ooo`@0
00000`3oool00`000000EJ[o0000000200000080VC<c00D0000009Tc<`00000000000:YE00030000
00D0EEGo00<000000?ooo`3oool0o`3oooo30?ooo`00>P3oool;00000080VC<c0P0000000`2I<c<0
0000000000030000000305EEo`000000000000<0EEGo0P00003o0?oool@0oooo00100?ooo`030000
000co`00<ol000P0000000<0c9W<0000003<VL`00P00000205EEo`030000001EEOl0EEGo0080EEGo
00<000000?ooo`3oool0o`3oooo10?ooo`00?`3oool303?o00P000000P3<VL`00`000000c9W<0<bI
c00200000080EEGo00<0000005EEo`1EEOl00P00003o0?oool<0oooo000n0?ooo`80<ol000@00000
03?o00000000ZZ[o1@0000030<bIc0030000003<VL`0c9W<008000000`1EEOl300000?l0ooooa03o
ool003h0oooo00D0<ol00?ooo`0co`00<ol00?ooo`02000000<0oooo00D000000<bIc03<VL`0c9W<
000000020<bIc08000000`1EEOl200000?l0ooooa@3oool003l0oooo0P0co`020?ooo`8000000`3o
ool010000000c9W<0<bIc03<VL`300000080oooo00<0000005EEo`000000o`3oooo70?ooo`00?P3o
ool203?o00@0oooo00D000000?ooo`3oool0oooo000000020<bIc08000001@3oool00`000000oooo
0?ooo`3o0?ooolH0oooo000n0?ooo`80<ol0103oool010000000oooo0?ooo`3oool400000?l0oooo
c`3oool003d0oooo0P0co`3o0?ooom`0oooo000i0?ooo`8000000P3oool203?o00<00000o`3ooooI
0?ooo`00>@3oool010000000ZUEE0<`c<`0co`040;6a/@800000o`3ooooH0?ooo`00>@3oool70000
0080/K6a00<000000?ooo`3oool0o`3ooooF0?ooo`00>P3oool5000000030;6a/@00000000000?l0
oooof@3oool003T0oooo1`0000000`2a/K4000000?ooo`3o0?ooomP0oooo000h0?ooo`80000000@0
VLbI0?ooo`000000ZUFZ1000003o0?ooomT0oooo000h0?ooo`040000002Ic9T0oooo0?ooo`<00000
o`3ooooL0?ooo`00=`3oool2000000<0oooo0P00003o0?ooomd0oooo000g0?ooo`030000003oool0
oooo0080oooo0P00003o0?ooomd0oooo003o0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00
o`3ooooo0?oooa`0oooo003o0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00o`3ooooo0?oo
oa`0oooo003o0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00o`3ooooo0?oooa`0oooo003o
0?ooool0oooo703oool00?l0ooooo`3ooolL0?ooo`00o`3ooooo0?oooa`0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{538, 486.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Variations on the Genome: Changes of the genetic information stored on the \
DNA result from a great variety of mutation mechanisms. The genome variations \
usually cause new or modified feature expressions (1, 3, 4). Neutral \
mutations change the genotype, however, the according phenotype exhibits no \
change (2). (Figure from C. Jacob, ",
  StyleBox["Principia Evolvica",
    FontWeight->"Bold"],
  ". dpunkt, Heidelberg, Germany. Chapter 3.2.3.)"
}], "NumberedFigure"],

Cell[TextData[{
  "More about ",
  ButtonBox["gene mutations",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ ], "03-GeneticAlgorithms", "GA-Mutation"}, 
        "GeneMutations.nb", CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  " \[Ellipsis]"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution as a Two-Level Adaptive Search Strategy", "Subsection"],

Cell["\<\
Evolution is a two-level adaptive process, with (inheritable) \
variations occuring on the genomes (genotypes). The selection filter acts on \
the phenotypes and is defined by the environment.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Adaptation of Individual Geno- and Phenotypes", "Subsubsection"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007M0001QB000`400?l00000o`00003oo`3ooooN
0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN
0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN
0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00oP3oool30>o_k``00000d03oool00>d0oooo0`3_
knlN00000<l0oooo003K0?ooo`<0kno_9000000:0>o_k`@00000c@3oool00<T0oooo0`3_knlU0000
01`0kno_1000003<0?ooo`00^03oool30>o_kb@00000<03_knl400000<X0oooo002V0?ooo`<0kno_
900000130>o_k`@00000b@3oool009D0oooo0P3_knlU000005H0kno_100000370?ooo`00P`3oool3
0>o_kb@00000J@3_knl400000<H0oooo001b0?ooo`80kno_9000001m0>o_k`@00000a03oool00600
oooo0P3_knlU000008l0kno_100000330?ooo`00CP3oool30>o_kb@00000X`3_knl400000<40oooo
000m0?ooo`80kno_9000002f0>o_k`@00000`03oool002/0oooo0P3_knlU00000<T0kno_1000002n
0?ooo`006P3oool20>o_kb@00000g03_knl400000;d0oooo000C0?oooa/00000l03_knl400000;/0
oooo000C0?ooo`X00000o`3_knl30>o_k`@00000^P3oool001D0oooo1`00001>0>o_k`030000003_
knl0kno_0;<0kno_00@0oooo0000000000000000^@3oool001P0oooo1P00001<0>o_k`800000]P3_
knl400000;L0oooo000K0?ooo`H00000B@3_knl300000;H0kno_1000002f0?ooo`007@3oool60000
03P0kno_2@0000050>o_k`D00000]`3_knl400000;@0oooo000P0?ooo`H00000<P3_knl200000003
0>o_k`000000000000X000000P3_knl600000;L0kno_1000001?0?ooo`8000001P3oool00`000000
oooo0?ooo`1I0?ooo`008P3oool7000002l0kno_0P0000030>o_k`8000000`3_knl3000000@0kno_
1`00002h0>o_k`@00000C`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05T0oooo
000U0?ooo`H00000?P3_knl800000;P0kno_1000001D0?ooo`030000003oool0oooo05T0oooo000X
0?ooo`H00000>P3_knl:00000;T0kno_1000001=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0F@3oool002X0oooo1`00000f0>o_k``00000^@3_knl4000001h0oooo1P0000000`3o
ool000000?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo100000030?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<000001P3oool4000000@0oooo1@0000130?ooo`00;@3oool6000003<0kno_3P00002j0>o_k`@0
00006`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`100?ooo`00<03oool600000380kno_3@00002j0>o_k`@000006@3oool00`000000oooo0?oo
o`050?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo000000060?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000060?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool0@03oool00380oooo1P00000d0>o_k`X00000^`3_knl4000001H0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo000000060?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000=0?ooo`800000@P3o
ool003D0oooo1P00000e0>o_k`L00000^`3_knl4000001D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0800000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P000000P3oool5000004<0oooo000g0?ooo`L00000=P3_knl4
00000;`0kno_1000000C0?ooo`030000003oool0oooo00<0oooo1@0000020?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000001P3oool010000000oooo0000000000170?ooo`00>P3oool60000
03P0kno_00<000000>o_k`3_knl0^P3_knl400000180oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`100?ooo`00?@3oool6000003H0kno_00H0oooo0000003oool000000?ooo`3_knl90000
0:l0kno_1000000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo0400oooo000o0?ooo`L00000<`3_knl00`000000oooo000000020>o_k`H00000
00<0kno_000000000000/@3_knl4000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`@00000103oool00`000000oooo00000003000000D0oooo100000020?ooo`@00000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool000000?ooo`@000001P3oool4000000@0
oooo1@0000130?ooo`00@P3oool600000340kno_00<0oooo0000003oool00P3_knl200000080kno_
1@00002c0>o_k`@000003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0IP3oool004D0oooo1P00000^0>o_k`030000003oool0000000<0oooo1P00
002f0>o_k`@000003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0IP3oool004L0oooo1P00000/0>o_k`030?ooo`000000oooo00<0000000<0oooo
0000000000000P00002i0>o_k`@000003@3oool500000240oooo00<000000?ooo`3oool0IP3oool0
04X0oooo1P00000Z0>o_k`030?ooo`00000000000080oooo00<000000?ooo`3oool0_03_knl40000
09/0oooo001<0?ooo`L00000:03_knl01@3oool00000000000000000oooo0080000000<0kno_0000
00000000103_knl00`000000kno_0>o_k`2d0>o_k`@00000V@3oool004l0oooo1P00000U0>o_k`80
000000@0oooo0000003oool000001@3oool30>o_k`<00000]P3_knl4000009P0oooo001B0?ooo`H0
00008@3_knl4000000050?ooo`000000oooo0000003oool00`0000020>o_k`H00000]P3_knl40000
09H0oooo001D0?ooo`L000007P3_knl400000080kno_00<000000?ooo`0000000`3oool010000000
oooo0?ooo`3oool20>o_k`<00000]P3_knl4000009D0oooo001G0?ooo`H00000703_knl600000007
0?ooo`000000oooo0000003oool000000?ooo`03000000<0kno_1000002f0>o_k`@00000T`3oool0
05X0oooo1P00000J0>o_k`P0000000@0oooo0000003oool000000`3oool50>o_k`@00000]@3_knl4
00000980oooo001L0?ooo`H00000603_knl8000000<0kno_00@0oooo0000003oool000001`3_knl4
00000;D0kno_1000002@0?ooo`00G`3oool6000001H0kno_1`0000000`3_knl00000000000020>o_
k`030000003oool0kno_00P0kno_1000002d0>o_k`@00000S`3oool00640oooo1`00000E0>o_k`P0
000000@0kno_0000003oool000002`3_knl400000;@0kno_1000002=0?ooo`00I03oool6000001D0
kno_1@0000030?ooo`030000003oool0kno_00`0kno_1@00000>0>o_k`800000XP3_knl4000008`0
oooo001W0?ooo`H000004@3_knl9000000030?ooo`000000kno_00h0kno_1@00000<0>o_k`@00000
X@3_knl0103oool0000000000000002;0?ooo`00J@3oool7000000h0kno_0`3oool010000000oooo
0?ooo`0000020?ooo`8000004@3_knl6000000T0kno_1P00000?0>o_k`<0oooo00@000000?ooo`00
0000oooo1P0000250>o_k`@00000R@3oool006`0oooo1P00000<0>o_k`<0000000D0oooo00000000
000000000?ooo`02000001D0kno_1P0000060>o_k`P00000303_knl01@3oool000000?ooo`000000
kno_00T000007`3_knlC000001L0kno_1000000i0>o_k`@00000R03oool006l0oooo1P0000090>o_
k`<0oooo00@000000?ooo`3oool0oooo1000000G0>o_k`L000000P3_knl:000000X0kno_00D00000
0?ooo`000000oooo0>o_k`0900000200kno_4P00000G0>o_k`X000002P3_knl2000002T0kno_1000
00260?ooo`00L@3oool6000000@0kno_0P0000001P3oool00000000000000000oooo000000@0kno_
0P00000J0>o_k`@000000P3_knl<000000P0kno_00<0oooo0000003oool00`0000000`3oool00000
00000002000002<0kno_400000060>o_k`070?ooo`000000kno_0000003oool000000?ooo`020>o_
k`D000002@3_knl;000000@0kno_1000000Y0>o_k`@00000Q@3oool007@0oooo1P000000103_knl0
oooo0?ooo`0000030?ooo`@0kno_1000000P0>o_k`h000001`3_knl00`3oool000000?ooo`020?oo
o`040000003oool0oooo00000080oooo8P3_knl?000000L0kno_00D000000?ooo`000000oooo0000
00020>o_k`H000004@3_knl3000000@0kno_1@00000[0>o_k`@00000P`3oool007H0oooo1`000000
103oool000000?ooo`0000040>o_k`@00000803_knl@000000D0kno_00@000000?ooo`0000000000
0P3_knl2000000030>o_k`000000000002<0kno_300000080>o_k`040000003oool000000?ooo`<0
kno_1`00000G0>o_k`L00000:`3_knl400000880oooo001i0?ooo`070000003oool000000?ooo`00
0000oooo000000020>o_k`H000008@3_knlB000000<0kno_0P000000103oool000000?ooo`000002
0?ooo`040>o_k`3oool0oooo0>o_k`80oooo4`3_knl<000000030>o_k`000000000000P000002P3_
knl00`3oool000000?ooo`020>o_k`8000000P3_knl5000001L0kno_2000000/0>o_k`@00000P03o
ool007X0oooo00<000000?ooo`0000002`00000P0>o_kaT0000000<0oooo0000003oool01@000000
0`3_knl00000000000060>o_ka@000001`3_knl7000000`0kno_00<000000?ooo`0000000P3_knl9
000001H0kno_2@00000]0>o_k`@00000O`3oool007T0oooo00<000000?ooo`0000000P3oool90000
0240kno_400000040>o_k`H000000P3_knl01P3oool000000?ooo`000000oooo00000080oooo4P00
000?0>o_k`D000003P3_knl0103oool000000?ooo`0000020?ooo`D00000603_knl;000002h0kno_
1000001m0?ooo`00NP3oool00`000000oooo00000002000000030?ooo`000000000000D000008@3_
knl500000100kno_1@000000203_knl0oooo0000003oool000000>o_k`000000oooo1`00000L0>o_
k`@00000403_knl00`3oool000000?ooo`07000001P0kno_3000000^0>o_k`@00000O03oool007/0
oooo0P0000020?ooo`030000003oool0000000P00000=03_knl6000000070?ooo`000000oooo0000
003oool000000?ooo`0S0>o_k`030000003_knl0kno_0100kno_00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0K0>o_k`/00000<03_knl4000007X0oooo001l0?ooo`<0000000@0oooo0000
00000000oooo0P0000000`3oool0000000000004000003<0kno_1`0000000`3_knl0000000000002
000000030?ooo`3_knl0kno_03@0kno_00<000000?ooo`0000001000000M0>o_k`X00000<03_knl4
000007T0oooo001j0?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`H00000<P3_knl70000
00<0oooo00<000000>o_k`3_knl0<`3_knl3000000D0oooo803_knl700000380kno_1000001g0?oo
o`00N@3oool6000000030?ooo`000000000000<000001P3oool700000340kno_00D0oooo00000000
000000000?ooo`04000003D0kno_0P0000000`3_knl000000?ooo`03000000030>o_k`0000000000
01l0kno_1P00000b0>o_k`@00000MP3oool007T0oooo1@00000@0?ooo`H00000;P3_knl50?ooo`05
0000003oool0oooo0?ooo`000000=@3_knl5000000<0oooo00<000000?ooo`3oool00P3_knl20?oo
oad0kno_1@00000c0>o_k`@00000M03oool007T0oooo0P0000080?ooo`8000000P3oool2000000P0
oooo1P00000Z0>o_k`030?ooo`000000000000<0000000@0oooo0000000000000000=@3_knl40000
00<0kno_0P0000000`3oool00000000000020>o_k`8000007`3_knl3000003@0kno_1000001c0?oo
o`00N@3oool3000000030?ooo`00000000000080oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`H000009@3_knl010000000oooo0?ooo`0000030?ooo`030000003_knl0kno_00@00000=03_knl3
000000H0kno_00<000000?ooo`0000000P3_knl20?ooob80kno_00<000000>o_k`3_knl0<`3_knl4
00000740oooo001i0?ooo`H0000000L0oooo0000003oool000000?ooo`000000oooo00<000003@3o
ool600000280kno_00@000000?ooo`000000kno_0P0000060>o_k`800000=03_knl4000000<0kno_
00L0oooo0000003oool000000?ooo`000000kno_00800000F@3_knl400000700oooo001j0?ooo`P0
000000H0oooo0000003oool000000?ooo`00000@0?ooo`L000007`3_knl01`3oool000000?ooo`00
0000oooo0000003oool00P0000000`3_knl0000000000002000003@0kno_1P0000020>o_k`060?oo
o`000000oooo0000003oool000000P3ooomK0>o_k`@00000KP3oool007/0oooo1`0000040?ooo`03
0000003oool000000180oooo1P00000L0>o_k`040?ooo`000000oooo00000080kno_2000000f0>o_
k`80000000<0kno_0000000000000P0000020>o_k`040000003oool000000?ooo`800000G03_knl4
000006d0oooo001l0?ooo`X0000000<0oooo0000003oool05@3oool6000001P0kno_00<0oooo0000
003oool00`3_knl2000000040>o_k`00000000000>o_k`<00000=P3_knl2000000030>o_k`000000
000000<000000`3_knl00`3oool000000?ooo`1O0>o_k`@00000J`3oool007d0oooo2P0000000`3o
ool000000?ooo`0F0?ooo`L000005P3_knl00`3oool000000?ooo`0;000003L0kno_10000000103_
knl000000000003_knl2000000030>o_k`3oool000000600kno_1000001Z0?ooo`00O`3oool00`00
0000oooo000000050?ooo`8000006P3oool6000001D0kno_00<0oooo0000003oool00P3oool50000
03/0kno_1P0000001P3_knl000000000003_knl000000?ooof80kno_1000001X0?ooo`00OP3oool3
000000030?ooo`000000000000D000007@3oool600000180kno_00<000000?ooo`0000001@000000
0`3_knl000000000000k0>o_k`/00000H`3_knl4000006L0oooo00200?ooo`8000001@3oool20000
01l0oooo1P00000@0>o_k`8000000`3oool010000000oooo0?ooo`3_knl20?oooc`0kno_1`000002
0?ooofH0kno_1000001U0?ooo`00N`3oool2000000050?ooo`00000000000000003oool01`00000R
0?ooo`H000003@3_knl3000000030?ooo`000000oooo00D0000000<0kno_000000000000>`3_knl4
000000030?ooo`000000000000800000I@3_knl4000006@0oooo001m0?ooo`030000003oool0oooo
00@0oooo1@00000T0?ooo`L000002@3_knl500000080kno_1@3oool00`3_knl0oooo0?ooo`0l0>o_
k`<0oooo00<000000?ooo`3oool00P00001W0>o_k`@00000HP3oool007/0oooo0P0000000`3oool0
0000000000060?ooo`<000009`3oool6000000L0kno_1@0000060>o_k`040000003oool000000000
03/0kno_00D0oooo00000000000000000?ooo`04000006P0kno_1000001Q0?ooo`00O`3oool00`00
0000oooo0?ooo`020?ooo`D00000:P3oool6000000D0kno_100000020>o_k`070?ooo`000000oooo
0000003_knl000000?ooo`0j0>o_k`80oooo00@0kno_0?ooo`3oool0oooo0`00001[0>o_k`040?oo
o`000000000000000600oooo001j0?ooo`<0000000D0oooo0000003oool000000?ooo`07000002`0
oooo1`0000030>o_k`H0000000L0oooo0000003oool000000?ooo`000000oooo03T0kno_0P000000
0`3oool0000000000005000006`0kno_1000001N0?ooo`00N@3oool01@000000oooo0000003oool0
00000080oooo2000000`0?ooo`H000000`3_knl7000000<0oooo00<000000>o_k`3_knl0=03_knl2
0?ooo`040>o_k`3oool0oooo000000<0oooo00@0kno_0000000000000000K@3_knl4000005d0oooo
001j0?ooo`040000003oool000000?ooo`80000000D0oooo00000000000000000?ooo`02000003@0
oooo1P0000020>o_k`P0000000<0oooo0>o_k`3_knl0=03_knl500000080kno_0P0000020>o_k`80
0000K`3_knl4000005/0oooo002m0?ooo`L000000`3oool01@000000oooo0?ooo`3oool0000003H0
kno_0`3oool00`000000oooo000000040>o_k`<00000L03_knl4000005X0oooo00300?ooo`L00000
00@0oooo0000003oool00000=`3_knl3000000030?ooo`000000oooo0080kno_1@00001b0>o_k`@0
0000F03oool00<40oooo00<000000?ooo`3oool00`3oool5000003D0kno_00D000000?ooo`3oool0
oooo000000020>o_k`H00000M03_knl4000005L0oooo002n0?ooo`<0000000D0oooo000000000000
00000?ooo`06000003D0kno_00@0oooo0000003oool000000P3_knl4000000030>o_k`0000000000
07H0kno_1000001E0?ooo`00_@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000000`3o
ool000000000000400000380kno_00D0oooo0000003oool000000>o_k`0200000080kno_1@00001g
0>o_k`@00000E03oool00;`0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`0=0000
02l0kno_00<000000?ooo`3_knl00P3_knl9000007T0kno_1000001B0?ooo`00c`3oool4000002d0
kno_00@0oooo0000003oool0kno_0P3oool5000007d0kno_1000001A0?ooo`00d03oool6000002/0
kno_00<0oooo0000003oool01`00001o0>o_k`@00000C`3oool00=80oooo1P00000Y0>o_k`030000
003oool000000080oooo0P0000230>o_k`@00000CP3oool00=D0oooo1P00000W0>o_k`030000003o
ool0000000@00000Q03_knl4000004`0oooo001m0?ooo`800000F03oool7000002<0kno_0`000005
0?ooohD0kno_1000001;0?ooo`00O@3oool2000005/0oooo:`0000000`3oool000000000002;0000
04X0oooo001m0?ooo`800000GP3ooolY000000<0oooo00<000000?ooo`3oool0Q`00001:0?ooo`00
O@3oool200000840oooo1@0000001@3oool00000000000000000oooo008000000P3oool200000<d0
oooo001m0?ooo`800000P@3oool4000000D0oooo00<000000?ooo`3oool0d@3oool007d0oooo0P00
00210?ooo`<000000`3oool010000000oooo0000003oool200000080oooo0P00003=0?ooo`00O@3o
ool200000840oooo1P0000030?ooo`030000003oool000000=40oooo001m0?ooo`800000P@3oool6
000000@0oooo00@000000?ooo`000000oooo0P00003=0?ooo`00`P3oool2000003d0oooo0P000000
0`3oool000000000000300000080oooo00<000000?ooo`000000c`3oool00<80oooo0P00000m0?oo
o`P000000`3oool00`000000oooo0000003>0?ooo`00`P3oool3000003d0oooo1`0000001@3oool0
00000000003oool000000<l0oooo00330?ooo`<00000?@3oool900000080oooo00<000000?ooo`3o
ool0c03oool00<@0oooo0P00000n0?ooo`P0000000<0oooo0000003oool0cP3oool00<@0oooo0`00
000n0?ooo`H0000000<0oooo0000000000000P00003=0?ooo`00a@3oool200000400oooo00D00000
0?ooo`000000oooo000000020?ooo`800000c@3oool00?l0oooo1`3oool00`000000oooo00000002
000000030?ooo`000000000000800000c@3oool007/0oooo0P00002;0?ooo`040000003oool0oooo
00000080oooo0P00003=0?ooo`00N`3oool2000008P0oooo0P0000001@3oool00000000000000000
oooo00<00000cP3oool007/0oooo0P00002:0?ooo`040000003oool0oooo0?ooo`@00000cP3oool0
07/0oooo0P0000250?ooo`D0000000D0oooo00000000000000000?ooo`0300000<h0oooo001j0?oo
o`<00000RP3oool00`000000oooo0?ooo`030?ooo`800000cP3oool007X0oooo0P0000260?ooo`D0
00001@3oool300000<h0oooo001j0?ooo`800000Q@3oool01@000000oooo0?ooo`3oool0000000H0
oooo0`00003>0?ooo`00NP3oool2000004d0oooo0P00000g0?ooo`030000003oool0000000@0oooo
1@00003?0?ooo`00NP3oool2000004d0oooo0P00000f0?ooo`030000003oool0000000@0oooo1P00
003?0?ooo`00NP3oool2000004d0oooo0`00003o0?oooa80oooo001i0?ooo`<00000CP3oool20000
0?l0oooo4P3oool007T0oooo0P00001?0?ooo`800000o`3ooolB0?ooo`00N@3oool2000004l0oooo
0`00003o0?oooa40oooo001i0?ooo`800000D03oool200000?l0oooo4@3oool00</0oooo0`00003o
0?oooa00oooo003<0?ooo`800000o`3oool@0?ooo`00c03oool300000?l0oooo3`3oool00<d0oooo
0P00003o0?ooo`l0oooo003=0?ooo`800000o`3oool?0?ooo`00c@3oool300000?l0oooo3P3oool0
0<h0oooo0P00003o0?ooo`h0oooo003o0?ooomh0oooo001h0?ooo`800000o`3ooomT0?ooo`00N03o
ool200000?l0ooooI03oool007P0oooo0P00003o0?ooof@0oooo001h0?ooo`800000o`3ooomT0?oo
o`00M`3oool300000?l0ooooI03oool007L0oooo0P00001J0?ooo`800000o`3oool90?ooo`00M`3o
ool2000005X0oooo0P00003o0?ooo`T0oooo001g0?ooo`800000FP3oool300000?l0oooo203oool0
07L0oooo0P00001K0?ooo`800000o`3oool80?ooo`00M`3oool2000005/0oooo0P00000Z0?ooo`80
0000f`3oool007H0oooo0`00001K0?ooo`<00000:@3oool200000=/0oooo001f0?ooo`800000G@3o
ool2000002P0oooo0`00003K0?ooo`00MP3oool2000005d0oooo0`00000W0?ooo`800000g03oool0
07H0oooo0P00001N0?ooo`8000009`3oool200000=`0oooo003F0?ooo`<000009@3oool300000=`0
oooo003G0?ooo`8000009@3oool200000=d0oooo003G0?ooo`800000903oool300000=d0oooo003G
0?ooo`<000008`3oool200000=h0oooo003H0?ooo`8000008`3oool200000=h0oooo003l0?ooo`<0
0000gP3oool00?`0oooo0P00003O0?ooo`00o03oool200000=l0oooo003k0?ooo`<00000g`3oool0
0?/0oooo0P00003P0?ooo`00MP3oool200000?l0ooooIP3oool007H0oooo0P00001U0?ooo`800000
oP3oool007H0oooo0P00001U0?ooo`800000oP3oool007H0oooo0P00001U0?ooo`<00000o@3oool0
07D0oooo0`00001V0?ooo`800000o@3oool007D0oooo0P00001W0?ooo`800000o@3oool007D0oooo
0P00001W0?ooo`<00000o03oool007D0oooo0P00001X0?ooo`800000o03oool007D0oooo0P00001X
0?ooo`<00000n`3oool007D0oooo0P00001Y0?ooo`800000n`3oool007@0oooo0`00001Y0?ooo`<0
00005@3oool200000><0oooo001d0?ooo`800000J`3oool2000001D0oooo0P00003S0?ooo`00M03o
ool2000006/0oooo0P00000D0?ooo`<00000h`3oool007@0oooo0P00001[0?ooo`<000004`3oool2
00000>@0oooo003R0?ooo`8000004`3oool200000>@0oooo003f0?ooo`<00000i03oool00?H0oooo
0P00003U0?ooo`00m@3oool300000>D0oooo003e0?ooo`800000iP3oool00?@0oooo0`00003V0?oo
o`00m03oool200000>L0oooo003d0?ooo`800000i`3oool007<0oooo0P00001n0?ooo`<00000i`3o
ool007<0oooo0P00001`0?ooo`800000303oool200000>P0oooo001c0?ooo`800000L03oool20000
0?H0oooo001c0?ooo`800000L03oool300000?D0oooo001b0?ooo`<00000L@3oool200000?D0oooo
001b0?ooo`800000LP3oool300000?@0oooo001b0?ooo`800000L`3oool200000?@0oooo001b0?oo
o`800000L`3oool300000?<0oooo001b0?ooo`800000M03oool200000?<0oooo001a0?ooo`<00000
M03oool300000?80oooo001a0?ooo`800000MP3oool200000?80oooo001a0?ooo`800000MP3oool3
000000<0oooo0P00003/0?ooo`00L@3oool2000007L0oooo0P0000030?ooo`800000k03oool00>h0
oooo0`00003/0?ooo`00kP3oool200000>d0oooo003^0?ooo`800000k@3oool00>d0oooo0`00003]
0?ooo`00k@3oool200000>h0oooo003/0?ooo`<00000kP3oool00>`0oooo0P00003_0?ooo`00j`3o
ool300000>l0oooo001_0?ooo`800000NP3oool200000080oooo0P00003/0?ooo`00K`3oool20000
07X0oooo0P0000020?ooo`800000k03oool006l0oooo0P00001i0?ooo`<000000P3oool300000>/0
oooo001_0?ooo`800000N@3oool2000000@0oooo0P00003[0?ooo`00K`3oool2000007l0oooo0P00
003[0?ooo`00K`3oool2000007l0oooo0`00003Z0?ooo`00K`3oool200000800oooo0P00003Z0?oo
o`00KP3oool300000800oooo0`00003Y0?ooo`00KP3oool200000880oooo0P00003Y0?ooo`00KP3o
ool200000880oooo0`00003X0?ooo`00KP3oool2000008<0oooo0P00003X0?ooo`00KP3oool20000
08<0oooo0P00003X0?ooo`00KP3oool2000008<0oooo0`00003W0?ooo`00KP3oool2000008@0oooo
0P00003W0?ooo`00i@3oool200000?H0oooo003U0?ooo`800000mP3oool00>D0oooo0P00003f0?oo
o`00i03oool300000?H0oooo003T0?ooo`800000m`3oool00>@0oooo0P00003g0?ooo`00i03oool2
00000?L0oooo003S0?ooo`<000004`3oool200000>80oooo001^0?ooo`800000L`3oool2000001@0
oooo0P00003R0?ooo`00KP3oool2000007<0oooo0P00000D0?ooo`<00000h@3oool006h0oooo0P00
001c0?ooo`8000005@3oool200000>40oooo001^0?ooo`800000LP3oool3000001D0oooo0`00003P
0?ooo`00K@3oool300000780oooo0P00000G0?ooo`800000h03oool006d0oooo0P00001c0?ooo`80
00005`3oool300000=l0oooo001]0?ooo`800000S@3oool300000=h0oooo001]0?ooo`800000SP3o
ool200000=h0oooo001]0?ooo`800000SP3oool300000=d0oooo001]0?ooo`800000S`3oool20000
0=d0oooo001/0?ooo`<00000S`3oool300000=`0oooo001/0?ooo`800000T@3oool200000=`0oooo
001/0?ooo`800000o`3ooom`0?ooo`00K03oool200000?l0ooooL03oool00?l0oooogP3oool00?l0
oooogP3oool00=d0oooo0P00003n0?ooo`00g@3oool200000?h0oooo003L0?ooo`<00000oP3oool0
0=`0oooo0P00003o0?ooo`00f`3oool300000?l0oooo003K0?ooo`8000009@3oool200000=T0oooo
001Z0?ooo`800000KP3oool3000002D0oooo0P00003I0?ooo`00JP3oool2000006h0oooo0P00000V
0?ooo`<00000f03oool006X0oooo0P00001^0?ooo`8000009`3oool200000=P0oooo001Z0?ooo`80
0000K@3oool3000002L0oooo0`00003G0?ooo`00J@3oool3000006d0oooo0P00000Y0?ooo`800000
e`3oool006T0oooo0P00001]0?ooo`<00000:@3oool300000=H0oooo001Y0?ooo`800000K@3oool2
000002/0oooo0P00003F0?ooo`00J@3oool2000009X0oooo0`00003E0?ooo`00J@3oool2000009/0
oooo0P00003E0?ooo`00H`3oool9000009X0oooo0`00003D0?ooo`00H`3oool<000008d0oooo3@00
003D0?ooo`00I03oool;000007d0oooo7000003E0?ooo`00I03oool;000006d0oooo8@0000090?oo
o`@00000d`3oool006@0oooo2P00001N0?ooob4000006P3oool400000=80oooo001T0?ooo`X00000
CP3ooolQ000002`0oooo0`00003A0?ooo`00I03oool9000003l0oooo8@00000m0?ooo`@00000c`3o
ool006D0oooo2000000_0?ooob400000CP3oool400000<h0oooo001U0?ooo`P000007`3ooolQ0000
02L0oooo0P00000g0?ooo`@00000c03oool006D0oooo1`00000?0?ooob800000=`3oool2000003P0
oooo1000003;0?ooo`00I@3ooolX000004H0oooo0`00000f0?ooo`8000000P3oool300000<X0oooo
001K0?ooob400000E`3oool2000003L0oooo0P0000030?ooo`@00000b03oool004/0oooo8@00001W
0?ooo`800000=`3oool3000000<0oooo100000370?ooo`00>`3ooolQ000000X0oooo1000001X0?oo
o`<00000>03oool2000000D0oooo100000350?ooo`00:`3ooolQ000001X0oooo1000001X0?ooo`80
0000>@3oool2000000H0oooo100000340?ooo`006`3ooolQ000002X0oooo0`00000<0?ooo`@0IVIV
F03oool3000003T0oooo0`0000020?ooo`030000003oool0oooo0080oooo0`0000330?ooo`002`3o
oolQ000003X0oooo0`00000:0?ooo`@0IVIVFP3oool2000003/0oooo1@0000050?ooo`@00000E`3o
ool2000000L0oooo00<000000?ooo`3oool0GP3oool000<0oooo6@00001;0?ooo`8000001`3oool3
06IVIP<0oooo0P1VIVIH0?ooo`<00000>P3oool6000000H0oooo1000001H0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0GP3oool000<0oooo2@00001K0?ooo`030000003oool0oooo
00<0oooo0`1VIVH70?ooo`0306IVIP3oool0oooo05H0oooo0P00000i0?ooo`T000001`3oool40000
05d0oooo00<000000?ooo`3oool0GP3oool000D0oooo1P00001L0?ooo`030000003oool0oooo00<0
IVIV2P3oool206IVIUL0oooo0P00000h0?ooo`X00000203oool4000005H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1N0?ooo`00203oool6000005T0oooo1@1VIVH<0?ooo`80IVIV
0P3oool00`1VIVH0oooo0?ooo`1@0?ooo`<00000=`3oool;000000X0oooo0`00000M0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`@00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo100000040?ooo`<00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<000001@3oool4000000D0oooo
1@0000180?ooo`002P3oool6000005@0oooo101VIVH30?ooo`80IVIV2`3oool406IVIU<0oooo0P00
000i0?ooo`X000002`3oool4000001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`150?ooo`003@3oool6
000004l0oooo0P1VIVH80?ooo`80IVIV203oool306IVIP030?ooo`1VIVH0oooo08l0oooo2@00000<
0?ooo`@000006P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000
1P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000060?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0A@3oool000l0oooo1P0000190?ooo`@0IVIV2`3oool00`1VIVH0oooo0?ooo`030?ooo`@0
IVIV0`3oool206IVIY00oooo2000000>0?ooo`@00000603oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000>0?ooo`800000A`3o
ool00180oooo1P0000140?ooo`<0IVIV00<0oooo06IVIP3oool0303oool00`1VIVH0oooo06IVIP02
06IVIPP0oooo0P1VIVJ@0?ooo`L000003`3oool4000001L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`P0000000<0oooo0000003oool0103o
ool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0000000L000000`3oool5000004P0
oooo000D0?ooo`H00000?`3oool406IVIP<0oooo0P1VIVH;0?ooo`0406IVIP000000000006IVIP/0
oooo00<0IVIV0?ooo`3oool0S`3oool700000100oooo1000000E0?ooo`P000000`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000050?oo
o`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`030000
003oool0oooo00800000C03oool001L0oooo1P00000i0?ooo`@0IVIV203oool00`1VIVH0oooo0?oo
o`050?ooo`@0IVIV00<0oooo03?o000co`00303oool406IVIXh0oooo1P00000A0?ooo`@00000503o
ool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo000000050?ooo`040000003oool0oooo000000H0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000060?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0A@3oool001T0oooo1P00000e0?ooo`<0IVIV2`3oool206IVIP<0oooo0`1VIVH6
0?ooo`80<ol02@3oool406IVIY40oooo1@00000C0?ooo`<000004`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo008000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`02000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`150?ooo`00703oool6000002h0oooo101VIVH20?ooo`80IVIV2`3oool506IVIPT0
oooo0P0co`000`3oool00000000000020?ooo`@0IVIV0P3oool206IVIY00oooo1@00000D0?ooo`@0
00004@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0000003oool0100000060?oo
o`@000000`3oool00`000000oooo00000003000000D0oooo100000030?ooo`@0000000<0oooo0000
003oool0103oool01@000000oooo0?ooo`000000oooo00@000001@3oool4000000D0oooo1@000018
0?ooo`007P3oool6000002X0oooo0`1VIVH60?ooo`80IVIV203oool506IVIPT0oooo100000000`0c
o`0000000000000206IVIPL0oooo00<0IVIV0?ooo`3oool0S`3oool4000001D0oooo1000000@0?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`1[
0?ooo`008@3oool6000002@0oooo101VIVH90?ooo`80IVIV103oool406IVIP<0oooo0P1VIVH90?oo
o`H000002@3oool206IVIY40oooo0`00000G0?ooo`@000003P3oool00`000000oooo0?ooo`040?oo
o`8000000P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06/0oooo000S0?ooo`H0
00008@3oool406IVIP/0oooo1P1VIVH70?ooo`80IVIV1P3oool406IVIP030?ooo`0co`0000000080
00002@3oool406IVIPH0oooo1000P1650?ooo`800000603oool4000000d0oooo200000030?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0J`3oool002H0oooo1P00000Q0?ooo`80IVIV
2@3oool406IVIP/0oooo0P1VIVH30?ooo`<0IVIV103oool203?o00<000001P3oool506IVIPL0oooo
2P00P14h0?ooo`8000008@3oool400204B40oooo0P00000I0?ooo`<00000Z`3oool002P0oooo1P00
000P0?ooo`80IVIV1@3oool406IVIP80oooo0P1VIVH;0?ooo`D0IVIV1@3oool00`0co`00000003?o
000203?o008000000P3oool406IVIP<0oooo00<0IVIV0?ooo`3oool02`3oool;00204C40oooo0P00
000Q0?ooo`T0080A7@3oool00`000000oooo0?ooo`0H0?ooo`@00000Z@3oool002/0oooo1P00000O
0?ooo`0306IVIP3oool0IVIV00<0IVIV1P3oool206IVIPL0oooo1P1VIVH60?ooo`80<ol000<00000
03?o003oool00P0co`0406IVIPH0oooo0P1VIVHB0?ooo`h0080A9`3oool300000240oooo3P00P14d
0?ooo`@00000Z03oool002d0oooo1P00000L0?ooo`<0IVIV2`3oool206IVIP@0oooo0`1VIVH40?oo
o`0306IVIP3oool0oooo00@0oooo0P0co`0010000000<ol006IVIP1VIVH203?o00X0oooo0P1VIVHH
0?oooa<0080A6P3oool300000280oooo4`00P14a0?ooo`@00000YP3oool00300oooo1P00000I0?oo
o`0306IVIP3oool0IVIV0080IVIV2P3oool506IVIPP0oooo00<0IVIV0?ooo`3oool00P3oool203?o
0080IVIV00@0<ol00?ooo`3oool0IVIV0`0000090?ooo`@0IVIV7P3ooolK00204@T0oooo0P00000S
0?oooaP0080A;@3oool400000:D0oooo000b0?ooo`H000006`3oool00`1VIVH0oooo0?ooo`070?oo
o`@0IVIV2P3oool206IVIP80oooo00<0IVIV03?o000co`000P3oool01@0co`00oooo0?ooo`3oool0
IVIV008000001`3oool306IVIR`0ooooEP00P14_0?ooo`<00000Y03oool003D0oooo1P00000I0?oo
o`0306IVIP3oool0oooo0080oooo101VIVH30?ooo`80IVIV2@3oool406IVIP030?ooo`0co`00oooo
0080oooo0P0co`030?ooo`030000003oool0oooo0080oooo101VIVI00?oood80080A<`3oool40000
0:80oooo000g0?ooo`L000005`3oool506IVIPL0oooo0P1VIVH50?ooo`@0IVIV00<0oooo06IVIP1V
IVH00P0co`030?ooo`80<ol0103oool506IVITD0oooo1`00000T0?oooa80080A=`3oool400000:40
oooo000j0?ooo`H00000503oool406IVIPX0oooo0P1VIVH00`3oool0IVIV06IVIP0206IVIPD0oooo
00<0IVIV03?o000co`00103oool00`0co`00oooo06IVIP0306IVITT0oooo2@00000R0?ooo`l0080A
?03oool4000009l0oooo000m0?ooo`H00000503oool206IVIPT0oooo101VIVH90?ooo`0303?o001V
IVH0000000<0000000<0<ol006IVIP1VIVH0C03oool:00000240oooo2`00P1510?ooo`@00000WP3o
ool003l0oooo1P00000C0?ooo`80IVIV1@3oool306IVIP80oooo0P1VIVH60?ooo`040000003oool0
000000000080IVIV100000000`0co`00oooo0?ooo`1;0?ooo`X000008@3oool800204DH0oooo1000
002L0?ooo`00@P3oool600000140oooo0P1VIVH00`3oool0IVIV06IVIP0206IVIPD0oooo0P1VIVH3
0?ooo`d00000C03oool;00000240oooo1@00P14j0?ooo`80IVIV3P3oool4000009/0oooo00140?oo
o`H000003`3oool306IVIPX0oooo0P1VIVH20?ooo`0306IVIP0000000000008000000P3oool00`00
0000I/co06K<o`07000004P0oooo2P00000R0?ooo`80080A?`3oool206IVIPh0oooo0`00002J0?oo
o`00A`3oool6000000h0oooo0P1VIVH:0?ooo`<0IVIV0`3oool2000000D0oooo0P0co`07000004H0
oooo2@00001K0?ooo`80IVIV203oool206IVIPh0oooo1000002H0?ooo`00B@3oool6000000d0oooo
0P1VIVH50?ooo`@0IVIV1P3oool0100co`0000000000000000030?ooo`030000000co`00<ol000T0
0000@`3oool8000005d0oooo0P1VIVH80?ooo`80IVIV3P3oool4000009L0oooo001<0?ooo`H00000
2`3oool706IVIPP0oooo0P0co`0300000080oooo0P00000303?o00<000000`3oool300000480oooo
1`00001F0?ooo`80IVIV1`3oool206IVIPP0oooo0P1VIVH20?ooo`80IVIV2`3oool4000009D0oooo
001>0?ooo`H000002@3oool306IVIP/0oooo00@0<ol00000000co`00oooo0`000000103oool0<ol0
03?o0000000203?o00040?ooo`0000000000000004L0oooo1`00001G0?ooo`80IVIV1`3oool206IV
IPL0oooo1@1VIVH=0?ooo`@00000U03oool00540oooo1P00000C0?ooo`0503?o00000000000003?o
003oool00`0000001P3oool0<ol003?o000co`00oooo03?o00<0oooo0P0000160?ooo`H00000C`3o
ool306IVIPL0oooo0P1VIVH70?ooo`80IVIV0P3oool506IVIP030?ooo`1VIVH0IVIV0100oooo0`00
002C0?ooo`00D`3oool600000140oooo0P0co`000`3oool0<ol00?ooo`040?ooo`80<ol00P3oool2
03?o00<0oooo0P0000150?ooo`D00000B@3oool00`1VIVH0oooo0?ooo`060?ooo`80IVIV1`3oool2
06IVIPH0oooo1@1VIVH60?ooo`80IVIV403oool400000940oooo001F0?ooo`H000003P3oool0100c
o`00oooo03?o000co`060?ooo`0303?o003oool0oooo0080<ol0BP3oool4000004X0oooo0P1VIVH8
0?ooo`80IVIV203oool706IVIP80oooo0P1VIVH70?ooo`80IVIV403oool400000900oooo001H0?oo
o`H000003P3oool203?o00H0oooo00@0<ol00?ooo`3oool0oooo0P00000209VIc0@00000@`3oool3
000004d0oooo0P1VIVH70?ooo`80IVIV1@3oool506IVIPL0oooo0P1VIVH70?ooo`80IVIV4@3oool4
000008h0oooo001K0?ooo`H000002`3oool203?o00H0oooo00<0<ol00?ooo`0000001000000409VI
c0030000003oool0oooo0400oooo1000000m0?ooo`<0080A3P3oool206IVIPP0oooo1P1VIVH30?oo
o`80IVIV1`3oool206IVIPP0oooo0P1VIVH@0?ooo`@00000S@3oool005d0oooo1P0000090?ooo`80
<ol01@3oool203?o00030?ooo`000000000000H0000000<0VIW<000000000000@@3oool3000002T0
oooo00<0080A0?ooo`3oool0403oool300204A40oooo0`1VIVH30?ooo`H0IVIV1`3oool206IVIPL0
oooo0P1VIVH80?ooo`80IVIV4@3oool3000008`0oooo001P0?ooo`H00000103oool5000000@0oooo
0P0co`00103oool000000000002ZEED30000000409VIc0000000000000000480oooo0P00000X0?oo
o`<0080A3`3oool400204AD0oooo1@1VIVH40?ooo`80IVIV203oool206IVIPH0oooo0P1VIVH80?oo
o`80IVIV0`3oool00`1VIVH0oooo0?ooo`0;0?ooo`@00000RP3oool00680oooo1P0000030?ooo`@0
0000103oool203?o00030?ooo`000000000000D000000P2IVL`00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo02D0oooo1@00P14<0?ooo`@0080A5@3oool606IVIPP0oooo0P1VIVH70?ooo`80
IVIV1`3oool206IVIPL0oooo1@1VIVH>0?ooo`@00000R@3oool006D0oooo2`0000030?ooo`80<ol0
1@0000020?ooo`@00000J@3oool600204@P0oooo1@00P14N0?ooo`80IVIV1`3oool206IVIPL0oooo
0P1VIVH70?ooo`80IVIV0P3oool706IVIQ80oooo100000270?ooo`00I`3oool9000000<0oooo00<0
<ol00?ooo`0000001000001]0?ooo`P0080A103oool600204B80oooo0P1VIVH70?ooo`80IVIV1`3o
ool206IVIPH0oooo101VIVH60?ooo`80IVIV4P3oool4000008H0oooo001Z0?ooo`H000000`3oool0
1@000000oooo0000003oool0000006d0oooo4000P14W0?ooo`80IVIV1`3oool206IVIPL0oooo0P1V
IVH00`3oool0IVIV06IVIP0306IVIP030?ooo`1VIVH0IVIV00L0oooo0P1VIVHC0?ooo`<000006`3o
ool900000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`@00000103oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
00003@3oool006`0oooo2@00001K0?ooo`0306IVIP3oool0oooo0100oooo3000P14^0?ooo`80IVIV
1`3oool306IVIP@0oooo0P1VIVH20000000306IVIP3oool0oooo00@0oooo0P1VIVH70?ooo`80IVIV
4`3oool4000001T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000
3`3oool006l0oooo1P00001G0?ooo`@0IVIV4@3oool>00204C00oooo0P1VIVH70?ooo`H0IVIV0P3o
ool00`1Eo`00IVIV06IVIP060?ooo`80IVIV1`3oool306IVIQ80oooo1000000H0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool000003`3oool00740oooo1P00001A0?ooo`@0IVIV503oool@00204C00oooo0P1V
IVH20?ooo`L0IVIV1@3oool0101Eo`00oooo06IVIP1VIVH70?ooo`80IVIV1`3oool206IVIQ<0oooo
1000000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000003`3oool00780oooo00<0<ol00000000000001@00
001:0?ooo`@0IVIV5P3ooolB00204C00oooo1@1VIVH50?ooo`80IVIV103oool00`1Eo`00oooo0?oo
o`0206IVIPL0oooo0P1VIVH70?ooo`80IVIV0P3oool206IVIPl0oooo1000000E0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo200000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000003`3oool00780oooo0P0co`020?ooo`H00000@`3oool606IVIP030?ooo`1VIVH0
IVIV01/0oooo3@00P14_0?ooo`80IVIV0P3oool206IVIPL0oooo1P0000020?ooo`80IVIV1`3oool2
06IVIPD0oooo1@1VIVHC0?ooo`@000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000060?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000
3`3oool00780oooo0P0co`050?ooo`H00000?03oool506IVIPL0oooo0P1VIVHT0?ooo`@0080A<`3o
ool206IVIPL0oooo00<0000006IVIP000000100000020?ooo`80IVIV1P3oool706IVIP80oooo0P1V
IVHD0?ooo`@000004P3oool8000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`00000?0?ooo`00LP3oool203?o00L0oooo
1P00000f0?ooo`D0IVIV303oool206IVIU/0oooo0`1VIVH60?ooo`L000000P3oool206IVIP80oooo
1P1VIVH70?ooo`80IVIV5@3oool300000140oooo00<000000?ooo`3oool0203oool2000000<0oooo
0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool20000
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo0P000002
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool03@3o
ool00780oooo00<0<ol00?ooo`3oool02@3oool6000002l0oooo1`1VIVH@0?ooo`80IVIV2@3oool3
06IVITl0oooo0P1VIVH40?ooo`L000000`3oool506IVIP@0oooo0P1VIVH70?ooo`80IVIV5@3oool4
000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo00000003000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000030?ooo`040000003oool00000000000<0oooo1000
00040?ooo`030000003oool0000000<000000`3oool00`000000oooo0000000200000080oooo0`00
00060?ooo`@00000103oool00`000000oooo0000000300000080oooo1000000=0?ooo`00LP3oool0
0`0co`00oooo0?ooo`0;0?ooo`H00000:@3oool506IVIPD0oooo0P1VIVH@0?ooo`80IVIV0`3oool5
06IVIU<0oooo0P1VIVH40?ooo`80000000@0/K6a0000000000000000101VIVH00`3oool0IVIV06IV
IP070?ooo`80IVIV1`3oool00`1VIVH0oooo0?ooo`0C0?ooo`@000003P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00d0oooo001b0?ooo`0303?o003oool0oooo00h0oooo1P00000R
0?ooo`D0IVIV2P3oool206IVIQ00oooo1@1VIVIH0?ooo`<0IVIV0P3oool40000000305Go001VIVH0
oooo00D0oooo0`1VIVH60?ooo`80IVIV7P3oool4000000`0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0=0?ooo`00LP3oool300000100oooo1P00000O0?ooo`80IVIV3`3oool306IV
IPX0oooo1@1VIVH00`000000IVIV0?ooo`1J0?ooo`80IVIV200000000`1VIVH0oooo0?ooo`050?oo
o`0306IVIP3oool0oooo00D0oooo00<0IVIV0?ooo`3oool07@3oool4000000/0oooo2@00000D0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00700oooo1@00000C0?ooo`H0
00007P3oool206IVIPl0oooo0P1VIVH50?ooo`D0IVIV103oool00`1Eo`00IVIV06IVIP1H0?ooo`<0
IVIV00<0oooo0000000000001`00000206IVIPH0oooo0P1VIVHW0?ooo`<00000M03oool00700oooo
1@00000E0?ooo`H000007@3oool206IVIPl0oooo1`1VIVH80?ooo`0405Go003oool0oooo06IVIUX0
oooo2P0000000`3oool0IVIV06IVIP0_0?ooo`@00000LP3oool00740oooo1000000H0?ooo`H00000
6`3oool306IVIP/0oooo1@1VIVH<0?ooo`0405Go003oool0oooo0?ooo`80IVIV203oool406IVITh0
oooo2@0000000`3oool0IVIV0?ooo`0_0?ooo`@00000L@3oool008l0oooo1P00000K0?ooo`80IVIV
1P3oool406IVIPD0oooo0P1VIVH90?ooo`80EOl0103oool206IVIP<0oooo1@1VIVIA0?ooo`0305Go
00000000000000H0000000<0EOl00?ooo`3oool0<@3oool4000006l0oooo002B0?ooo`H000006@3o
ool206IVIP030?ooo`1VIVH0IVIV0080IVIV2P3oool206IVIPP0oooo0P1Eo`040?ooo`D0IVIVE@3o
ool9000000030?ooo`1Eo`00EOl003<0oooo1000001^0?ooo`00U03oool6000001T0oooo0P1VIVH>
0?ooo`<0IVIV1P3oool205Go00D0IVIV00@0oooo06IVIP1VIVH0IVIVD`3oool60000000305Go0000
0000000000<0000000@0oooo05Go000000000000<`3oool3000006d0oooo002G0?ooo`H000005`3o
ool206IVIPl0oooo0P1VIVH00`3oool0IVIV06IVIP0206IVIP0305Go003oool0oooo00L0oooo0P1V
IVIC0?ooo`/0000000D0oooo000000000000000005Go000c0?ooo`@00000J`3oool009T0oooo1P00
000F0?ooo`<0IVIV303oool506IVIP<0oooo00<0EOl00?ooo`3oool0203oool00`1VIVH0oooo0?oo
o`1A0?ooo`/00000103oool00`1Eo`0000000?ooo`0b0?ooo`@00000JP3oool009`0oooo1P00000E
0?ooo`80IVIV1P3oool606IVIP<0oooo0P1VIVH20?ooo`0305Go003oool0oooo05d0oooo00@0EOl0
000000000000d=3@1P0000040?ooo`<00000=03oool4000006P0oooo002N0?ooo`L000004`3oool2
06IVIP030?ooo`1VIVH0IVIV00<0IVIV2@3oool206IVIP80EOl0GP3oool00`1Eo`00000000000007
000000L0oooo0P1Eo`0d0?ooo`@00000I`3oool00:40oooo1P00000C0?ooo`80IVIV3P3oool00`1V
IVH0EOl00?ooo`1N0?ooo`0305Go00000000000000@0000000@0EOl00?ooo`00000000001`3oool2
05Go03D0oooo1000001U0?ooo`00Y03oool600000140oooo0P1VIVH=0?ooo`<00000G03oool80000
00030?ooo`000000000000<000001`3oool3000003@0oooo1000001T0?ooo`00YP3oool600000100
oooo0P1VIVH;0?ooo`@0EOl0F`3oool7000000030?ooo`1Eo`00oooo00H000001`3oool2000003H0
oooo0`00001S0?ooo`00Z@3oool6000001X0oooo101Eo`1K0?ooo`D000000`3oool00`1Eo`00oooo
00000005000000T0oooo00<0EOl00000003oool0=03oool400000640oooo002[0?ooo`H000005`3o
ool305Go00030?ooo`1Eo`00EOl005T0oooo00<0EOl00000000000000`0000030?ooo`0305Go003o
ool0000000D000002@3oool30000000305Go003oool0oooo0380oooo1000001P0?ooo`00[P3oool6
000001<0oooo00@0EOl00000003oool0EOl00P3oool00`1Eo`00oooo0?ooo`1G0?ooo`80EOl00P00
00050?ooo`H00000303oool010000000oooo05Go001Eo`0e0?ooo`@00000GP3oool00;00oooo1P00
000@0?ooo`80EOl0100000000`3oool0EOl00?ooo`1F0?ooo`@0000000<0WIfM000000000000103o
ool20000000405Go003oool0EOl0000000l0oooo0P1Eo`0e0?ooo`@00000G@3oool00;<0oooo1P00
000<0?ooo`80EOl000<0oooo05FZZP1EZZX00P1EZZX20000000305Go003oool0oooo05<0oooo2000
00050?ooo`80EOl000<0oooo0000000000000P00000>0?ooo`<00000=@3oool3000005`0oooo002e
0?ooo`H000001@3oool40000000404i>CP1Eo`00CTi>04i>CPP00000D`3oool3000000030?ooo`00
0000000000<00000103oool8000000h0oooo0`00000f0?ooo`@00000FP3oool00;P0oooo1P000002
0?ooo`030000001>CTh0CTi>0080CTi>20000000101EZZX0EOl000000000001A0?ooo`0305Go0000
000000000080oooo00<0EOl00?ooo`3oool00P0000040?ooo`P00000B03oool4000005T0oooo002j
0?ooo``000000P1>CTh:000004l0oooo0`0000020?ooo`80EOl0203oool00`1Eo`0000000?ooo`02
0?ooo`0305Go003oool0oooo04X0oooo1000001G0?ooo`00_@3oool800000080CTi>2`00001=0?oo
o`D000000P3oool00`1Eo`00oooo0?ooo`060?ooo`80000000D0EOl00?ooo`3oool0oooo05Go001=
0?ooo`@00000EP3oool00;l0oooo2@0000000`2QXJ4000000:6QX@08000004`0oooo0`0000040?oo
o`0305Go003oool0oooo00D0oooo0`0000000`1Eo`00oooo0?ooo`03000004h0oooo0`00001E0?oo
o`00_@3oool;000000030:6QX@00000000000080000000<0ZUGo0000001Eo`001000001:0?ooo`80
EOl0103oool4000000L0oooo00@0EOl000000000000000000P3oool2000004l0oooo1000001C0?oo
o`00_`3oool00`000000EOl000000009000000030:6QX@000000ZUGo0080000000<0EOl000000000
00000P0000180?ooo`<000000P3oool7000000D0oooo00<0EOl00?ooo`3oool00P0000020?ooo`03
05Go003oool0oooo04l0oooo1000001B0?ooo`00_`3oool205Go00@0000000<0oooo000000000000
1`00000205Go00030000003oool0oooo04P0oooo00<0EOl00000000000000`3oool7000000D0oooo
00<0EOl00?ooo`3oool0103oool205Go0580oooo1000001@0?ooo`00_@3oool01@00o`00EOl005Go
001Eo`00000000<0oooo0P0000020:6QX@P000000P1Eo`180?ooo`80EOl01P3oool6000000<0oooo
0P0000000`1Eo`00oooo0?ooo`040?ooo`800000D`3oool4000004l0oooo002l0?ooo`D0EOl0103o
ool2000000<0XJ6Q200000000`1Eo`00oooo0?ooo`140?ooo`<00000203oool00`1Eo`0000000000
0002000000<0oooo0`0000060?ooo`<00000E03oool3000004h0oooo002k0?ooo`H0EOl01@3oool5
000000<0oooo1P000000102ZEOl000000000000000120?ooo`800000203oool0101Eo`00oooo05Go
001Eo`040?ooo`0305Go003oool0oooo05h0oooo1000001<0?ooo`00^@3oool505Go00030?ooo`1E
o`00oooo00d0oooo00<0EOl00000000000001`0000190?ooo`H0000000@0EOl00?ooo`3oool0oooo
0P00001Q0?ooo`@00000B`3oool00;P0oooo0`00000205Go0080oooo00<0EOl00?ooo`3oool02`3o
ooo6000004X0oooo002g0?ooo`80EOl00P0000000`1Eo`00oooo00000002000000`0oooo1P000000
103<VIT000000000002ZEOnm000004X0oooo002d0?ooo`80000000<04@0000000000000010000002
05FZo`800000403oool00`000000c9VI00000002000000030:YEo`000000oooo04`0oooo0`000003
05Go0;80oooo002d0?ooo`030000001Eo`00000000P0000000<0EJ[o0000003oool03P3oool20000
00030<bIV@000000000000<00000CP3oool010000000oooo00000000002c0?ooo`00/`3oool205Go
00<0000000<0Z_nZ0?ooo`0000000P000000101EZ_l0000000000000000?0?ooo`@00000DP3oool0
101Eo`00000000000000002c0?ooo`00/@3oool305Go0080000000P0Z_nZ0?ooo`3oool000000?nZ
ZP000000oooo00000080EJ[o0P00001S0?ooo`D00000/`3oool00;00oooo0P1Eo`000`00o`000000
000000040?ooo`<0000000<0oooo0000000000000P00001T0?ooo`<0000000<0oooo05Go003oool0
/P3oool00:d0oooo100000000`3oool00000000000050?ooo`8000000`3oool00`1Eo`0000000?oo
o`1U0?ooo`0405Go003oool0oooo05Go0;<0oooo002]0?ooo`@000003@3oool00`1Eo`00oooo0?oo
o`1U0?ooo`0305Go003oool0oooo00<00000/@3oool00:l0oooo00<000000?ooo`3oool0203oool7
000006D0oooo00<0EOl00?ooo`0000000`00002a0?ooo`00_03oool00`000000EOl0000000030000
06<0oooo0`00002e0?ooo`00_@3oool205Go06H0oooo0P00002f0?ooo`00_@3oool305Go06H0oooo
00<0EOl00?ooo`3oool0]03oool00;d0oooo00<0EOl0000000000000IP3oool200000;D0oooo002m
0?ooo`<0EOl0IP3oool200000;D0oooo002m0?ooo`@0EOl0o`3ooolM0?ooo`00_@3oool205Go0003
0?ooo`1Eo`00oooo0?l0oooo703oool00;d0oooo0P1Eo`3o0?oooal0oooo002m0?ooo`80EOl0o`3o
oolO0?ooo`00^P3oool20000000304i>CP000000000000800000o`3ooolM0?ooo`00^P3oool70000
0?l0oooo7@3oool00;/0oooo1P00003o0?oooad0oooo002l0?ooo`D00000o`3ooolM0?ooo`00o`3o
oooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00o`3ooooN0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{477, 389.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The evolution of an individual on the genotypical and phenotypical \
level (both multi-dimensional search spaces). The mapping from genotype to \
phenotype is non-linear, expressed by the different genome / phenome paths.\
\
\>", "NumberedFigure"]
}, Closed]],

Cell[CellGroupData[{

Cell["Adaptation of Populations", "Subsubsection"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008I00017B000`400?l00000o`00003oo`3ooooo
0?oooa/0oooo003o0?ooool0oooo6`3oool00?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo
003o0?ooool0oooo6`3oool00?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo003o0?ooool0
oooo6`3oool00?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo003o0?ooool0oooo6`3oool0
0?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo003o0?ooool0oooo6`3oool00?l0ooooo`3o
oolK0?ooo`00o`3ooonK0?ooo`L000000`3oool3000000030?ooo`000000oooo00@0oooo10000000
0`3oool000000?ooo`030?ooo`<000000`3oool300000080oooo100000001@3oool000000?ooo`3o
ool0000000H0oooo100000040?ooo`D00000>P3oool00?l0ooooVP3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000040?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0g0?ooo`00o`3ooonJ0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0=`3oool00?l0ooooJ`3oool2
0>o_k`d00000803oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool02`3oool2000003T0oooo003o0?oooeP0oooo0P3_knlQ000002L0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000
103oool8000000<0oooo0`00000k0?ooo`00o`3ooom50?ooo`80kno_9`00000;0>o_k`@000008`3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`040?ooo`040000003oool00000000003h0oooo003o
0?oooc80oooo0P3_knlW000001l0kno_1000000N0?ooo`@000001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0g0?ooo`00
o`3ooolN0?ooo`80kno_:000000d0>o_k`@000006P3oool2000000T0oooo00@000000?ooo`3oool0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020000
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo03L0oooo003o0?ooo`/0oooo0P3_knlX000004P0kno_1000000I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`02000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool00P3oool4000000030?ooo`00000000000080000000<0oooo0000
003oool0103oool01@000000oooo0?ooo`000000oooo008000000`3oool4000000@0oooo1@00000j
0?ooo`00m`3oool20>o_kbL00000GP3_knl4000001L0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`00000I0?ooo`030000003oool0oooo05P0oooo003S0?ooo`80kno_:000001b0>o_
k`@000005P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000001T0oooo00<00000
0?ooo`3oool0F03oool00=00oooo0P3_knlX000008L0kno_1000000E0?ooo`L00000N03oool00;d0
oooo0P3_knlW000009`0kno_1000002C0?ooo`00ZP3oool20>o_kbL00000/@3_knl400000940oooo
002F0?ooo`80kno_:00000350>o_k`@00000T03oool008<0oooo0P3_knlX00000=X0kno_1000001?
0?ooo`8000001P3oool00`000000oooo0?ooo`0d0?ooo`00L03oool20>o_kbL00000k`3_knl40000
0500oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`00G@3oool20>o_kbL0
0000o`3_knl50>o_k`<00000D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0
oooo001E0?oooah00000o`3_knlI0>o_k`@000008`3oool400000080oooo00<000000?ooo`3oool0
0P3oool4000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`@00000
0`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000@0oooo
00<000000?ooo`3oool00P3oool3000002H0oooo001E0?ooo`/00000o`3_knl]0>o_k`@000008@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo0P0000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000002D0oooo001G0?ooo`H00000o`3_knlb
0>o_k`@000007P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0000
00050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool005X0oooo1P00
003o0>o_kc00kno_1000000L0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0X0?ooo`00G03oool700000?l0kno_;`3_knl4000001X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08000000030?ooo`000000oooo00@0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo000000050?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02P0oooo001O0?ooo`H00000o`3_knl^0>o_k`@000006@3oool00`000000oooo0?ooo`020?oo
o`D000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
:03oool00680oooo1P00003o0>o_k`@0kno_4P00000G0>o_k`@000005`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0280oooo001T0?ooo`H00000o`3_knlE000001L0kno_1000000F0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`00I`3oool6
000003@0kno_0P0000040>o_k`800000103_knl200000;P0kno_1@00000<0>o_k`8000000P3_knl3
000001P0kno_1000000D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool4
000000<0oooo00<000000?ooo`0000000P0000060?ooo`@000000P3oool4000000030?ooo`000000
oooo00@0oooo00@000000?ooo`000000oooo0`0000040?ooo`030000003oool0oooo0080oooo1000
000U0?ooo`00J@3oool700000340kno_0P0000040>o_k`800000103_knl2000001/0kno_0P00002I
0>o_k`D000003@3_knl400000080kno_1000000G0>o_k`@00000503oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@03oool006`0oooo1P0000130>o_
k`P00000303_knl4000009H0kno_1@0000020>o_k`@00000203_knl600000080kno_1000000H0>o_
k`@000004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0@03oool006l0oooo1P0000100>o_k`h000001@3_knl5000009@0kno_1@0000030>o_k`D0
0000203_knl6000000@0kno_0`00000H0>o_k`@000004`3oool4000003D0oooo00<000000?ooo`3o
ool0:`3oool00740oooo1P0000170>o_k`P0000000<0kno_0000000000001@00000?0>o_ka<00000
L03_knl4000000@0kno_1P0000080>o_k`H000001@3_knl3000001T0kno_1000001h0?ooo`00M03o
ool6000004d0kno_1`00000=0>o_kaH00000K`3_knl2000000H0kno_1P0000080>o_k`H000001P3_
knl2000001X0kno_1000001g0?ooo`00MP3oool7000004T0kno_2@00000:0>o_k`D000004@3_knl3
000006d0kno_0`0000060>o_k`H00000203_knl5000000L0kno_0P00000L0>o_k`@00000M@3oool0
07T0oooo1P0000170>o_k`X000001`3_knl5000001@0kno_0`00001/0>o_k`8000001`3_knl60000
00P0kno_100000080>o_k`8000007@3_knl4000007@0oooo001l0?ooo`H00000A03_knl:000000D0
kno_1@0000090>o_k`800000303_knl3000006/0kno_0P00000?0>o_k`H000002`3_knl3000001l0
kno_1000001b0?ooo`00OP3oool600000440kno_300000020>o_k`D000002P3_knl4000000`0kno_
0`00001Y0>o_k`<000003`3_knl6000000/0kno_0P00000Q0>o_k`@00000L@3oool00840oooo1P00
001;0>o_k`@00000303_knl4000000d0kno_0`00001X0>o_k`800000403_knl6000000/0kno_0P00
000S0>o_k`@00000K`3oool008<0oooo1`0000180>o_k`8000003`3_knl2000000l0kno_0`00001W
0>o_k`800000403_knl6000000/0kno_0P00000T0>o_k`@00000KP3oool008H0oooo1P0000160>o_
k`8000000`3_knl4000001X0kno_0`00001U0>o_k`<00000403_knl5000000`0kno_0P00000V0>o_
k`@00000K03oool008T0oooo1P0000130>o_k`8000000P3_knl6000001X0kno_0P00001U0>o_k`80
00004@3_knl4000000d0kno_0P00000J0>o_k`030000003_knl0kno_00X0kno_1000001[0?ooo`00
R`3oool600000440kno_0P0000020>o_k`H000006@3_knl3000006D0kno_0P0000070>o_k`H00000
503_knl3000001T0kno_0P00000>0>o_k`@00000J@3oool008h0oooo1P00000n0>o_k`8000000`3_
knl4000001X0kno_0P00001U0>o_k`<000001P3_knl7000001@0kno_0P00000I0>o_k`<000003`3_
knl4000006P0oooo002@0?ooo`L00000>`3_knl200000240kno_0P00001U0>o_k`<000001@3_knl7
000000D0kno_1000000;0>o_k`<00000103_knl<000000T0kno_1000000@0>o_k`@00000IP3oool0
09<0oooo1P00000h0>o_k`<00000803_knl3000006D0kno_100000040>o_k`H000001@3_knl50000
00X0kno_100000040>o_ka4000000`3_knl500000140kno_1000001U0?ooo`00UP3oool6000001D0
kno_5`3M20H90>o_k`8000003P3_knl4000000l0kno_0P00001X0>o_k`<00000103_knl5000000@0
kno_1P0000080>o_k`@000004P3_knl500000080kno_1P00000C0>o_k`<00000I03oool009P0oooo
1P00000D0>o_kaD0g@P62P3_knl2000000d0kno_1P00000=0>o_k`<00000J@3_knl4000000<0kno_
100000040>o_k`H000001`3_knl4000001T0kno_2000000C0>o_k`@00000HP3oool009/0oooo1P00
000A0>o_ka<0g@P6303_knl2000000d0kno_1P0000050>o_k`8000001P3_knl2000006/0kno_1000
000:0>o_k`H000001@3_knl4000001X0kno_2@00000D0>o_k`@00000H@3oool009d0oooo1`00000>
0>o_ka80g@P63@3_knl2000000h0kno_100000050>o_k`@000001@3_knl2000006d0kno_0`000009
0>o_k`H00000103_knl4000001X0kno_2P00000F0>o_k`@00000G`3oool00:00oooo1P00000;0>o_
ka80g@P63P3_knl2000000H0kno_1000000=0>o_k`@000000`3_knl4000006h0kno_1`00000<0>o_
k`@000007`3_knl8000001H0kno_1000001N0?ooo`00X`3oool6000000D0kno_4`3M20H@0>o_k`80
00001@3_knl6000000d0kno_0P0000030>o_k`@00000L03_knl>000000<0kno_1000000V0>o_k`80
0000603_knl4000005`0oooo002U0?ooo`H000001`3M20H00`3_knl0g@P60=d81P0;0=d81Q40kno_
0`0000040>o_k`H00000403_knl4000007L0kno_3P0000130>o_k`@00000F`3oool00:P0oooo1`3M
20H40>o_k`/0g@P6503_knl3000000@0kno_1000000@0>o_k`@00000P03_knl5000004H0kno_1000
001I0?ooo`00Y@3oool70=d81P@00000103_knl90=d81P`0kno_0P0000080>o_k`<000005@3_knl4
00000340kno_4`00000U0>o_k``00000F@3_knl4000005P0oooo002Q0?ooo`P0g@P6103oool60000
00030>o_k`3M20H0g@P600D0g@P63P3_knl2000000T0kno_0`00000C0>o_k`@00000<@3_knlE0000
02D0kno_2`00001K0>o_k`@00000EP3oool009h0oooo203M20H90?ooo`D000001P3M20H>0>o_k`<0
00002P3_knl300000100kno_100000020>o_k`030000003_knl0kno_02`0kno_1000000A0>o_k`<0
0000903_knl:000005d0kno_1000001E0?ooo`00V`3oool70=d81Q00oooo0P0000050=d81Ph0kno_
0`00000<0>o_k`<000003P3_knl400000080kno_1000000[0>o_k`@000004`3_knl3000002<0kno_
2P0000110>o_k`800000103_knl2000000@0kno_0P00000@0>o_k`@00000D`3oool009P0oooo1`3M
20HF0?ooo`80g@P61000000<0>o_k`8000003P3_knlB000000H0kno_1000000W0>o_k`@000001@3_
knl4000000d0kno_0`00000S0>o_k`P00000@P3_knl2000000@0kno_0P0000040>o_k`8000004@3_
knl400000580oooo002E0?ooo`L0g@P66@3oool00`3M20H0oooo00000005000000T0kno_0`00000?
0>o_ka0000002@3_knl5000002<0kno_100000050>o_k`D000003P3_knl3000001h0kno_0`000000
0`3_knl0000000000006000006<0kno_1000001@0?ooo`00T@3oool80=d81R40oooo1P0000050>o_
k`<00000:`3_knl6000000d0kno_0P00000?0>o_k`@000001P3_knl6000000l0kno_0`00000J0>o_
k`D000000P3_knl7000006D0kno_1000001?0?ooo`00SP3oool80=d81RH0oooo1`0000020>o_k`80
0000;`3_knl5000000/0kno_0`00000=0>o_k`@000001`3_knl600000100kno_0`00000F0>o_k`H0
00001@3_knl6000006L0kno_1000001=0?ooo`00R`3oool70=d81Rd0oooo1P00000c0>o_k`L00000
1`3_knl4000000/0kno_0`00000:0>o_k`D000002P3_knl2000000D0kno_0`00000A0>o_k`L00000
2@3_knl400000180kno_0P00001E0>o_k`@00000C03oool008P0oooo1`3M20Hc0?ooo`H00000<`3_
knl7000000@0kno_1@00000:0>o_k`800000303_knl4000000T0kno_100000050>o_k`8000003@3_
knl8000000`0kno_1000000B0>o_k`800000E`3_knl4000004X0oooo00250?ooo`L0g@P6>03oool6
000003@0kno_1`0000000`3_knl0000000000004000000T0kno_0P00000F0>o_k`P000000`3_knl3
000000P0kno_2@00000A0>o_k`8000004`3_knl2000005P0kno_100000190?ooo`00PP3oool70=d8
1Sh0oooo1P00000e0>o_k`<0000000<0kno_0000000000001@0000070>o_k`<000005P3_knl80000
00<0kno_0P0000040>o_k`X000005P3_knl00`000000kno_0>o_k`0@0>o_k`<00000FP3_knl40000
04L0oooo001n0?ooo`P0g@P6@`3oool7000003H0kno_200000060>o_k`8000001@3_knl4000000P0
kno_100000020>o_k`P000000P3_knl<000002h0kno_0P00001L0>o_k`@00000AP3oool007/0oooo
203M20I90?ooo`H00000=03_knl9000000D0kno_0P0000040>o_k`D000001`3_knl500000080kno_
200000020>o_k`L00000<`3_knl2000005h0kno_100000140?ooo`00N03oool70=d81U00oooo1P00
000a0>o_k`P000001P3_knl2000000<0kno_1P0000060>o_k`H000000`3_knl4000000D0kno_0P00
000h0>o_k`800000G`3_knl4000004<0oooo001e0?ooo`L0g@P6E@3oool6000002h0kno_1`000008
0>o_k`8000000`3_knl6000000H0kno_1P0000040>o_k`8000001@3_knl3000003L0kno_0`00001Q
0>o_k`@00000@@3oool00640oooo00<000000?ooo`3oool03P3oool70=d81TH0oooo0P00000C0?oo
o`H00000:`3_knl4000000X0kno_0`0000040>o_k`D000001P3_knl6000000/0kno_0P00000h0>o_
k`800000H`3_knl400000400oooo001Q0?ooo`030000003oool0oooo00`0oooo1P3M20I90?ooo`80
00005@3oool7000002P0kno_0P00000<0>o_k`8000001P3_knl4000000@0kno_200000090>o_k`@0
0000>03_knl2000006D0kno_0`00000o0?ooo`00HP3oool00`000000oooo0?ooo`0;0?ooo`<0g@P6
B`3oool3000001P0oooo1P00000U0>o_k`030000003_knl0kno_00`0kno_0`00000<0>o_k`@00000
3@3_knl400000:40kno_1000000m0?ooo`00?P3oool5000000030?ooo`000000oooo00<0oooo1000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<0
00000?ooo`0000000P0000050?ooo`@000001@3oool4000000<0oooo00<000000?ooo`3oool0?`3o
ool2000001`0oooo1P00000b0>o_k`<00000203_knl8000000X0kno_1000002T0>o_k`@00000?03o
ool003d0oooo0P0000040?ooo`030000003oool000000080oooo0P0000030?ooo`80000000<0oooo
000000000000103oool010000000oooo0?ooo`3oool2000000<0oooo0P0000000`3oool000000000
00030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`00
0000000003l0oooo0`00000N0?ooo`H00000<@3_knl3000000L0kno_200000090>o_k`@00000Y`3_
knl4000003X0oooo000m0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo000000060?ooo`030000003o
ool0000003l0oooo0P00000R0?ooo`H00000;`3_knl3000000H0kno_200000070>o_k`@00000ZP3_
knl4000003T0oooo000l0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000060?ooo`030000003oool0000000H0oooo00<000000?ooo`000000
?P3oool3000002@0oooo1`00000]0>o_k`<000001@3_knl8000000H0kno_1000002]0>o_k`@00000
=`3oool003`0oooo00<000000?ooo`3oool01P3oool200000080oooo1`0000000`3oool000000000
00040?ooo`040000003oool0oooo0?ooo`L0000000<0oooo000000000000103oool3000000H0oooo
00<000000?ooo`0000001P3oool010000000oooo00000000000m0?ooo`800000:03oool6000002`0
kno_0`0000050>o_k`@000001`3_knl400000;00kno_1000000f0?ooo`00?@3oool00`000000oooo
0?ooo`020?ooo`D000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo000000050?ooo`030000003oool0000000H0
oooo00<000000?ooo`0000001P3oool00`000000oooo0000000m0?ooo`800000:`3oool6000002X0
kno_0`0000050>o_k`8000001`3_knl400000;<0kno_1000000d0?ooo`00?@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo
0?ooo`0000060?ooo`040000003oool00000000000@0oooo00<000000?ooo`0000001P3oool00`00
0000oooo000000060?ooo`030000003oool0000003`0oooo0`00000]0?ooo`H00000:@3_knlB0000
0;H0kno_1000000c0?ooo`00?@3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool200000004
0?ooo`0000000000000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80000000@0oooo
00000000000000000P3oool200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P00
00000`3oool000000000000k0?ooo`800000<@3oool6000002L0kno_4000002i0>o_k`@00000<@3o
ool003h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`@000000`3oool0
0`000000oooo00000002000000H0oooo100000030?ooo`030000003oool00000008000001@3oool4
000000D0oooo100000030?ooo`030000003oool0oooo03P0oooo0`00000c0?ooo`H00000:`3_knl2
000004T0kno_0P00001g0>o_k`@00000<03oool003l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo0P00000g0?ooo`H000009`3_knl30000
04T0kno_0P00001i0>o_k`@00000;P3oool00400oooo0P0000030?ooo`800000>03oool2000003P0
oooo0`00000i0?ooo`L00000903_knl2000004X0kno_0P00001j0>o_k`@00000;@3oool00480oooo
1000000j0?ooo`030000003oool0oooo03H0oooo0P00000m0?ooo`H000008P3_knl2000004T0kno_
0`00001l0>o_k`@00000:`3oool00?/0oooo1P00000O0>o_k`800000B@3_knl2000007h0kno_1000
000Z0?ooo`00o@3oool6000001`0kno_0`0000190>o_k`800000P03_knl4000002P0oooo003o0?oo
o`40oooo1P00000I0>o_k`800000BP3_knl200000840kno_1000000W0?ooo`00o`3oool30?ooo`L0
00005P3_knl2000004T0kno_0`0000230>o_k`@000009@3oool00?l0oooo1P3oool6000005l0kno_
0P0000250>o_k`@00000903oool00?l0oooo2@3oool6000005`0kno_0P0000270>o_k`@000008P3o
ool00?l0oooo2`3oool6000005X0kno_0P0000280>o_k`@000008@3oool00?l0oooo3P3oool60000
05H0kno_0`00002:0>o_k`@000007`3oool00;<0oooo0P00001J0?ooo`L00000D`3_knl2000008`0
kno_1000000N0?ooo`00/`3oool2000005d0oooo1P00001A0>o_k`800000SP3_knl4000001`0oooo
002b0?ooo`<00000H03oool6000004h0kno_0P00002?0>o_k`@000006`3oool00;80oooo0P00001S
0?ooo`H00000B`3_knl300000940kno_1000000I0?ooo`00/@3oool3000006H0oooo1P0000180>o_
k`800000T`3_knl4000001P0oooo002a0?ooo`800000J@3oool7000004D0kno_0P00002E0>o_k`<0
00005`3oool00;00oooo0`00001Z0?ooo`P00000f`3_knl4000001D0oooo002`0?ooo`800000J`3o
ool2000000<0oooo1P00003I0>o_k`@00000503oool00:l0oooo0`00001Z0?ooo`<000001@3oool6
00000=T0kno_1000000B0?ooo`00[`3oool2000006/0oooo0P0000090?ooo`H00000e`3_knl40000
0140oooo002^0?ooo`<00000J`3oool2000000/0oooo1`00003F0>o_k`@000003`3oool00:h0oooo
0P00001[0?ooo`<000003P3oool600000=D0kno_1000000>0?ooo`00[@3oool3000006/0oooo0P00
000B0?ooo`H00000e03_knl4000000`0oooo002]0?ooo`800000K03oool2000001@0oooo1P00003C
0>o_k`@000002`3oool00?l0oooo6`3oool3000001L0oooo1P00003B0>o_k`@000002@3oool00?l0
oooo6`3oool2000001X0oooo1`00003@0>o_k`@00000203oool00?l0oooo6`3oool2000001d0oooo
1P00003@0>o_k`@000001P3oool00?l0oooo6P3oool300000200oooo1P00003>0>o_k`@000001@3o
ool00?l0oooo6P3oool2000002<0ooooe`0000040?ooo`00o`3ooolJ0?ooo`8000009P3ooooD0000
00@0oooo003o0?ooofD0oooo0P00002c0?ooo`00o`3ooomT0?ooo`<00000/`3oool00?l0ooooI03o
ool200000;@0oooo003o0?ooof@0oooo0P00002d0?ooo`00Y`3oool200000;T0oooo0`00002d0?oo
o`00Y`3oool200000;T0oooo0P00002e0?ooo`00YP3oool300000;T0oooo0P00002e0?ooo`00Y@3o
ool300000;X0oooo0P00002e0?ooo`00Y03oool300000;X0oooo0`00002e0?ooo`00Y03oool20000
0;/0oooo0P00002f0?ooo`00X`3oool3000006l0oooo0P00001:0?ooo`800000]P3oool00:80oooo
0`00001`0?ooo`800000B@3oool300000;H0oooo002R0?ooo`800000L@3oool2000004T0oooo0P00
002g0?ooo`00X@3oool300000740oooo0P0000190?ooo`800000]`3oool00:00oooo0`00001a0?oo
o`<00000o`3oool30?ooo`00W`3oool300000780oooo0P00003o0?ooo`@0oooo002O0?ooo`800000
L`3oool200000?l0oooo103oool00?l0oooo5@3oool200000?l0oooo103oool00?l0oooo5@3oool2
00000?l0oooo103oool00?l0oooo503oool300000?l0oooo103oool00?l0oooo503oool200000?l0
oooo1@3oool00?l0oooo503oool200000?l0oooo1@3oool00?l0oooo503oool200000?l0oooo1@3o
ool00?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo002I0?ooo`800000`@3oool200000;/0
oooo002I0?ooo`800000`@3oool200000;/0oooo002H0?ooo`<00000`@3oool200000;/0oooo002H
0?ooo`800000`@3oool300000;/0oooo002H0?ooo`800000`@3oool200000;`0oooo002G0?ooo`<0
0000`@3oool200000;`0oooo002G0?ooo`800000`@3oool300000;`0oooo002G0?ooo`800000`@3o
ool200000;d0oooo002F0?ooo`<00000MP3oool2000004T0oooo0P00002m0?ooo`00UP3oool20000
07L0oooo0P0000190?ooo`800000_@3oool009H0oooo0P00001g0?ooo`800000B03oool300000;d0
oooo002E0?ooo`<00000MP3oool3000004P0oooo0P00002n0?ooo`00U@3oool2000007L0oooo0P00
00190?ooo`800000_P3oool009D0oooo0P00001g0?ooo`800000B03oool300000;h0oooo002D0?oo
o`<00000M`3oool2000004P0oooo0P00002o0?ooo`00U03oool2000007P0oooo0P0000180?ooo`80
0000_`3oool00?l0oooo3P3oool300000?l0oooo2P3oool00?l0oooo3P3oool200000?l0oooo2`3o
ool00?l0oooo3P3oool200000?l0oooo2`3oool00?l0oooo3P3oool200000?l0oooo2`3oool00?l0
oooo3P3oool200000?l0oooo2`3oool00?l0oooo3@3oool300000?l0oooo2`3oool00?l0oooo3@3o
ool200000?l0oooo303oool00?l0oooo3@3oool200000?l0oooo303oool008h0oooo0P00003o0?oo
ohX0oooo002>0?ooo`800000o`3ooon:0?ooo`00S@3oool300000?l0ooooRP3oool008`0oooo0`00
003o0?oooh/0oooo002<0?ooo`800000b03oool200000<40oooo002;0?ooo`<00000b03oool20000
0<40oooo00240?ooo`<000000`3oool3000008`0oooo3@00000_0?ooo`<00000`@3oool008@0oooo
2000001i0?ooob800000;P3oool200000<80oooo00240?ooo`P00000IP3ooolX000000/0oooo1000
000[0?ooo`<00000`P3oool008@0oooo2@00001A0?ooobP00000103oool2000001X0oooo1000000Z
0?ooo`800000``3oool008<0oooo3000000k0?ooobT000005`3oool2000001`0oooo1000000X0?oo
o`800000``3oool008<0oooo3@00000V0?ooobT00000:P3oool3000001d0oooo1000000V0?ooo`<0
0000``3oool008<0oooo3000000C0?ooobT00000?P3oool200000200oooo1000000T0?ooo`800000
a03oool008<0oooo2`0000000`3oool000000000000V00000580oooo0P00000Q0?ooo`@000008P3o
ool300000<@0oooo001k0?ooobP00000IP3oool2000002<0oooo1000000P0?ooo`800000a@3oool0
06L0oooo:@00001h0?ooo`<00000903oool5000001d0oooo0`0000350?ooo`00D`3ooolY000000H0
oooo2@00001g0?ooo`<000000`3oool2000002L0oooo1000000L0?ooo`800000aP3oool003l0oooo
:@00000J0?ooo`P00000N03oool8000002T0oooo1000000J0?ooo`800000aP3oool002`0oooo:000
000^0?ooo`L00000N@3oool8000002X0oooo1000000H0?ooo`<00000aP3oool001P0oooo:0000012
0?ooo`H00000NP3oool;000002T0oooo1000000F0?ooo`800000a`3oool000h0oooo7`00001D0?oo
o`H00000N`3oool;000002X0oooo1000003N0?ooo`003P3oool;000006P0oooo1@00001l0?ooo`/0
0000;03oool400000=`0oooo000@0?ooo`L00000JP3oool4000007d0oooo2P00000^0?ooo`@00000
f`3oool001<0oooo1P00001X0?ooo`<00000OP3oool:00000300oooo1000003I0?ooo`005P3oool6
000006D0oooo0P00001o0?ooo`T00000<P3oool400000=P0oooo000H0?ooo`L00000H@3oool20000
0800oooo2000000e0?ooo`@00000eP3oool001/0oooo1P00001O0?ooo`030000003oool0oooo07l0
oooo2000000f0?ooo`@00000e@3oool001h0oooo1P00003N0?ooo`L00000>@3oool400000=<0oooo
000P0?ooo`L00000f`3oool7000003X0oooo1000003B0?ooo`008`3oool700000=P0oooo1P00000m
0?ooo`@00000;@3oool7000000H0oooo100000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo100000000`3oool00000000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool4000000@0oooo100000001@3oool000000?ooo`3oool0000000D0oooo
1@00001F0?ooo`009P3oool600000=H0oooo1@00000o0?ooo`D00000:`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00050?ooo`040000003oool0oooo000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo0P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1C0?oo
o`00:@3oool600000=<0oooo1@0000110?ooo`@000000P3oool2000002H0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`0000060?ooo`8000001@3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo05<0oooo000[0?ooo`L00000d03oool4000004@0oooo1P00
000V0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`0000001@3oool01000
0000oooo0?ooo`0000090?ooo`800000E@3oool002h0oooo1P00000l0?oooa000000PP3oool40000
04D0oooo1@00000V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@0000050?oo
o`040000003oool0oooo0?ooo`H00000103oool00`000000oooo000000030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000060?ooo`<00000
E`3oool00340oooo1P00000i0?oooa000000PP3oool3000004P0oooo1000000U0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`8000001@3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`000004
0?ooo`800000FP3oool003<0oooo1`00000f0?oooa000000PP3oool3000004P0oooo1@00000T0?oo
o`L00000103oool00`000000oooo0?ooo`040?ooo`8000001@3oool010000000oooo0?ooo`000005
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool003H0oooo1P00000d0?oooa000000
PP3oool2000004T0oooo0P0000000`3oool000000000000200000280oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
00000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo05<0oooo000i0?ooo`H00000<@3oool@00000880oooo00<000000?ooo`3oool0B03o
ool200000080oooo1000000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool400000080oooo00<000000?ooo`0000000P0000050?ooo`D000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000@0oooo100000030?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool000000?ooo`0200000080oooo1@00001F0?ooo`00>`3oool7000002h0oooo4000
00220?ooo`030000003oool0oooo04L0oooo0`0000040?ooo`@000007`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S@3oool003h0oooo1P00000/
0?oooa000000a@3oool3000000@0oooo0P0000060?ooo`@000007P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S@3oool00440oooo1P00000Y0?oo
oa000000a@3oool6000000030?ooo`000000000000P0oooo1000000L0?ooo`L00000303oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo07<0oooo00130?ooo`L000009P3oool@00000<D0
oooo2P0000080?ooo`@00000_P3oool004H0oooo1`00000S0?oooa0000001P3oool500204KX0oooo
3@0000070?ooo`@00000_03oool004T0oooo1P00000Q0?oooa000000203oool700204DL0oooo1@00
P14O0?oooa000000>`3oool=000000P0oooo1000002k0?ooo`00C03oool6000001h0oooo4000000;
0?ooo`T0080A@P3oool<00204AP0oooo4000000k0?ooo`d000002P3oool400000;T0oooo001>0?oo
o`L000005@3oool50=d81R40oooo2P00P14m0?oooa80080A4@3oool@000003`0oooo2`00000<0?oo
o`@00000^03oool00540oooo1P0000080?ooo`l0g@P69`3oool<00204CH0oooo6@00P14:0?oooa00
0000?03oool;000000h0oooo1000002f0?ooo`00E03oool5000001<0g@P6;`3oool?00204Bd0oooo
6P00P1490?oooa000000?03oool:00000100oooo1@00000S0?ooo`030000003oool0oooo00T0oooo
100000050?ooo`@0000000@0oooo000000000000oooo0`0000030?ooo`@0000000D0oooo0000003o
ool0oooo000000060?ooo`@000001@3oool5000000h0oooo100000001@3oool000000000003oool0
000000D0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo02X0oooo001F0?oo
o`<000004P3M20Hg0?oooaD0080A803ooolG00204@`0oooo4000000l0?ooo`X000004P3oool40000
0280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool200000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
0P00000[0?ooo`00F@3ooolA0=d81T40oooo:`00P1420?oooa<0080A3`3oool@000003`0oooo2@00
000E0?ooo`@00000803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?ooo`00FP3o
ool>0=d81U00oooo7`00P1400`3oool0080A00204@0?00204A40oooo4000000l0?ooo`P000005`3o
ool4000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0:@3oool005T0oooo3P3M20Ia0?ooo`h0080A503oool@000003`0oooo2000000I0?oo
o`@000007@3oool00`000000oooo0?ooo`070?ooo`P000000`3oool600000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo20000004
0?ooo`<000003`3oool600000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo02T0oooo001G0?ooo`h0g@P60P00001a0?ooo``0080A5P3oool@
000003`0oooo1`00000K0?ooo`@00000703oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo008000005`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0:@3oool005@0oooo403M20H6000006h0oooo2@00P14I0?oooa00
0000?03oool7000001d0oooo1000000J0?ooo`L000000`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:@3oool00580
oooo1P3M20H30?ooo`L0g@P6103oool7000006/0oooo1P00P14L0?oooa000000?03oool6000001l0
oooo1000000I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P00000[0?ooo`00D03oool50=d81PH0oooo1P3M20H80?ooo`L00000J03oool400204Ah0oooo4000
000l0?ooo`H000008@3oool4000001L0oooo00<000000?ooo`3oool02@3oool4000000D0oooo1@00
00020?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool0
0P0000030?ooo`@000001@3oool5000000h0oooo1@0000030?ooo`030000003oool0000000800000
1P3oool3000000030?ooo`000000oooo02X0oooo001=0?ooo`H0g@P6203oool50=d81P`0oooo1P00
001V0?ooo`0300204@3oool0oooo01l0oooo4000000l0?ooo`D000008`3oool4000001H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02T0oooo001;
0?ooo`H0g@P62`3oool20=d81Q40oooo1P00003B0?ooo`@000009@3oool4000001@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02T0oooo00190?oo
o`D0g@P63P3oool00`3M20H0oooo0?ooo`0B0?ooo`L00000c`3oool3000002L0oooo1000000C0?oo
o`P00000G@3oool00`000000oooo0?ooo`0Y0?ooo`00AP3oool60=d81RP0oooo1P00003=0?ooo`80
0000:P3oool400000:80oooo00140?ooo`H0g@P6;@3oool600000900oooo0P00P14h0?ooo`800000
:`3oool400000:40oooo00130?ooo`@0g@P6<P3oool7000008h0oooo0P00P14g0?ooo`030000003o
ool0oooo02`0oooo1000002O0?ooo`00@`3oool20=d81SL0oooo1P00002=0?ooo`80080A=P3oool0
0`000000oooo0?ooo`0]0?ooo`@00000WP3oool007l0oooo1P00002;0?ooo`<0080AIP3oool40000
05<0oooo0P0000060?ooo`030000003oool0oooo03h0oooo00210?ooo`L00000R@3oool300204FH0
oooo1@00001C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool003@0oooo
1@00001;0?ooo`H00000R@3oool300204@l0oooo0P00P15E0?ooo`@00000D`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03h0oooo000d0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0B`3oool6000008L0oooo1000P14=0?ooo`@0080AE@3oool4000001`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`@00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo100000030?ooo`<00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000800000103oool00`000000oooo
0?ooo`020?ooo`<00000<03oool003X0oooo00<000000?ooo`3oool0C03oool7000008H0oooo1@00
P14:0?ooo`H0080AE03oool4000001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo00000003
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
0000000_0?ooo`003`3oool4000000@0oooo00<000000?ooo`3oool02`3oool5000000D0oooo00<0
00000?ooo`3oool0103oool3000000030?ooo`000000oooo0080oooo100000001@3oool000000000
003oool0000000D0oooo00@000000?ooo`3oool000000`3oool5000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`D000007P3oool60000
08L0oooo1000P1470?ooo`P0080AE@3oool4000001T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001@3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0/0?ooo`003P3oool2000000<0oooo0P0000030?ooo`030000003oool0
oooo00T0oooo0P0000040?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`8000000`3oool0
10000000oooo0?ooo`3oool3000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000000000030?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`030000003oool0oooo0080oooo0P00000O0?ooo`H00000QP3o
ool500204@@0oooo2P00P14C0?ooo`l00000<P3oool4000001P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0<P3oool000h0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool07`3oool7000008H0oooo1@00P1400`3oool0080A00204@0:00204A40oooo3`00000d0?ooo`@0
00005P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001`0000000`3oool000000?ooo`040?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0b0?ooo`003P3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000040?ooo`040000003o
ool0oooo000000D0oooo00@000000?ooo`3oool000001`3oool200000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00000T0?ooo`L0
0000Q@3ooolB00204@l0oooo3`00000e0?ooo`@000005@3oool7000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<P3o
ool000h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000T0oooo0P00
00080?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo1P0000000`3oool00000000000040?ooo`030000003oool0oooo00800000103o
ool2000000@0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000:@3o
ool6000008H0oooo4@00P14=0?ooo`l00000=`3oool4000001<0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000001P3oool00`000000oooo
000000050?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool000l0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00000^0?ooo`H0
0000P`3ooolC00204@/0oooo3`00000h0?ooo`@000004P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0;03oool000l0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:@3oool70000
0800oooo5000P14:0?ooo`l00000>P3oool400000100oooo00<000000?ooo`3oool0103oool01P00
0000oooo0?ooo`3oool000000?ooo`<000001@3oool4000000<0oooo00<000000?ooo`0000000P00
00060?ooo`@000000P3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`000000oooo
0`0000040?ooo`030000003oool0oooo0080oooo1000000_0?ooo`00403oool2000000<0oooo0P00
00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool2000000040?ooo`00
00000000000000<0oooo0P0000020?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`800000
00@0oooo00000000000000000`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000@0
oooo0P000000103oool000000000000000020?ooo`8000000`3oool00`000000oooo0?ooo`020000
00@0oooo0P00000]0?ooo`H00000O@3ooolG00204@P0oooo3`00000k0?ooo`@000003`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000008P3oool00`000000oooo0?ooo`1:
0?ooo`004P3oool4000000<0oooo100000080?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool000000?ooo`02000000<0oooo0`0000000`3oool000000?ooo`020?ooo`D000000`3oool0
0`000000oooo00000002000000@0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`030000003o
ool000000080000000<0oooo0000000000000P0000040?ooo`D00000<@3oool6000007X0oooo6@00
P1460?ooo`l00000?@3oool4000000d0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool000000280oooo00<000000?ooo`3oool0BP3oool001X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo1`00001g0?oooa<0080A303o
ool?000003h0oooo1000000<0?ooo`L00000103oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo03D0oooo000K0?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`800000N03oool6
000007@0oooo1`00P14I0?ooo`l00000@03oool4000008D0oooo000K0?ooo`<000002`3oool50000
02D0oooo00<000000?ooo`3oool0E03oool600000940oooo3`0000110?ooo`D00000P`3oool00:`0
oooo1`00002>0?ooo`l00000@`3oool400000880oooo000Y0?ooo`030000003oool0oooo08<0oooo
1P00003P0?ooo`@00000P03oool002T0oooo00<000000?ooo`3oool0QP3oool600000=h0oooo1000
001o0?ooo`00:P3oool00`000000oooo0?ooo`270?ooo`L00000g@3oool4000007d0oooo000G0?oo
o`030000003oool0oooo00X0oooo100000020?ooo`030000003oool00000008000001@3oool40000
00050?ooo`000000oooo0?ooo`0000000`3oool4000000030?ooo`00000000000080oooo0P000000
0`3oool000000?ooo`040?ooo`@000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05D0oooo1`00003K0?ooo`@00000O03oool001L0oooo0P00000:0?ooo`8000000`3oool40000
00<0oooo0P0000030?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000000P3oool0
10000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool00P0000030?ooo`8000000`3o
ool2000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0F03oool600000=/0oooo1000
001j0?ooo`00603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P000005
0?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`1J0?ooo`H00000f@3oool4000007T0oooo000H0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000D0oooo00@000000?ooo`3o
ool000001@3oool010000000oooo0?ooo`0000020?ooo`800000103oool010000000oooo0?ooo`00
00030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000050?ooo`030000
003oool0oooo05`0oooo1`00003H0?ooo`@00000M`3oool001P0oooo0P0000090?ooo`030000003o
ool0oooo00@0oooo0`0000040?ooo`80000000<0oooo0000000000001@3oool010000000oooo0000
000000030?ooo`H000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0
103oool010000000oooo0000000000040?ooo`030000003oool0oooo05l0oooo1P00003G0?ooo`@0
0000MP3oool001T0oooo1`0000040?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`040000
003oool0oooo000000D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo0640oooo1P00003F0?ooo`@00000M03oool001T0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000H0oooo0`0000040?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool0H`3oool700000=@0oooo1000001c0?ooo`006@3oool2000000D0oooo00<000000?oo
o`3oool00P3oool2000000<0oooo1@0000020?ooo`8000000P3oool2000000D0oooo00@000000?oo
o`00000000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`02
000000<0oooo0P0000030?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo0?oo
o`1V0?ooo`H00000e03oool400000740oooo000J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool400000080oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool500000080oooo100000000`3oool000000?oo
o`040?ooo`@000000`3oool00`000000oooo00000002000006`0oooo1P00003B0?ooo`@00000L03o
ool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0P@3oool700000=40oooo1000001^0?ooo`006P3oool20000
00D0oooo00<000000?ooo`3oool06`3oool2000000/0oooo00<000000?ooo`3oool0P`3oool60000
0=00oooo1000001]0?ooo`006`3oool7000001h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`220?ooo`H00000c`3oool4000006/0oooo003G0?ooo`L00000c@3oool5000006T0oooo
003J0?ooo`L00000c03oool4000006P0oooo003M0?ooo`H00000c03oool4000006H0oooo003P0?oo
o`H00000bP3oool4000006D0oooo003R0?ooo`L00000b@3oool4000006<0oooo003U0?ooo`H00000
b03oool400000680oooo003X0?ooo`H00000a`3oool400000600oooo003Z0?ooo`L00000a@3oool4
000005l0oooo003]0?ooolh00000GP3oool00?00oooob`00001N0?ooo`00o`3ooooo0?oooa/0oooo
003o0?ooool0oooo6`3oool00?l0ooooo`3ooolK0?ooo`00o`3ooooo0?oooa/0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{537, 285},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Evolutionary adaptation of species and their genepools", 
  "NumberedFigure"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preconditions for Evolution", "Section"],

Cell[TextData[{
  "Following ",
  Cell[BoxData[
      \(TraditionalForm\`Darwin\^\[Prime]\)]],
  "s model of biological evolution, the minimal requirements for evolutionary \
processes (in a phylogenetic sense) to occur are the following ",
  ButtonBox["(Banzhaf et al., 1998):",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Banzhaf et al. 1998"},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"Preconditions"],

Cell[TextData[{
  StyleBox["Reproduction",
    FontWeight->"Bold"],
  " of individuals in the population"
}], "ListSquare"],

Cell[TextData[{
  StyleBox["Variation",
    FontWeight->"Bold"],
  " that affects the likelihood of survival of individuals"
}], "ListSquare"],

Cell[TextData[{
  StyleBox["Heredity",
    FontWeight->"Bold"],
  " in reproduction"
}], "ListSquare"],

Cell[TextData[{
  StyleBox["Competition",
    FontWeight->"Bold"],
  " for finite resources"
}], "ListSquare"],

Cell[TextData[{
  "Lewontin describes three \"Units of Selection\": Variability, differential \
reproduction, and inheritance of fitness ",
  ButtonBox["(Lewontin, 1970)",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Lewontin 1970"},
    ButtonStyle->"Hyperlink"],
  " cited in ",
  ButtonBox["(Wieser, 1994b)",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Wieser 1994b"},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell["Variability, Diversity, Heterogeneity", "Subsection"],

Cell["\<\
The genotypical structures in a population are heterogeneous. \
Individual phenotypes of the population exhibit differential characteristics \
(appearance, behavior, etc.). \
\>", "Text"],

Cell["Each individual is unique. ", "Text"],

Cell["\<\
The diversity of a population is a fundamental prerequisite for \
that population to be able to adapt to varying environmental \
conditions.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Differential Reproduction, Fitness", "Subsection"],

Cell["\<\
Populations develop by the reproduction of their individuals over \
many generations. \
\>", "Text"],

Cell["\<\
The reproduction rate of each phenotype is influenced by the \
specific conditions of the milieu the individual is living in, and by the \
ability (fitness) of the individual organism to survive and produce \
offspring.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitness Inheritance and Variation", "Subsection"],

Cell["\<\
The genotypic information is transferred from a parent individual \
to its offspring or, for sexual reproduction, from parents to offspring. \
\
\>", "Text"],

Cell["\<\
Thus the phenotypic fitness is indirectly inherited by the \
offspring.\
\>", "Text"],

Cell["\<\
Due to slight mutations, recombination of genomes and \"noise\" \
inherent in the reproduction process, the offspring genome is never a \
perfectly identical copy of the parent genome(s).\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution as a Reproductive Plan", "Section"],

Cell[CellGroupData[{

Cell["Phenotypic Selection and Genotypic Variation", "Subsection",
  CellTags->"Reproductive Plan"],

Cell[CellGroupData[{

Cell["Evolution of Populations as an Adaptive Process", "Subsubsection"],

Cell[TextData[{
  "The evolution of populations can be considered as a two-level process of \
phenotypic selection and genotypic variation. Figure ",
  
  CounterBox["NumberedFigure", "Evolution as Adaptation (Figure)"],
  " shows the two-fold representation of a phenotypic space \[ScriptCapitalE] \
of expressible features and the genotypic structure space \[ScriptCapitalS]. \
"
}], "Text"],

Cell["\<\
Each point in \[ScriptCapitalS] represents a specific genepool, the \
collection of all genomes belonging to a population.\
\>", "Text"],

Cell[TextData[
"A point in \[ScriptCapitalE] represents an expressed population of \
individuals (phenotypes), their traits and behaviors."], "Text"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008H00017R000`400?l00000o`00003oo`3ooooo
0?oooaX0oooo003o0?ooool0oooo6P3oool00?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo
003o0?ooool0oooo6P3oool00?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo003o0?ooool0
oooo6P3oool00?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo003o0?ooool0oooo6P3oool0
0?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo003o0?ooool0oooo6P3oool00?l0ooooo`3o
oolJ0?ooo`00o`3ooonJ0?ooo`L000000P3oool300000080oooo00<000000?ooo`3oool00`3oool4
000000030?ooo`000000oooo00<0oooo0`0000030?ooo`<000000P3oool4000000050?ooo`000000
oooo0?ooo`0000001P3oool4000000@0oooo1@00000j0?ooo`00o`3ooonI0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000@0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo03L0oooo003o0?oooiT0oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0g0?ooo`00o`3ooom/0?ooo`d0
0000803oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo000000050?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02`3o
ool2000003T0oooo003o0?oooeT0oooo8@00000W0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000@0oooo200000030?ooo`<0
0000>`3oool00?l0ooooAP3ooolW000000T0kno_0P3oool4000002<0oooo0P0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0103oool010000000oooo00000000000n0?ooo`00o`3ooolc
0?ooobL000007@3_knl20?ooo`@000007P3oool4000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
=`3oool00?l0oooo7`3ooolX00000380kno_0P3oool4000001X0oooo0P0000080?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`02000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo03L0oooo003o0?ooo``0oooo:00000160>o_k`80oooo1000000I0?ooo`030000
003oool0oooo00D0oooo1@0000020?ooo`060000003oool000000000003oool000001@3oool00`00
0000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool000000?ooo`040?oo
o`050000003oool0oooo0000003oool00P0000030?ooo`@00000103oool5000003X0oooo003h0?oo
obL00000G03_knl20?ooo`@000005`3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
01X0oooo00<000000?ooo`3oool0F03oool00>@0oooo:000001`0>o_k`80oooo1000000F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000006P3oool00`000000oooo0?ooo`1H0?ooo`00
d@3ooolX000008D0kno_0P3oool4000001D0oooo1`00001h0?ooo`00_P3ooolW000009X0kno_0P3o
ool4000009<0oooo002[0?ooobL00000[`3_knl20?ooo`@00000T@3oool009L0oooo:00000330>o_
k`80oooo1000002@0?ooo`00Q03ooolX00000=P0kno_0P3oool4000004l0oooo0P0000060?ooo`03
0000003oool0oooo03@0oooo001a0?ooobL00000k@3_knl20?ooo`@00000D03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03@0oooo001N0?ooobL00000o`3_knl30>o_k`80oooo1000
001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool005@0oooo7P00003o
0>o_kaL0kno_0P3oool4000002<0oooo100000020?ooo`030000003oool0oooo0080oooo10000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool400000080oooo0`000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0
oooo00<0oooo0`00000V0?ooo`00E03oool;00000?l0kno_;03_knl20?ooo`@00000803oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000
00060?ooo`030000003oool0000000<0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`3oool0oooo0000000U0?ooo`00EP3oool700000?l0kno_;`3_knl20?ooo`@00000
7P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000D0oooo00@000000?ooo`3oool000001P3oool2000000H0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0R0?ooo`00F@3oool600000?l0kno_;`3_knl20?ooo`@00000
6`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000060?ooo`8000001P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0X0?oo
o`00G03oool600000?l0kno_;P3_knl00`3oool0000000000002000001X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`08000000030?ooo`000000oooo00@0oooo00@000000?ooo`3o
ool000001P3oool2000000H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0:03oool005h0oooo1P00003o0>o_kbd0
kno_0P3oool4000001P0oooo00<000000?ooo`3oool00P3oool500000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000050?ooo`040000003oool0oooo000000H0oooo0P0000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0:03oool00640oooo1P00003o0>o_kb`0kno_00<0oooo0000
000000000P00000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000050?ooo`040000003oool0oooo000000H0oooo0P0000050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`00H`3oool700000?l0kno_:P3_knl2
0?ooo`@000005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo
001V0?ooo`H00000>P3_knl2000000@0kno_0P0000040>o_k`800000h@3_knl00`3oool000000000
0002000001@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`@000000`3o
ool00`000000oooo00000002000000H0oooo100000000`3oool000000000000200000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0000003oool3000000<0oooo00<000000?ooo`3oool0
0`3oool4000002D0oooo001Y0?ooo`H00000=`3_knl2000000@0kno_0P0000040>o_k`800000hP3_
knl20?ooo`@000004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0@@3oool006/0oooo1`0000120>o_k`T00000f`3_knl00`3oool0000000000002
000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0440oooo001^0?ooo`H00000@03_knl>00000=L0kno_0P3oool400000180oooo1000000d0?oo
o`030000003oool0oooo02`0oooo001a0?ooo`H00000AP3_knl900000=D0kno_00<0oooo00000000
00000P00001h0?ooo`00L`3oool6000004X0kno_1P00003C0>o_k`80oooo1000001f0?ooo`00MP3o
ool6000004X0kno_1@00003C0>o_k`030?ooo`000000000000800000M@3oool007P0oooo1`00001:
0>o_k`<00000d`3_knl20?ooo`@00000L`3oool007/0oooo1P00001:0>o_k`<00000d`3_knl00`3o
ool000000000000200000780oooo001n0?ooo`H00000B03_knl300000=<0kno_0P3oool400000700
oooo00200?ooo`L00000AP3_knl200000=D0kno_00<0oooo0000000000000P00001_0?ooo`00P`3o
ool6000004D0kno_0P00003E0>o_k`80oooo1000001]0?ooo`00QP3oool600000480kno_0P000003
0>o_k`@00000d03_knl00`3oool0000000000002000006`0oooo00280?ooo`H00000@`3_knl80000
0<l0kno_0P3oool4000006X0oooo002;0?ooo`H00000@03_knl800000=40kno_00<0oooo00000000
00000P00001Y0?ooo`00S@3oool7000003`0kno_2P00003A0>o_k`80oooo1000001W0?ooo`00T03o
ool6000003X0kno_2P00003C0>o_k`030?ooo`000000000000800000IP3oool009<0oooo1P00000g
0>o_k`X00000e03_knl20?ooo`@00000I03oool009D0oooo1P00000F0>o_kaH0g@P62@3_knl:0000
09<0kno_1P00000m0>o_k`030?ooo`000000000000800000H`3oool009P0oooo1P00000D0>o_ka@0
g@P62`3_knl8000009<0kno_2000000m0>o_k`80oooo1000001Q0?ooo`00VP3oool700000140kno_
4P3M20H=0>o_k`P000001P3_knl3000008T0kno_2P0000030>o_k`P00000<`3_knl00`3oool00000
0000000200000600oooo002M0?ooo`H000003`3_knlA0=d81Q00kno_100000090>o_k`<00000R03_
knl:000000<0kno_3@00000_0>o_k`80oooo1000001N0?ooo`00X03oool6000000/0kno_403M20HP
0>o_k`@00000P03_knl2000000@0kno_2P00000;0>o_k`P00000;P3_knl00`3oool0000000000002
000005d0oooo002R0?ooo`L000001@3_knlB0=d81R<0kno_0`00001n0>o_k`<00000103_knl:0000
0100kno_1P00000/0>o_k`80oooo1000001K0?ooo`00Y@3oool6000000L0g@P600<0kno_0=d81P3M
20H02@3M20HV0>o_k`@00000NP3_knl4000000H0kno_2000000D0>o_k`D00000;03_knl00`3oool0
000000000002000005X0oooo002X0?ooo`L0g@P6103_knl:0=d81RT0kno_1000001g0>o_k`<00000
2@3_knl6000001P0kno_0`00000/0>o_k`80oooo1000001H0?ooo`00Y@3oool70=d81P@00000103_
knl80=d81P`0kno_0P00000N0>o_k`@00000L`3_knl3000002X0kno_0`00000]0>o_k`030?ooo`00
0000000000800000E`3oool00:40oooo203M20H40?ooo`H0000000<0kno_0=d81P3M20H0103M20H>
0>o_k`8000007`3_knl5000006l0kno_1000000]0>o_k`800000;@3_knl20?ooo`@000009@3oool3
000002d0oooo002N0?ooo`P0g@P62@3oool5000000D0g@P63P3_knl300000240kno_1@00001Z0>o_
k`D00000;`3_knl3000002h0kno_00<0oooo0000000000000P00000R0?ooo`H00000;03oool009/0
oooo1`3M20H@0?ooo`<000000P3M20H00`000000kno_0>o_k`0<0>o_k`<00000903_knl5000006H0
kno_1@00000b0>o_k`80000000<0kno_000000000000103_knl2000000@0kno_0P00000P0>o_k`80
oooo1000000P0?ooo`030000003oool0oooo0080oooo0P00000[0?ooo`00V03oool70=d81QH0oooo
00<0g@P60000000000000`00000:0>o_k`<00000:03_knl500000600kno_1@00000e0>o_k`800000
00<0kno_000000000000103_knl2000000@0kno_0P00000R0>o_k`030?ooo`000000000000800000
903oool2000002/0oooo002E0?ooo`L0g@P66`3oool7000000H0kno_0`00000[0>o_k`D00000F`3_
knl6000006`0kno_00@0oooo00000000000000008`3oool2000002/0oooo002A0?ooo`P0g@P68@3o
ool6000000@0kno_0P00000^0>o_k`H00000E@3_knl600000700kno_00<0oooo0000000000000P00
000O0?ooo`<00000;03oool008h0oooo203M20HW0?ooo`H00000=03_knl6000002D0kno_1@00000T
0>o_k`L000007`3_knl2000005@0kno_1000000M0?ooo`<00000;@3oool008/0oooo1`3M20H]0?oo
o`H00000=@3_knl7000001l0kno_2@00000N0>o_k`P000008P3_knl2000005D0kno_00<0oooo0000
000000000P00000I0?ooo`<00000;`3oool008P0oooo1`3M20Hc0?ooo`H00000=@3_knl8000001X0
kno_2`00000I0>o_k`P000009P3_knl2000005L0kno_1000000H0?ooo`030000003oool0oooo02l0
oooo00250?ooo`L0g@P6>03oool7000003H0kno_2@00000E0>o_k`/000004`3_knl:000002T0kno_
0`00001H0>o_k`030?ooo`0000000000008000005P3oool00`000000oooo0?ooo`0_0?ooo`00PP3o
ool70=d81Sh0oooo1P00000h0>o_k`X00000403_knl;000000`0kno_3000000^0>o_k`800000F`3_
knl4000001D0oooo1P00000/0?ooo`00OP3oool80=d81T@0oooo1P00000i0>o_k`l000001`3_knl;
000000030>o_k`000000000001000000<`3_knl2000005`0kno_00<0oooo0000000000000P00000E
0?ooo`@00000;03oool007/0oooo203M20I90?ooo`L00000?03_knl;000000H0kno_2@0000000`3_
knl000000000000:000003X0kno_0P00001N0>o_k`@00000A03oool007P0oooo1`3M20I@0?ooo`H0
0000@`3_knl2000000P0kno_1@0000030>o_k`030000003_knl0kno_0480kno_0`00001O0>o_k`03
0?ooo`000000000000800000@P3oool007D0oooo1`3M20I20?ooo`8000004P3oool6000009L0kno_
0P00001R0>o_k`@00000@@3oool00600oooo00<000000?ooo`3oool03`3oool70=d81TD0oooo0P00
000D0?ooo`H00000U@3_knl2000006<0kno_00<0oooo0000000000000P00000o0?ooo`00H03oool0
0`000000oooo0?ooo`0=0?ooo`H0g@P6A`3oool3000001L0oooo1P00003i0>o_k`@00000?P3oool0
0640oooo00<000000?ooo`3oool0303oool30=d81TX0oooo0P00000J0?ooo`L00000m`3_knl00`3o
ool0000000000002000003`0oooo000n0?ooo`D0000000<0oooo0000003oool00`3oool4000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool00`000000
oooo00000002000000H0oooo100000050?ooo`@000000`3oool00`000000oooo0?ooo`0n0?ooo`80
00007@3oool600000?L0kno_1000000k0?ooo`00?@3oool2000000@0oooo00<000000?ooo`000000
0P3oool2000000<0oooo0P0000000`3oool00000000000040?ooo`040000003oool0oooo0?ooo`80
00000`3oool4000000<0oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?ooo`80
000000<0oooo000000000000?P3oool300000200oooo1P00003e0>o_k`030?ooo`00000000000080
0000>@3oool003d0oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool0
103oool00`000000oooo000000050?ooo`040000003oool0oooo000000H0oooo0P0000050?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`0000001P3oool00`000000oooo0000000n0?oo
o`8000008`3oool700000?@0kno_1000000h0?ooo`00?03oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0000
00060?ooo`030000003oool0000003h0oooo0P00000V0?ooo`H00000l`3_knl00`3oool000000000
0002000003H0oooo000l0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`L0000000<0oooo
000000000000103oool010000000oooo0?ooo`3oool9000000@0oooo0P0000000`3oool000000?oo
o`050?ooo`030000003oool0000000H0oooo00@000000?ooo`0000000000?03oool3000002T0oooo
1P00003b0>o_k`@00000=@3oool003d0oooo00<000000?ooo`3oool00P3oool500000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000050?ooo`040000003oool0oooo000000H0oooo
0P0000050?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`0000001P3oool00`000000
oooo0000000l0?ooo`800000;03oool600000?40kno_00<0oooo0000000000000P00000c0?ooo`00
?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`0000060?ooo`<00000103oool010000000oooo0?ooo`0000060?oo
o`030000003oool0000000H0oooo00<000000?ooo`000000?03oool2000002l0oooo1P00000_0>o_
k`800000_`3_knl400000380oooo000m0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`80
000000@0oooo00000000000000000`3oool010000000oooo0?ooo`3oool2000000<0oooo1@000002
0?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`000000
000003X0oooo0`00000a0?ooo`L00000;03_knl200000<00kno_00<0oooo0000000000000P00000`
0?ooo`00?P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo100000030?oo
o`030000003oool00000008000001P3oool400000080oooo00<000000?ooo`0000000P0000060?oo
o`@000001@3oool4000000<0oooo00<000000?ooo`3oool0>03oool2000003D0oooo1P00000Z0>o_
k`800000B03_knl2000007P0kno_1000000_0?ooo`00?`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0>03oool2000003P0oooo1P00000V0>o_k`<0
0000B03_knl2000007T0kno_00<0oooo0000000000000P00000]0?ooo`00@03oool2000000<0oooo
0P00000h0?ooo`800000>03oool3000003X0oooo1`00000S0>o_k`800000B@3_knl2000007/0kno_
1000000/0?ooo`00@P3oool4000003X0oooo00<000000?ooo`3oool0=P3oool2000003h0oooo1P00
000Q0>o_k`800000B03_knl3000007`0kno_00<0oooo0000000000000P00000Z0?ooo`00o03oool6
000001h0kno_0P0000180>o_k`800000O`3_knl4000002T0oooo003n0?ooo`H000006`3_knl30000
04P0kno_0P0000200>o_k`030?ooo`0000000000008000009`3oool00?l0oooo0P3oool6000001P0
kno_0P0000190>o_k`800000PP3_knl4000002H0oooo003o0?ooo`@0oooo1`00000E0>o_k`800000
B03_knl3000008<0kno_00<0oooo0000000000000P00000T0?ooo`00o`3oool70?ooo`H00000G@3_
knl2000008H0kno_1000000S0?ooo`00o`3oool:0?ooo`H00000FP3_knl2000008L0kno_00<0oooo
0000000000000P00000Q0?ooo`00o`3oool<0?ooo`H00000F03_knl2000008T0kno_1000000P0?oo
o`00o`3oool?0?ooo`H00000E03_knl3000008X0kno_00<0oooo0000000000000P00000N0?ooo`00
/`3oool2000005/0oooo1`00001A0>o_k`800000S@3_knl4000001d0oooo002c0?ooo`800000GP3o
ool6000004l0kno_0P00002?0>o_k`@000006`3oool00;80oooo0`00001Q0?ooo`H00000C03_knl2
00000900kno_1000000J0?ooo`00/P3oool2000006@0oooo1`0000180>o_k`<00000TP3_knl40000
01P0oooo002a0?ooo`<00000I`3oool6000004H0kno_0P00002D0>o_k`@000005`3oool00;40oooo
0P00001Z0?ooo`L00000@`3_knl2000009H0kno_1000000E0?ooo`00/03oool3000006X0oooo0P00
00000`3oool000000000000400000=X0kno_1000000D0?ooo`00[`3oool3000006X0oooo0`000004
0?ooo`H00000f@3_knl400000180oooo002_0?ooo`800000J`3oool2000000L0oooo1`00003G0>o_
k`@000004@3oool00:h0oooo0`00001[0?ooo`8000002P3oool600000=L0kno_1000000?0?ooo`00
[P3oool2000006/0oooo0`00000=0?ooo`H00000e@3_knl4000000h0oooo002]0?ooo`<00000J`3o
ool200000100oooo1`00003D0>o_k`@00000303oool00:d0oooo0P00001/0?ooo`8000004`3oool6
00000=<0kno_1000000;0?ooo`00o`3ooolK0?ooo`<000005P3oool600000=80kno_100000090?oo
o`00o`3ooolK0?ooo`8000006@3oool600000=40kno_100000080?ooo`00o`3ooolK0?ooo`800000
703oool6000002D0kno_0P00002Y0>o_k`@000001P3oool00?l0oooo6P3oool3000001h0oooo1`00
000R0>o_k`800000ZP3_knl4000000D0oooo003o0?oooaX0oooo0P00000R0?ooomL00000103oool0
0?l0oooo6P3oool2000002D0ooooe00000040?ooo`00o`3ooomS0?ooo`800000]03oool00?l0oooo
H`3oool200000;@0oooo003o0?ooof<0oooo0P00002d0?ooo`00o`3ooomR0?ooo`<00000]03oool0
0:L0oooo0P00002h0?ooo`800000]@3oool00:L0oooo0P00002h0?ooo`800000]@3oool00:H0oooo
0`00002h0?ooo`800000]@3oool00:D0oooo0`00002h0?ooo`<00000]@3oool00:D0oooo0P00002i
0?ooo`800000]P3oool00:@0oooo0`00002i0?ooo`800000]P3oool00:<0oooo0`00001_0?ooo`80
0000B@3oool200000;H0oooo002S0?ooo`800000L03oool2000004P0oooo0`00002f0?ooo`00XP3o
ool300000700oooo0P0000180?ooo`800000]`3oool00:40oooo0`00001a0?ooo`800000B03oool2
00000;L0oooo002Q0?ooo`800000L@3oool300000?l0oooo0P3oool00:00oooo0`00001a0?ooo`80
0000o`3oool30?ooo`00W`3oool300000780oooo0P00003o0?ooo`<0oooo002O0?ooo`800000L`3o
ool200000?l0oooo0`3oool00?l0oooo5@3oool200000?l0oooo0`3oool00?l0oooo5@3oool20000
0?l0oooo0`3oool00?l0oooo503oool300000?l0oooo0`3oool00?l0oooo503oool200000?l0oooo
103oool00?l0oooo503oool200000?l0oooo103oool00?l0oooo503oool200000?l0oooo103oool0
0?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo002I0?ooo`800000`@3oool200000;X0oooo
002I0?ooo`800000`@3oool200000;X0oooo002H0?ooo`<00000`@3oool200000;X0oooo002H0?oo
o`800000`@3oool300000;X0oooo002G0?ooo`<00000`@3oool200000;/0oooo002G0?ooo`800000
`P3oool200000;/0oooo002G0?ooo`800000`@3oool300000;/0oooo002F0?ooo`<00000`@3oool2
00000;`0oooo002F0?ooo`800000M`3oool2000004T0oooo0P00002l0?ooo`00U@3oool3000007L0
oooo0P0000190?ooo`800000_03oool009D0oooo0P00001h0?ooo`800000B03oool300000;`0oooo
002D0?ooo`<00000M`3oool3000004P0oooo0P00002m0?ooo`00U03oool2000007P0oooo0P000019
0?ooo`800000_@3oool009@0oooo0P00001h0?ooo`800000B03oool300000;d0oooo002C0?ooo`<0
0000M`3oool3000004P0oooo0P00002n0?ooo`00T`3oool2000007P0oooo0P0000190?ooo`800000
_P3oool00?l0oooo3P3oool200000?l0oooo2P3oool00?l0oooo3@3oool300000?l0oooo2P3oool0
0?l0oooo3@3oool200000?l0oooo2`3oool00?l0oooo3@3oool200000?l0oooo2`3oool00?l0oooo
303oool300000?l0oooo2`3oool00?l0oooo303oool200000?l0oooo303oool00?l0oooo303oool2
00000?l0oooo303oool008d0oooo0P00003o0?ooohX0oooo002=0?ooo`800000o`3ooon:0?ooo`00
S03oool300000?l0ooooRP3oool008/0oooo0`00003o0?oooh/0oooo002;0?ooo`800000b@3oool2
00000<00oooo002:0?ooo`<00000b@3oool200000<00oooo00240?ooo`8000000`3oool3000008d0
oooo3@00000_0?ooo`<00000`03oool008@0oooo1`00001j0?ooob800000;P3oool200000<40oooo
00240?ooo`L00000I`3ooolX000000/0oooo1000000[0?ooo`<00000`@3oool008@0oooo2000001B
0?ooobP000000`3oool2000001/0oooo1000000Z0?ooo`800000`P3oool008<0oooo2`00000l0?oo
obT000005P3oool2000001d0oooo1000000X0?ooo`800000`P3oool008<0oooo3000000W0?ooobT0
0000:@3oool3000001h0oooo1000000V0?ooo`<00000`P3oool008<0oooo3000000C0?ooobT00000
?@3oool200000240oooo1000000T0?ooo`800000``3oool008<0oooo=000001A0?ooo`8000008P3o
ool400000280oooo0`0000330?ooo`00N`3ooolX000006D0oooo0P00000T0?ooo`@00000803oool2
00000<@0oooo001W0?ooobT00000M`3oool3000002D0oooo1000000N0?ooo`<00000a03oool005<0
oooo:@0000060?ooo`X00000M@3oool3000000<0oooo0P00000X0?ooo`@00000703oool200000<D0
oooo000o0?ooobT000006P3oool9000007H0oooo2000000Y0?ooo`@000006`3oool200000<D0oooo
000/0?ooobP00000;P3oool8000007L0oooo2@00000Z0?ooo`@00000603oool300000<D0oooo000H
0?ooobP00000@P3oool7000007P0oooo3000000X0?ooo`D000005P3oool200000<H0oooo000>0?oo
oal00000E@3oool6000007T0oooo3000000Z0?ooo`@00000g@3oool000h0oooo2`00001X0?ooo`H0
0000NP3oool<000002`0oooo1000003K0?ooo`00403oool7000006X0oooo1@00001k0?ooo`/00000
;P3oool400000=X0oooo000C0?ooo`H00000J03oool4000007`0oooo2P00000a0?ooo`@00000f03o
ool001H0oooo1P00001U0?ooo`<00000O@3oool:00000380oooo1000003G0?ooo`00603oool70000
0680oooo0P00001n0?ooo`T00000=@3oool400000=D0oooo000K0?ooo`H00000G`3oool2000007l0
oooo2@00000f0?ooo`@00000e03oool001h0oooo1P00001L0?ooo`030000003oool0oooo07h0oooo
2000000i0?ooo`@00000dP3oool00200oooo1`00003J0?ooo`L00000>`3oool400000=40oooo000S
0?ooo`L00000e`3oool7000003d0oooo1000000]0?ooo`L000001@3oool4000000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000030?ooo`000000000000@0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`@00000103oool4000000040?ooo`000000oooo000000H0
oooo1@00001E0?ooo`009P3oool600000=D0oooo1P00000o0?ooo`@00000;03oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000050?oo
o`040000003oool0oooo000000@0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool002T0oooo1P00
003B0?ooo`H00000@@3oool4000002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
00060?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0000000D0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0580oooo000[0?ooo`L00000c`3oool5000004<0oooo100000000`3oool00000
0000000V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000050?oo
o`030000003oool0000000X0oooo0P00001D0?ooo`00;P3oool600000<d0oooo100000160?ooo`D0
00009P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000L0000000<0oooo0000003o
ool0103oool010000000oooo0?ooo`3oool6000000@0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo00000007
0?ooo`<00000EP3oool00340oooo1P00000i0?oooa000000P@3oool4000004L0oooo1000000V0?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003o
ool0000000D0oooo0P00001I0?ooo`00<`3oool7000003H0oooo400000210?ooo`<00000B@3oool5
000002@0oooo1`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool003H0oooo1P00
000d0?oooa000000P@3oool3000004T0oooo1P00000S0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo008000000`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
0000000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?ooo`00>@3oool6
00000340oooo400000210?ooo`800000BP3oool200000080oooo1000000Q0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<000000?ooo`0000000P000005
0?ooo`D000000`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool4000000<0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0000003oool2000000<0oooo1@00001E0?ooo`00>`3oool7
000002h0oooo400000210?ooo`030000003oool0oooo04P0oooo0`0000030?ooo`@00000803oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S03oool0
03h0oooo1P00000/0?oooa000000P@3oool00`000000oooo0?ooo`180?ooo`8000001P3oool40000
01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
08`0oooo00110?ooo`H00000:@3oool@00000<@0oooo1@0000030?ooo`8000001`3oool4000001d0
oooo1`00000<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L`3oool004<0oooo
1`00000V0?oooa000000a03oool;000000P0oooo1000002m0?ooo`00AP3oool7000002<0oooo4000
00070?ooo`030000003oool000000;X0oooo3P0000060?ooo`@00000_03oool004T0oooo1P00000Q
0?oooa000000203oool01`000000oooo0000003oool000000?ooo`000000A`3oool00`000000oooo
0000000P0?oooa000000>`3oool>000000P0oooo1000002j0?ooo`00C03oool6000001h0oooo4000
000;0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000004<0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000006@3oool@000003/0oooo3P0000090?ooo`D00000
^03oool004h0oooo1`00000E0?ooo`D0g@P68@3oool02@000000oooo0000003oool000000?ooo`00
0000oooo0000000o0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000180oooo4000000k0?ooo`d00000303oool400000;L0oooo001A0?oo
o`H000001`3oool@0=d81RL0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000g0?ooo`0G0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000002`3oool@000003`0
oooo2`00000?0?ooo`@00000]@3oool005@0oooo1000000D0=d81Rh0oooo00l000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000;`3oool05`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool0000000X0oooo4000000l0?ooo`/00000403oool4000002<0
oooo00<000000?ooo`3oool02@3oool4000000D0oooo10000000103oool000000000003oool30000
00<0oooo100000001@3oool000000?ooo`3oool0000000H0oooo100000050?ooo`D000003P3oool4
000000050?ooo`00000000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`<0000000<0
oooo0000003oool0:P3oool005H0oooo0`00000B0=d81SH0oooo01D000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000008@3oool05@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000=0?oooa000000?03oool:000001<0
oooo1000000Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`800000:`3oool005T0oooo4@3M20I00?ooo`0[0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000030?ooo`0C0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000>0?oooa00
0000?03oool:000001@0oooo1000000P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
02T0oooo001I0?ooo`l0g@P6C`3oool07`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000`3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000A0?oooa000000?03oool9000001L0
oooo1000000N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00`0oooo0P00000<0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02T0oooo001I0?ooo`h0g@P6L@3oool03@000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000503oool@000003`0oooo2000000I0?ooo`@000007@3o
ool00`000000oooo0?ooo`070?ooo`P000000`3oool600000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo200000040?ooo`<00000
3`3oool600000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo02T0oooo001G0?ooo`h0g@P60P00001b0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000001L0oooo4000000l0?ooo`P000006`3oool4000001/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000001L0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02T0oooo001D0?oooa00
g@P61P00001^0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000001P0oooo4000
000l0?ooo`L000007@3oool4000001X0oooo1`0000030?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?ooo`00DP3o
ool60=d81P<0oooo1`3M20H40?ooo`L00000K03oool01@000000oooo0000003oool0000001/0oooo
4000000l0?ooo`L000007`3oool4000001P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool2000002/0oooo001@0?ooo`D0g@P61P3oool60=d81PP0oooo1`00001X
0?ooo`030000003oool0000001h0oooo4000000l0?ooo`H000008@3oool4000001L0oooo00<00000
0?ooo`3oool02@3oool4000000D0oooo1@0000020?ooo`@000000P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0000003oool00P0000030?ooo`@000001@3oool5000000h0oooo1@00
00030?ooo`030000003oool00000008000001P3oool3000000030?ooo`000000oooo02X0oooo001=
0?ooo`H0g@P6203oool50=d81P`0oooo1P0000270?oooa000000?03oool5000002@0oooo1000000E
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0Y
0?ooo`00B`3oool60=d81P/0oooo0P3M20HA0?ooo`H00000d@3oool4000002D0oooo1000000D0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0Y0?oo
o`00B@3oool50=d81Ph0oooo00<0g@P60?ooo`3oool04P3oool700000<h0oooo0`00000X0?ooo`@0
00004P3oool8000005d0oooo00<000000?ooo`3oool0:@3oool004H0oooo1P3M20HX0?ooo`H00000
c03oool3000002T0oooo1000002R0?ooo`00A03oool60=d81Rd0oooo1P0000390?ooo`800000;03o
ool400000:00oooo00130?ooo`@0g@P6<P3oool7000008`0oooo00<000000?ooo`000000=`3oool0
0`000000oooo0?ooo`0/0?ooo`@00000W`3oool004<0oooo0P3M20Hg0?ooo`H00000R`3oool00`00
0000oooo0000000f0?ooo`030000003oool0oooo02h0oooo1000002M0?ooo`00O`3oool6000008T0
oooo00<000000?ooo`000000I`3oool4000005<0oooo0P0000060?ooo`030000003oool0oooo03h0
oooo00210?ooo`L00000R@3oool00`000000oooo0?ooo`1V0?ooo`@00000D`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo03h0oooo000d0?ooo`D00000B`3oool6000008P0oooo00<0
00000?ooo`0000004@3oool00`000000oooo0?ooo`1B0?ooo`@00000D`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03h0oooo000d0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0B`3oool6000008H0oooo00<000000?ooo`0000003`3oool00`000000oooo0000001E
0?ooo`@00000703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool4000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`@000000P3oool3000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002
000000<0oooo00<000000?ooo`3oool00`3oool300000300oooo000j0?ooo`030000003oool0oooo
04`0oooo1`0000260?ooo`030000003oool0000000d0oooo00<000000?ooo`000000E@3oool50000
01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo000000060?ooo`030000003oool0000000<0oooo0P0000030?ooo`040000
003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`003`3oool4000000@0
oooo00<000000?ooo`3oool02`3oool5000000D0oooo00<000000?ooo`3oool0103oool300000003
0?ooo`000000oooo0080oooo100000001@3oool000000000003oool0000000D0oooo00@000000?oo
o`3oool000000`3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`D000007P3oool6000008D0oooo00D000000?ooo`000000oooo
000000090?ooo`070000003oool000000?ooo`000000oooo0000001D0?ooo`@000006@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo000000050?ooo`040000003oool0oooo000000H0oooo0P0000060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0;03oool000h0oooo0P0000030?ooo`8000000`3oool0
0`000000oooo0?ooo`090?ooo`800000103oool2000000<0oooo0P0000040?ooo`8000000P3oool2
000000<0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000000000040?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000000`3o
ool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000007`3o
ool6000008D0oooo00<000000?ooo`0000001`3oool02@000000oooo0000003oool000000?ooo`00
0000oooo0000000C0?oooa000000<P3oool4000001L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000060?ooo`8000001P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0b0?ooo`003P3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0O0?ooo`L00000Q@3o
ool01@000000oooo0000003oool0000000<0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000000@0?oooa000000<`3oool4000001H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0000000<0oooo0000003oool0103o
ool010000000oooo0?ooo`0000060?ooo`8000001P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0b0?ooo`003P3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P0000040?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001`3oool2
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo0P00000T0?ooo`L00000Q@3oool04@000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000l0oooo4000000e0?ooo`@00000
503oool7000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0b0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000002@3oool2000000P0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool6000000030?ooo`000000000000@0oooo00<00000
0?ooo`3oool00P0000040?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P00000Y0?ooo`H00000QP3oool03`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000000>0?oooa000000=P3oool4000001<0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000060?ooo`8000001@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool000l0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00000^0?ooo`H0
0000Q03oool04@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000000/0oooo4000000h0?ooo`@000004@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02`0oooo000?0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02T0
oooo1`0000200?ooo`0C0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000000:0?oooa000000>@3oool400000100oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`000000oooo00<000001P3oool4000000<0oooo
00<000000?ooo`0000000P0000060?ooo`@0000000<0oooo0000000000000P0000020?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`000000oooo0`0000030?ooo`030000003oool0oooo00<0
oooo1000000_0?ooo`00403oool2000000<0oooo0P0000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool2000000040?ooo`0000000000000000<0oooo0P0000020?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo00000000000000000`3oool00`00
0000oooo0?ooo`02000000030?ooo`000000000000@0oooo0P000000103oool00000000000000002
0?ooo`8000000`3oool00`000000oooo0?ooo`02000000@0oooo0P00000]0?ooo`H00000O@3oool0
5@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo000000090?oooa000000>`3oool4000000h0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`00000R0?ooo`030000003oool0oooo04/0oooo000B0?oo
o`@000000`3oool4000000P0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`000000
oooo008000000`3oool3000000030?ooo`000000oooo0080oooo1@0000030?ooo`030000003oool0
000000800000103oool010000000oooo0?ooo`3oool5000000<0oooo00<000000?ooo`0000000P00
00000`3oool0000000000002000000@0oooo1@00000a0?ooo`H00000N`3oool05`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000H0oooo4000000l0?ooo`@000003@3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0B`3oool001X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo1`00
001g0?ooo`0A0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`0000003@3oool@000003h0oooo1000000;0?ooo`L000000`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03H0oooo000K0?ooo`030000003oool0oooo00T0oooo
0P0000040?ooo`800000N03oool6000007@0oooo00D000000?ooo`000000oooo0000000J0?oooa00
0000?`3oool4000008D0oooo000K0?ooo`<000002`3oool5000002D0oooo00<000000?ooo`3oool0
E03oool600000900oooo400000110?ooo`@00000P`3oool00:`0oooo1`00002=0?oooa000000@P3o
ool400000880oooo000Y0?ooo`030000003oool0oooo08<0oooo1P00003O0?ooo`@00000P03oool0
02T0oooo00<000000?ooo`3oool0QP3oool600000=d0oooo1000001o0?ooo`00:P3oool00`000000
oooo0?ooo`270?ooo`L00000g03oool4000007d0oooo000G0?ooo`030000003oool0oooo00T0oooo
100000030?ooo`030000003oool00000008000001@3oool4000000050?ooo`000000oooo0?ooo`00
00000`3oool4000000030?ooo`00000000000080oooo0P0000000`3oool000000?ooo`040?ooo`@0
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05H0oooo1`00003J0?ooo`@0
0000O03oool001L0oooo0P0000090?ooo`8000000`3oool2000000030?ooo`000000000000<0oooo
0P0000030?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000000P3oool010000000
oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool00P0000030?ooo`8000000`3oool40000
00@0oooo00<000000?ooo`3oool0F@3oool600000=X0oooo1000001j0?ooo`00603oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000
oooo0?ooo`0000040?ooo`8000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`8000001@3oool00`000000oooo
0?ooo`1K0?ooo`H00000f03oool4000007T0oooo000H0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000050?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000000P3oool2000000@0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo0P0000050?ooo`030000003oool0oooo05d0oooo1`00003G
0?ooo`@00000M`3oool001P0oooo0P0000080?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`0000000000103oool2000000030?ooo`000000000000D0oooo00@000000?ooo`00000000000`3o
ool600000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@0oooo0`00
00040?ooo`030000003oool0oooo0600oooo1P00003F0?ooo`@00000MP3oool001T0oooo1`000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`00
00050?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000050?ooo`030000003oool0oooo0680oooo1P00003E0?oo
o`@00000M03oool001T0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000060?oo
o`040000003oool00000000000@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000050?ooo`030000003oool0oooo06@0oooo1`00003C0?oo
o`@00000L`3oool001T0oooo0P0000050?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00040?ooo`000000000000000080oooo0P0000020?ooo`8000001@3oool010000000oooo00000000
00020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo008000000`3o
ool2000000<0oooo1@0000030?ooo`030000003oool0oooo06L0oooo1P00003C0?ooo`@00000L@3o
ool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`@000000`3oool0
0`000000oooo00000002000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`D000000P3oool4000000030?ooo`000000oooo00@0oooo100000020?ooo`030000003o
ool0000000800000K@3oool600000=40oooo1@00001_0?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`21
0?ooo`L00000d03oool4000006h0oooo000J0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?oo
o`8000002`3oool00`000000oooo0?ooo`230?ooo`H00000d03oool400000280oooo1`0000130?oo
o`006`3oool7000001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`220?ooo`H0
0000cP3oool400000240oooo1`0000130?ooo`00e`3oool700000<d0oooo1000000O0?ooo`030000
003oool0oooo04L0oooo003J0?ooo`L00000b`3oool4000001h0oooo00<000000?ooo`3oool0A`3o
ool00=d0oooo1P00003;0?ooo`@00000703oool00`000000oooo0?ooo`170?ooo`00h03oool60000
0<T0oooo1000000K0?ooo`H00000A03oool00>80oooo1`0000380?ooo`@000006@3oool6000004@0
oooo003U0?ooo`H00000a`3oool4000001P0oooo00<000000?ooo`3oool0A`3oool00>P0oooo1P00
00360?ooo`@000005P3oool00`000000oooo0?ooo`170?ooo`00jP3oool700000<@0oooo1000000E
0?ooo`030000003oool0oooo04L0oooo003]0?ooold00000503oool7000004<0oooo003`0?ooolX0
0000503oool7000004<0oooo003o0?ooool0oooo6P3oool00?l0ooooo`3ooolJ0?ooo`00o`3ooooo
0?oooaX0oooo003o0?ooool0oooo6P3oool00?l0ooooo`3ooolJ0?ooo`00o`3ooooo0?oooaX0oooo
0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{536, 286.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Two-Level Evolution of Populations: Variations occur on the \
genotypic structures (\[ScriptCapitalS]) whereas selection is performed on \
the phenotypic level (E).\
\>", "NumberedFigure",
  CellTags->"Evolution as Adaptation (Figure)"]
}, Closed]],

Cell[CellGroupData[{

Cell["A Single Adaptation Step", "Subsubsection"],

Cell[TextData[{
  "More formally, one adaptation step, consisting of selection and variation, \
can be described as follows (compare Figures 5 and ",
  
  CounterBox["NumberedFigure", "Figure: selection and variation"],
  "):"
}], "Text"],

Cell[TextData[{
  "Expression:",
  StyleBox[
  " The expression of the individuals of a genepool (1) results in a \
population of organisms (2).",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell[TextData[{
  "Evaluation and Selection:",
  StyleBox[
  " Taking only the fitnesses of the organisms into account (pure selection), \
a fitness dependent distribution of individuals would result as the \
\[RightGuillemet]offspring\[LeftGuillemet] generation (3).",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell[TextData[{
  "Variation:",
  StyleBox[
  " New phenotypic features are \[RightGuillemet]invented\[LeftGuillemet] on \
the genotypic level (4): The selected individuals, i.e., the individuals that \
are able to reproduce, transfer their genomes to their offspring. Mutations \
and recombinations occur during the reproduction processes and result in a \
new genepool collection (5).",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell[TextData[{
  "Offspring Expression:",
  StyleBox[
  " The expression of the genomes in the genepool results in the actual, \
newly adapted population (next generation). ",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool300000080oooo0`0000020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`030?ooo`<000001@3oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`8000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`800000
G03oool00?l0oooo=@3oool<000002T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo1`000003
0?ooo`800000GP3oool00?l0oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo0P00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000H03oool00?l0oooo4@3ooolU000000X0kno_
1000000Q0?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3_knl4
000001l0oooo00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`P0000000<0oooo0000003oool00`3oool0
1P000000oooo0?ooo`3oool000000?ooo`8000000P3oool3000000D0oooo1000001L0?ooo`00k@3o
oolT00000340kno_1000000M0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
5`3oool00`000000oooo0?ooo`1h0?ooo`00f`3ooolT000004@0kno_1000000L0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`1h0?ooo`00b@3o
oolU000005L0kno_1000000K0?ooo`H00000UP3oool00;L0oooo9@00001Z0>o_k`@00000]P3oool0
0:D0oooo9@00001n0>o_k`@00000]03oool009<0oooo9@00002A0>o_k`@00000/`3oool00840oooo
9@00002U0>o_k`@00000/@3oool006l0oooo9@00002h0>o_k`@00000/03oool005d0oooo9@00003<
0>o_k`@00000[P3oool004`0oooo9000003O0>o_k`@00000C`3oool2000000D0oooo00<000000?oo
o`3oool0E03oool003X0oooo9000003c0>o_k`@00000C`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05@0oooo000X0?ooobD00000o`3_knl60>o_k`@00000C`3oool01@000000oooo
0?ooo`3oool0000005H0oooo000F0?ooobD00000o`3_knlJ0>o_k`@00000903oool500000080oooo
00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool3000000<0oooo0`0000040?ooo`060000003oool0oooo0?ooo`000000oooo0`000004
0?ooo`030000003oool0oooo0080oooo0`0000160?ooo`003@3ooolL00000?l0kno_;@3_knl40000
0280oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo0P0000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000004D0oooo000=0?ooo`X0
0000o`3_knm10>o_k`@000007`3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003o
ool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo000?
0?ooo`L00000o`3_knm30>o_k`@000007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0B03oool00180oooo1P00003o0>o_kd<0kno_1000
000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0B03oool001D0oooo1P00003o0>o_kb80kno_00<000000>o_k`3_knl02P3_knl00`00
0000kno_0>o_k`0?0>o_k`@000006`3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000
003oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool001L0
oooo1P00003o0>o_kal0kno_00<000000>o_k`3_knl0303_knl00`000000kno_0>o_k`0@0>o_k`@0
00006@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0>o_ka/0
kno_00<000000>o_k`3_knl03P3_knl00`000000kno_0>o_k`0@0>o_k`@00000603oool00`000000
oooo0?ooo`0:0?ooo`<00000103oool00`000000oooo00000002000000D0oooo0`0000020?ooo`@0
000000<0oooo0000003oool0103oool2000000040?ooo`0000000000000000@0oooo00<000000?oo
o`3oool00P3oool4000004D0oooo000L0?ooo`L00000@03_knl2000000@0kno_0P0000030>o_k`80
0000b@3_knl00`000000kno_0>o_k`020>o_k`H00000203_knl00`000000kno_0>o_k`0A0>o_k`@0
00005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0G`3oool001l0oooo1P00000n0>o_k`800000103_knl2000000<0kno_0P0000380>o_k`800000
103_knl3000000<0kno_00<000000>o_k`3_knl01@3_knl2000001<0kno_1000000F0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1O0?ooo`008P3o
ool600000?l0kno_4@3_knl00`000000kno_0>o_k`090>o_k`8000001`3_knl00`000000kno_0>o_
k`0C0>o_k`@000005@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00003o
0>o_k`d0kno_0P00000<0>o_k`8000001P3_knl2000001D0kno_1000002H0?ooo`009`3oool60000
0:L0kno_1@00P14:0>o_ka00080A2@3_knl<00204AD0kno_0P00P14H0>o_k`800000303_knl20000
00H0kno_0P00000G0>o_k`<00000U`3oool002X0oooo1P00002M0>o_k``0080A2P3_knl@00204@T0
kno_3`00P14B0>o_k`@0080A5P3_knl2000000`0kno_0P0000060>o_k`800000603_knl4000009D0
oooo000/0?ooo`H00000A@3_knl00`000000kno_0>o_k`0:0>o_k`030000003_knl0kno_03D0kno_
1000P1490>o_k``0080A<P3_knl600204A00kno_1P00P14D0>o_k`8000002`3_knl3000000H0kno_
0P00000I0>o_k`@00000U03oool002l0oooo1P0000110>o_k`030000003_knl0kno_00`0kno_00<0
00000>o_k`3_knl0;`3_knl900204@T0kno_1@00P14l0>o_k`<0080A2@3_knl?00204A80kno_0P00
000;0>o_k`<000001P3_knl2000001/0kno_1000002B0?ooo`00<@3oool7000003d0kno_00<00000
0>o_k`3_knl03P3_knl00`000000kno_0>o_k`0Z0>o_k`X0080AF@3_knlA00204A00kno_0P000009
0>o_k`@000001`3_knl2000001`0kno_1000002A0?ooo`00=03oool6000003X0kno_00<000000>o_
k`3_knl0103_knl6000000H0kno_00<000000>o_k`3_knl09`3_knl700204F@0kno_3@00P14?0>o_
k`030000003_knl0kno_00@0kno_1P0000080>o_k`030000003_knl0kno_01d0kno_1000002?0?oo
o`00=`3oool6000003H0kno_0P0000080>o_k`800000203_knl2000002P0kno_0`00P15X0>o_k`h0
080A3P3_knl2000000D0kno_100000090>o_k`800000803_knl4000008h0oooo000i0?ooo`H00000
=03_knl00`000000kno_0>o_k`070>o_k`8000002@3_knl00`000000kno_0>o_k`080>o_k`D00000
303_knl400204G@0kno_4000P14=0>o_k`030000003_knl0kno_00<0kno_0P00000;0>o_k`030000
003_knl0kno_0240kno_1000002<0?ooo`00?03oool600000300kno_0P0000090>o_k`8000002@3_
knl2000000L0kno_2@0000060>o_k`P0080AM03_knlB00204@`0kno_00<000000>o_k`3_knl00`3_
knl00`000000kno_0>o_k`080>o_k`030000003_knl0kno_02<0kno_1000002;0?ooo`00?P3oool7
000002d0kno_0P0000090>o_k`8000002@3_knl2000000L0kno_2@0000040>o_k`L0080AM`3_knlD
00204@/0kno_00<000000>o_k`3_knl00P3_knl6000000@0kno_00<000000>o_k`3_knl09P3_knl4
000008T0oooo00110?ooo`H00000:`3_knl2000000T0kno_0P0000090>o_k`8000001P3_knl;0000
00<0kno_0`00P15k0>o_kaH0080A2P3_knl00`000000kno_0>o_k`020>o_k`H000000P3_knl00`00
0000kno_0>o_k`0X0>o_k`@00000R03oool004@0oooo1P00000X0>o_k`8000002@3_knl2000000T0
kno_0P0000060>o_k`/00000f`3_knl4000008H0oooo00160?ooo`L000009@3_knl2000000T0kno_
0P0000090>o_k`8000001P3_knl;00000=`0kno_100000250?ooo`00B@3oool6000002<0kno_0P00
00090>o_k`8000002@3_knl2000000L0kno_2@00002M0>o_k`D00000?@3_knl4000008<0oooo001<
0?ooo`H000008@3_knl00`000000kno_0>o_k`070>o_k`8000002@3_knl00`000000kno_0>o_k`06
0>o_k`T00000V`3_knl9000003`0kno_100000220?ooo`00CP3oool6000001l0kno_0P0000080>o_
k`800000203_knl2000000X0kno_1@00002M0>o_k`T00000?P3_knl400000800oooo001A0?ooo`H0
00007@3_knl00`000000kno_0>o_k`060>o_k`800000203_knl00`000000kno_0>o_k`2Z0>o_k`/0
0000?P3_knl4000007l0oooo001C0?ooo`L000006`3_knl00`000000kno_0>o_k`050>o_k`800000
1`3_knl00`000000kno_0>o_k`2[0>o_k`/00000@03_knl4000007d0oooo001F0?ooo`H000006P3_
knl00`000000kno_0>o_k`020>o_k`@000001P3_knl00`000000kno_0>o_k`2V0>o_k`80003D103_
knl;00000440kno_1000001l0?ooo`00F@3oool6000001P0kno_00<000000>o_k`3_knl00`3_knl2
000000D0kno_00<000000>o_k`3_knl0Y03_knl50000e0D0kno_2@0000140>o_k`@00000NP3oool0
05/0oooo1`0000360>o_k`L0003D1P3_knl9000004D0kno_1000001i0?ooo`00GP3oool600000<00
kno_2P000=@90>o_k`D00000B@3_knl4000007L0oooo001Q0?ooo`H00000^P3_knl<0000e5T0kno_
1000001f0?ooo`00H`3oool600000;D0kno_3P000=AL0>o_k`@00000M03oool006H0oooo1P00002`
0>o_k`l0003DGP3_knl4000007<0oooo001X0?ooo`L00000[@3_knl>0000e380kno_0P0000040>o_
k`8000000`3_knl200000280kno_1000001a0?ooo`00J`3oool600000:`0kno_30000=@c0>o_k`80
0000103_knl2000000<0kno_0P00000S0>o_k`@00000L03oool006h0oooo1P00002Y0>o_k`/0003D
IP3_knl4000006h0oooo001`0?ooo`L00000XP3_knl?0000e6L0kno_1000001]0?ooo`00L`3oool6
000001P0kno_0P00001D0>o_k`D00000:@3_knl70000e0030>o_k`000=@0003D00P0003D503_knl2
000005@0kno_1000001[0?ooo`00MP3oool6000001D0kno_0P00001B0>o_k`T00000903_knl70000
e0D0kno_20000=@E0>o_k`800000E@3_knl4000006X0oooo001h0?ooo`H000004`3_knl2000003T0
kno_00<000000>o_k`3_knl02P3_knl00`000000kno_0>o_k`090>o_k`8000001@3oool2000001l0
kno_20000=@:0>o_k`H0003D5P3_knl2000005L0kno_1000001X0?ooo`00N`3oool600000100kno_
0P00000h0>o_k`030000003_knl0kno_00`0kno_00<000000>o_k`3_knl01`3_knl2000000L0oooo
0P00000I0>o_k`T0003D3P3_knl50000e1L0kno_0P00001H0>o_k`@00000I`3oool007d0oooo1`00
000=0>o_k`800000=`3_knl00`000000kno_0>o_k`0>0>o_k`030000003_knl0kno_00H0kno_0P00
00070?ooo`800000503_knl:0000e1<0kno_0`000=@H0>o_k`800000FP3_knl4000006D0oooo0020
0?ooo`H000002`3_knl2000003H0kno_00<000000>o_k`3_knl0203_knl2000000H0kno_00<00000
0>o_k`3_knl01@3_knl2000000L0oooo0P00000<0>o_k`d0003D6@3_knl00`000=@0kno_0>o_k`0G
0>o_k`800000F`3_knl4000006@0oooo00230?ooo`H00000203_knl2000003D0kno_0P00000:0>o_
k`8000001P3_knl2000000L0kno_0P0000050?ooo`8000000`3_knlB0000e3P0kno_0P00001M0>o_
k`@00000HP3oool008D0oooo1`0000050>o_k`800000=@3_knl00`000000kno_0>o_k`090>o_k`80
00001`3_knl00`000000kno_0>o_k`050>o_k`T000000P3_knl;0000e400kno_0P00001N0>o_k`@0
0000H@3oool008P0oooo1P0000030>o_k`800000=03_knl2000000/0kno_0P0000070>o_k`800000
203_knl5000000@0kno_00<0003D0>o_k`3_knl0B03_knl200000600kno_1000001O0?ooo`00R`3o
ool8000003@0kno_0P0000040>o_k`/000001@3_knl2000005`0kno_0P00001Q0>o_k`@00000GP3o
ool008d0oooo1P00000d0>o_k`800000103_knl00`000000kno_0>o_k`040>o_k`8000001`3_knl2
000003d0kno_1000000K0>o_k`800000H`3_knl4000005`0oooo002@0?ooo`H00000<@3_knl20000
00D0kno_00<000000>o_k`3_knl00`3_knl2000000L0kno_0P00000m0>o_k`050000003_knl0kno_
0>o_k`0000006P3_knl2000006@0kno_1000001K0?ooo`00T@3oool8000002h0kno_0P0000060>o_
k`030000003_knl0kno_0080kno_0P0000070>o_k`800000@P3_knl00`000000kno_0>o_k`0G0>o_
k`800000IP3_knl4000005T0oooo002A0?ooo`8000000P3oool6000002`0kno_0P0000070>o_k`04
0000003_knl0kno_0>o_k`8000001`3_knl2000003l0kno_1000000I0>o_k`800000I`3_knl40000
05P0oooo002A0?ooo`8000001@3oool6000002X0kno_00<000000>o_k`3_knl01P3_knl00`000000
kno_0>o_k`02000000L0kno_00<000000>o_k`3_knl0?@3_knl200000080kno_0P00000H0>o_k`80
0000J@3_knl4000005H0oooo002A0?ooo`8000001`3oool6000002P0kno_0P0000070>o_k`030000
003_knl0kno_008000001P3_knl2000003l0kno_00<000000>o_k`3_knl00P3_knl00`000000kno_
0>o_k`0F0>o_k`800000JP3_knl4000005D0oooo002A0?ooo`8000002P3oool6000002H0kno_00<0
00000>o_k`3_knl01P3_knl010000000kno_0000000000060>o_k`030000003_knl0kno_02P0kno_
0P0000060>o_k`@0000000D0kno_000000000000kno_000000050>o_k`030000003_knl0kno_0080
kno_00<000000>o_k`3_knl05P3_knl2000006`0kno_1000001C0?ooo`00T@3oool2000000`0oooo
1`00000T0>o_k`030000003_knl0kno_00H0kno_0`0000050>o_k`030000003_knl0kno_02T0kno_
0P0000050>o_k`8000000`3_knl200000080kno_00<000000>o_k`3_knl0103_knl010000000kno_
0>o_k`3_knl2000001L0kno_0P00001]0>o_k`@00000DP3oool00940oooo0P00000?0?ooo`H00000
8`3_knl00`000000kno_0>o_k`060>o_k`800000103_knl00`000000kno_0>o_k`0Y0>o_k`040000
003_knl0kno_000000D0kno_00<000000>o_k`3_knl00P3_knl200000080kno_00<000000>o_k`3_
knl00`3_knl00`000000kno_0>o_k`020>o_k`030000003_knl0kno_01D0kno_0P00001_0>o_k`@0
0000D03oool00940oooo0P00000B0?ooo`H000008@3_knl00`000000kno_0>o_k`050>o_k`800000
0`3_knl00`000000kno_0>o_k`0Z0>o_k`030000003_knl0kno_00800000103_knl00`000000kno_
0>o_k`030>o_k`040000003_knl0kno_000000H0kno_00<000000>o_k`3_knl00P00000G0>o_k`80
0000L03_knl4000004l0oooo002A0?ooo`800000503oool7000005P0kno_00D000000>o_k`3_knl0
kno_000000050>o_k`H000000P3_knl00`000000kno_0>o_k`050>o_k`<0000000<0kno_0000003_
knl05@3_knl200000780kno_1000001=0?ooo`00T@3oool2000001L0oooo1P00001F0>o_k`030000
003_knl0kno_0080kno_00<000000>o_k`3_knl01`3_knl010000000kno_0>o_k`00000R0>o_k`80
0000L`3_knl4000004`0oooo002A0?ooo`8000006P3oool6000005<0kno_00<000000>o_k`3_knl0
0P3_knl00`000000kno_0>o_k`020>o_k`030000003_knl0kno_00<0kno_00@000000>o_k`3_knl0
00008@3_knl2000007D0kno_1000001:0?ooo`00T@3oool2000001`0oooo1P00001A0>o_k`030000
003_knl0kno_00<0kno_00D000000>o_k`3_knl0kno_000000050>o_k`030000003_knl0kno_0080
0000803_knl2000007H0kno_100000190?ooo`00T@3oool2000001l0oooo1P00000]0>o_k`80003D
7`3_knl00`000000kno_0>o_k`030>o_k`030000003_knl0kno_0080kno_1@0000030>o_k`040000
003_knl00000000001h0kno_0P00001h0>o_k`@00000A`3oool00940oooo0P00000Q0?ooo`L00000
:P3_knl20000e1l0kno_00<000000>o_k`3_knl0103_knl00`000000kno_0>o_k`0[0>o_k`800000
N@3_knl4000004H0oooo002A0?ooo`800000903oool6000002P0kno_0P000=@O0>o_k`030000003_
knl0kno_00D0kno_00<000000>o_k`3_knl0:P3_knl2000007/0kno_100000140?ooo`00T@3oool2
000002L0oooo1P00000T0>o_k`@0003D7P3_knl00`000000kno_0>o_k`050>o_k`030000003_knl0
kno_02X0kno_0P00001l0>o_k`@00000@`3oool00940oooo0P00000Y0?ooo`L000008@3_knl40000
e5<0kno_0P00001n0>o_k`<00000@P3oool00940oooo0P00000/0?ooo`H000007`3_knl40000e5<0
kno_0P00001o0>o_k`@00000@03oool00940oooo0P00000_0?ooo`H000006`3_knl50000e5<0kno_
0P0000200>o_k`@00000?`3oool00940oooo0P00000a0?ooo`H000006@3_knl60000e580kno_0P00
00220>o_k`@00000?@3oool00940oooo0P00000d0?ooo`H000005P3_knl60000e580kno_0P000023
0>o_k`@00000?03oool00940oooo0P00000f0?ooo`L000004P3_knl70000e580kno_0P0000250>o_
k`@00000>P3oool00940oooo0P00000i0?ooo`H00000403_knl80000e540kno_0P0000260>o_k`@0
0000>@3oool00940oooo0P00000l0?ooo`H000003@3_knl80000e540kno_0P0000280>o_k`@00000
=`3oool00940oooo0P00000n0?ooo`L000002@3_knl90000e540kno_0P0000290>o_k`@00000=P3o
ool00940oooo0P0000110?ooo`H000001`3_knl90000e540kno_0P00002;0>o_k`@00000=03oool0
0940oooo0P0000140?ooo`H00000103_knl:0000e500kno_0P00002<0>o_k`@00000<`3oool00940
oooo0P0000160?ooo`H0000000<0kno_0000e0000=@02@000=A@0>o_k`800000SP3_knl400000340
oooo002A0?ooo`800000B@3oool4000000/0003DD03_knl2000008l0kno_1000000`0?ooo`00T@3o
ool2000004/0oooo0P00000<0000e4l0kno_0P00002A0>o_k`@00000;P3oool00940oooo0P00001<
0?ooo`d0003DC`3_knl200000980kno_1000000]0?ooo`00T@3oool200000540oooo0P0000020000
e0800000D@3_knl2000009@0kno_1000000[0?ooo`00T@3oool2000005<0oooo0P000=@4000004l0
kno_0P00002E0>o_k`@00000:P3oool00940oooo0P00001C0?ooo`80003D00<0oooo000000000000
1000001<0>o_k`800000U`3_knl4000002P0oooo002A0?ooo`800000D`3oool20000e0<0oooo1`00
00190>o_k`800000V03_knl4000002L0oooo002A0?ooo`800000D`3oool20000e0H0oooo1P000017
0>o_k`800000VP3_knl4000002D0oooo002A0?ooo`800000D`3oool20000e0T0oooo1P0000140>o_
k`800000V`3_knl4000002@0oooo002A0?ooo`800000D`3oool20000e0/0oooo1`0000110>o_k`80
0000W@3_knl400000280oooo002A0?ooo`800000D`3oool20000e0h0oooo1P00000o0>o_k`800000
WP3_knl400000240oooo002A0?ooo`800000D`3oool20000e140oooo1P00000l0>o_k`800000X03_
knl4000001l0oooo002A0?ooo`800000D`3oool20000e1<0oooo1P00000j0>o_k`800000X@3_knl4
000001h0oooo002A0?ooo`800000D`3oool20000e1H0oooo1P00000g0>o_k`800000X`3_knl40000
01`0oooo002A0?ooo`800000D`3oool20000e1P0oooo1`00000d0>o_k`800000Y03_knl4000001/0
oooo002A0?ooo`800000D`3oool20000e1/0ooooh`00000J0?ooo`00T@3oool2000005<0oooo0P00
0=@N0?ooon0000006P3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e3L0oooo3@00000?
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D903ooolQ000000h0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=@@0?ooobP000002`3oool4000000`0oooo0P0000330?ooo`00
T@3oool200000580oooo:000000O0?ooo`@000002`3oool200000<<0oooo002A0?ooo`800000?P3o
oolX000003D0oooo100000090?ooo`800000``3oool00940oooo0P00000[0?ooobP000000P000=A7
0?ooo`@00000203oool200000<<0oooo002A0?ooo`8000005`3ooolX000001@0oooo0P000=A90?oo
o`@000001P3oool200000<<0oooo002A0?ooo`8000000`3ooolY000002L0oooo0P000=A:0?ooo`D0
0000103oool200000<<0oooo00230?ooobP00000>`3oool20000e4`0oooo100000030?ooo`800000
``3oool006l0oooo:000001?0?ooo`80003DCP3oool4000000030?ooo`00000000000<<0oooo001L
0?ooobP00000203oool;000004l0oooo0P000=A?0?ooo`H00000``3oool004P0oooo:000000L0?oo
o`/00000C`3oool20000e540oooo100000330?ooo`00=@3ooolX00000300oooo2P00001?0?ooo`80
003DDP3oool400000<80oooo000Q0?ooobP00000A03oool900000500oooo0P000=AC0?ooo`D00000
`03oool000h0oooo:000001G0?ooo`T00000D03oool20000e5<0oooo1P00002o0?ooo`00103ooolN
000006/0oooo2@00001@0?ooo`80003DD`3oool200000080oooo1000002m0?ooo`00103oool;0000
07h0oooo2000001A0?ooo`80003DD`3oool2000000<0oooo1000002l0?ooo`001P3oool700000840
oooo1`00001A0?ooo`80003DD`3oool2000000D0oooo1000002j0?ooo`002@3oool7000007h0oooo
1`00001A0?ooo`80003DD`3oool2000000H0oooo1000002i0?ooo`00303oool6000007`0oooo1`00
001A0?ooo`80003DD`3oool2000000P0oooo1000002g0?ooo`003`3oool6000007T0oooo1P00001B
0?ooo`80003DD`3oool2000000T0oooo1000002f0?ooo`004@3oool7000007L0oooo1@00001B0?oo
o`80003DD`3oool2000000/0oooo1000002d0?ooo`00503oool6000007D0oooo1@00001B0?ooo`80
003DD`3oool2000000`0oooo1@00002b0?ooo`005`3oool600000780oooo1@00001B0?ooo`80003D
D`3oool2000000h0oooo1000002a0?ooo`006@3oool7000006l0oooo1000001C0?ooo`80003DD`3o
ool200000100oooo1000000_0?ooo`L000001@3oool3000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool3000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`<00000103oool3000000050?ooo`000000oooo0?ooo`00
00001@3oool4000003T0oooo000L0?ooo`L00000K@3oool3000005<0oooo0P000=AC0?ooo`800000
4@3oool4000002h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`800000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=P3oool001l0oooo1P00001[0?ooo`<00000D`3oool20000e5<0oooo0P00
000C0?ooo`@00000;03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03H0oooo000R0?ooo`H00000J03oool2000005@0oooo0P000=AC0?ooo`800000503oool40000
02/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`030?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000
003oool0oooo000000L0oooo0P00000i0?ooo`00903oool7000006D0oooo0P00001D0?ooo`80003D
D`3oool2000001H0oooo1000000Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool000001@3oool2000003/0oooo000W0?ooo`H00000H`3oool20000
05@0oooo0P000=AC0?ooo`8000005`3oool4000002P0oooo1`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03/0
oooo000Z0?ooo`H00000A`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0DP3oool20000e4`0oooo3000000F0?ooo`@000009P3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0f0?ooo`00;03oool7000004<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1N0?ooo`80003DC@3oool;000001L0oooo1000000U0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`0000000P0000040?ooo`@000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo1000000i0?ooo`00;`3o
ool7000003l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1M0?ooo`80003DC@3o
ool;000001T0oooo1000000S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1[0?ooo`00<P3oool6000003`0oooo00<000000?ooo`3oool00P3oool8
000000H0oooo00<000000?ooo`3oool0G03oool20000e4d0oooo2P00000K0?ooo`@000008P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool0
03D0oooo1P00000h0?ooo`8000001@3oool7000000H0oooo0P00000h0?ooob@0080A00<0oooo0000
e0000=@0CP3oool9000001d0oooo1000000P0?ooo`L000002`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo05<0oooo000g0?ooo`L00000=@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?oooch0
080AA03oool9000001h0oooo1000002O0?ooo`00>P3oool600000380oooo0P0000080?ooo`030000
003oool0oooo00T0oooo0P00000R0?oooaD0080A903ooolE00204C`0oooo2@00000P0?ooo`@00000
W@3oool003d0oooo1P00000_0?ooo`800000203oool2000000X0oooo0P0000020?ooo`l000002P3o
ool?00204C80oooo0P000=@:0?ooo`l0080A7P3oool200204AH0oooo1`00000R0?ooo`D00000V`3o
ool003l0oooo1`00000/0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000P3oool?
000000D0oooo2`00P14k0?ooo`80003D4`3oool<00204AP0oooo0`00P14E0?ooo`L00000903oool4
000009X0oooo00120?ooo`L00000:@3oool2000000X0oooo00<000000?ooo`3oool01`3oool20000
0080oooo3`0000070?ooo`80080A@P3oool20000e1X0oooo2P00P14B0?ooo`D0080A503oool70000
02H0oooo1000002H0?ooo`00A@3oool6000002L0oooo0P00000:0?ooo`800000203oool200000080
oooo3`00001;0?ooo`80003D7`3oool900204@h0oooo1P00P14D0?ooo`H000009`3oool4000009L0
oooo00180?ooo`H00000903oool2000000/0oooo00<000000?ooo`3oool01P3oool200000080oooo
3`00001;0?ooo`80003D903oool800204@T0oooo2000P14C0?ooo`D00000:P3oool4000009D0oooo
001:0?ooo`L000008P3oool00`000000oooo0?ooo`090?ooo`8000001`3oool010000000oooo0?oo
o`3oool?000004/0oooo0P000=@Y0?ooo`L0080A1@3oool900204A80oooo1@00000[0?ooo`@00000
U03oool004d0oooo1P00000P0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool2000000<0oooo3`00001;0?ooo`80003D;@3oool600204@030?ooo`00P140080A00T0080A4P3o
ool4000002d0oooo1000002B0?ooo`00D03oool6000001h0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000060?ooo`030000003oool0oooo0080oooo3`00001;0?ooo`80003D=03oool=
00204A00oooo1000000^0?ooo`@00000903oool00`000000oooo0?ooo`080?ooo`<000001@3oool3
000000030?ooo`00000000000080oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo0000
00060?ooo`<000001@3oool4000000h0oooo0`0000000`3oool00000000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo00d0oooo001B
0?ooo`L00000703oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001@3o
ool00`000000oooo0?ooo`030?ooo`l00000B`3oool20000e3<0oooo3`00P14?0?ooo`<00000<@3o
ool400000280oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000h0oooo
001E0?ooo`L000006P3oool010000000oooo0?ooo`3oool6000000D0oooo00<000000?ooo`3oool0
103oool?000004/0oooo0P000=@c0?oooa00080A3`3oool200000380oooo1000000Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0<0?ooo`00F03oool6000001T0oooo
00@000000?ooo`3oool0oooo100000050?ooo`030000003oool0oooo00D0oooo3`0000050?ooo`80
003DA03oool20000e3<0oooo4@00P14>0?ooo`800000=03oool4000001l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`<0000000<0oooo0000003oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`09
0?ooo`8000003P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00`0oooo001K0?ooo`H00000:`3oool?
000000D0oooo0`000=A30?ooo`80003D=P3oool?00204@d0oooo0P00000e0?ooo`@000007P3oool0
0`000000oooo0?ooo`060?ooo`L000001@3oool3000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000@0oooo1`0000030?ooo`8000004P3oool3000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00`0
oooo001M0?ooo`L00000:03oool?000000L0oooo0P000=A20?ooo`80003D>`3oool;00204DD0oooo
1000000L0?ooo`H000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0<0?ooo`00H03oool6000002H0oooo3`0000080?ooo`<0003D
P`3oool600204DD0oooo1000000K0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`8000003P3oool006<0oooo1P00000S0?ooo`l000002@3oool30000e8L0oooo0P00
P1560?ooo`@000006@3oool00`000000oooo0?ooo`080?ooo`<000001@3oool4000000<0oooo1000
00000`3oool000000?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000
1@3oool4000000h0oooo100000040?ooo`030000003oool00000008000001@3oool3000000030?oo
o`000000oooo00d0oooo001U0?ooo`L00000>@3oool40000e<h0oooo1@00000G0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0<0?ooo`00J03oool7
000003P0oooo10000=C>0?ooo`@000005P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0303oool006/0oooo1P00000h0?ooo`@0003DcP3oool40000
01@0oooo1`00001G0?ooo`030000003oool0oooo00`0oooo001^0?ooo`H00000=`3oool40000e<d0
oooo100000200?ooo`00L03oool7000003H0oooo1@000=@>0?ooo`80003D6@3ooolA00000980oooo
1000001n0?ooo`00L`3oool6000003L0oooo1@000=@;0?ooo`@0003D5`3ooolA000009<0oooo1000
001m0?ooo`00MP3oool6000003H0oooo1P000=@70?ooo`P0003D503oool2000000d0oooo0P00002E
0?ooo`@00000N`3oool007P0oooo1`00000g0?ooo`H0003D0`3oool:0000e180oooo0P00000=0?oo
o`800000A03oool@00000480oooo1000001j0?ooo`00N`3oool7000003L0oooo4P000=@@0?ooo`80
00003@3oool2000004@0oooo4000000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool09@3oool4000007P0oooo001n0?ooo`H00000>P3oool?0000e0h0oooo0P00000=0?ooo`800000
A03oool@000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`@00000
M`3oool00840oooo1P00000g0?oooa40003D303oool2000000d0oooo0P0000140?oooa0000003@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo1000001>0?ooo`8000001@3o
ool00`000000oooo0?ooo`0M0?ooo`00P`3oool7000003@0oooo50000=@90?ooo`8000003@3oool2
000004@0oooo4000000<0?ooo`030000003oool0oooo00D0oooo100000070?ooo`030000003oool0
oooo02H0oooo1000001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool0
08H0oooo1P00000b0?oooaH0003D1`3oool2000000d0oooo0P0000140?oooa0000002`3oool20000
00H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`800000:@3oool4000004h0oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`00R@3oool6000002l0oooo4`000=@:0?ooo`8000003@3oool2
000004@0oooo4000000;0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:03oool4000001/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00000@0?ooo`00R`3o
ool7000002`0oooo3P000=@?0?ooo`8000003@3oool2000004@0oooo4000000:0?ooo`8000001@3o
ool2000000D0oooo0P0000060?ooo`800000:`3oool4000001T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`0000000P3oool2000000<0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000l0oooo002>0?ooo`L000007P3oool00`000000oooo0?oo
o`080?ooo`P0003D5@3oool2000000d0oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0:P3oool@000000X0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0P00
000/0?ooo`D000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo002A0?ooo`H00000703oool00`000000oooo0?ooo`080?ooo`<0003D6P3ooolA000000T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?oooa0000002P3oool2000000D0
oooo0P0000050?ooo`8000001P3oool2000002h0oooo1000000F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0180oooo002D0?ooo`H000006P3oool00`000000oooo0?ooo`0T0?oooa400000203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo4000000:0?ooo`8000001@3oool2
000000D0oooo0P0000060?ooo`800000<03oool4000001@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0000000<0oooo0000003oool00`3oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?oo
o`00UP3oool7000001L0oooo00@000000?ooo`0000000000>`3oool010000000oooo0?ooo`3oool6
000000T0oooo00<000000?ooo`3oool09`3oool@000000X0oooo0P0000050?ooo`<000000`3oool2
000000L0oooo0P00000a0?ooo`@000004`3oool7000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo00000005
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`00V@3oool6000001H0oooo00<000000?ooo`3oool00P00000h0?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool01P3oool2000002P0oooo4000000:0?ooo`8000001@3oool20000
00030?ooo`000000000000800000203oool2000003<0oooo1000000A0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000103oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
09`0oooo1P00000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?ooo`@00000403oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0000003oool00`0000050?ooo`<000000`3oool0
0`000000oooo00000002000000D0oooo0`0000030?ooo`@0000000<0oooo0000003oool0103oool2
000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool00P3oool4000000l0oooo002N
0?ooo`L00000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo0P00000;
0?ooo`8000001`3oool200000480oooo0P0000050?ooo`8000002`3oool2000003L0oooo1000000>
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?oo
o`0X0?ooo`00WP3oool:000000030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool2000000/0oooo0P000007
0?ooo`800000@`3oool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo0?ooo`0g
0?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000200oooo00<0
00000?ooo`3oool0:03oool009d0oooo0P0000040?ooo`L000000`3oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`8000002`3oool2
000000L0oooo0P0000140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0j0?ooo`@000002`3oool7000000<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0E0?ooo`00W@3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000
00000000100000001@3oool000000000003oool0000000@0oooo0P0000020?ooo`030000003oool0
oooo03@0oooo0P00000:0?ooo`<000001`3oool2000004D0oooo00<000000?ooo`3oool0103oool2
000000H0oooo00<000000?ooo`3oool0?03oool400000600oooo002M0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0200000000`3oool000000?ooo`040?ooo`@00000=P3oool20000
00T0oooo0`0000080?ooo`800000AP3oool00`000000oooo0?ooo`050?ooo`<000000P3oool00`00
0000oooo0?ooo`0o0?ooo`@00000GP3oool00:D0oooo00<000000?ooo`3oool02P00000o0?ooo`80
00001P3oool6000000P0oooo0P00002F0?ooo`@00000G@3oool00:<0oooo0P0000030?ooo`030000
003oool0oooo00@0oooo1P00000m0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000
003oool0oooo09L0oooo1000001K0?ooo`00W`3oool5000000D0oooo00<000000?ooo`3oool00`3o
ool9000003X0oooo0P0000090?ooo`030000003oool0oooo00H0oooo0P00002J0?ooo`@00000FP3o
ool009h0oooo0P00000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?oo
o`07000003P0oooo00<000000?ooo`3oool01`3oool2000000L0oooo00<000000?ooo`3oool0V`3o
ool4000005P0oooo002N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4
000000<0oooo00<000000?ooo`3oool00P3oool6000003L0oooo00@000000?ooo`3oool000001@3o
ool2000000H0oooo00<000000?ooo`3oool0W@3oool5000005H0oooo002N0?ooo`8000001P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo1P00000e0?ooo`040000003oool0
oooo000000<0oooo0`0000050?ooo`030000003oool0oooo0:00oooo1000001E0?ooo`00W`3oool2
000000@0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo1`00000c0?ooo`030000003oool0
oooo00D000001@3oool00`000000oooo0?ooo`2S0?ooo`@00000D`3oool00:40oooo1@00000=0?oo
o`030000003oool0oooo00T0oooo1P00003U0?ooo`@00000DP3oool00<80oooo1P00003T0?ooo`@0
0000D03oool00<@0oooo1`00003R0?ooo`@00000C`3oool00<L0oooo1`00003Q0?ooo`@00000C@3o
ool00<X0oooo1P00003P0?ooo`@00000C03oool00<d0oooo1P00003O0?ooo`@00000BP3oool00<l0
oooo1`00003M0?ooo`@00000B@3oool00=80oooo1P00003M0?ooo`@00000A`3oool00=D0oooo1P00
003K0?ooo`@00000AP3oool00=L0oooo1`00003J0?ooo`@00000A03oool00=X0oooo1`00003H0?oo
o`@00000@`3oool00=d0oooo1P00003H0?ooo`@00000@@3oool00>00oooo1P00003F0?ooo`D00000
?`3oool00>80oooo1`00003E0?ooo`@00000?P3oool00>D0oooo1P00003E0?ooo`@00000?03oool0
0>P0oooo1P00003C0?ooo`@00000>`3oool00>X0oooo1`00003B0?ooo`@00000>@3oool00>d0oooo
1`00003@0?ooo`@00000>03oool00?00oooof@00000g0?ooo`00l`3ooooF000003L0oooo003o0?oo
ool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3o
ool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`@@3`l?04000001/0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000G0?ooo`H00000o`3`l?110?3`l0@000006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0?3`l3l0l?3`1000000H0?oo
o`030000003oool0oooo00X0oooo0`0000040?ooo`030000003oool00000008000001@3oool30000
0080oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`020?ooo`@00000A@3oool001`0oooo1`00003o0?3`l3h0l?3`1000000F0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1O0?oo
o`007`3oool600000?l0l?3`?@3`l?04000001H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo000R0?ooo`H00000o`3`l?0l0?3`l0@00000
5@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00003o0?3`l3X0l?3`1000
002H0?ooo`009`3oool600000?l0l?3`>P3`l?03000009L0oooo000Z0?ooo`H00000o`3`l?0h0?3`
l0@00000U@3oool002`0oooo1P0000150?3`l0030000003`l?00l?3`00X0l?3`00<000000?3`l03`
l?00h@3`l?04000009@0oooo000_0?ooo`H00000@@3`l?000`000000l?3`0?3`l00<0?3`l0030000
003`l?00l?3`0>80l?3`1000002B0?ooo`00<@3oool7000003d0l?3`00<000000?3`l03`l?003P3`
l?000`000000l?3`0?3`l03R0?3`l0@00000T@3oool003@0oooo1P00000j0?3`l0030000003`l?00
l?3`00@0l?3`1P0000060?3`l0030000003`l?00l?3`0><0l?3`1000002?0?ooo`00=`3oool60000
03H0l?3`0P0000080?3`l0800000203`l?0200000>D0l?3`1000002>0?ooo`00>@3oool6000003@0
l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?00i@3`l?04000008`0
oooo000l0?ooo`H00000<03`l?02000000T0l?3`0P0000090?3`l0800000i`3`l?04000008/0oooo
000n0?ooo`L00000;@3`l?02000000T0l?3`0P0000090?3`l08000002@3`l?0500000=/0l?3`1000
00290?ooo`00@@3oool6000002/0l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`2@00003J
0?3`l0@00000R03oool004@0oooo1P00000X0?3`l08000002@3`l?02000000T0l?3`0P0000060?3`
l0/00000f`3`l?04000008H0oooo00160?ooo`L000009@3`l?02000000T0l?3`0P0000090?3`l080
00001P3`l?0;00000=`0l?3`100000250?ooo`00B@3oool6000002<0l?3`0P0000090?3`l0800000
2@3`l?02000000H0l?3`2`00003N0?3`l0@00000P`3oool004`0oooo1P00000Q0?3`l0030000003`
l?00l?3`00L0l?3`0P0000090?3`l0030000003`l?00l?3`00H0l?3`2@00003P0?3`l0@00000PP3o
ool004h0oooo1P00000O0?3`l0800000203`l?02000000P0l?3`0P00000:0?3`l0D00000i03`l?04
00000800oooo001A0?ooo`H000007@3`l?000`000000l?3`0?3`l0060?3`l0800000203`l?000`00
0000l?3`0?3`l03c0?3`l0@00000O`3oool005<0oooo1`00000K0?3`l0030000003`l?00l?3`00D0
l?3`0P0000070?3`l0030000003`l?00l?3`0?H0l?3`1000001m0?ooo`00EP3oool6000001X0l?3`
00<000000?3`l03`l?000P3`l?04000000H0l?3`00<000000?3`l03`l?00n03`l?04000007`0oooo
001I0?ooo`H00000603`l?000`000000l?3`0?3`l0030?3`l08000001@3`l?000`000000l?3`0?3`
l03k0?3`l0@00000NP3oool005/0oooo1`00003o0?3`l280l?3`1000001i0?ooo`00GP3oool60000
0?l0l?3`8P3`l?04000007L0oooo001Q0?ooo`H00000o`3`l?0P0?3`l0@00000MP3oool006<0oooo
1P00003o0?3`l200l?3`1000001d0?ooo`00IP3oool600000?l0l?3`7P3`l?04000007<0oooo001X
0?ooo`L00000o`3`l?0M0?3`l0@00000L@3oool006/0oooo1P00003o0?3`l1`0l?3`1000001`0?oo
o`00KP3oool600000?l0l?3`6`3`l?04000006h0oooo001`0?ooo`L00000o`3`l?0I0?3`l0@00000
K@3oool007<0oooo1P00003o0?3`l1T0l?3`1000001[0?ooo`00MP3oool600000?l0l?3`5`3`l?04
000006X0oooo001h0?ooo`H000004`3`l?0200000?l0l?3`0P3`l?04000006P0oooo001k0?ooo`H0
0000403`l?0200000?l0l?3`0`3`l?04000006L0oooo001m0?ooo`L000003@3`l?0200000?l0l?3`
1@3`l?04000006D0oooo00200?ooo`H000002`3`l?0200000?l0l?3`1P3`l?04000006@0oooo0023
0?ooo`H00000203`l?0200000?l0l?3`203`l?0400000680oooo00250?ooo`L000001@3`l?020000
0?l0l?3`2@3`l?0400000640oooo00280?ooo`H000000`3`l?0200000?l0l?3`2`3`l?04000005l0
oooo002;0?ooo`P00000o`3`l?0<0?3`l0@00000GP3oool008d0oooo1P00003o0?3`l0h0l?3`1000
001L0?ooo`00T03oool600000?l0l?3`303`l?04000005/0oooo002A0?ooo`P00000o`3`l?0;0?3`
l0@00000F@3oool00940oooo0P0000020?ooo`H00000o`3`l?0:0?3`l0@00000F03oool00940oooo
0P0000050?ooo`H00000o`3`l?090?3`l0@00000EP3oool00940oooo0P0000070?ooo`H00000o`3`
l?080?3`l0@00000E@3oool00940oooo0P00000:0?ooo`H00000o`3`l?070?3`l0@00000D`3oool0
0940oooo0P00000<0?ooo`L00000o`3`l?050?3`l0@00000DP3oool00940oooo0P00000?0?ooo`H0
0000o`3`l?050?3`l0@00000D03oool00940oooo0P00000B0?ooo`H00000o`3`l?030?3`l0@00000
C`3oool00940oooo0P00000D0?ooo`L00000o`3`l?020?3`l0@00000C@3oool00940oooo0P00000G
0?ooo`H00000o`3`l?010?3`l0@00000C03oool00940oooo0P00000J0?ooo`H00000o`3`l?040000
04X0oooo002A0?ooo`800000703oool600000?h0l?3`100000190?ooo`00T@3oool2000001l0oooo
1P00003m0?3`l0@00000A`3oool00940oooo0P00000Q0?ooo`L00000n`3`l?04000004H0oooo002A
0?ooo`800000903oool600000?/0l?3`100000140?ooo`00T@3oool2000002L0oooo1P00003i0?3`
l0@00000@`3oool00940oooo0P00000Y0?ooo`L00000n03`l?0300000480oooo002A0?ooo`800000
;03oool600000?L0l?3`100000100?ooo`00T@3oool2000002l0oooo1P00003e0?3`l0@00000?`3o
ool00940oooo0P00000a0?ooo`H00000m@3`l?04000003d0oooo002A0?ooo`800000=03oool60000
0?<0l?3`1000000l0?ooo`00T@3oool2000003H0oooo1`00003b0?3`l0@00000>P3oool00940oooo
0P00000i0?ooo`H00000l@3`l?04000003T0oooo002A0?ooo`800000?03oool600000?00l?3`1000
000g0?ooo`00T@3oool2000003h0oooo1`00003^0?3`l0@00000=P3oool00940oooo0P0000110?oo
o`H00000kP3`l?04000003@0oooo002A0?ooo`800000A03oool600000>`0l?3`1000000c0?ooo`00
T@3oool2000004H0oooo1P00003/0?3`l0@00000<@3oool00940oooo0P0000190?ooo`H00000jP3`
l?0400000300oooo002A0?ooo`800000B`3oool700000>T0l?3`1000000^0?ooo`00T@3oool20000
04h0oooo1P00003X0?3`l0@00000;@3oool00940oooo0P00001A0?ooo`H00000i`3`l?04000002/0
oooo002A0?ooo`800000D`3oool600000>H0l?3`1000000Z0?ooo`00T@3oool2000005H0oooo1P00
003U0?3`l0@00000:03oool00940oooo0P00001H0?ooo`L00000h`3`l?04000002L0oooo002A0?oo
o`800000F`3oool600000><0l?3`1000000U0?ooo`00T@3oool2000005h0oooo1P00003Q0?3`l0@0
0000903oool00940oooo0P00001P0?ooo`L00000h03`l?0400000280oooo002A0?ooo`800000H`3o
ool600000=l0l?3`1000000Q0?ooo`00T@3oool2000006H0oooo1P00003N0?3`l0@000007`3oool0
0940oooo0P00001X0?ooo`H00000g@3`l?04000001h0oooo002A0?ooo`800000J`3oool600000=`0
l?3`1000000L0?ooo`00T@3oool2000006d0oooo1`00003J0?3`l0@000006`3oool00940oooo0P00
001`0?ooon<000006P3oool00940oooo0P00001c0?ooon0000006P3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000S03oool=00000=@0oooo002A0?ooo`80
0000N@3ooolQ00000=<0oooo002A0?ooo`800000I@3ooolX000000/0oooo1000003A0?ooo`00T@3o
ool200000580oooo:000000O0?ooo`@00000d03oool00940oooo0P00000n0?ooobP00000=@3oool4
00000<h0oooo002A0?ooo`800000:`3ooolX000004T0oooo1000003=0?ooo`00T@3oool2000001L0
oooo:000001O0?ooo`@00000b`3oool00940oooo0P0000030?ooobT00000L`3oool500000<T0oooo
00230?ooobP00000R@3oool400000<P0oooo001_0?ooobP00000W`3oool400000<H0oooo001L0?oo
obP00000203oool=000009h0oooo100000350?ooo`00B03ooolX000001`0oooo3@00002P0?ooo`@0
0000``3oool003D0oooo:000000_0?ooo`d00000X@3oool400000<80oooo000Q0?ooobP00000@`3o
ool<00000:@0oooo100000300?ooo`003P3ooolX000005L0oooo2`00002U0?ooo`@00000_`3oool0
00@0oooo7P00001[0?ooo`/00000Y`3oool400000;d0oooo00040?ooo`/00000OP3oool:00000:T0
oooo1000002l0?ooo`001P3oool700000840oooo2@00002[0?ooo`@00000^P3oool000T0oooo1`00
001n0?ooo`T00000[03oool400000;T0oooo000<0?ooo`H00000O03oool800000:l0oooo1000002g
0?ooo`003`3oool6000007X0oooo1`00002`0?ooo`@00000]P3oool00140oooo1`00001g0?ooo`H0
0000/`3oool400000;@0oooo000D0?ooo`H00000M@3oool600000;@0oooo1@00002b0?ooo`005`3o
ool6000007<0oooo1@00002f0?ooo`@00000/@3oool001T0oooo1`00001`0?ooo`@00000^@3oool4
00000:l0oooo000L0?ooo`L00000K@3oool400000;X0oooo1000002^0?ooo`007`3oool6000006`0
oooo0`00002l0?ooo`@00000;03oool7000000D0oooo0`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000000000050?ooo`050000003oool0oooo
0?ooo`0000001@3oool3000000@0oooo0`0000001@3oool000000?ooo`3oool0000000D0oooo1000
000h0?ooo`008P3oool6000006T0oooo0P00002n0?ooo`@00000:`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000<0oooo0P0000050?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e
0?ooo`00903oool700000?l0oooo:@3oool4000002T0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo000W0?ooo`H00000o`3ooolX0?ooo`@00000
:03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000oooo00@0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000070?ooo`800000>03oool002X0oooo1P00003o0?ooobL0oooo1000000V
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000050?ooo`800000>P3oool002`0oooo1`00003o0?ooobD0oooo1000000U0?ooo`L00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo03X0oooo000_0?ooo`L00000@@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0=80oooo1000000S0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool0
0380oooo1P00000n0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0dP3oool40000
0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`00
0000oooo00000002000000@0oooo100000040?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`<000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P000002
0?ooo`@00000>03oool003D0oooo1P00000j0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0d`3oool400000200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo06/0oooo000g0?ooo`L00000=P3oool00`000000oooo0?ooo`020?ooo`P0
00001P3oool00`000000oooo0?ooo`3C0?ooo`@000007`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool003X0oooo1P00000c0?ooo`800000
1@3oool7000000H0oooo0P00003F0?ooo`@000007@3oool7000000/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1C0?ooo`00?@3oool600000300oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo
4@0000330?ooo`D00000V`3oool003l0oooo1`00000/0?ooo`800000203oool00`000000oooo0?oo
o`090?ooo`8000000P3ooolA00000<D0oooo1000002J0?ooo`00@P3oool7000002T0oooo0P000008
0?ooo`8000002P3oool200000080oooo4@0000370?ooo`@00000V03oool004D0oooo1P00000W0?oo
o`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000P3ooolA00000<P0oooo1000002G0?oo
o`00B03oool6000002@0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo0P0000020?oooa40
0000bP3oool4000009D0oooo001:0?ooo`L000008@3oool2000000X0oooo0P0000080?ooo`800000
0P3ooolA00000</0oooo1000002D0?ooo`00C@3oool6000001l0oooo0P00000;0?ooo`030000003o
ool0oooo00H0oooo0P0000020?oooa400000c@3oool400000980oooo001@0?ooo`H000007@3oool0
0`000000oooo0?ooo`090?ooo`8000001`3oool010000000oooo0?ooo`3ooolA00000<h0oooo1000
000T0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`<0000000@0oooo000000000000oooo
0`0000020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`<00000
103oool4000000L0oooo0`0000001@3oool000000000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool3000000030?ooo`000000oooo01P0oooo001B0?ooo`L000006P3oool2000000@0oooo
00<000000?ooo`3oool00`3oool2000000H0oooo0P0000030?oooa400000d03oool400000280oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000001T0oooo001E0?ooo`L00000
603oool00`000000oooo0?ooo`020?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0
0P3ooolA00000=40oooo1000000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3o
ool005P0oooo1P00000G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`00
00050?ooo`030000003oool0oooo00<0oooo4@00003C0?ooo`@000007`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0203oool2000000L0oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00F`3oool6000001D0oooo00@000000?oo
o`3oool0oooo1P0000050?ooo`030000003oool0oooo00@0oooo4@00003D0?ooo`@000007P3oool0
0`000000oooo0?ooo`050?ooo`L00000103oool300000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool700000080oooo0P00000;0?ooo`<00000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool05`3oool005d0oooo1`00000C0?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000
oooo0?ooo`050?oooa400000eP3oool4000001`0oooo1P0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00H03oool600000?l0oooo3`3o
ool4000001/0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000006@3o
ool006<0oooo1P00003o0?ooo`h0oooo1000000I0?ooo`030000003oool0oooo00L0oooo0`000004
0?ooo`@000000P3oool4000000030?ooo`000000oooo00<0oooo00H000000?ooo`3oool0oooo0000
003oool2000000<0oooo0`0000040?ooo`@000001`3oool4000000<0oooo00<000000?ooo`000000
0P0000050?ooo`<0000000<0oooo0000003oool0603oool006D0oooo1`00003o0?ooo``0oooo1@00
000G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0G0?ooo`00J03oool700000?l0oooo2`3oool4000001H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001[0?ooo`H00000o`3oool;0?oo
o`@00000503oool7000004`0oooo00<000000?ooo`3oool05`3oool006h0oooo1P00003o0?ooo`T0
oooo100000200?ooo`00L03oool700000?l0oooo203oool4000007h0oooo001c0?ooo`H00000o`3o
ool70?ooo`@00000O@3oool007H0oooo1P00003o0?ooo`H0oooo1000001k0?ooo`00N03oool70000
0?l0oooo103oool4000007X0oooo001k0?ooo`L00000o`3oool30?ooo`@00000N03oool007h0oooo
1P00003o0?ooo`80oooo1000001g0?ooo`00P@3oool600000?l0oooo0@3oool4000004h0oooo0P00
00050?ooo`030000003oool0oooo01d0oooo00230?ooo`L00000oP3oool4000004l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`00QP3oool600000?h0oooo1000001>0?oo
o`050000003oool0oooo0?ooo`0000007`3oool008T0oooo1P00003l0?ooo`@000006`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool30000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<00000103oool30000
00@0oooo00H000000?ooo`3oool0oooo0000003oool3000000<0oooo00<000000?ooo`3oool00P3o
ool300000100oooo002;0?ooo`L00000n`3oool4000001T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`0000000P3oool2000000<0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0?ooo`3oool0000000l0oooo002>0?ooo`L00000n@3oool5000001L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00T@3oool600000?T0oooo
1000000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo0180oooo002D0?ooo`H00000n03oool40000
01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`0B0?ooo`00UP3oool700000?H0oooo1000000C0?ooo`L00000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00`0oooo002I0?ooo`H00000mP3oool400000140oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo008000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`00W03oool600000?@0oooo1000000@0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool000000?ooo`03000000D0oooo0`0000030?ooo`030000003oool0000000800000
1@3oool3000000<0oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`020?ooo`@000003`3oool009h0oooo1`00003c0?ooo`@00000
3P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3o
ool0:03oool00:40oooo1`00003a0?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000200oooo00<000000?ooo`3oool0:03oool00:@0oooo1P00003a0?ooo`@00000
2`3oool7000000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0E0?ooo`00Y`3o
ool600000>l0oooo1000001P0?ooo`00Z@3oool700000>h0oooo1000001N0?ooo`00[03oool60000
0>d0oooo1000001M0?ooo`00[`3oool600000>`0oooo1000001K0?ooo`00/@3oool700000>X0oooo
1000001J0?ooo`00]03oool700000>T0oooo1000001H0?ooo`00]`3oool600000>P0oooo1@00001F
0?ooo`00^P3oool600000>L0oooo1000001E0?ooo`00_03oool700000>H0oooo1000001C0?ooo`00
_`3oool600000>D0oooo1000001B0?ooo`00`P3oool600000>@0oooo1000001@0?ooo`00a03oool7
00000>80oooo1000001?0?ooo`00a`3oool700000>40oooo1000001=0?ooo`00bP3oool600000>00
oooo1000001<0?ooo`00c@3oool600000=l0oooo1000001:0?ooo`00c`3oool700000=d0oooo1000
00190?ooo`00dP3oool600000=d0oooo100000170?ooo`00e@3oool600000=/0oooo100000160?oo
o`00e`3oool700000=X0oooo100000140?ooo`00fP3oool700000=P0oooo100000130?ooo`00g@3o
ool600000=P0oooo100000110?ooo`00h03oool600000=H0oooo1@00000o0?ooo`00hP3oool70000
0=D0oooo1000000n0?ooo`00i@3oool600000=D0oooo1000000l0?ooo`00j03oool600000=<0oooo
1000000k0?ooo`00jP3oool700000=80oooo1000000i0?ooo`00k@3oool700000=00oooo1000000h
0?ooo`00l03ooooI000003L0oooo003c0?ooomH00000=`3oool00?l0ooooo`3oool20?ooo`00o`3o
oooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`@@3`l?04000001/0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000G0?ooo`H00000o`3`l?110?3`l0@000006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0?3`l3l0l?3`1000000H0?oo
o`030000003oool0oooo00X0oooo0`0000040?ooo`030000003oool00000008000001@3oool30000
0080oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`020?ooo`@00000A@3oool001`0oooo1`00003o0?3`l3h0l?3`1000000F0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1O0?oo
o`007`3oool600000?l0l?3`?@3`l?04000001H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo000R0?ooo`H00000o`3`l?0l0?3`l0@00000
5@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00003o0?3`l3X0l?3`1000
002H0?ooo`009`3oool600000?l0l?3`>P3`l?03000009L0oooo000Z0?ooo`H00000o`3`l?0h0?3`
l0@00000U@3oool002`0oooo1P0000150?3`l0030000003`l?00l?3`00X0l?3`00<000000?3`l03`
l?00h@3`l?04000009@0oooo000_0?ooo`H00000@@3`l?000`000000l?3`0?3`l00<0?3`l0030000
003`l?00l?3`0>80l?3`1000002B0?ooo`00<@3oool7000003d0l?3`00<000000?3`l03`l?003P3`
l?000`000000l?3`0?3`l03R0?3`l0@00000T@3oool003@0oooo1P00000j0?3`l0030000003`l?00
l?3`00@0l?3`1P0000060?3`l0030000003`l?00l?3`0><0l?3`1000002?0?ooo`00=`3oool60000
03H0l?3`0P0000080?3`l0800000203`l?0200000>D0l?3`1000002>0?ooo`00>@3oool6000003@0
l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?00203`l?0500000=P0
l?3`1000002<0?ooo`00?03oool600000300l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`
2@00003G0?3`l0@00000R`3oool003h0oooo1`00000]0?3`l08000002@3`l?02000000T0l?3`0P00
00070?3`l0T00000f@3`l?04000008T0oooo00110?ooo`H00000:`3`l?02000000T0l?3`0P000009
0?3`l08000001P3`l?0;00000=T0l?3`100000280?ooo`00A03oool6000002P0l?3`0P0000090?3`
l08000002@3`l?02000000H0l?3`2`00003K0?3`l0@00000QP3oool004H0oooo1`00000U0?3`l080
00002@3`l?02000000T0l?3`0P0000060?3`l0/00000g03`l?04000008D0oooo00190?ooo`H00000
8`3`l?02000000T0l?3`0P0000090?3`l08000001`3`l?0900000=l0l?3`100000230?ooo`00C03o
ool600000240l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?001P3`
l?0900000>00l?3`100000220?ooo`00CP3oool6000001l0l?3`0P0000080?3`l0800000203`l?02
000000X0l?3`1@00003T0?3`l0@00000P03oool00540oooo1P00000M0?3`l0030000003`l?00l?3`
00H0l?3`0P0000080?3`l0030000003`l?00l?3`0?<0l?3`1000001o0?ooo`00D`3oool7000001/0
l?3`00<000000?3`l03`l?001@3`l?02000000L0l?3`00<000000?3`l03`l?00mP3`l?04000007d0
oooo001F0?ooo`H000006P3`l?000`000000l?3`0?3`l0020?3`l0@000001P3`l?000`000000l?3`
0?3`l03h0?3`l0@00000O03oool005T0oooo1P00000H0?3`l0030000003`l?00l?3`00<0l?3`0P00
00050?3`l0030000003`l?00l?3`0?/0l?3`1000001j0?ooo`00F`3oool700000?l0l?3`8P3`l?04
000007T0oooo001N0?ooo`H00000o`3`l?0R0?3`l0@00000M`3oool00640oooo1P00003o0?3`l200
l?3`1000001f0?ooo`00H`3oool600000?l0l?3`803`l?04000007@0oooo001V0?ooo`H00000o`3`
l?0N0?3`l0@00000L`3oool006P0oooo1`00003o0?3`l1d0l?3`1000001a0?ooo`00J`3oool60000
0?l0l?3`703`l?0400000700oooo001^0?ooo`H00000o`3`l?0K0?3`l0@00000KP3oool00700oooo
1`00003o0?3`l1T0l?3`1000001]0?ooo`00L`3oool6000001P0l?3`0P00003n0?3`l0@00000J`3o
ool007H0oooo1P00000E0?3`l0800000o`3`l?04000006X0oooo001h0?ooo`H000004`3`l?020000
0?l0l?3`0P3`l?04000006P0oooo001k0?ooo`H00000403`l?0200000?l0l?3`0`3`l?04000006L0
oooo001m0?ooo`L000003@3`l?0200000?l0l?3`1@3`l?04000006D0oooo00200?ooo`H000002`3`
l?0200000?l0l?3`1P3`l?04000006@0oooo00230?ooo`H00000203`l?0200000?l0l?3`203`l?04
00000680oooo00250?ooo`L000001@3`l?0200000?l0l?3`2@3`l?0400000640oooo00280?ooo`H0
00000`3`l?0200000?l0l?3`2`3`l?04000005l0oooo002;0?ooo`P00000o`3`l?0<0?3`l0@00000
GP3oool008d0oooo1P00003o0?3`l0h0l?3`1000001L0?ooo`00T03oool600000?l0l?3`303`l?04
000005/0oooo002A0?ooo`P00000o`3`l?0;0?3`l0@00000F@3oool00940oooo0P0000020?ooo`H0
0000o`3`l?0:0?3`l0@00000F03oool00940oooo0P0000050?ooo`H00000o`3`l?090?3`l0@00000
EP3oool00940oooo0P0000070?ooo`H00000o`3`l?080?3`l0@00000E@3oool00940oooo0P00000:
0?ooo`H00000o`3`l?070?3`l0@00000D`3oool00940oooo0P00000<0?ooo`L00000o`3`l?050?3`
l0@00000DP3oool00940oooo0P00000?0?ooo`H00000o`3`l?050?3`l0@00000D03oool00940oooo
0P00000B0?ooo`H00000o`3`l?030?3`l0@00000C`3oool00940oooo0P00000D0?ooo`L00000o`3`
l?020?3`l0@00000C@3oool00940oooo0P00000G0?ooo`H00000o`3`l?010?3`l0@00000C03oool0
0940oooo0P00000J0?ooo`H00000o`3`l?04000004X0oooo002A0?ooo`800000703oool600000?h0
l?3`100000190?ooo`00T@3oool2000001l0oooo1P00003m0?3`l0@00000A`3oool00940oooo0P00
000Q0?ooo`L00000n`3`l?04000004H0oooo002A0?ooo`800000903oool600000?/0l?3`10000014
0?ooo`00T@3oool2000002L0oooo1P00003i0?3`l0@00000@`3oool00940oooo0P00000Y0?ooo`L0
0000n03`l?0300000480oooo002A0?ooo`800000;03oool600000?L0l?3`100000100?ooo`00T@3o
ool2000002l0oooo1P00003e0?3`l0@00000?`3oool00940oooo0P00000a0?ooo`H00000m@3`l?04
000003d0oooo002A0?ooo`800000=03oool600000?<0l?3`1000000l0?ooo`00T@3oool2000003H0
oooo1`00003b0?3`l0@00000>P3oool00940oooo0P00000i0?ooo`H00000l@3`l?04000003T0oooo
002A0?ooo`800000?03oool600000?00l?3`1000000g0?ooo`00T@3oool2000003h0oooo1`00003^
0?3`l0@00000=P3oool00940oooo0P0000110?ooo`H00000kP3`l?04000003@0oooo002A0?ooo`80
0000A03oool600000>`0l?3`1000000c0?ooo`00T@3oool2000004H0oooo1P00003/0?3`l0@00000
<@3oool00940oooo0P0000190?ooo`H00000jP3`l?0400000300oooo002A0?ooo`800000B`3oool7
00000>T0l?3`1000000^0?ooo`00T@3oool2000004h0oooo1P00003X0?3`l0@00000;@3oool00940
oooo0P00001A0?ooo`H00000i`3`l?04000002/0oooo002A0?ooo`800000D`3oool600000>H0l?3`
1000000Z0?ooo`00T@3oool2000005H0oooo1P00003U0?3`l0@00000:03oool00940oooo0P00001H
0?ooo`L00000h`3`l?04000002L0oooo002A0?ooo`800000F`3oool600000><0l?3`1000000U0?oo
o`00T@3oool2000005h0oooo1P00003Q0?3`l0@00000903oool00940oooo0P00001P0?ooo`L00000
h03`l?0400000280oooo002A0?ooo`800000H`3oool600000=l0l?3`1000000Q0?ooo`00T@3oool2
000006H0oooo1P00003N0?3`l0@000007`3oool00940oooo0P00001X0?ooo`H00000g@3`l?040000
01h0oooo002A0?ooo`800000J`3oool600000=`0l?3`1000000L0?ooo`00T@3oool2000006d0oooo
1`00003J0?3`l0@000006`3oool00940oooo0P00001`0?ooon<000006P3oool00940oooo0P00001c
0?ooon0000006P3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo
002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?oo
ofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00
003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940
oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3o
ool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool200000?l0
ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00T@3oool2
00000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^0?ooo`00
T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000o`3ooom^
0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?ooo`800000
o`3ooom^0?ooo`00T@3oool200000?l0ooooKP3oool00940oooo0P00003o0?ooofh0oooo002A0?oo
o`800000S03oool=00000=@0oooo002A0?ooo`800000N@3ooolQ00000=<0oooo002A0?ooo`800000
I@3ooolX000000/0oooo1000003A0?ooo`00T@3oool200000580oooo:000000O0?ooo`@00000d03o
ool00940oooo0P00000n0?ooobP00000=@3oool400000<h0oooo002A0?ooo`800000:`3ooolX0000
04T0oooo1000003=0?ooo`00T@3oool2000001L0oooo:000001O0?ooo`@00000b`3oool00940oooo
0P0000030?ooobT00000L`3oool500000<T0oooo00230?ooobP00000R@3oool400000<P0oooo001_
0?ooobP00000W`3oool400000<H0oooo001L0?ooobP00000203oool=000009h0oooo100000350?oo
o`00B03ooolX000001`0oooo3@00002P0?ooo`@00000``3oool003D0oooo:000000_0?ooo`d00000
X@3oool400000<80oooo000Q0?ooobP00000@`3oool<00000:@0oooo100000300?ooo`003P3ooolX
000005L0oooo2`00002U0?ooo`@00000_`3oool000@0oooo7P00001[0?ooo`/00000Y`3oool40000
0;d0oooo00040?ooo`/00000OP3oool:00000:T0oooo1000002l0?ooo`001P3oool700000840oooo
2@00002[0?ooo`@00000^P3oool000T0oooo1`00001n0?ooo`T00000[03oool400000;T0oooo000<
0?ooo`H00000O03oool800000:l0oooo1000002g0?ooo`003`3oool6000007X0oooo1`00002`0?oo
o`@00000]P3oool00140oooo1`00001g0?ooo`H00000/`3oool400000;@0oooo000D0?ooo`H00000
M@3oool600000;@0oooo1@00002b0?ooo`005`3oool6000007<0oooo1@00002f0?ooo`@00000/@3o
ool001T0oooo1`00001`0?ooo`@00000^@3oool4000002l0oooo1`0000050?ooo`<000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000001@3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`0000040?ooo`<0000000D0oooo0000003oool0
oooo000000050?ooo`@00000>03oool001`0oooo1`00001]0?ooo`@00000^P3oool4000002h0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=@3oool001l0oooo1P00001/0?ooo`<00000_03oool4000002`0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo000R0?oo
o`H00000J@3oool200000;h0oooo1000000[0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0
oooo0000003oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000040?ooo`040000003oool0oooo000000L0oooo0P00000h0?ooo`00
903oool700000?l0oooo:@3oool4000002T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`07000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool3000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`040000003oool0oooo000000D0oooo0P00000j0?ooo`009`3oool60000
0?l0oooo:03oool4000002P0oooo1`0000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0>P3oool002X0oooo
1P0000170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0c`3oool4000002H0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0e0?ooo`00;03oool7000004<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`3?0?ooo`@000009@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`030000003oool0000000800000103oool4000000@0oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo0`0000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool000000?ooo`0200000080oooo1000000h0?ooo`00;`3oool7000003l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3@0?ooo`@000008`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool00380oooo1P00000l
0?ooo`030000003oool0oooo0080oooo200000060?ooo`030000003oool0oooo0=00oooo1000000R
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[
0?ooo`00=@3oool6000003P0oooo0P0000050?ooo`L000001P3oool200000=<0oooo1000000P0?oo
o`L000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05<0oooo000g0?ooo`L0
0000=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3B0?ooo`@00000W`3oool003X0oooo1P00000b0?ooo`800000
203oool00`000000oooo0?ooo`090?ooo`800000e@3oool4000009d0oooo000m0?ooo`H00000;`3o
ool2000000P0oooo0P00000:0?ooo`8000000P3ooolA00000<<0oooo1@00002K0?ooo`00?`3oool7
000002`0oooo0P0000090?ooo`030000003oool0oooo00P0oooo0P0000020?oooa400000a@3oool4
000009X0oooo00120?ooo`L00000:@3oool2000000X0oooo00<000000?ooo`3oool01`3oool20000
0080oooo4@0000370?ooo`@00000V03oool004D0oooo1P00000W0?ooo`8000002P3oool2000000P0
oooo0P0000020?oooa400000b03oool4000009L0oooo00180?ooo`H00000903oool2000000/0oooo
00<000000?ooo`3oool01P3oool200000080oooo4@00003:0?ooo`@00000U@3oool004X0oooo1`00
000R0?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`040000003oool0oooo0?oooa400000
b`3oool4000009@0oooo001=0?ooo`H00000803oool2000000@0oooo00<000000?ooo`3oool00`3o
ool2000000H0oooo0P0000030?oooa400000c@3oool400000980oooo001@0?ooo`H000007P3oool0
0`000000oooo0?ooo`020?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool00P3ooolA
00000<h0oooo1000000T0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`<0000000@0oooo
000000000000oooo0`0000020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`040?ooo`<00000103oool4000000L0oooo0`0000001@3oool000000000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo01P0oooo001B0?ooo`L00000703o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo
0?ooo`030?oooa400000d03oool400000280oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool2000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000`3oool2000001T0oooo001E0?ooo`L000006P3oool010000000oooo0?ooo`3oool6000000D0
oooo00<000000?ooo`3oool0103ooolA000000040?ooo`000?l0003o0000old0oooo1000000Q0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool005P0oooo1P00000I0?ooo`040000
003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`050?oooa40000000<0oooo0000o`00
0?l00P000?o>0?ooo`@000007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool2000000L0oooo0`000000
1@3oool000000?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0G0?ooo`00F`3oool6000002/0oooo4@0000030?ooo`@0003oc@3oool4000001h0oooo00<0
00000?ooo`3oool01@3oool7000000@0oooo0`0000020?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo1`0000020?ooo`8000002`3oool300000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
01L0oooo001M0?ooo`L00000:03ooolA000000@0oooo1@000?o=0?ooo`@00000703oool600000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo
001P0?ooo`H00000?@3oool40000old0oooo1000000K0?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000001T0oooo001S0?ooo`H00000?03oool40000old0oooo1000000I
0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`@000000P3oool4000000030?ooo`000000
oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo0`0000040?ooo`@00000
1`3oool4000000<0oooo00<000000?ooo`0000000P0000050?ooo`<0000000<0oooo0000003oool0
603oool006D0oooo1`00000j0?ooo`D0003oc03oool5000001L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001X0?ooo`L00000>@3oool4
0000old0oooo1000000F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0G0?ooo`00J`3oool6000003T0oooo1@000?o<0?ooo`@00000503oool70000
04`0oooo00<000000?ooo`3oool05`3oool006h0oooo1P00000g0?ooo`P0003ob@3oool400000800
oooo001`0?ooo`L00000=`3oool:0000o`T0oooo0`000?lI0?oooa400000T03oool4000007h0oooo
001c0?ooo`H00000>@3oool:0000o`D0oooo1@000?lG0?oooa400000T@3oool4000007d0oooo001f
0?ooo`H00000>`3oool90000o`030?ooo`000?l0003o00D0003o5@3oool2000000d0oooo0P00002C
0?ooo`@00000N`3oool007P0oooo1`00000l0?oooa00003o4P3oool2000000d0oooo0P00002D0?oo
o`@00000NP3oool007/0oooo1`00000m0?ooo`h0003o403oool2000000d0oooo0P00002F0?ooo`@0
0000N03oool007h0oooo1P00000l0?ooo`l0003o3P3oool2000000d0oooo0P00002G0?ooo`@00000
M`3oool00840oooo1P00000i0?oooa40003o303oool2000000d0oooo0P00002I0?ooo`@00000CP3o
ool2000000D0oooo00<000000?ooo`3oool07@3oool008<0oooo1`00000f0?oooa80003o2`3oool2
000000d0oooo0P00002J0?ooo`@00000C`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01d0oooo00260?ooo`H00000=03ooolB0000o`/0oooo0P00000=0?ooo`800000W03oool40000
04h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00R@3oool600000340oooo3@000?l@0?oo
o`8000003@3oool2000009d0oooo1000000K0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0`0000040?ooo`<00000103oool01P000000oooo0?ooo`3oool0
00000?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000403oool008/0oooo1`00000^
0?ooo`D0003o603oool2000000d0oooo0P00002O0?ooo`@000006@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000020?ooo`8000000`3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000003`3oool008h0oooo1`00000N0?ooo`030000003oool0
oooo02L0oooo4@0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0R03oool5
000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00
T@3oool6000001`0oooo00<000000?ooo`3oool09`3ooolA000000L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`290?ooo`@000005P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B
0?ooo`00U03oool6000001X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo08X0oooo1000000D0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`07000000030?ooo`000000oooo00<0oooo00@000000?oo
o`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3oool009H0oooo
1`00000G0?ooo`040000003oool00000000003/0oooo00@000000?ooo`3oool0oooo1P0000090?oo
o`030000003oool0oooo08X0oooo1000000C0?ooo`L000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`00
00050?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo002I0?ooo`H000005P3oool00`000000oooo0?ooo`02000003P0oooo0P0000030?ooo`80
0000103oool00`000000oooo0?ooo`060?ooo`800000S@3oool400000140oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo008000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`00W03oool6000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00P0oooo0P0000080?ooo`030000003oool0oooo08`0oooo1000000@0?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool000000?ooo`03000000D0oooo0`0000030?oo
o`030000003oool00000008000001@3oool3000000<0oooo100000000`3oool000000?ooo`040?oo
o`80000000@0oooo00000000000000000`3oool00`000000oooo0?ooo`020?ooo`@000003`3oool0
09h0oooo1`00000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool20000
00/0oooo0P0000070?ooo`800000S`3oool4000000h0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo002N0?ooo`X0000000<0oooo0000
000000000P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0c0?ooo`8000002`3oool2000000L0oooo0P00002@0?ooo`@000003@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0:03oool0
09d0oooo0P0000040?ooo`L000000`3oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`8000002`3oool2000000L0oooo0P00002B0?oo
o`@000002`3oool7000000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0E0?oo
o`00W@3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo000000000000100000001@3oool0
00000000003oool0000000@0oooo0P0000020?ooo`030000003oool0oooo03@0oooo0P00000:0?oo
o`<000001`3oool2000009<0oooo1000001P0?ooo`00W@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0000000<0oooo0000003oool0103oool4000003H0oooo0P0000090?ooo`<0
0000203oool2000009D0oooo1000001N0?ooo`00Y@3oool00`000000oooo0?ooo`0:000003l0oooo
0P0000060?ooo`H00000203oool2000009H0oooo1000001M0?ooo`00X`3oool2000000<0oooo00<0
00000?ooo`3oool0103oool6000003d0oooo00<000000?ooo`3oool01P3oool2000000X0oooo00<0
00000?ooo`3oool0U`3oool4000005/0oooo002O0?ooo`D000001@3oool00`000000oooo0?ooo`03
0?ooo`T00000>P3oool2000000T0oooo00<000000?ooo`3oool01P3oool2000009X0oooo1000001J
0?ooo`00WP3oool2000000X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000
oooo00L00000>03oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?ooo`2K
0?ooo`@00000F03oool009h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`@000000`3oool00`000000oooo0?ooo`020?ooo`H00000=`3oool010000000oooo0?ooo`000005
0?ooo`8000001P3oool00`000000oooo0?ooo`2M0?ooo`D00000EP3oool009h0oooo0P0000060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool6000003D0oooo00@000000?oo
o`3oool000000`3oool3000000D0oooo00<000000?ooo`3oool0X03oool4000005D0oooo002O0?oo
o`800000103oool2000000`0oooo00<000000?ooo`3oool01P3oool7000003<0oooo00<000000?oo
o`3oool01@0000050?ooo`030000003oool0oooo0:<0oooo1000001C0?ooo`00X@3oool5000000d0
oooo00<000000?ooo`3oool02@3oool600000>D0oooo1000001B0?ooo`00`P3oool600000>@0oooo
1000001@0?ooo`00a03oool700000>80oooo1000001?0?ooo`00a`3oool700000>40oooo1000001=
0?ooo`00bP3oool600000>00oooo1000001<0?ooo`00c@3oool600000=l0oooo1000001:0?ooo`00
c`3oool700000=d0oooo100000190?ooo`00dP3oool600000=d0oooo100000170?ooo`00e@3oool6
00000=/0oooo100000160?ooo`00e`3oool700000=X0oooo100000140?ooo`00fP3oool700000=P0
oooo100000130?ooo`00g@3oool600000=P0oooo100000110?ooo`00h03oool600000=H0oooo1@00
000o0?ooo`00hP3oool700000=D0oooo1000000n0?ooo`00i@3oool600000=D0oooo1000000l0?oo
o`00j03oool600000=<0oooo1000000k0?ooo`00jP3oool700000=80oooo1000000i0?ooo`00k@3o
ool700000=00oooo1000000h0?ooo`00l03ooooI000003L0oooo003c0?ooomH00000=`3oool00?l0
ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool2
0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`@@3`l?04000001/0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000G0?ooo`H00000o`3`l?110?3`l0@000006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0?3`l3l0l?3`1000000H0?oo
o`030000003oool0oooo00X0oooo0`0000040?ooo`030000003oool00000008000001@3oool30000
0080oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`020?ooo`@00000A@3oool001`0oooo1`00003o0?3`l3h0l?3`1000000F0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1O0?oo
o`007`3oool600000?l0l?3`?@3`l?04000001H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo000R0?ooo`H00000o`3`l?0l0?3`l0@00000
5@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00003o0?3`l3X0l?3`1000
002H0?ooo`009`3oool600000?l0l?3`>P3`l?03000009L0oooo000Z0?ooo`H00000o`3`l?0h0?3`
l0@00000U@3oool002`0oooo1P0000150?3`l0030000003`l?00l?3`00X0l?3`00<000000?3`l03`
l?00h@3`l?04000009@0oooo000_0?ooo`H00000@@3`l?000`000000l?3`0?3`l00<0?3`l0030000
003`l?00l?3`0>80l?3`1000002B0?ooo`00<@3oool7000003d0l?3`00<000000?3`l03`l?003P3`
l?000`000000l?3`0?3`l03R0?3`l0@00000T@3oool003@0oooo1P00000j0?3`l0030000003`l?00
l?3`00@0l?3`1P0000060?3`l0030000003`l?00l?3`0><0l?3`1000002?0?ooo`00=`3oool60000
03H0l?3`0P0000080?3`l0800000203`l?0200000>D0l?3`1000002>0?ooo`00>@3oool6000003@0
l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?00i@3`l?04000008`0
oooo000l0?ooo`H00000<03`l?02000000T0l?3`0P0000090?3`l0800000i`3`l?04000008/0oooo
000n0?ooo`L00000;@3`l?02000000T0l?3`0P0000090?3`l08000002@3`l?0500000=/0l?3`1000
00290?ooo`00@@3oool6000002/0l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`2@00003J
0?3`l0@00000R03oool004@0oooo1P00000X0?3`l08000002@3`l?02000000T0l?3`0P0000060?3`
l0/00000f`3`l?04000008H0oooo00160?ooo`L000009@3`l?02000000T0l?3`0P0000090?3`l080
00001P3`l?0;00000=`0l?3`100000250?ooo`00B@3oool6000002<0l?3`0P0000090?3`l0800000
2@3`l?02000000H0l?3`2`00003N0?3`l0@00000P`3oool004`0oooo1P00000Q0?3`l0030000003`
l?00l?3`00L0l?3`0P0000090?3`l0030000003`l?00l?3`00H0l?3`2@00003P0?3`l0@00000PP3o
ool004h0oooo1P00000O0?3`l0800000203`l?02000000P0l?3`0P00000:0?3`l0D00000i03`l?04
00000800oooo001A0?ooo`H000007@3`l?000`000000l?3`0?3`l0060?3`l0800000203`l?000`00
0000l?3`0?3`l03c0?3`l0@00000O`3oool005<0oooo1`00000K0?3`l0030000003`l?00l?3`00D0
l?3`0P0000070?3`l0030000003`l?00l?3`0?H0l?3`1000001m0?ooo`00EP3oool6000001X0l?3`
00<000000?3`l03`l?000P3`l?04000000H0l?3`00<000000?3`l03`l?00n03`l?04000007`0oooo
001I0?ooo`H00000603`l?000`000000l?3`0?3`l0030?3`l08000001@3`l?000`000000l?3`0?3`
l03k0?3`l0@00000NP3oool005/0oooo1`00003o0?3`l280l?3`1000001i0?ooo`00GP3oool60000
0?l0l?3`8P3`l?04000007L0oooo001Q0?ooo`H00000o`3`l?0P0?3`l0@00000MP3oool006<0oooo
1P00003o0?3`l200l?3`1000001d0?ooo`00IP3oool600000?l0l?3`7P3`l?04000007<0oooo001X
0?ooo`L00000o`3`l?0M0?3`l0@00000L@3oool006/0oooo1P00003o0?3`l1`0l?3`1000001`0?oo
o`00KP3oool600000?l0l?3`6`3`l?04000006h0oooo001`0?ooo`L00000o`3`l?0I0?3`l0@00000
K@3oool007<0oooo1P00001^0?3`l0D00000Y@3`l?04000006/0oooo001f0?ooo`H00000J@3`l?09
00000:@0l?3`1000001Z0?ooo`00N03oool6000001<0l?3`0P00000i0?3`l0030000003`l?00l?3`
00X0l?3`00<000000?3`l03`l?002@3`l?02000000D0oooo0P00002V0?3`l0@00000J03oool007/0
oooo1P00000@0?3`l0800000>03`l?000`000000l?3`0?3`l00<0?3`l0030000003`l?00l?3`00L0
l?3`0P0000070?ooo`800000YP3`l?04000006L0oooo001m0?ooo`L000003@3`l?02000003L0l?3`
00<000000?3`l03`l?003P3`l?000`000000l?3`0?3`l0060?3`l08000001`3oool200000:P0l?3`
1000001U0?ooo`00P03oool6000000/0l?3`0P00000f0?3`l0030000003`l?00l?3`00P0l?3`0P00
00060?3`l0030000003`l?00l?3`00D0l?3`0P0000070?ooo`800000Z@3`l?04000006@0oooo0023
0?ooo`H00000203`l?02000003D0l?3`0P00000:0?3`l08000001P3`l?02000000L0l?3`0P000005
0?ooo`800000[03`l?0400000680oooo00250?ooo`L000001@3`l?02000003D0l?3`00<000000?3`
l03`l?002@3`l?02000000L0l?3`00<000000?3`l03`l?001@3`l?0900000:d0l?3`1000001Q0?oo
o`00R03oool6000000<0l?3`0P00000d0?3`l08000002`3`l?02000000L0l?3`0P0000080?3`l0D0
0000/@3`l?04000005l0oooo002;0?ooo`P00000=03`l?02000000@0l?3`2`0000050?3`l0800000
_`3`l?04000005h0oooo002=0?ooo`H00000=03`l?02000000@0l?3`00<000000?3`l03`l?00103`
l?02000000L0l?3`0P0000310?3`l0@00000G03oool00900oooo1P00000a0?3`l08000001@3`l?00
0`000000l?3`0?3`l0030?3`l08000001`3`l?0200000<80l?3`1000001K0?ooo`00T@3oool80000
02h0l?3`0P0000060?3`l0030000003`l?00l?3`0080l?3`0P0000070?3`l0800000a03`l?040000
05T0oooo002A0?ooo`8000000P3oool6000002`0l?3`0P0000070?3`l0040000003`l?00l?3`0?3`
l08000001`3`l?0200000<D0l?3`1000001H0?ooo`00T@3oool2000000D0oooo1P00000Z0?3`l003
0000003`l?00l?3`00H0l?3`00<000000?3`l03`l?000P0000070?3`l0030000003`l?00l?3`0<H0
l?3`1000001F0?ooo`00T@3oool2000000L0oooo1P00000X0?3`l08000001`3`l?000`000000l?3`
0?3`l002000000H0l?3`0P0000390?3`l0@00000E@3oool00940oooo0P00000:0?ooo`H000009P3`
l?000`000000l?3`0?3`l0060?3`l0040000003`l?000000000000H0l?3`00<000000?3`l03`l?00
bP3`l?04000005<0oooo002A0?ooo`800000303oool7000002@0l?3`00<000000?3`l03`l?001P3`
l?03000000D0l?3`00<000000?3`l03`l?00c03`l?0400000580oooo002A0?ooo`8000003`3oool6
000002<0l?3`00<000000?3`l03`l?001P3`l?02000000@0l?3`00<000000?3`l03`l?00c`3`l?04
00000500oooo002A0?ooo`8000004P3oool600000240l?3`00<000000?3`l03`l?001@3`l?020000
00<0l?3`00<000000?3`l03`l?00d@3`l?04000004l0oooo002A0?ooo`800000503oool700000?l0
l?3`0P3`l?04000004d0oooo002A0?ooo`8000005`3oool600000?l0l?3`0@3`l?04000004`0oooo
002A0?ooo`8000006P3oool600000?l0l?3`1000001:0?ooo`00T@3oool2000001`0oooo1P00003n
0?3`l0@00000B@3oool00940oooo0P00000O0?ooo`H00000;P3`l?020000old0l?3`100000170?oo
o`00T@3oool200000240oooo1`00000[0?3`l080003ocP3`l?04000004H0oooo002A0?ooo`800000
903oool6000002T0l?3`0P000?o@0?3`l0@00000A03oool00940oooo0P00000W0?ooo`H000009@3`
l?040000om00l?3`100000130?ooo`00T@3oool2000002T0oooo1`00000R0?3`l0@0003odP3`l?03
00000480oooo002A0?ooo`800000;03oool600000200l?3`10000?oC0?3`l0@00000@03oool00940
oooo0P00000_0?ooo`H00000703`l?050000om@0l?3`1000000o0?ooo`00T@3oool200000340oooo
1P00000J0?3`l0H0003oe@3`l?04000003d0oooo002A0?ooo`800000=03oool6000001L0l?3`1P00
0?oF0?3`l0@00000?03oool00940oooo0P00000f0?ooo`L000004`3`l?070000omP0l?3`1000000j
0?ooo`00T@3oool2000003T0oooo1P00000A0?3`l0L0003of@3`l?04000003T0oooo002A0?ooo`80
0000?03oool6000000h0l?3`1`000?oK0?3`l0@00000=`3oool00940oooo0P00000n0?ooo`L00000
2`3`l?080000om/0l?3`1000000f0?ooo`00T@3oool200000440oooo1P0000080?3`l0T0003og@3`
l?04000003@0oooo002A0?ooo`800000A03oool6000000D0l?3`2@000?oN0?3`l0@00000<`3oool0
0940oooo0P0000160?ooo`H000000`3`l?090000on00l?3`1000000a0?ooo`00T@3oool2000004T0
oooo1@00000;0000on00l?3`1000000`0?ooo`00T@3oool2000004/0oooo0`00000;0000on80l?3`
1000000^0?ooo`00T@3oool2000004h0oooo2`000?oS0?3`l0@00000;@3oool00940oooo0P00001A
0?ooo`8000000P000?l200000>L0l?3`1000000[0?ooo`00T@3oool2000005<0oooo0P000?l40000
0>H0l?3`1000000Z0?ooo`00T@3oool2000005<0oooo0P000?l00`3oool000000000000400000>D0
l?3`1000000X0?ooo`00T@3oool2000005<0oooo0P000?l30?ooo`L00000h`3`l?04000002L0oooo
002A0?ooo`800000D`3oool20000o`H0oooo1P00003S0?3`l0@000009@3oool00940oooo0P00001C
0?ooo`80003o2@3oool600000>40l?3`1000000T0?ooo`00T@3oool2000005<0oooo0P000?l;0?oo
o`L00000h03`l?0400000280oooo002A0?ooo`800000D`3oool20000o`h0oooo1P00003O0?3`l0@0
00008@3oool00940oooo0P00001C0?ooo`80003o4@3oool600000=h0l?3`1000000O0?ooo`00T@3o
ool2000005<0oooo0P000?lC0?ooo`H00000g@3`l?04000001h0oooo002A0?ooo`800000D`3oool2
0000oaH0oooo1P00003L0?3`l0@00000703oool00940oooo0P00001C0?ooo`80003o603oool70000
0=X0l?3`1000000K0?ooo`00T@3oool2000005<0oooo0P000?lK0?ooon<000006P3oool00940oooo
0P00001C0?ooo`80003o7P3ooooP000001X0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003o=`3oool=00000=@0oooo002A0?ooo`800000D`3oool20000ob@0oooo8@00003C
0?ooo`00T@3oool2000005<0oooo0P000?l@0?ooobP000002`3oool400000=40oooo002A0?ooo`80
0000DP3ooolX000001l0oooo1000003@0?ooo`00T@3oool2000003h0oooo:000000e0?ooo`@00000
cP3oool00940oooo0P00000[0?ooobP000000P000?m70?ooo`@00000c@3oool00940oooo0P00000G
0?ooobP00000503oool20000odT0oooo1000003;0?ooo`00T@3oool2000000<0oooo:@00000W0?oo
o`80003oBP3oool500000<T0oooo00230?ooobP00000>`3oool20000od`0oooo100000380?ooo`00
K`3ooolX000004l0oooo0P000?m>0?ooo`@00000aP3oool005`0oooo:00000080?ooo`d00000C@3o
ool20000odl0oooo100000350?ooo`00B03ooolX000001`0oooo3@00001=0?ooo`80003oD@3oool4
00000<<0oooo000e0?ooobP00000;`3oool=000004d0oooo0P000?mB0?ooo`@00000`P3oool00240
oooo:00000130?ooo``00000CP3oool20000oe@0oooo100000300?ooo`003P3ooolX000005L0oooo
2`00001>0?ooo`80003oE@3oool400000;l0oooo00040?oooah00000J`3oool;000004h0oooo0P00
0?mG0?ooo`@00000_@3oool000@0oooo2`00001n0?ooo`X00000C`3oool20000oeP0oooo1000002l
0?ooo`001P3oool700000840oooo2@00001?0?ooo`80003oFP3oool400000;X0oooo00090?ooo`L0
0000OP3oool9000004l0oooo0P000?mK0?ooo`@00000^@3oool000`0oooo1P00001l0?ooo`P00000
D03oool20000oed0oooo1000002g0?ooo`003`3oool6000007X0oooo1`00001@0?ooo`80003oGP3o
ool400000;H0oooo000A0?ooo`L00000M`3oool600000540oooo0P000?mP0?ooo`@00000]03oool0
01@0oooo1P00001e0?ooo`H00000D@3oool20000of40oooo1@00002b0?ooo`005`3oool6000007<0
oooo1@00001A0?ooo`80003oH`3oool400000;40oooo000I0?ooo`L00000L03oool400000580oooo
0P000?mU0?ooo`@00000[`3oool001`0oooo1`00001]0?ooo`@00000DP3oool20000ofH0oooo1000
002^0?ooo`007`3oool6000006`0oooo0`00001B0?ooo`80003oJ03oool4000002`0oooo1`000005
0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0
oooo0000000000001@3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000040?ooo`<00000
00D0oooo0000003oool0oooo000000050?ooo`@00000>03oool00280oooo1P00001Y0?ooo`800000
D`3oool20000ofT0oooo1000000[0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool2
000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo000T0?ooo`L00000^`3o
ool20000of/0oooo1000000Y0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0e0?ooo`009`3oool600000;T0oooo0P000?m/0?ooo`@00000:03oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000070?ooo`800000>03oool002X0oooo1P00002f0?ooo`80003oKP3oool4000002H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00`3oool3000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`040000003oool0oooo
000000D0oooo0P00000j0?ooo`00;03oool700000;<0oooo0P000?m_0?ooo`@000009@3oool70000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0j0?ooo`00;`3oool700000440oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1O0?ooo`80003oL@3oool4000002<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P0000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0e0?ooo`00<P3oool6000003h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1N0?ooo`80003oLP3oool400000280oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`<000000`3oool00`000000oooo00000002000000@0oooo100000040?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`@00000>03oool003D0oooo1P00000j0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0G@3oool20000og@0oooo1000000P0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`00=`3oool7
000003H0oooo00<000000?ooo`3oool00P3oool8000000H0oooo00<000000?ooo`3oool0G03oool2
0000ogD0oooo1000000O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1[0?ooo`00>P3oool6000003<0oooo0P0000050?ooo`L000001P3oool20000
05d0oooo0P000?mg0?ooo`@000007@3oool7000000/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1C0?ooo`00?@3oool600000300oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo4@0000190?oo
o`80003oN03oool5000009/0oooo000o0?ooo`L00000;03oool2000000P0oooo00<000000?ooo`3o
ool02@3oool200000080oooo4@0000190?ooo`80003oNP3oool4000009X0oooo00120?ooo`L00000
:@3oool2000000P0oooo0P00000:0?ooo`8000000P3ooolA000004T0oooo0P000?ml0?ooo`@00000
V03oool004D0oooo1P00000W0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000P3o
oolA000004T0oooo0P000?mm0?ooo`@00000U`3oool004P0oooo1P00000T0?ooo`8000002P3oool0
0`000000oooo0?ooo`070?ooo`8000000P3ooolA000004T0oooo0P000?mo0?ooo`@00000U@3oool0
04X0oooo1`00000Q0?ooo`8000002P3oool2000000P0oooo0P0000020?oooa400000B@3oool20000
oh00oooo1000002D0?ooo`00C@3oool6000001l0oooo0P00000;0?ooo`030000003oool0oooo00H0
oooo0P0000020?oooa400000B@3oool20000oh80oooo1000002B0?ooo`00D03oool6000001d0oooo
00<000000?ooo`3oool02@3oool2000000L0oooo00@000000?ooo`3oool0oooo4@0000190?ooo`80
003oP`3oool4000002@0oooo00<000000?ooo`3oool01`3oool3000000@0oooo0`000000103oool0
00000000003oool300000080oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo
00@0oooo0`0000040?ooo`@000001`3oool3000000050?ooo`00000000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool0603oool00580oooo1`00000J0?oo
o`800000103oool00`000000oooo0?ooo`030?ooo`8000001P3oool2000000<0oooo4@0000190?oo
o`80003oQ@3oool400000280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool2000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2
000001T0oooo001E0?ooo`L00000603oool00`000000oooo0?ooo`020?ooo`800000103oool20000
00H0oooo00<000000?ooo`3oool00P3ooolA000000040?ooo`000?l0003o0000odD0oooo0P000?n6
0?ooo`@000008@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo001H0?ooo`H0
00005`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001@3oool00`00
0000oooo0?ooo`030?oooa40000000<0oooo0000o`000?l00P000?m40?ooo`80003oR03oool40000
01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`<0000000D0oooo0000
003oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`<0000000D0oooo0000003oool0oooo
000000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool005/0oooo
1P00000E0?ooo`040000003oool0oooo0?ooo`H000001@3oool00`000000oooo0?ooo`040?oooa40
00000`3oool40000od80oooo0P000?n90?ooo`@000007P3oool00`000000oooo0?ooo`050?ooo`L0
0000103oool300000080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool700000080oooo0P00000;0?ooo`<000000P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool005d0oooo1`00000C
0?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`050?oooa400000103o
ool50000od00oooo0P000?n;0?ooo`@00000703oool600000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo001P0?ooo`H00000?@3oool40000
old0oooo1000000K0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`800000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
01T0oooo001S0?ooo`H00000?03oool40000old0oooo1000000I0?ooo`030000003oool0oooo00L0
oooo0`0000040?ooo`@000000P3oool4000000030?ooo`000000oooo00<0oooo00H000000?ooo`3o
ool0oooo0000003oool2000000<0oooo0`0000040?ooo`@000001`3oool4000000<0oooo00<00000
0?ooo`0000000P0000050?ooo`<0000000<0oooo0000003oool0603oool006D0oooo1`00000j0?oo
o`D0003oc03oool5000001L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo01L0oooo001X0?ooo`L00000>@3oool40000old0oooo1000000F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0G0?ooo`00
J`3oool6000003T0oooo1@000?o<0?ooo`@00000503oool7000004`0oooo00<000000?ooo`3oool0
5`3oool006h0oooo1P00000g0?ooo`L0003obP3oool400000800oooo001`0?ooo`L00000=`3oool7
0000o``0oooo0`000?lI0?oooa400000T03oool4000007h0oooo001c0?ooo`H00000>03oool70000
o`T0oooo1@000?lG0?oooa400000T@3oool4000007d0oooo001f0?ooo`H00000>03oool70000o`H0
oooo1`000?lE0?ooo`8000003@3oool2000009<0oooo1000001k0?ooo`00N03oool7000003P0oooo
1`000?l20?ooo`/0003o4P3oool2000000d0oooo0P00002D0?ooo`@00000NP3oool007/0oooo1`00
000h0?oooa<0003o403oool2000000d0oooo0P00002F0?ooo`@00000N03oool007h0oooo1P00000i
0?oooa80003o3P3oool2000000d0oooo0P00002G0?ooo`@00000M`3oool00840oooo1P00000i0?oo
oa40003o303oool2000000d0oooo0P00002I0?ooo`@00000CP3oool2000000D0oooo00<000000?oo
o`3oool07@3oool008<0oooo1`00000f0?oooa80003o2`3oool2000000d0oooo0P00002J0?ooo`@0
0000C`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00260?ooo`H00000
=03ooolB0000o`/0oooo0P00000=0?ooo`800000W03oool4000004h0oooo00D000000?ooo`3oool0
oooo0000000O0?ooo`00R@3oool600000340oooo3@000?l@0?ooo`8000003@3oool2000009d0oooo
1000000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000040?ooo`<00000103oool01P000000oooo0?ooo`3oool000000?ooo`<000000`3oool00`00
0000oooo0?ooo`020?ooo`<00000403oool008/0oooo1`00000^0?ooo`D0003o603oool2000000d0
oooo0P00002O0?ooo`@000006@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
000000020?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000003`3oool008h0oooo1`00000N0?ooo`030000003oool0oooo02L0oooo4@0000080?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0R03oool5000001L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00T@3oool6000001`0oooo00<00000
0?ooo`3oool09`3ooolA000000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`29
0?ooo`@000005P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`00U03oool6000001X0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08X0oooo
1000000D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`07000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000001@3oool010000000
oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool04P3oool009H0oooo1`00000G0?ooo`040000003oool0
0000000003/0oooo00@000000?ooo`3oool0oooo1P0000090?ooo`030000003oool0oooo08X0oooo
1000000C0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo002I0?ooo`H000005P3o
ool00`000000oooo0?ooo`02000003P0oooo0P0000030?ooo`800000103oool00`000000oooo0?oo
o`060?ooo`800000S@3oool400000140oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00800000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`060000003oool0oooo0?ooo`000000oooo0P0000030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00W03oool6000001<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00P0oooo0P00
00080?ooo`030000003oool0oooo08`0oooo1000000@0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool000000?ooo`03000000D0oooo0`0000030?ooo`030000003oool0000000800000
1@3oool3000000<0oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`020?ooo`@000003`3oool009h0oooo1`00000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0=03oool2000000/0oooo0P0000070?ooo`800000
S`3oool4000000h0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000P0?ooo`03
0000003oool0oooo02P0oooo002Q0?ooo`L000003P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03<0oooo0P00000;0?ooo`8000001`3oool200000900oooo1000000=0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`0X0?ooo`00
Y03oool6000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`800000
2`3oool2000000L0oooo0P00002B0?ooo`@000002`3oool7000000<0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0E0?ooo`00WP3oool5000000@0oooo1P0000030?ooo`030000003o
ool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo03@0oooo0P00000:0?ooo`<000001`3o
ool2000009<0oooo1000001P0?ooo`00W@3oool2000000@0oooo0P0000030?ooo`T000001P3oool4
000003H0oooo0P0000090?ooo`<00000203oool2000009D0oooo1000001N0?ooo`00W@3oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool010000000oooo0?ooo`3oool6000003l0oooo0P000006
0?ooo`H00000203oool2000009H0oooo1000001M0?ooo`00W@3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000H0oooo1P00000m0?ooo`030000003oool0oooo00H0oooo0P00000:
0?ooo`030000003oool0oooo09L0oooo1000001K0?ooo`00Y@3oool00`000000oooo0?ooo`080000
00030?ooo`000000000000D00000>P3oool2000000T0oooo00<000000?ooo`3oool01P3oool20000
09X0oooo1000001J0?ooo`00X`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000020?ooo`L00000>03oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`000000
oooo0?ooo`2K0?ooo`@00000F03oool009l0oooo1@0000050?ooo`030000003oool0oooo00<0oooo
0P0000000`3oool000000?ooo`030?ooo`H00000=`3oool010000000oooo0?ooo`0000050?ooo`80
00001P3oool00`000000oooo0?ooo`2M0?ooo`D00000EP3oool009h0oooo0P00000:0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool6000003D0oooo00@000000?ooo`3o
ool000000`3oool3000000D0oooo00<000000?ooo`3oool0X03oool4000005D0oooo002N0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<000000?ooo`3o
ool01`3oool7000003<0oooo00<000000?ooo`3oool01@0000050?ooo`030000003oool0oooo0:<0
oooo1000001C0?ooo`00WP3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`H00000i@3oool400000580oooo002O0?ooo`800000103oool2000000`0oooo00<0
00000?ooo`3oool0303oool600000>@0oooo1000001@0?ooo`00X@3oool5000000d0oooo00<00000
0?ooo`3oool03P3oool700000>80oooo1000001?0?ooo`00a`3oool700000>40oooo1000001=0?oo
o`00bP3oool600000>00oooo1000001<0?ooo`00c@3oool600000=l0oooo1000001:0?ooo`00c`3o
ool700000=d0oooo100000190?ooo`00dP3oool600000=d0oooo100000170?ooo`00e@3oool60000
0=/0oooo100000160?ooo`00e`3oool700000=X0oooo100000140?ooo`00fP3oool700000=P0oooo
100000130?ooo`00g@3oool600000=P0oooo100000110?ooo`00h03oool600000=H0oooo1@00000o
0?ooo`00hP3oool700000=D0oooo1000000n0?ooo`00i@3oool600000=D0oooo1000000l0?ooo`00
j03oool600000=<0oooo1000000k0?ooo`00jP3oool700000=80oooo1000000i0?ooo`00k@3oool7
00000=00oooo1000000h0?ooo`00l03ooooI000003L0oooo003c0?ooomH00000=`3oool00?l0oooo
o`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?oo
o`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`@@3`l?04000001/0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000G0?ooo`H00000o`3`l?110?3`l0@000006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0?3`l1d0l?3`00<000000?3`
l03`l?002P3`l?000`000000l?3`0?3`l00B0?3`l0@00000603oool00`000000oooo0?ooo`0:0?oo
o`<00000103oool00`000000oooo00000002000000D0oooo0`0000020?ooo`@0000000<0oooo0000
003oool0103oool2000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00P3oool4
000004D0oooo000L0?ooo`L00000o`3`l?0I0?3`l0030000003`l?00l?3`00`0l?3`00<000000?3`
l03`l?004`3`l?04000001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05l0oooo000O0?ooo`H00000o`3`l?0F0?3`l0030000003`l?00l?3`00h0
l?3`00<000000?3`l03`l?004`3`l?04000001H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo000R0?ooo`H00000o`3`l?0B0?3`l0030000
003`l?00l?3`0080l?3`1P0000080?3`l0030000003`l?00l?3`01@0l?3`1000000E0?ooo`H00000
<03oool00`000000oooo0?ooo`1;0?ooo`00903oool700000?l0l?3`3P3`l?02000000@0l?3`0`00
00030?3`l0030000003`l?00l?3`00D0l?3`0P00000F0?3`l0@00000V03oool002L0oooo1P00003o
0?3`l0`0l?3`00<000000?3`l03`l?002@3`l?02000000L0l?3`00<000000?3`l03`l?005P3`l?03
000009L0oooo000Z0?ooo`H00000o`3`l?080?3`l0800000303`l?02000000H0l?3`0P00000H0?3`
l0@00000U@3oool002`0oooo1P00003o0?3`l0H0l?3`0P00000<0?3`l08000001P3`l?02000001T0
l?3`1000002D0?ooo`00;`3oool600000?l0l?3`0`3`l?02000000`0l?3`0P0000060?3`l0800000
6`3`l?0400000980oooo000a0?ooo`L00000?`3`l?000`000000l?3`0?3`l00:0?3`l0030000003`
l?00l?3`0;00l?3`0P00000;0?3`l0<000001P3`l?02000001`0l?3`1000002A0?ooo`00=03oool6
000003`0l?3`00<000000?3`l03`l?00303`l?000`000000l?3`0?3`l02_0?3`l08000002`3`l?03
000000H0l?3`0P00000N0?3`l0@00000S`3oool003L0oooo1P00000h0?3`l0030000003`l?00l?3`
00h0l?3`00<000000?3`l03`l?00[P3`l?02000000T0l?3`100000070?3`l08000007`3`l?040000
08h0oooo000i0?ooo`H00000=@3`l?000`000000l?3`0?3`l0040?3`l0H000001P3`l?000`000000
l?3`0?3`l02^0?3`l0030000003`l?00l?3`00@0l?3`1P0000080?3`l0030000003`l?00l?3`0200
l?3`1000002<0?ooo`00?03oool600000340l?3`0P0000080?3`l0800000203`l?0200000:l0l?3`
0P0000050?3`l0@000002@3`l?02000002<0l?3`1000002;0?ooo`00?P3oool7000002h0l?3`00<0
00000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?00203`l?0500000:40l?3`00<0
00000?3`l03`l?000`3`l?02000000/0l?3`00<000000?3`l03`l?00903`l?04000008T0oooo0011
0?ooo`H00000:`3`l?02000000T0l?3`0P0000090?3`l08000001`3`l?0900000:00l?3`00<00000
0?3`l03`l?000`3`l?000`000000l?3`0?3`l0080?3`l0030000003`l?00l?3`02H0l?3`10000028
0?ooo`00A03oool6000002P0l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`2@00002Q0?3`
l0030000003`l?00l?3`0080l?3`1P0000040?3`l0030000003`l?00l?3`02T0l?3`100000260?oo
o`00AP3oool7000002D0l?3`0P0000090?3`l08000002@3`l?02000000H0l?3`2`00002Q0?3`l003
0000003`l?00l?3`0080l?3`1P0000020?3`l0030000003`l?00l?3`02/0l?3`100000250?ooo`00
B@3oool6000002<0l?3`0P0000090?3`l08000002@3`l?02000000H0l?3`2`00002L0?3`l0D00000
?@3`l?04000008<0oooo001<0?ooo`H00000803`l?02000000T0l?3`0P0000090?3`l08000001P3`
l?0;000009X0l?3`2@00000l0?3`l0@00000PP3oool004h0oooo1P00000N0?3`l08000002@3`l?02
000000T0l?3`0P0000070?3`l0T00000V`3`l?09000003h0l?3`100000200?ooo`00D@3oool60000
01`0l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?001P3`l?090000
09X0l?3`2`00000n0?3`l0@00000O`3oool005<0oooo1`00000I0?3`l0800000203`l?02000000P0
l?3`0P00000:0?3`l0D00000W03`l?0;00000400l?3`1000001m0?ooo`00EP3oool6000001P0l?3`
00<000000?3`l03`l?001P3`l?02000000P0l?3`00<000000?3`l03`l?00ZP3`l?0;00000440l?3`
1000001l0?ooo`00F@3oool6000001H0l?3`00<000000?3`l03`l?001@3`l?02000000L0l?3`00<0
00000?3`l03`l?00[03`l?09000004@0l?3`1000001j0?ooo`00F`3oool7000001@0l?3`00<00000
0?3`l03`l?000P3`l?04000000H0l?3`00<000000?3`l03`l?00XP3`l?060000o`D0l?3`2@000015
0?3`l0@00000N@3oool005h0oooo1P00000C0?3`l0030000003`l?00l?3`00<0l?3`0P0000050?3`
l0030000003`l?00l?3`09X0l?3`3`000?l70?3`l0D00000B@3`l?04000007L0oooo001Q0?ooo`H0
0000]@3`l?0B0000oeP0l?3`1000001f0?ooo`00H`3oool600000;<0l?3`4@000?mK0?3`l0@00000
M03oool006H0oooo1P00002`0?3`l100003oG@3`l?04000007<0oooo001X0?ooo`L00000[P3`l?0>
0000of00l?3`1000001a0?ooo`00J`3oool600000:d0l?3`30000?mR0?3`l0@00000L03oool006h0
oooo1P00002W0?3`l0d0003oIP3`l?04000006h0oooo001`0?ooo`L00000X@3`l?0?0000ofP0l?3`
1000001]0?ooo`00L`3oool6000009`0l?3`1`000?l30?3`l0L0003oJ`3`l?04000006/0oooo001f
0?ooo`H00000U@3`l?080000o`L0l?3`1@000?m]0?3`l0@00000JP3oool007P0oooo1P00000C0?3`
l0800000>@3`l?000`000000l?3`0?3`l00:0?3`l0030000003`l?00l?3`00/0l?3`1@00000R0?3`
l0P0003o2P3`l?040000og00l?3`1000001X0?ooo`00N`3oool600000100l?3`0P00000h0?3`l003
0000003`l?00l?3`00`0l?3`00<000000?3`l03`l?00203`l?09000001d0l?3`1`000?l?0?3`l080
003oLP3`l?04000006L0oooo001m0?ooo`L000003@3`l?02000003L0l?3`00<000000?3`l03`l?00
3P3`l?000`000000l?3`0?3`l0060?3`l0<000001@3oool3000001H0l?3`2P000?n80?3`l0@00000
I@3oool00800oooo1P00000;0?3`l0800000=P3`l?000`000000l?3`0?3`l0080?3`l08000001P3`
l?000`000000l?3`0?3`l0050?3`l08000001`3oool2000000h0l?3`3`000?n<0?3`l0@00000I03o
ool008<0oooo1P0000080?3`l0800000=@3`l?02000000X0l?3`0P0000060?3`l08000001P3`l?03
000000D0oooo0`0000060?3`l140003oU03`l?0400000680oooo00250?ooo`L000001@3`l?020000
03D0l?3`00<000000?3`l03`l?002@3`l?02000000L0l?3`00<000000?3`l03`l?001@3`l?090000
00<0l?3`3@000?nM0?3`l0@00000H@3oool008P0oooo1P0000030?3`l0800000=03`l?02000000/0
l?3`0P0000070?3`l0800000203`l?05000000D0l?3`1@000?nW0?3`l0@00000G`3oool008/0oooo
2000000d0?3`l0800000103`l?0;000000D0l?3`0P00002o0?3`l0@00000GP3oool008d0oooo1P00
000d0?3`l0800000103`l?000`000000l?3`0?3`l0040?3`l08000001`3`l?02000003`0l?3`1000
00210?3`l0@00000G03oool00900oooo1P00000a0?3`l08000001@3`l?000`000000l?3`0?3`l003
0?3`l08000001`3`l?02000003`0l?3`00D000000?3`l03`l?00l?3`000000210?3`l0@00000F`3o
ool00940oooo2000000^0?3`l08000001P3`l?000`000000l?3`0?3`l0020?3`l08000001`3`l?02
00000440l?3`00<000000?3`l03`l?00P03`l?04000005T0oooo002A0?ooo`8000000P3oool60000
02`0l?3`0P0000070?3`l0040000003`l?00l?3`0?3`l08000001`3`l?02000003h0l?3`10000023
0?3`l0@00000F03oool00940oooo0P0000050?ooo`H00000:P3`l?000`000000l?3`0?3`l0060?3`
l0030000003`l?00l?3`008000001`3`l?000`000000l?3`0?3`l00l0?3`l08000000P3`l?020000
08@0l?3`1000001F0?ooo`00T@3oool2000000L0oooo1P00000X0?3`l08000001`3`l?000`000000
l?3`0?3`l002000000H0l?3`0P00000n0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00P`3`l?04000005D0oooo002A0?ooo`8000002P3oool6000002H0l?3`00<000000?3`l03`l?00
1P3`l?0010000000l?3`0000000000060?3`l0030000003`l?00l?3`02P0l?3`0P0000050?3`l0@0
000000D0l?3`000000000000l?3`000000050?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?00Q@3`l?04000005<0oooo002A0?ooo`800000303oool7000002@0l?3`00<000000?3`l03`
l?001P3`l?03000000D0l?3`00<000000?3`l03`l?00:@3`l?02000000@0l?3`0P0000030?3`l080
00000P3`l?000`000000l?3`0?3`l0040?3`l0040000003`l?00l?3`0?3`l0800000Q`3`l?040000
0580oooo002A0?ooo`8000003`3oool6000002<0l?3`00<000000?3`l03`l?001P3`l?02000000@0
l?3`00<000000?3`l03`l?00:@3`l?0010000000l?3`0?3`l00000040?3`l0030000003`l?00l?3`
0080l?3`0P0000020?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0270?3`l0@00000D03oool00940oooo0P00000B0?ooo`H000008@3`l?000`000000
l?3`0?3`l0050?3`l08000000`3`l?000`000000l?3`0?3`l00Z0?3`l0030000003`l?00l?3`0080
00000`3`l?000`000000l?3`0?3`l0030?3`l0040000003`l?00l?3`000000H0l?3`00<000000?3`
l03`l?000P00002:0?3`l0@00000C`3oool00940oooo0P00000D0?ooo`L00000F03`l?001@000000
l?3`0?3`l03`l?00000000@0l?3`1P0000020?3`l0030000003`l?00l?3`00D0l?3`0`0000000`3`
l?0000000?3`l02:0?3`l0@00000C@3oool00940oooo0P00000G0?ooo`H00000EP3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`00@000000?3`l03`l?000000V03`l?040000
04`0oooo002A0?ooo`8000006P3oool6000005<0l?3`00<000000?3`l03`l?000P3`l?001@000000
l?3`0?3`l03`l?00000000D0l?3`00@000000?3`l03`l?000000V@3`l?04000004X0oooo002A0?oo
o`800000703oool600000540l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l0000005
0?3`l0030000003`l?00l?3`00800000V@3`l?04000004T0oooo002A0?ooo`8000007`3oool60000
02h0l?3`0P000?lN0?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`l?00l?3`1@000003
0?3`l0040000003`l?000000000009T0l?3`100000170?ooo`00T@3oool200000240oooo1`00000[
0?3`l080003o7P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0:H0l?3`10000016
0?ooo`00T@3oool2000002@0oooo1P00000Y0?3`l080003o7P3`l?000`000000l?3`0?3`l0050?3`
l0030000003`l?00l?3`0:L0l?3`100000140?ooo`00T@3oool2000002L0oooo1P00000U0?3`l0@0
003o7@3`l?000`000000l?3`0?3`l0050?3`l0030000003`l?00l?3`0:P0l?3`100000130?ooo`00
T@3oool2000002T0oooo1`00000R0?3`l0@0003odP3`l?0300000480oooo002A0?ooo`800000;03o
ool600000200l?3`10000?oC0?3`l0@00000@03oool00940oooo0P00000_0?ooo`H00000703`l?05
0000om@0l?3`1000000o0?ooo`00T@3oool200000340oooo1P00000J0?3`l0H0003oe@3`l?040000
03d0oooo002A0?ooo`800000=03oool6000001L0l?3`1P000?oF0?3`l0@00000?03oool00940oooo
0P00000f0?ooo`L000004`3`l?070000omP0l?3`1000000j0?ooo`00T@3oool2000003T0oooo1P00
000A0?3`l0L0003of@3`l?04000003T0oooo002A0?ooo`800000?03oool6000000h0l?3`1`000?oK
0?3`l0@00000=`3oool00940oooo0P00000n0?ooo`L000002`3`l?080000om/0l?3`1000000f0?oo
o`00T@3oool200000440oooo1P0000080?3`l0T0003og@3`l?04000003@0oooo002A0?ooo`800000
A03oool6000000D0l?3`2@000?oN0?3`l0@00000<`3oool00940oooo0P0000160?ooo`H000000`3`
l?090000on00l?3`1000000a0?ooo`00T@3oool2000004T0oooo1@00000;0000on00l?3`1000000`
0?ooo`00T@3oool2000004/0oooo0`00000;0000on80l?3`1000000^0?ooo`00T@3oool2000004h0
oooo2`000?oS0?3`l0@00000;@3oool00940oooo0P00001A0?ooo`8000000P000?l200000>L0l?3`
1000000[0?ooo`00T@3oool2000005<0oooo0P000?l400000>H0l?3`1000000Z0?ooo`00T@3oool2
000005<0oooo0P000?l00`3oool000000000000400000>D0l?3`1000000X0?ooo`00T@3oool20000
05<0oooo0P000?l30?ooo`L00000h`3`l?04000002L0oooo002A0?ooo`800000D`3oool20000o`H0
oooo1P00003S0?3`l0@000009@3oool00940oooo0P00001C0?ooo`80003o2@3oool600000>40l?3`
1000000T0?ooo`00T@3oool2000005<0oooo0P000?l;0?ooo`L00000h03`l?0400000280oooo002A
0?ooo`800000D`3oool20000o`h0oooo1P00003O0?3`l0@000008@3oool00940oooo0P00001C0?oo
o`80003o4@3oool600000=h0l?3`1000000O0?ooo`00T@3oool2000005<0oooo0P000?lC0?ooo`H0
0000g@3`l?04000001h0oooo002A0?ooo`800000D`3oool20000oaH0oooo1P00003L0?3`l0@00000
703oool00940oooo0P00001C0?ooo`80003o603oool700000=X0l?3`1000000K0?ooo`00T@3oool2
000005<0oooo0P000?lK0?ooon<000006P3oool00940oooo0P00001C0?ooo`80003o7P3ooooP0000
01X0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00
T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3o
ool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oo
oaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o
o`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool2
0000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0
oooo0P000?oo0?oooaT0oooo002A0?ooo`800000D`3oool20000ool0oooo6@3oool00940oooo0P00
001C0?ooo`80003oo`3ooolI0?ooo`00T@3oool2000005<0oooo0P000?oo0?oooaT0oooo002A0?oo
o`800000D`3oool20000ool0oooo6@3oool00940oooo0P00001C0?ooo`80003o=`3oool=00000=@0
oooo002A0?ooo`800000D`3oool20000ob@0oooo8@00003C0?ooo`00T@3oool2000005<0oooo0P00
0?l@0?ooobP000002`3oool400000=40oooo002A0?ooo`800000DP3ooolX000001l0oooo1000003@
0?ooo`00T@3oool2000003h0oooo:000000e0?ooo`@00000cP3oool00940oooo0P00000[0?ooobP0
00000P000?m70?ooo`@00000c@3oool00940oooo0P00000G0?ooobP00000503oool20000odT0oooo
1000003;0?ooo`00T@3oool2000000<0oooo:@00000W0?ooo`80003oBP3oool500000<T0oooo0023
0?ooobP00000>`3oool20000od`0oooo100000380?ooo`00K`3ooolX000004l0oooo0P000?m>0?oo
o`@00000aP3oool005`0oooo:00000080?ooo`d00000C@3oool20000odl0oooo100000350?ooo`00
B03ooolX000001`0oooo3@00001=0?ooo`80003oD@3oool400000<<0oooo000e0?ooobP00000;`3o
ool=000004d0oooo0P000?mB0?ooo`@00000`P3oool00240oooo:00000130?ooo``00000CP3oool2
0000oe@0oooo100000300?ooo`003P3ooolX000005L0oooo2`00001>0?ooo`80003oE@3oool40000
0;l0oooo00040?oooah00000J`3oool;000004h0oooo0P000?mG0?ooo`@00000_@3oool000@0oooo
2`00001n0?ooo`X00000C`3oool20000oeP0oooo1000002l0?ooo`001P3oool700000840oooo2@00
001?0?ooo`80003oFP3oool400000;X0oooo00090?ooo`L00000OP3oool9000004l0oooo0P000?mK
0?ooo`@00000^@3oool000`0oooo1P00001l0?ooo`P00000D03oool20000oed0oooo1000002g0?oo
o`003`3oool6000007X0oooo1`00001@0?ooo`80003oGP3oool400000;H0oooo000A0?ooo`L00000
M`3oool600000540oooo0P000?mP0?ooo`@00000]03oool001@0oooo1P00001e0?ooo`H00000D@3o
ool20000of40oooo1@00002b0?ooo`005`3oool6000007<0oooo1@00001A0?ooo`80003oH`3oool4
00000;40oooo000I0?ooo`L00000L03oool400000580oooo0P000?mU0?ooo`@00000[`3oool001`0
oooo1`00001]0?ooo`@00000DP3oool20000ofH0oooo1000002^0?ooo`007`3oool6000006`0oooo
0`00001B0?ooo`80003oJ03oool4000002`0oooo1`0000050?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000001@3oool01@000000
oooo0?ooo`3oool0000000D0oooo0`0000040?ooo`<0000000D0oooo0000003oool0oooo00000005
0?ooo`@00000>03oool00280oooo1P00001Y0?ooo`800000D`3oool20000ofT0oooo1000000[0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03D0oooo000T0?ooo`L00000^`3oool20000of/0oooo1000000Y0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`009`3o
ool600000;T0oooo0P000?m/0?ooo`@00000:03oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool300000003
0?ooo`000000oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000070?ooo`800000>03oool0
02X0oooo1P00002f0?ooo`80003oKP3oool4000002H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`07000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool30000
00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000D0oooo0P00000j0?ooo`00;03o
ool700000;<0oooo0P000?m_0?ooo`@000009@3oool7000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j
0?ooo`00;`3oool700000440oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1O0?oo
o`80003oL@3oool4000002<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`00<P3oool6000003h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1N0?ooo`80003oLP3oool400000280
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000
oooo00000002000000@0oooo100000040?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000020?oo
o`@00000>03oool003D0oooo1P00000j0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0G@3oool20000og@0oooo1000000P0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1[0?ooo`00=`3oool7000003H0oooo00<000000?ooo`3oool0
0P3oool8000000H0oooo00<000000?ooo`3oool0G03oool20000ogD0oooo1000000O0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`00>P3o
ool6000003<0oooo0P0000050?ooo`L000001P3oool2000005d0oooo0P000?mg0?ooo`@000007@3o
ool7000000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1C0?ooo`00?@3oool6
00000300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool0oooo4@0000190?ooo`80003oN03oool5000009/0oooo000o
0?ooo`L00000;03oool2000000P0oooo00<000000?ooo`3oool02@3oool200000080oooo4@000019
0?ooo`80003oNP3oool4000009X0oooo00120?ooo`L00000:@3oool2000000P0oooo0P00000:0?oo
o`8000000P3ooolA000004T0oooo0P000?ml0?ooo`@00000V03oool004D0oooo1P00000W0?ooo`80
00002@3oool00`000000oooo0?ooo`080?ooo`8000000P3ooolA000004T0oooo0P000?mm0?ooo`@0
0000U`3oool004P0oooo1P00000T0?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`800000
0P3ooolA000004T0oooo0P000?mo0?ooo`@00000U@3oool004X0oooo1`00000Q0?ooo`8000002P3o
ool2000000P0oooo0P0000020?oooa400000B@3oool20000oh00oooo1000002D0?ooo`00C@3oool6
000001l0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0P0000020?oooa400000B@3oool2
0000oh80oooo1000002B0?ooo`00D03oool6000001d0oooo00<000000?ooo`3oool02@3oool20000
00L0oooo00@000000?ooo`3oool0oooo4@0000190?ooo`80003oP`3oool400000940oooo001B0?oo
o`L000006P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P0000030?oo
oa400000B@3oool20000ohD0oooo1000002?0?ooo`00E@3oool7000001P0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo0P0000060?ooo`030000003oool0oooo0080oooo4@000000103oool0
003o0000o`000?m50?ooo`80003oQP3oool400000240oooo00<000000?ooo`3oool01`3oool30000
00@0oooo0`000000103oool000000000003oool300000080oooo0`0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`@000001`3oool3000000050?ooo`000000
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool0603o
ool005P0oooo1P00000G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`00
00050?ooo`030000003oool0oooo00<0oooo4@0000000`3oool0003o0000o`020000od@0oooo0P00
0?n80?ooo`@000007`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`3oool200000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`800000
6@3oool005/0oooo1P00000E0?ooo`040000003oool0oooo0?ooo`H000001@3oool00`000000oooo
0?ooo`040?oooa4000000`3oool30000od<0oooo0P000?n90?ooo`@000007P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo01L0oooo001M0?ooo`L000004`3oool010000000oooo0?ooo`3o
ool4000000D0oooo00<000000?ooo`3oool01@3ooolA000000@0oooo10000?m10?ooo`80003oR`3o
ool4000001`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`<0000000D0
oooo0000003oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`<0000000D0oooo0000003o
ool0oooo000000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool0
0600oooo1P00000l0?ooo`@0003ocP3oool4000001/0oooo00<000000?ooo`3oool01@3oool70000
00@0oooo0`0000020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo1`0000020?ooo`8000002`3oool300000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo001S0?ooo`H00000>`3o
ool30000oll0oooo1000000I0?ooo`H000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool05`3oool006D0oooo1`00000i0?ooo`<0003oc`3oool50000
01L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000006@3oool006P0
oooo1`00000g0?ooo`@0003oc`3oool4000001H0oooo00<000000?ooo`3oool01`3oool3000000@0
oooo100000020?ooo`@0000000<0oooo0000003oool00`3oool01P000000oooo0?ooo`3oool00000
0?ooo`8000000`3oool3000000@0oooo100000070?ooo`@000000`3oool00`000000oooo00000002
000000D0oooo0`0000000`3oool000000?ooo`0H0?ooo`00J`3oool6000003H0oooo10000?o@0?oo
o`@00000503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool05`3oool006h0oooo1P00000e0?ooo`<0003od03oool4000001<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001`0?ooo`L00000
<`3oool50000oa80oooo0`000?lI0?oooa400000T03oool400000140oooo1`00001<0?ooo`030000
003oool0oooo01L0oooo001c0?ooo`H00000<P3oool80000o`h0oooo1@000?lG0?oooa400000T@3o
ool4000007d0oooo001f0?ooo`H00000<P3oool:0000o`T0oooo1`000?lE0?ooo`8000003@3oool2
000009<0oooo1000001k0?ooo`00N03oool7000003<0oooo2P000?l40?ooo`/0003o4P3oool20000
00d0oooo0P00002D0?ooo`@00000NP3oool007/0oooo1`00000e0?oooaH0003o403oool2000000d0
oooo0P00002F0?ooo`@00000N03oool007h0oooo1P00000g0?oooa@0003o3P3oool2000000d0oooo
0P00002G0?ooo`@00000M`3oool00840oooo1P00000h0?oooa80003o303oool2000000d0oooo0P00
002I0?ooo`@00000CP3oool2000000D0oooo00<000000?ooo`3oool07@3oool008<0oooo1`00000f
0?oooa80003o2`3oool2000000d0oooo0P00002J0?ooo`@00000C`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01d0oooo00260?ooo`H00000=03ooolB0000o`/0oooo0P00000=0?oo
o`800000W03oool4000004h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00R@3oool60000
0340oooo3`000?l>0?ooo`8000003@3oool2000009d0oooo1000000K0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<00000103oool01P00
0000oooo0?ooo`3oool000000?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000403o
ool008/0oooo1`00000^0?ooo`/0003o4P3oool2000000d0oooo0P00002O0?ooo`@000006@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000003`3oool008h0oooo1`00000[
0?ooo`L0003o5P3oool2000000d0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0R03oool5000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000103oool010000000oooo0?oo
o`0000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`00T@3oool6000002T0oooo0`000?lJ0?oooa4000001`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo08T0oooo1000000F0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0180oooo002D0?ooo`H000006@3oool00`000000oooo0?ooo`0W0?oooa4000001P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo08X0oooo1000000D0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07000000030?ooo`000000oooo
00<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool04P3oool009H0oooo1`00000F0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool0
oooo1P0000090?ooo`030000003oool0oooo08X0oooo1000000C0?ooo`L000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000103oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo002I0?ooo`H000005@3oool00`000000oooo0?ooo`0k0?ooo`800000
0`3oool2000000@0oooo00<000000?ooo`3oool01P3oool2000008d0oooo1000000A0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool01P000000oooo0?ooo`3oool000000?ooo`800000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool009`0oooo1P00000B0?ooo`040000003oool00000000003X0oooo00<000000?ooo`3o
ool0203oool2000000P0oooo00<000000?ooo`3oool0S03oool400000100oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`000000oooo00<000001@3oool3000000<0oooo00<000000?oo
o`0000000P0000050?ooo`<000000`3oool4000000030?ooo`000000oooo00@0oooo0P000000103o
ool000000000000000030?ooo`030000003oool0oooo0080oooo1000000?0?ooo`00WP3oool70000
0100oooo00<000000?ooo`3oool00P00000g0?ooo`8000002`3oool2000000L0oooo0P00002?0?oo
o`@000003P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000200oooo00<00000
0?ooo`3oool0:03oool00:40oooo1`00000=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=03oool2000000/0oooo0P0000070?ooo`800000T03oool4000000d0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo002T0?oo
o`H000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo0P00000;0?oo
o`8000001`3oool200000980oooo1000000;0?ooo`L000000`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo01D0oooo002N0?ooo`D00000103oool6000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P00000:0?ooo`<0
00001`3oool2000009<0oooo1000001P0?ooo`00W@3oool2000000@0oooo0P0000030?ooo`T00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P0000090?ooo`<00000
203oool2000009D0oooo1000001N0?ooo`00W@3oool00`000000oooo0?ooo`040?ooo`8000000P3o
ool010000000oooo0?ooo`3oool6000000@0oooo0P0000020?ooo`030000003oool0oooo03@0oooo
0P0000060?ooo`H00000203oool2000009H0oooo1000001M0?ooo`00W@3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo000000H0oooo1P0000020?ooo`@00000=`3oool00`000000oooo
0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`2G0?ooo`@00000F`3oool00:D0oooo00<0
00000?ooo`3oool0200000000`3oool0000000000005000003X0oooo0P0000090?ooo`030000003o
ool0oooo00H0oooo0P00002J0?ooo`@00000FP3oool00:<0oooo0P0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000P3oool7000003P0oooo00<000000?ooo`3oool01`3oool2
000000L0oooo00<000000?ooo`3oool0V`3oool4000005P0oooo002O0?ooo`D000001@3oool00`00
0000oooo0?ooo`030?ooo`80000000<0oooo0000003oool00`3oool6000003L0oooo00@000000?oo
o`3oool000001@3oool2000000H0oooo00<000000?ooo`3oool0W@3oool5000005H0oooo002N0?oo
o`8000002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo1P00000e
0?ooo`040000003oool0oooo000000<0oooo0`0000050?ooo`030000003oool0oooo0:00oooo1000
001E0?ooo`00WP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo10000003
0?ooo`030000003oool0oooo00L0oooo1`00000c0?ooo`030000003oool0oooo00D000001@3oool0
0`000000oooo0?ooo`2S0?ooo`@00000D`3oool009h0oooo0P0000060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool600000>D0oooo1000001B0?ooo`00W`3oool2000000@0
oooo0P00000<0?ooo`030000003oool0oooo00`0oooo1P00003T0?ooo`@00000D03oool00:40oooo
1@00000=0?ooo`030000003oool0oooo00h0oooo1`00003R0?ooo`@00000C`3oool00<L0oooo1`00
003Q0?ooo`@00000C@3oool00<X0oooo1P00003P0?ooo`@00000C03oool00<d0oooo1P00003O0?oo
o`@00000BP3oool00<l0oooo1`00003M0?ooo`@00000B@3oool00=80oooo1P00003M0?ooo`@00000
A`3oool00=D0oooo1P00003K0?ooo`@00000AP3oool00=L0oooo1`00003J0?ooo`@00000A03oool0
0=X0oooo1`00003H0?ooo`@00000@`3oool00=d0oooo1P00003H0?ooo`@00000@@3oool00>00oooo
1P00003F0?ooo`D00000?`3oool00>80oooo1`00003E0?ooo`@00000?P3oool00>D0oooo1P00003E
0?ooo`@00000?03oool00>P0oooo1P00003C0?ooo`@00000>`3oool00>X0oooo1`00003B0?ooo`@0
0000>@3oool00>d0oooo1`00003@0?ooo`@00000>03oool00?00oooof@00000g0?ooo`00l`3ooooF
000003L0oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`8P3`l?000`000000l?3`0?3`l00:
0?3`l0030000003`l?00l?3`00l0l?3`1000000K0?ooo`030000003oool0oooo00<0oooo10000000
0`3oool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`12
0?ooo`005`3oool600000?l0l?3`7`3`l?000`000000l?3`0?3`l00<0?3`l0030000003`l?00l?3`
0100l?3`1000000I0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`006P3oool60000
0?l0l?3`6`3`l?000`000000l?3`0?3`l00>0?3`l0030000003`l?00l?3`0100l?3`1000000H0?oo
o`030000003oool0oooo00X0oooo0`0000040?ooo`030000003oool00000008000001@3oool30000
0080oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`020?ooo`@00000A@3oool001`0oooo1`0000100?3`l0800000103`l?020000
00<0l?3`0P0000390?3`l0030000003`l?00l?3`0080l?3`1P0000080?3`l0030000003`l?00l?3`
0140l?3`1000000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1O0?ooo`007`3oool6000003h0l?3`0P0000040?3`l08000000`3`l?0200000<P0
l?3`0P0000040?3`l0<000000`3`l?000`000000l?3`0?3`l0050?3`l08000004`3`l?04000001H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05l0
oooo000R0?ooo`H00000o`3`l?0A0?3`l0030000003`l?00l?3`00T0l?3`0P0000070?3`l0030000
003`l?00l?3`01<0l?3`1000000E0?ooo`H00000<03oool00`000000oooo0?ooo`1;0?ooo`00903o
ool700000?l0l?3`3@3`l?02000000`0l?3`0P0000060?3`l08000005@3`l?04000009P0oooo000W
0?ooo`H00000o`3`l?0;0?3`l0800000303`l?02000000H0l?3`0P00000G0?3`l0<00000U`3oool0
02X0oooo1P00003o0?3`l0P0l?3`0P00000<0?3`l08000001P3`l?02000001P0l?3`1000002E0?oo
o`00;03oool6000004D0l?3`00<000000?3`l03`l?002P3`l?000`000000l?3`0?3`l02`0?3`l080
00002`3`l?03000000H0l?3`0P00000I0?3`l0@00000U03oool002l0oooo1P0000110?3`l0030000
003`l?00l?3`00`0l?3`00<000000?3`l03`l?00[`3`l?02000000/0l?3`0`0000060?3`l0800000
6`3`l?0400000980oooo000a0?ooo`L00000?@3`l?000`000000l?3`0?3`l00>0?3`l0030000003`
l?00l?3`0:h0l?3`0P0000090?3`l0@000001`3`l?02000001`0l?3`1000002A0?ooo`00=03oool6
000003X0l?3`00<000000?3`l03`l?00103`l?06000000H0l?3`00<000000?3`l03`l?00[P3`l?00
0`000000l?3`0?3`l0040?3`l0H00000203`l?000`000000l?3`0?3`l00M0?3`l0@00000S`3oool0
03L0oooo1P00000f0?3`l0800000203`l?02000000P0l?3`0P00002_0?3`l08000001@3`l?040000
00T0l?3`0P00000P0?3`l0@00000SP3oool003T0oooo1P00000d0?3`l0030000003`l?00l?3`00L0
l?3`0P0000090?3`l0030000003`l?00l?3`00P0l?3`1@00002Q0?3`l0030000003`l?00l?3`00<0
l?3`0P00000;0?3`l0030000003`l?00l?3`0240l?3`1000002<0?ooo`00?03oool600000300l?3`
0P0000090?3`l08000002@3`l?02000000L0l?3`2@00002P0?3`l0030000003`l?00l?3`00<0l?3`
00<000000?3`l03`l?00203`l?000`000000l?3`0?3`l00S0?3`l0@00000R`3oool003h0oooo1`00
000]0?3`l08000002@3`l?02000000T0l?3`0P0000070?3`l0T00000X@3`l?000`000000l?3`0?3`
l0020?3`l0H00000103`l?000`000000l?3`0?3`l00V0?3`l0@00000R@3oool00440oooo1P00000[
0?3`l08000002@3`l?02000000T0l?3`0P0000060?3`l0/00000X@3`l?000`000000l?3`0?3`l002
0?3`l0H000000P3`l?000`000000l?3`0?3`l00X0?3`l0@00000R03oool004@0oooo1P00000X0?3`
l08000002@3`l?02000000T0l?3`0P0000060?3`l0/00000f`3`l?04000008H0oooo00160?ooo`L0
00009@3`l?02000000T0l?3`0P0000090?3`l08000001P3`l?0;00000=`0l?3`100000250?ooo`00
B@3oool6000002<0l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`2@00002M0?3`l0D00000
?@3`l?04000008<0oooo001<0?ooo`H000008@3`l?000`000000l?3`0?3`l0070?3`l08000002@3`
l?000`000000l?3`0?3`l0060?3`l0T00000V`3`l?09000003`0l?3`100000220?ooo`00CP3oool6
000001l0l?3`0P0000080?3`l0800000203`l?02000000X0l?3`1@00002M0?3`l0T00000?P3`l?04
00000800oooo001A0?ooo`H000007@3`l?000`000000l?3`0?3`l0060?3`l0800000203`l?000`00
0000l?3`0?3`l02Z0?3`l0/00000?P3`l?04000007l0oooo001C0?ooo`L000006`3`l?000`000000
l?3`0?3`l0050?3`l08000001`3`l?000`000000l?3`0?3`l02[0?3`l0/00000@03`l?04000007d0
oooo001F0?ooo`H000006P3`l?000`000000l?3`0?3`l0020?3`l0@000001P3`l?000`000000l?3`
0?3`l02T0?3`l0@0003o103`l?0;00000440l?3`1000001l0?ooo`00F@3oool6000001P0l?3`00<0
00000?3`l03`l?000`3`l?02000000D0l?3`00<000000?3`l03`l?00X03`l?090000o`D0l?3`2@00
00140?3`l0@00000NP3oool005/0oooo1`0000310?3`l0`0003o1P3`l?09000004D0l?3`1000001i
0?ooo`00GP3oool600000;X0l?3`40000?l90?3`l0D00000B@3`l?04000007L0oooo001Q0?ooo`H0
0000]@3`l?0A0000oeT0l?3`1000001f0?ooo`00H`3oool600000;<0l?3`40000?mL0?3`l0@00000
M03oool006H0oooo1P00002a0?3`l0h0003oGP3`l?04000007<0oooo001X0?ooo`L00000[`3`l?0<
0000oc80l?3`0P0000040?3`l08000000`3`l?0200000280l?3`1000001a0?ooo`00J`3oool60000
0:h0l?3`2P000?lc0?3`l0800000103`l?02000000<0l?3`0P00000S0?3`l0@00000L03oool006h0
oooo1P00002W0?3`l0d0003oIP3`l?04000006h0oooo001`0?ooo`L00000X@3`l?070000o`030?3`
l0000?l0003o00D0003oJ03`l?04000006d0oooo001c0?ooo`H00000603`l?02000005@0l?3`1@00
000Y0?3`l0L0003o103`l?060000oaD0l?3`0P00001D0?3`l0@00000J`3oool007H0oooo1P00000E
0?3`l0800000DP3`l?09000002<0l?3`20000?l70?3`l0D0003o5P3`l?02000005D0l?3`1000001Z
0?ooo`00N03oool6000001<0l?3`0P00000i0?3`l0030000003`l?00l?3`00X0l?3`00<000000?3`
l03`l?002@3`l?02000000D0oooo0P00000P0?3`l0P0003o2`3`l?030000oaL0l?3`0P00001G0?3`
l0@00000J03oool007/0oooo1P00000@0?3`l0800000>03`l?000`000000l?3`0?3`l00<0?3`l003
0000003`l?00l?3`00L0l?3`0P0000070?ooo`800000703`l?070000o`l0l?3`0P000?lH0?3`l080
0000F03`l?04000006L0oooo001m0?ooo`L000003@3`l?02000003L0l?3`00<000000?3`l03`l?00
3P3`l?000`000000l?3`0?3`l0060?3`l08000001`3oool2000001@0l?3`30000?l/0?3`l0800000
FP3`l?04000006D0oooo00200?ooo`H000002`3`l?02000003H0l?3`00<000000?3`l03`l?00203`
l?02000000H0l?3`00<000000?3`l03`l?001@3`l?02000000L0oooo0P0000080?3`l1D0003o;`3`
l?02000005/0l?3`1000001T0?ooo`00P`3oool6000000P0l?3`0P00000e0?3`l08000002P3`l?02
000000H0l?3`0P0000070?3`l08000001@3oool2000000<0l?3`4`000?lg0?3`l0800000G@3`l?04
00000680oooo00250?ooo`L000001@3`l?02000003D0l?3`00<000000?3`l03`l?002@3`l?020000
00L0l?3`00<000000?3`l03`l?001@3`l?09000000<0l?3`1`000?m30?3`l0800000GP3`l?040000
0640oooo00280?ooo`H000000`3`l?02000003@0l?3`0P00000;0?3`l08000001`3`l?02000000P0
l?3`1@00001?0?3`l0800000H03`l?04000005l0oooo002;0?ooo`P00000=03`l?02000000@0l?3`
2`0000050?3`l0800000G03`l?0200000640l?3`1000001N0?ooo`00S@3oool6000003@0l?3`0P00
00040?3`l0030000003`l?00l?3`00@0l?3`0P0000070?3`l0800000?03`l?04000001`0l?3`0P00
001S0?3`l0@00000G03oool00900oooo1P00000a0?3`l08000001@3`l?000`000000l?3`0?3`l003
0?3`l08000001`3`l?02000003`0l?3`00D000000?3`l03`l?00l?3`0000000K0?3`l0800000I03`
l?04000005/0oooo002A0?ooo`P00000;P3`l?02000000H0l?3`00<000000?3`l03`l?000P3`l?02
000000L0l?3`0P0000110?3`l0030000003`l?00l?3`01P0l?3`0P00001V0?3`l0@00000F@3oool0
0940oooo0P0000020?ooo`H00000;03`l?02000000L0l?3`00@000000?3`l03`l?00l?3`0P000007
0?3`l0800000?P3`l?04000001X0l?3`0P00001W0?3`l0@00000F03oool00940oooo0P0000050?oo
o`H00000:P3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`008000001`3`l?000`00
0000l?3`0?3`l00l0?3`l08000000P3`l?02000001T0l?3`0P00001Y0?3`l0@00000EP3oool00940
oooo0P0000070?ooo`H00000:03`l?02000000L0l?3`00<000000?3`l03`l?000P0000060?3`l080
0000?P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`01L0l?3`0P00001Z0?3`l0@0
0000E@3oool00940oooo0P00000:0?ooo`H000009P3`l?000`000000l?3`0?3`l0060?3`l0040000
003`l?000000000000H0l?3`00<000000?3`l03`l?00:03`l?02000000D0l?3`100000001@3`l?00
00000000003`l?00000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l00G0?3`
l0800000K03`l?04000005<0oooo002A0?ooo`800000303oool7000002@0l?3`00<000000?3`l03`
l?001P3`l?03000000D0l?3`00<000000?3`l03`l?00:@3`l?02000000@0l?3`0P0000030?3`l080
00000P3`l?000`000000l?3`0?3`l0040?3`l0040000003`l?00l?3`0?3`l0800000603`l?020000
06d0l?3`1000001B0?ooo`00T@3oool2000000l0oooo1P00000S0?3`l0030000003`l?00l?3`00H0
l?3`0P0000040?3`l0030000003`l?00l?3`02T0l?3`00@000000?3`l03`l?000000103`l?000`00
0000l?3`0?3`l0020?3`l08000000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?005P3`l?02000006l0l?3`1000001@0?ooo`00T@3oool200000180
oooo1P00000Q0?3`l0030000003`l?00l?3`00D0l?3`0P0000030?3`l0030000003`l?00l?3`02X0
l?3`00<000000?3`l03`l?000P0000030?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`
l?0000001P3`l?000`000000l?3`0?3`l002000001P0l?3`0P00001`0?3`l0@00000C`3oool00940
oooo0P00000D0?ooo`L00000F03`l?001@000000l?3`0?3`l03`l?00000000@0l?3`1P0000020?3`
l0030000003`l?00l?3`00D0l?3`0`0000000`3`l?0000000?3`l00F0?3`l0800000LP3`l?040000
04d0oooo002A0?ooo`8000005`3oool6000005H0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0060?3`l0040000003`l?00l?3`000002<0l?3`0P00001c0?3`l0@00000C03oool00940
oooo0P00000J0?ooo`H00000D`3`l?000`000000l?3`0?3`l0020?3`l0050000003`l?00l?3`0?3`
l00000001@3`l?0010000000l?3`0?3`l000000R0?3`l0800000M@3`l?04000004X0oooo002A0?oo
o`800000703oool600000540l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l0000005
0?3`l0030000003`l?00l?3`008000008@3`l?02000007H0l?3`100000190?ooo`00T@3oool20000
01l0oooo1P00000^0?3`l080003o7P3`l?000`000000l?3`0?3`l0030?3`l0040000003`l?00l?3`
0?3`l0D000000`3`l?0010000000l?3`00000000000O0?3`l0800000N03`l?04000004L0oooo002A
0?ooo`8000008@3oool7000002/0l?3`0P000?lN0?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?00:`3`l?02000007T0l?3`100000160?ooo`00T@3oool2000002@0oooo1P00000Y0?3`
l080003o7P3`l?000`000000l?3`0?3`l0050?3`l0030000003`l?00l?3`02X0l?3`0P00001k0?3`
l0@00000A03oool00940oooo0P00000W0?ooo`H000009@3`l?040000oad0l?3`00<000000?3`l03`
l?001@3`l?000`000000l?3`0?3`l00Z0?3`l0800000O03`l?04000004<0oooo002A0?ooo`800000
:@3oool700000280l?3`10000?mB0?3`l0800000OP3`l?0300000480oooo002A0?ooo`800000;03o
ool600000200l?3`10000?mB0?3`l0800000O`3`l?0400000400oooo002A0?ooo`800000;`3oool6
000001`0l?3`1@000?mB0?3`l0800000P03`l?04000003l0oooo002A0?ooo`800000<@3oool60000
01X0l?3`1P000?mA0?3`l0800000PP3`l?04000003d0oooo002A0?ooo`800000=03oool6000001L0
l?3`1P000?mA0?3`l0800000P`3`l?04000003`0oooo002A0?ooo`800000=P3oool7000001<0l?3`
1`000?mA0?3`l0800000Q@3`l?04000003X0oooo002A0?ooo`800000>@3oool600000140l?3`1`00
0?mA0?3`l0800000QP3`l?04000003T0oooo002A0?ooo`800000?03oool6000000h0l?3`1`000?mA
0?3`l0800000R03`l?04000003L0oooo002A0?ooo`800000?P3oool7000000/0l?3`20000?m@0?3`
l0800000R@3`l?04000003H0oooo002A0?ooo`800000@@3oool6000000P0l?3`2@000?m@0?3`l080
0000R`3`l?04000003@0oooo002A0?ooo`800000A03oool6000000D0l?3`2@000?m@0?3`l0800000
S03`l?04000003<0oooo002A0?ooo`800000AP3oool6000000<0l?3`2@000?m@0?3`l0800000SP3`
l?0400000340oooo002A0?ooo`800000B@3oool5000000/0003oC`3`l?02000008l0l?3`1000000`
0?ooo`00T@3oool2000004/0oooo0`00000;0000odl0l?3`0P00002A0?3`l0@00000;P3oool00940
oooo0P00001>0?ooo`/0003oC`3`l?0200000980l?3`1000000]0?ooo`00T@3oool200000540oooo
0P0000020000o`800000D@3`l?02000009@0l?3`1000000[0?ooo`00T@3oool2000005<0oooo0P00
0?l4000004l0l?3`0P00002E0?3`l0@00000:P3oool00940oooo0P00001C0?ooo`80003o00<0oooo
0000000000001000001<0?3`l0800000U`3`l?04000002P0oooo002A0?ooo`800000D`3oool20000
o`<0oooo1`0000190?3`l0800000V03`l?04000002L0oooo002A0?ooo`800000D`3oool20000o`H0
oooo1P0000170?3`l0800000VP3`l?04000002D0oooo002A0?ooo`800000D`3oool20000o`T0oooo
1P0000140?3`l0800000V`3`l?04000002@0oooo002A0?ooo`800000D`3oool20000o`/0oooo1`00
00110?3`l0800000W@3`l?0400000280oooo002A0?ooo`800000D`3oool20000o`h0oooo1P00000o
0?3`l0800000WP3`l?0400000240oooo002A0?ooo`800000D`3oool20000oa40oooo1P00000l0?3`
l0800000X03`l?04000001l0oooo002A0?ooo`800000D`3oool20000oa<0oooo1P00000j0?3`l080
0000X@3`l?04000001h0oooo002A0?ooo`800000D`3oool20000oaH0oooo1P00000g0?3`l0800000
X`3`l?04000001`0oooo002A0?ooo`800000D`3oool20000oaP0oooo1`00000d0?3`l0800000Y03`
l?04000001/0oooo002A0?ooo`800000D`3oool20000oa/0ooooh`00000J0?ooo`00T@3oool20000
05<0oooo0P000?lN0?ooon0000006P3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000ocL0
oooo3@00000?0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o903ooolQ000000h0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000?l@0?ooobP000002`3oool4000000`0oooo0P00
00330?ooo`00T@3oool200000580oooo:000000O0?ooo`@000002`3oool200000<<0oooo002A0?oo
o`800000?P3ooolX000003D0oooo100000090?ooo`800000``3oool00940oooo0P00000[0?ooobP0
00000P000?m70?ooo`@00000203oool200000<<0oooo002A0?ooo`8000005`3ooolX000001@0oooo
0P000?m90?ooo`@000001P3oool200000<<0oooo002A0?ooo`8000000`3ooolY000002L0oooo0P00
0?m:0?ooo`D00000103oool200000<<0oooo00230?ooobP00000>`3oool20000od`0oooo10000003
0?ooo`800000``3oool006l0oooo:000001?0?ooo`80003oCP3oool4000000030?ooo`0000000000
0<<0oooo001L0?ooobP00000203oool=000004d0oooo0P000?m?0?ooo`H00000``3oool004P0oooo
:000000L0?ooo`d00000C@3oool20000oe40oooo100000330?ooo`00=@3ooolX000002l0oooo3@00
001=0?ooo`80003oDP3oool400000<80oooo000Q0?ooobP00000@`3oool<000004h0oooo0P000?mC
0?ooo`D00000`03oool000h0oooo:000001G0?ooo`/00000CP3oool20000oe<0oooo1P00002o0?oo
o`00103ooolN000006/0oooo2`00001>0?ooo`80003oD`3oool200000080oooo1000002m0?ooo`00
103oool;000007h0oooo2P00001?0?ooo`80003oD`3oool2000000<0oooo1000002l0?ooo`001P3o
ool700000840oooo2@00001?0?ooo`80003oD`3oool2000000D0oooo1000002j0?ooo`002@3oool7
000007h0oooo2@00001?0?ooo`80003oD`3oool2000000H0oooo1000002i0?ooo`00303oool60000
07`0oooo2000001@0?ooo`80003oD`3oool2000000P0oooo1000002g0?ooo`003`3oool6000007X0
oooo1`00001@0?ooo`80003oD`3oool2000000T0oooo1000002f0?ooo`004@3oool7000007L0oooo
1P00001A0?ooo`80003oD`3oool2000000/0oooo1000002d0?ooo`00503oool6000007D0oooo1P00
001A0?ooo`80003oD`3oool2000000`0oooo1@00002b0?ooo`005`3oool6000007<0oooo1@00001A
0?ooo`80003oD`3oool2000000h0oooo1000002a0?ooo`006@3oool700000700oooo1000001B0?oo
o`80003oD`3oool200000100oooo1000000_0?ooo`L000001@3oool3000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000000000D0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`<00000103oool3000000050?ooo`000000oooo0?ooo`000000
1@3oool4000003P0oooo000L0?ooo`L00000K@3oool400000580oooo0P000?mC0?ooo`8000004@3o
ool4000002h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0=@3oool001l0oooo1P00001/0?ooo`<00000DP3oool2
0000oe<0oooo0P00000C0?ooo`@00000;03oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=@3oool00280oooo1P00001Y0?ooo`800000D`3oool20000oe<0
oooo0P00000D0?ooo`@00000:`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000
oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000070?ooo`800000>03oool002@0oooo1`00
002k0?ooo`80003oC@3oool<00000180oooo1000000Y0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0`00
00040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`800000>P3oool002L0
oooo1P00002i0?ooo`80003oC@3oool<000001<0oooo1000000X0?ooo`L000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo03X0oooo000Z0?ooo`H00000A`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo05l0oooo0P000?m=0?ooo``000005@3oool4000002H0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P0000030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0e0?ooo`00;03oool7000004<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1N
0?ooo`80003oCP3oool;000001H0oooo1000000U0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`0000000P0000040?ooo`@00000103oool0
0`000000oooo0?ooo`030?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`000000oooo008000000P3oool4000003P0oooo000_0?ooo`L00000?`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05d0oooo0P000?m>0?ooo`X000006@3oool4
000002<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo06/0oooo000b0?ooo`H00000?03oool00`000000oooo0?ooo`020?ooo`P000001P3oool00`00
0000oooo0?ooo`1L0?ooo`80003oCP3oool:000001X0oooo1000000R0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`00=@3oool6000003P0
oooo0P0000050?ooo`L000001P3oool2000005d0oooo0P000?m?0?ooo`T00000703oool400000200
oooo1`00000;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D`3oool003L0oooo
1`00000e0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo05/0oooo0P000?m?0?ooo`T000007@3oool4000009l0oooo
000j0?ooo`H00000<P3oool2000000P0oooo00<000000?ooo`3oool02@3oool2000005`0oooo0P00
0?m?0?ooo`P00000803oool4000009d0oooo000m0?ooo`H00000;`3oool2000000P0oooo0P00000:
0?ooo`8000000P3ooolA000004T0oooo0P000?m@0?ooo`L000008@3oool5000009/0oooo000o0?oo
o`L00000;03oool2000000T0oooo00<000000?ooo`3oool0203oool200000080oooo4@0000190?oo
o`80003oD03oool7000002<0oooo1000002J0?ooo`00@P3oool7000002T0oooo0P00000:0?ooo`03
0000003oool0oooo00L0oooo0P0000020?oooa400000B@3oool20000oe00oooo1`00000U0?ooo`@0
0000V03oool004D0oooo1P00000W0?ooo`8000002P3oool2000000P0oooo0P0000020?oooa400000
B@3oool20000oe40oooo1P00000V0?ooo`@00000U`3oool004P0oooo1P00000T0?ooo`8000002`3o
ool00`000000oooo0?ooo`060?ooo`8000000P3ooolA000004T0oooo0P000?mA0?ooo`D00000:@3o
ool4000009D0oooo001:0?ooo`L000008P3oool00`000000oooo0?ooo`090?ooo`8000001`3oool0
10000000oooo0?ooo`3ooolA000004T0oooo0P000?mA0?ooo`D00000:P3oool4000009@0oooo001=
0?ooo`H00000803oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P000003
0?oooa400000B@3oool20000oe80oooo1000000/0?ooo`@00000TP3oool00500oooo1P00000N0?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`020?oo
oa400000B@3oool20000oe80oooo1000000]0?ooo`@00000903oool00`000000oooo0?ooo`070?oo
o`<00000103oool3000000040?ooo`00000000000?ooo`<000000P3oool3000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool0103oool3000000@0oooo100000070?ooo`<0000000D0oooo
000000000000oooo000000040?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?oo
o`0H0?ooo`00DP3oool7000001`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3o
ool3000000D0oooo00<000000?ooo`3oool00`3ooolA000004T0oooo0P000?mB0?ooo`<00000<03o
ool400000280oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000001T0oooo
001E0?ooo`L000006P3oool010000000oooo0?ooo`3oool6000000D0oooo00<000000?ooo`3oool0
103ooolA000000040?ooo`000?l0003o0000odD0oooo0P000?mC0?ooo`800000<@3oool400000240
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00F03oool6000001T0oooo00@0
00000?ooo`3oool0oooo100000050?ooo`030000003oool0oooo00D0oooo4@0000000`3oool0003o
0000o`020000od@0oooo0P000?n80?ooo`@000007`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool20000
00L0oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`0G0?ooo`00F`3oool6000002/0oooo4@0000030?ooo`@0003o@P3oool2
0000ohT0oooo1000000N0?ooo`030000003oool0oooo00D0oooo1`0000040?ooo`<000000P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`L00000
0P3oool2000000/0oooo0`0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0G0?ooo`00G@3oool7000002P0oooo4@0000040?ooo`D0003o
@03oool20000oh/0oooo1000000L0?ooo`H000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool05`3oool00600oooo1P00000m0?ooo`@0003oc@3oool4
000001/0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000006@3oool0
06<0oooo1P00000l0?ooo`@0003oc@3oool4000001T0oooo00<000000?ooo`3oool01`3oool30000
00@0oooo100000020?ooo`@0000000<0oooo0000003oool00`3oool01P000000oooo0?ooo`3oool0
00000?ooo`8000000`3oool3000000@0oooo100000070?ooo`@000000`3oool00`000000oooo0000
0002000000D0oooo0`0000000`3oool000000?ooo`0H0?ooo`00I@3oool7000003X0oooo1@000?o<
0?ooo`D000005`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool05`3oool006P0oooo1`00000i0?ooo`@0003oc@3oool4000001H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001[0?ooo`H0
0000>@3oool50000ol`0oooo1000000D0?ooo`L00000C03oool00`000000oooo0?ooo`0G0?ooo`00
KP3oool6000003L0oooo20000?o90?ooo`@00000P03oool00700oooo1`00000g0?ooo`X0003o2@3o
ool30000oaT0oooo4@00002@0?ooo`@00000OP3oool007<0oooo1P00000i0?ooo`X0003o1@3oool5
0000oaL0oooo4@00002A0?ooo`@00000O@3oool007H0oooo1P00000k0?ooo`T0003o00<0oooo0000
o`000?l01@000?lE0?ooo`8000003@3oool2000004@0oooo3P0000110?ooo`@00000N`3oool007P0
oooo1`00000l0?oooa00003o4P3oool2000000d0oooo0P0000140?ooo`h00000@P3oool4000007X0
oooo001k0?ooo`L00000?@3oool>0000oa00oooo0P00000=0?ooo`800000A03oool>000000l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`@00000N03oool007h0oooo1P00
000l0?ooo`l0003o3P3oool2000000d0oooo0P0000140?ooo`h000003P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02D0oooo1000001g0?ooo`00P@3oool6000003T0oooo4@000?l<
0?ooo`8000003@3oool2000004@0oooo3P00000=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool09P3oool4000004h0oooo0P0000050?ooo`030000003oool0oooo01d0oooo00230?oo
o`L00000=P3ooolB0000o`/0oooo0P00000=0?ooo`800000A03oool>000000`0oooo00<000000?oo
o`3oool01@3oool4000000L0oooo00<000000?ooo`3oool09P3oool4000004l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`00QP3oool6000003@0oooo4P000?l;0?ooo`80
00003@3oool2000004@0oooo3P00000;0?ooo`8000001P3oool010000000oooo0?ooo`3oool20000
00H0oooo0P00000Y0?ooo`@00000CP3oool01@000000oooo0?ooo`3oool0000001l0oooo00290?oo
o`H00000<@3oool=0000oa00oooo0P00000=0?ooo`800000A03oool>000000/0oooo00<000000?oo
o`3oool0103oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?oo
o`@000006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`<00000103oool3000000@0oooo00H000000?ooo`3oool0oooo0000003oool3000000<0oooo00<0
00000?ooo`3oool00P3oool300000100oooo002;0?ooo`L00000;P3oool50000oaP0oooo0P00000=
0?ooo`800000A03oool>000000X0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0P00000[
0?ooo`@000006@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?oo
o`8000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000003`3o
ool008h0oooo1`00000N0?ooo`030000003oool0oooo02L0oooo4@0000080?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0;03oool>000000X0oooo0P0000050?ooo`8000001@3oool2
000000H0oooo0P00000/0?ooo`D000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000003o
ool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo002A0?ooo`H00000703oool00`000000oooo0?ooo`0W0?oooa400000
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02/0oooo3P00000:0?ooo`800000
1@3oool2000000D0oooo0P0000060?ooo`800000;P3oool4000001H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool04P3oool009@0oooo1P00000J0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0Z0?ooo`h000002P3oool2000000D0oooo0P0000050?oo
o`8000001P3oool200000300oooo1000000D0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`07000000030?ooo`000000oooo00<0oooo00@000000?oo
o`3oool000001@3oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3oool009H0oooo
1`00000G0?ooo`040000003oool00000000003/0oooo00@000000?ooo`3oool0oooo1P0000090?oo
o`030000003oool0oooo0440oooo0P0000050?ooo`<000000`3oool2000000L0oooo0P00000a0?oo
o`@000004`3oool7000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?oo
o`0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`00V@3oool6000001H0
oooo00<000000?ooo`3oool00P00000h0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3o
ool01P3oool200000480oooo0P0000050?ooo`80000000<0oooo0000000000000P0000080?ooo`80
0000<`3oool400000140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00W03oool6000001<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo03<0oooo1000000@0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool000000?ooo`03000000D0oooo0`0000030?ooo`030000003oool00000008000001@3oool30000
00<0oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo00000000000000000`3oool0
0`000000oooo0?ooo`020?ooo`@000003`3oool009h0oooo1`00000@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=03oool2000000/0oooo0P0000070?ooo`800000@P3oool20000
00D0oooo0P00000;0?ooo`800000=`3oool4000000h0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo002N0?ooo`X0000000<0oooo0000
000000000P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0c0?ooo`8000002`3oool2000000L0oooo0P0000130?ooo`030000003oool0oooo
00@0oooo0P00000:0?ooo`030000003oool0oooo03L0oooo1000000=0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`0X0?ooo`00W@3oool20000
00@0oooo1`0000030?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03<0oooo0P00000;0?ooo`8000001`3oool2000004@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo1000000;0?oo
o`L000000`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01D0oooo002M0?ooo`03
0000003oool0oooo00@0oooo0P0000000`3oool0000000000004000000050?ooo`00000000000?oo
o`000000103oool200000080oooo00<000000?ooo`3oool0=03oool2000000X0oooo0`0000070?oo
o`800000A@3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`0l0?oo
o`@00000H03oool009d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0800000003
0?ooo`000000oooo00@0oooo1000000f0?ooo`8000002@3oool3000000P0oooo0P0000160?ooo`03
0000003oool0oooo00D0oooo0`0000020?ooo`030000003oool0oooo03l0oooo1000001N0?ooo`00
Y@3oool00`000000oooo0?ooo`0:000003l0oooo0P0000060?ooo`H00000203oool2000009H0oooo
1000001M0?ooo`00X`3oool2000000<0oooo00<000000?ooo`3oool0103oool6000003d0oooo00<0
00000?ooo`3oool01P3oool2000000X0oooo00<000000?ooo`3oool0U`3oool4000005/0oooo002O
0?ooo`D000001@3oool00`000000oooo0?ooo`030?ooo`T00000>P3oool2000000T0oooo00<00000
0?ooo`3oool01P3oool2000009X0oooo1000001J0?ooo`00WP3oool2000000X0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`000000oooo00L00000>03oool00`000000oooo0?ooo`07
0?ooo`8000001`3oool00`000000oooo0?ooo`2K0?ooo`@00000F03oool009h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`@000000`3oool00`000000oooo0?ooo`020?oo
o`H00000=`3oool010000000oooo0?ooo`0000050?ooo`8000001P3oool00`000000oooo0?ooo`2M
0?ooo`D00000EP3oool009h0oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool6000003D0oooo00@000000?ooo`3oool000000`3oool3000000D0oooo00<00000
0?ooo`3oool0X03oool4000005D0oooo002O0?ooo`800000103oool2000000`0oooo00<000000?oo
o`3oool01P3oool7000003<0oooo00<000000?ooo`3oool01@0000050?ooo`030000003oool0oooo
0:<0oooo1000001C0?ooo`00X@3oool5000000d0oooo00<000000?ooo`3oool02@3oool600000>D0
oooo1000001B0?ooo`00`P3oool600000>@0oooo1000001@0?ooo`00a03oool700000>80oooo1000
001?0?ooo`00a`3oool700000>40oooo1000001=0?ooo`00bP3oool600000>00oooo1000001<0?oo
o`00c@3oool600000=l0oooo1000001:0?ooo`00c`3oool700000=d0oooo100000190?ooo`00dP3o
ool600000=d0oooo100000170?ooo`00e@3oool600000=/0oooo100000160?ooo`00e`3oool70000
0=X0oooo100000140?ooo`00fP3oool700000=P0oooo100000130?ooo`00g@3oool600000=P0oooo
100000110?ooo`00h03oool600000=H0oooo1@00000o0?ooo`00hP3oool700000=D0oooo1000000n
0?ooo`00i@3oool600000=D0oooo1000000l0?ooo`00j03oool600000=<0oooo1000000k0?ooo`00
jP3oool700000=80oooo1000000i0?ooo`00k@3oool700000=00oooo1000000h0?ooo`00l03ooooI
000003L0oooo003c0?ooomH00000=`3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`8P3`l?000`000000l?3`0?3`l00:
0?3`l0030000003`l?00l?3`00l0l?3`1000000K0?ooo`030000003oool0oooo00<0oooo10000000
0`3oool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000050?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`12
0?ooo`005`3oool600000?l0l?3`7`3`l?000`000000l?3`0?3`l00<0?3`l0030000003`l?00l?3`
0100l?3`1000000I0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`006P3oool60000
0?l0l?3`6`3`l?000`000000l?3`0?3`l00>0?3`l0030000003`l?00l?3`0100l?3`1000000H0?oo
o`030000003oool0oooo00X0oooo0`0000040?ooo`030000003oool00000008000001@3oool30000
0080oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`020?ooo`@00000A@3oool001`0oooo1`00003o0?3`l1L0l?3`00<000000?3`
l03`l?000P3`l?06000000P0l?3`00<000000?3`l03`l?004@3`l?04000001H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05l0oooo000O0?ooo`H0
0000o`3`l?0D0?3`l0800000103`l?03000000<0l?3`00<000000?3`l03`l?001@3`l?02000001<0
l?3`1000000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1O0?ooo`008P3oool600000?l0l?3`4@3`l?000`000000l?3`0?3`l0090?3`l0800000
1`3`l?000`000000l?3`0?3`l00C0?3`l0@000005@3oool600000300oooo00<000000?ooo`3oool0
B`3oool002@0oooo1`00003o0?3`l0d0l?3`0P00000<0?3`l08000001P3`l?02000001D0l?3`1000
002H0?ooo`009`3oool600000:L0l?3`1@00o`0:0?3`l1000?l02@3`l?0<003o01L0l?3`0`00o`0E
0?3`l0800000303`l?02000000H0l?3`0P00000G0?3`l0<00000U`3oool002X0oooo1P00002M0?3`
l0`00?l02P3`l?0@003o00T0l?3`3`00o`0D0?3`l0D00?l04`3`l?02000000`0l?3`0P0000060?3`
l0800000603`l?04000009D0oooo000/0?ooo`H00000A@3`l?000`000000l?3`0?3`l00:0?3`l003
0000003`l?00l?3`03L0l?3`1000o`070?3`l0`00?l0<P3`l?06003o0140l?3`1`00o`0B0?3`l080
00002`3`l?03000000H0l?3`0P00000I0?3`l0@00000U03oool002l0oooo1P0000110?3`l0030000
003`l?00l?3`00`0l?3`00<000000?3`l03`l?00<@3`l?09003o00L0l?3`1@00o`0l0?3`l0<00?l0
2@3`l?0A003o0100l?3`0P00000;0?3`l0<000001P3`l?02000001/0l?3`1000002B0?ooo`00<@3o
ool7000003d0l?3`00<000000?3`l03`l?003P3`l?000`000000l?3`0?3`l00[0?3`l0/00?l0E`3`
l?0C003o00h0l?3`0P0000090?3`l0@000001`3`l?02000001`0l?3`1000002A0?ooo`00=03oool6
000003X0l?3`00<000000?3`l03`l?00103`l?06000000H0l?3`00<000000?3`l03`l?009`3`l?09
003o06<0l?3`3@00o`0>0?3`l0030000003`l?00l?3`00@0l?3`1P0000080?3`l0030000003`l?00
l?3`01d0l?3`1000002?0?ooo`00=`3oool6000003H0l?3`0P0000080?3`l0800000203`l?020000
02P0l?3`1000o`1X0?3`l0l00?l0303`l?02000000D0l?3`100000090?3`l0800000803`l?040000
08h0oooo000i0?ooo`H00000=03`l?000`000000l?3`0?3`l0070?3`l08000002@3`l?000`000000
l?3`0?3`l00I0?3`l0@00?l0M03`l?0B003o00/0l?3`00<000000?3`l03`l?000`3`l?02000000/0
l?3`00<000000?3`l03`l?008@3`l?04000008`0oooo000l0?ooo`H00000<03`l?02000000T0l?3`
0P0000090?3`l08000005P3`l?08003o07@0l?3`4`00o`0;0?3`l0030000003`l?00l?3`00<0l?3`
00<000000?3`l03`l?00203`l?000`000000l?3`0?3`l00S0?3`l0@00000R`3oool003h0oooo1`00
000]0?3`l08000002@3`l?02000000T0l?3`0P0000090?3`l0D000001P3`l?07003o07L0l?3`5000
o`0;0?3`l0030000003`l?00l?3`0080l?3`1P0000040?3`l0030000003`l?00l?3`02H0l?3`1000
00290?ooo`00@@3oool6000002/0l?3`0P0000090?3`l08000002@3`l?02000000L0l?3`2@000004
0?3`l0<00?l0N`3`l?0D003o00`0l?3`00<000000?3`l03`l?000P3`l?0600000080l?3`00<00000
0?3`l03`l?00:03`l?04000008P0oooo00140?ooo`H00000:03`l?02000000T0l?3`0P0000090?3`
l08000001P3`l?0;00000=/0l?3`100000260?ooo`00AP3oool7000002D0l?3`0P0000090?3`l080
00002@3`l?02000000H0l?3`2`00003L0?3`l0@00000Q@3oool004T0oooo1P00000S0?3`l0800000
2@3`l?02000000T0l?3`0P0000060?3`l0/00000W03`l?05000003d0l?3`100000230?ooo`00C03o
ool600000240l?3`00<000000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?001P3`
l?09000009/0l?3`2@00000l0?3`l0@00000PP3oool004h0oooo1P00000O0?3`l0800000203`l?02
000000P0l?3`0P00000:0?3`l0D00000W@3`l?09000003h0l?3`100000200?ooo`00D@3oool60000
01d0l?3`00<000000?3`l03`l?001P3`l?02000000P0l?3`00<000000?3`l03`l?00ZP3`l?0;0000
03h0l?3`1000001o0?ooo`00D`3oool7000001/0l?3`00<000000?3`l03`l?001@3`l?02000000L0
l?3`00<000000?3`l03`l?00Z`3`l?0;00000400l?3`1000001m0?ooo`00EP3oool6000001X0l?3`
00<000000?3`l03`l?000P3`l?04000000H0l?3`00<000000?3`l03`l?00Y03`l?040000o`@0l?3`
2`0000110?3`l0@00000O03oool005T0oooo1P00000H0?3`l0030000003`l?00l?3`00<0l?3`0P00
00050?3`l0030000003`l?00l?3`0:00l?3`2@000?l50?3`l0T00000A03`l?04000007X0oooo001K
0?ooo`L00000`@3`l?0<0000o`H0l?3`2@0000150?3`l0@00000N@3oool005h0oooo1P00002j0?3`
l100003o2@3`l?05000004T0l?3`1000001g0?ooo`00H@3oool600000;D0l?3`4@000?mI0?3`l0@0
0000MP3oool006<0oooo1P00002c0?3`l100003oG03`l?04000007@0oooo001V0?ooo`H00000/03`
l?0?0000oeh0l?3`1000001c0?ooo`00J03oool700000:h0l?3`3@000?mQ0?3`l0@00000L@3oool0
06/0oooo1P00002]0?3`l0/0003oH`3`l?0400000700oooo001^0?ooo`H00000Y`3`l?0=0000ofH0
l?3`1000001^0?ooo`00L03oool700000:40l?3`3`000?mX0?3`l0@00000K@3oool007<0oooo1P00
001^0?3`l0D00000:@3`l?070000o`<0l?3`1`000?m[0?3`l0@00000J`3oool007H0oooo1P00001Y
0?3`l0T000008`3`l?080000o`L0l?3`1@000?m]0?3`l0@00000JP3oool007P0oooo1P00000C0?3`
l0800000>@3`l?000`000000l?3`0?3`l00:0?3`l0030000003`l?00l?3`00T0l?3`0P0000050?oo
o`800000803`l?080000o`X0l?3`10000?lG0?3`l0800000E`3`l?04000006P0oooo001k0?ooo`H0
0000403`l?02000003P0l?3`00<000000?3`l03`l?00303`l?000`000000l?3`0?3`l0070?3`l080
00001`3oool2000001`0l?3`1`000?l?0?3`l080003o603`l?02000005P0l?3`1000001W0?ooo`00
O@3oool7000000d0l?3`0P00000g0?3`l0030000003`l?00l?3`00h0l?3`00<000000?3`l03`l?00
1P3`l?02000000L0oooo0P00000F0?3`l0X0003o;03`l?02000005X0l?3`1000001U0?ooo`00P03o
ool6000000/0l?3`0P00000f0?3`l0030000003`l?00l?3`00P0l?3`0P0000060?3`l0030000003`
l?00l?3`00D0l?3`0P0000070?ooo`8000003P3`l?0?0000obl0l?3`0P00001K0?3`l0@00000I03o
ool008<0oooo1P0000080?3`l0800000=@3`l?02000000X0l?3`0P0000060?3`l08000001`3`l?02
000000D0oooo0P0000070?3`l140003o=@3`l?02000005d0l?3`1000001R0?ooo`00Q@3oool70000
00D0l?3`0P00000e0?3`l0030000003`l?00l?3`00T0l?3`0P0000070?3`l0030000003`l?00l?3`
00D0l?3`2@0000030?3`l0d0003o?@3`l?02000005h0l?3`1000001Q0?ooo`00R03oool6000000<0
l?3`0P00000d0?3`l08000002`3`l?02000000L0l?3`0P0000080?3`l0D000001@3`l?050000odD0
l?3`0P00001P0?3`l0@00000G`3oool008/0oooo2000000d0?3`l0800000103`l?0;000000D0l?3`
0P00001L0?3`l0800000H@3`l?04000005h0oooo002=0?ooo`H00000=03`l?02000000@0l?3`00<0
00000?3`l03`l?00103`l?02000000L0l?3`0P00000l0?3`l0@00000703`l?02000006<0l?3`1000
001L0?ooo`00T03oool600000340l?3`0P0000050?3`l0030000003`l?00l?3`00<0l?3`0P000007
0?3`l0800000?03`l?001@000000l?3`0?3`l03`l?00000001/0l?3`0P00001T0?3`l0@00000F`3o
ool00940oooo2000000^0?3`l08000001P3`l?000`000000l?3`0?3`l0020?3`l08000001`3`l?02
00000440l?3`00<000000?3`l03`l?00603`l?02000006H0l?3`1000001I0?ooo`00T@3oool20000
0080oooo1P00000/0?3`l08000001`3`l?0010000000l?3`0?3`l03`l?02000000L0l?3`0P00000n
0?3`l0@000006P3`l?02000006L0l?3`1000001H0?ooo`00T@3oool2000000D0oooo1P00000Z0?3`
l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?000P0000070?3`l0030000003`l?00l?3`
03`0l?3`0P0000020?3`l08000006@3`l?02000006T0l?3`1000001F0?ooo`00T@3oool2000000L0
oooo1P00000X0?3`l08000001`3`l?000`000000l?3`0?3`l002000000H0l?3`0P00000n0?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?005`3`l?02000006X0l?3`1000001E0?ooo`00
T@3oool2000000X0oooo1P00000V0?3`l0030000003`l?00l?3`00H0l?3`00@000000?3`l0000000
00001P3`l?000`000000l?3`0?3`l00X0?3`l08000001@3`l?04000000050?3`l000000000000?3`
l00000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`01L0l?3`0P00001/0?3`
l0@00000D`3oool00940oooo0P00000<0?ooo`L00000903`l?000`000000l?3`0?3`l0060?3`l0<0
00001@3`l?000`000000l?3`0?3`l00Y0?3`l0800000103`l?02000000<0l?3`0P0000020?3`l003
0000003`l?00l?3`00@0l?3`00@000000?3`l03`l?00l?3`0P00000H0?3`l0800000K@3`l?040000
0580oooo002A0?ooo`8000003`3oool6000002<0l?3`00<000000?3`l03`l?001P3`l?02000000@0
l?3`00<000000?3`l03`l?00:@3`l?0010000000l?3`0?3`l00000040?3`l0030000003`l?00l?3`
0080l?3`0P0000020?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l00F0?3`l0800000K`3`l?0400000500oooo002A0?ooo`8000004P3oool600000240
l?3`00<000000?3`l03`l?001@3`l?02000000<0l?3`00<000000?3`l03`l?00:P3`l?000`000000
l?3`0?3`l002000000<0l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000060?3`
l0030000003`l?00l?3`00800000603`l?0200000700l?3`1000001?0?ooo`00T@3oool2000001@0
oooo1`00001H0?3`l0050000003`l?00l?3`0?3`l0000000103`l?0600000080l?3`00<000000?3`
l03`l?001@3`l?03000000030?3`l0000000l?3`01H0l?3`0P00001b0?3`l0@00000C@3oool00940
oooo0P00000G0?ooo`H00000EP3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0
l?3`00@000000?3`l03`l?0000008`3`l?02000007<0l?3`1000001<0?ooo`00T@3oool2000001X0
oooo1P00001C0?3`l0030000003`l?00l?3`0080l?3`00D000000?3`l03`l?00l?3`000000050?3`
l0040000003`l?00l?3`00000280l?3`0P00001e0?3`l0@00000BP3oool00940oooo0P00000L0?oo
o`H00000D@3`l?000`000000l?3`0?3`l0030?3`l0040000003`l?00l?3`000000D0l?3`00<00000
0?3`l03`l?000P00000Q0?3`l0800000MP3`l?04000004T0oooo002A0?ooo`8000007`3oool60000
02h0l?3`0P000?lN0?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`l?00l?3`1@000003
0?3`l0040000003`l?000000000001l0l?3`0P00001h0?3`l0@00000A`3oool00940oooo0P00000Q
0?ooo`L00000:`3`l?020000oah0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00[
0?3`l0800000N@3`l?04000004H0oooo002A0?ooo`800000903oool6000002T0l?3`0P000?lN0?3`
l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?00:P3`l?02000007/0l?3`100000140?oo
o`00T@3oool2000002L0oooo1P00000U0?3`l0@0003o7@3`l?000`000000l?3`0?3`l0050?3`l003
0000003`l?00l?3`02X0l?3`0P00001l0?3`l0@00000@`3oool00940oooo0P00000Y0?ooo`L00000
8P3`l?040000oe80l?3`0P00001n0?3`l0<00000@P3oool00940oooo0P00000/0?ooo`H00000803`
l?040000oe80l?3`0P00001o0?3`l0@00000@03oool00940oooo0P00000_0?ooo`H00000703`l?05
0000oe80l?3`0P0000200?3`l0@00000?`3oool00940oooo0P00000a0?ooo`H000006P3`l?060000
oe40l?3`0P0000220?3`l0@00000?@3oool00940oooo0P00000d0?ooo`H000005`3`l?060000oe40
l?3`0P0000230?3`l0@00000?03oool00940oooo0P00000f0?ooo`L000004`3`l?070000oe40l?3`
0P0000250?3`l0@00000>P3oool00940oooo0P00000i0?ooo`H000004@3`l?070000oe40l?3`0P00
00260?3`l0@00000>@3oool00940oooo0P00000l0?ooo`H000003P3`l?070000oe40l?3`0P000028
0?3`l0@00000=`3oool00940oooo0P00000n0?ooo`L000002`3`l?080000oe00l?3`0P0000290?3`
l0@00000=P3oool00940oooo0P0000110?ooo`H00000203`l?090000oe00l?3`0P00002;0?3`l0@0
0000=03oool00940oooo0P0000140?ooo`H000001@3`l?090000oe00l?3`0P00002<0?3`l0@00000
<`3oool00940oooo0P0000160?ooo`H000000`3`l?090000oe00l?3`0P00002>0?3`l0@00000<@3o
ool00940oooo0P0000190?ooo`D000002`000?m?0?3`l0800000S`3`l?0400000300oooo002A0?oo
o`800000B`3oool3000000/0003oC`3`l?0200000940l?3`1000000^0?ooo`00T@3oool2000004h0
oooo2`000?m?0?3`l0800000TP3`l?04000002d0oooo002A0?ooo`800000D@3oool200000080003o
0P00001A0?3`l0800000U03`l?04000002/0oooo002A0?ooo`800000D`3oool20000o`@00000C`3`
l?02000009D0l?3`1000000Z0?ooo`00T@3oool2000005<0oooo0P000?l00`3oool0000000000004
000004`0l?3`0P00002G0?3`l0@00000:03oool00940oooo0P00001C0?ooo`80003o0`3oool70000
04T0l?3`0P00002H0?3`l0@000009`3oool00940oooo0P00001C0?ooo`80003o1P3oool6000004L0
l?3`0P00002J0?3`l0@000009@3oool00940oooo0P00001C0?ooo`80003o2@3oool6000004@0l?3`
0P00002K0?3`l0@00000903oool00940oooo0P00001C0?ooo`80003o2`3oool700000440l?3`0P00
002M0?3`l0@000008P3oool00940oooo0P00001C0?ooo`80003o3P3oool6000003l0l?3`0P00002N
0?3`l0@000008@3oool00940oooo0P00001C0?ooo`80003o4@3oool6000003`0l?3`0P00002P0?3`
l0@000007`3oool00940oooo0P00001C0?ooo`80003o4`3oool6000003X0l?3`0P00002Q0?3`l0@0
00007P3oool00940oooo0P00001C0?ooo`80003o5P3oool6000003L0l?3`0P00002S0?3`l0@00000
703oool00940oooo0P00001C0?ooo`80003o603oool7000003@0l?3`0P00002T0?3`l0@000006`3o
ool00940oooo0P00001C0?ooo`80003o6`3ooooS000001X0oooo002A0?ooo`800000D`3oool20000
oah0ooooh000000J0?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
oe<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003oD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003oD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000oe<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000?mC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003o=`3oool=000000l0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000?lT0?ooob4000003P3oool200000<<0oooo
002A0?ooo`800000D`3oool20000oa00oooo:000000;0?ooo`@00000303oool200000<<0oooo002A
0?ooo`800000DP3ooolX000001l0oooo1000000;0?ooo`800000``3oool00940oooo0P00000n0?oo
obP00000=@3oool4000000T0oooo0P0000330?ooo`00T@3oool2000002/0oooo:00000020000odL0
oooo100000080?ooo`800000``3oool00940oooo0P00000G0?ooobP00000503oool20000odT0oooo
100000060?ooo`800000``3oool00940oooo0P0000030?ooobT000009`3oool20000odX0oooo1@00
00040?ooo`800000``3oool008<0oooo:000000k0?ooo`80003oC03oool4000000<0oooo0P000033
0?ooo`00K`3ooolX000004l0oooo0P000?m>0?ooo`@0000000<0oooo000000000000``3oool005`0
oooo:00000080?ooo`d00000C@3oool20000odl0oooo1P0000330?ooo`00B03ooolX000001`0oooo
3@00001=0?ooo`80003oD@3oool400000<<0oooo000e0?ooobP00000;`3oool=000004d0oooo0P00
0?mB0?ooo`@00000`P3oool00240oooo:00000130?ooo``00000CP3oool20000oe<0oooo1@000030
0?ooo`003P3ooolX000005L0oooo2`00001>0?ooo`80003oD`3oool600000;l0oooo00040?oooah0
0000J`3oool;000004h0oooo0P000?mC0?ooo`8000000P3oool400000;d0oooo00040?ooo`/00000
OP3oool:000004l0oooo0P000?mC0?ooo`8000000`3oool400000;`0oooo00060?ooo`L00000P@3o
ool9000004l0oooo0P000?mC0?ooo`8000001@3oool400000;X0oooo00090?ooo`L00000OP3oool9
000004l0oooo0P000?mC0?ooo`8000001P3oool400000;T0oooo000<0?ooo`H00000O03oool80000
0500oooo0P000?mC0?ooo`800000203oool400000;L0oooo000?0?ooo`H00000NP3oool700000500
oooo0P000?mC0?ooo`8000002@3oool400000;H0oooo000A0?ooo`L00000M`3oool600000540oooo
0P000?mC0?ooo`8000002`3oool400000;@0oooo000D0?ooo`H00000M@3oool600000540oooo0P00
0?mC0?ooo`800000303oool500000;80oooo000G0?ooo`H00000L`3oool500000540oooo0P000?mC
0?ooo`8000003P3oool400000;40oooo000I0?ooo`L00000L03oool400000580oooo0P000?mC0?oo
o`800000403oool400000:l0oooo000L0?ooo`L00000K@3oool400000580oooo0P000?mC0?ooo`80
00004@3oool400000:h0oooo000O0?ooo`H00000K03oool300000580oooo0P000?mC0?ooo`800000
4`3oool4000002`0oooo1`0000050?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`<0000000<0oooo0000000000001@3oool01@000000oooo0?ooo`3oool00000
00D0oooo0`0000040?ooo`<0000000D0oooo0000003oool0oooo000000050?ooo`@00000>03oool0
0280oooo1P00001Y0?ooo`800000D`3oool20000oe<0oooo0P00000D0?ooo`@00000:`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0e0?ooo`00903oool700000;/0oooo0P000?m=0?ooo``000004P3oool4000002T0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo
000W0?ooo`H00000^@3oool20000odd0oooo3000000C0?ooo`@00000:03oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`000007
0?ooo`800000>03oool002X0oooo1P00002f0?ooo`80003oC@3oool<000001D0oooo1000000V0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`0000000`3oool000000?ooo`030?oo
o`030000003oool0oooo00<0oooo0`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?oo
o`0000050?ooo`800000>P3oool002`0oooo1`00002c0?ooo`80003oCP3oool;000001H0oooo1000
000U0?ooo`L000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo03X0oooo000_0?ooo`L00000@@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo4@00o`0B0?ooo`80003oCP3oool:0000
01T0oooo1000000S0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo008000000`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool00380oooo1P00000n0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool^003o04d0oooo2P00000J0?ooo`@0
00008P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`03
0000003oool0000000800000103oool4000000@0oooo00<000000?ooo`3oool00`3oool2000000D0
oooo0`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`020000
0080oooo1000000h0?ooo`00=@3oool6000003X0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0Y0?oooa800?l03`3ooolT003o0400oooo2@00000L0?ooo`@00000803oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool003L0oooo
1`00000f0?ooo`030000003oool0oooo0080oooo200000060?ooo`030000003oool0oooo0200oooo
4P00o`0Z0?ooo`80003o5`00o`0h0?ooo`T000007@3oool4000001l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo000j0?ooo`H00000<`3o
ool2000000D0oooo1`0000060?ooo`8000006@3ooolA003o03<0oooo0P000?l>0?oooa400?l0<03o
ool800000200oooo1000000M0?ooo`L000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo05<0oooo000m0?ooo`H00000<03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3ooolA000000030?ooo`00
o`000?l000/00?l0>`3oool20000oaH0oooo4000o`0A0?ooo`800?l05`3oool700000240oooo1@00
002K0?ooo`00?`3oool7000002`0oooo0P0000080?ooo`030000003oool0oooo00T0oooo0P000002
0?oooa40000000<0oooo003o0000o`000`00o`130?ooo`80003o7P3oool=003o00`0oooo0`00o`0F
0?ooo`L000008`3oool4000009X0oooo00120?ooo`L00000:@3oool2000000P0oooo0P00000:0?oo
o`8000000P3ooolA000004T0oooo0P000?lU0?ooo`/00?l01P3oool5003o01D0oooo1`00000U0?oo
o`@00000V03oool004D0oooo1P00000W0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`80
00000P3ooolA000004T0oooo0P000?lZ0?ooo`/00?l000<0oooo003o0000o`001000o`0E0?ooo`H0
00009P3oool4000009L0oooo00180?ooo`H00000903oool2000000X0oooo00<000000?ooo`3oool0
1`3oool200000080oooo4@0000190?ooo`80003o;`3oool>003o01@0oooo1@00000Y0?ooo`@00000
U@3oool004X0oooo1`00000Q0?ooo`8000002P3oool2000000P0oooo0P0000020?oooa400000B@3o
ool20000oc@0oooo2P00o`0C0?ooo`D00000:P3oool4000009@0oooo001=0?ooo`H000007`3oool2
000000/0oooo00<000000?ooo`3oool01P3oool200000080oooo4@0000190?ooo`80003o=@3oool:
003o01<0oooo1000000/0?ooo`@00000TP3oool00500oooo1P00000M0?ooo`030000003oool0oooo
00T0oooo0P0000070?ooo`040000003oool0oooo0?oooa400000B@3oool20000ocD0oooo2`00o`0B
0?ooo`@00000;@3oool4000002@0oooo00<000000?ooo`3oool01`3oool3000000@0oooo0`000000
103oool000000000003oool300000080oooo0`0000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo00@0oooo0`0000040?ooo`@000001`3oool3000000050?ooo`00000000000?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool0603oool00580oooo1`00
000J0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001P3oool2000000<0oooo4@00
00190?ooo`80003o=03oool=003o0140oooo0`00000`0?ooo`@000008P3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool200000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`8000006@3oool005D0oooo1`00000H0?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`020?oooa40000000@0
oooo0000o`000?l0003oA@3oool20000oc@0oooo3P00o`0A0?ooo`800000<@3oool400000240oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00F03oool6000001L0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool00`3o
oolA000000030?ooo`000?l0003o0080003oA03oool20000oc@0oooo3`00o`150?ooo`@000007`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0`0000001@3oool000000?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0203oool2000000L0oooo0`0000001@3oool000000?ooo`3oool00000
00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00F`3oool60000
01D0oooo00@000000?ooo`3oool0oooo1P0000050?ooo`030000003oool0oooo00@0oooo4@000003
0?ooo`@0003o@P3oool20000ocL0oooo3@00o`150?ooo`@000007P3oool00`000000oooo0?ooo`05
0?ooo`L00000103oool300000080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool700000080oooo0P00000;0?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool005d0oooo
1`00000C0?ooo`040000003oool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`050?oooa40
0000103oool50000od00oooo0P000?lk0?ooo`X00?l0AP3oool4000001`0oooo1P0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00H03o
ool6000003d0oooo10000?n00?ooo`L00?l0AP3oool4000001/0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`8000006@3oool006<0oooo1P00000l0?ooo`@0003oPP3oool3
003o04P0oooo1000000I0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`@000000P3oool4
000000030?ooo`000000oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo
0`0000040?ooo`@000001`3oool4000000<0oooo00<000000?ooo`0000000P0000050?ooo`<00000
00<0oooo0000003oool0603oool006D0oooo1`00000j0?ooo`D0003oc03oool5000001L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001X
0?ooo`L00000>@3oool40000old0oooo1000000F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0G0?ooo`00J`3oool6000003T0oooo1@000?o<0?oo
o`@00000503oool7000004`0oooo00<000000?ooo`3oool05`3oool006h0oooo1P00000g0?ooo`L0
003obP3oool400000800oooo001`0?ooo`L00000=`3oool70000o``0oooo0`000?lI0?oooa400000
T03oool4000007h0oooo001c0?ooo`H00000>03oool70000o`T0oooo1@000?lG0?oooa400000T@3o
ool4000007d0oooo001f0?ooo`H00000>03oool70000o`H0oooo1`000?lE0?ooo`8000003@3oool2
000004@0oooo3P0000110?ooo`@00000N`3oool007P0oooo1`00000h0?ooo`L0003o0P3oool;0000
oa80oooo0P00000=0?ooo`800000A03oool>00000480oooo1000001j0?ooo`00N`3oool7000003P0
oooo4`000?l@0?ooo`8000003@3oool2000004@0oooo3P00000?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool09@3oool4000007P0oooo001n0?ooo`H00000>@3ooolB0000o`h0oooo
0P00000=0?ooo`800000A03oool>000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0U0?ooo`@00000M`3oool00840oooo1P00000i0?oooa40003o303oool2000000d0oooo0P00
00140?ooo`h000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo1000
001>0?ooo`8000001@3oool00`000000oooo0?ooo`0M0?ooo`00P`3oool7000003H0oooo4P000?l;
0?ooo`8000003@3oool2000004@0oooo3P00000<0?ooo`030000003oool0oooo00D0oooo10000007
0?ooo`030000003oool0oooo02H0oooo1000001?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool07@3oool008H0oooo1P00000d0?oooa80003o2`3oool2000000d0oooo0P0000140?oo
o`h000002`3oool2000000H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`800000:@3oool4
000004h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00R@3oool600000340oooo3@000?l@
0?ooo`8000003@3oool2000004@0oooo3P00000;0?ooo`030000003oool0oooo00@0oooo0P000004
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:03oool4000001/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`000004
0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000030?ooo`030000003oool0oooo0080oooo
0`00000@0?ooo`00R`3oool7000002h0oooo1@000?lH0?ooo`8000003@3oool2000004@0oooo3P00
000:0?ooo`8000001@3oool2000000D0oooo0P0000060?ooo`800000:`3oool4000001T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3oool2000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000l0oooo002>0?ooo`L000007P3o
ool00`000000oooo0?ooo`0W0?oooa400000203oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02`0oooo3P00000:0?ooo`8000001@3oool2000000D0oooo0P0000060?ooo`800000;03o
ool5000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`00T@3oool6000001`0oooo00<000000?ooo`3oool09`3ooolA000000L0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0[0?ooo`h000002P3oool2000000D0oooo0P0000050?ooo`80
00001P3oool2000002h0oooo1000000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0oooo0180oooo002D
0?ooo`H000006P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0:P3oool>000000X0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0P00000`
0?ooo`@00000503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0180oooo002F0?ooo`L000005`3oool010000000
oooo00000000000k0?ooo`040000003oool0oooo0?ooo`H000002@3oool00`000000oooo0?ooo`0Y
0?ooo`h000002P3oool2000000D0oooo0`0000030?ooo`8000001`3oool200000340oooo1000000C
0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo002I0?ooo`H000005P3oool00`00
0000oooo0?ooo`02000003P0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`060?oo
o`800000:P3oool>000000X0oooo0P0000050?ooo`80000000<0oooo0000000000000P0000080?oo
o`800000<`3oool400000140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00W03oool6000001<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00P0oooo0P0000080?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03<0oooo1000000@0?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool000000?ooo`03000000D0oooo0`0000030?ooo`030000003oool00000008000001@3oool3
000000<0oooo100000000`3oool000000?ooo`040?ooo`80000000@0oooo00000000000000000`3o
ool00`000000oooo0?ooo`020?ooo`@000003`3oool009h0oooo1`00000@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0=03oool2000000/0oooo0P0000070?ooo`800000@P3oool2
000000D0oooo0P00000;0?ooo`800000=`3oool4000000h0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo002Q0?ooo`L000003P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P00000;0?ooo`8000001`3oool2
000004<0oooo00<000000?ooo`3oool0103oool2000000X0oooo00<000000?ooo`3oool0=`3oool4
000000d0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000P0?ooo`030000003o
ool0oooo02P0oooo002T0?ooo`H00000303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03<0oooo0P00000;0?ooo`8000001`3oool2000004@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo1000000;0?ooo`L000000`3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01D0oooo002N0?ooo`D00000103oool60000
00<0oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool0=03oool20000
00X0oooo0`0000070?ooo`800000A@3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`00
0000oooo0?ooo`0l0?ooo`@00000H03oool009d0oooo0P0000040?ooo`8000000`3oool9000000H0
oooo1000000f0?ooo`8000002@3oool3000000P0oooo0P0000160?ooo`030000003oool0oooo00D0
oooo0`0000020?ooo`030000003oool0oooo03l0oooo1000001N0?ooo`00W@3oool00`000000oooo
0?ooo`040?ooo`8000000P3oool010000000oooo0?ooo`3oool6000003l0oooo0P0000060?ooo`H0
0000203oool2000009H0oooo1000001M0?ooo`00W@3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000H0oooo1P00000m0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`03
0000003oool0oooo09L0oooo1000001K0?ooo`00Y@3oool00`000000oooo0?ooo`08000000030?oo
o`000000000000D00000>P3oool2000000T0oooo00<000000?ooo`3oool01P3oool2000009X0oooo
1000001J0?ooo`00X`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00020?ooo`L00000>03oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?oo
o`2K0?ooo`@00000F03oool009l0oooo1@0000050?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool000000?ooo`030?ooo`H00000=`3oool010000000oooo0?ooo`0000050?ooo`8000001P3o
ool00`000000oooo0?ooo`2M0?ooo`D00000EP3oool009h0oooo0P00000:0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001`3oool6000003D0oooo00@000000?ooo`3oool00000
0`3oool3000000D0oooo00<000000?ooo`3oool0X03oool4000005D0oooo002N0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<000000?ooo`3oool01`3o
ool7000003<0oooo00<000000?ooo`3oool01@0000050?ooo`030000003oool0oooo0:<0oooo1000
001C0?ooo`00WP3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`H00000i@3oool400000580oooo002O0?ooo`800000103oool2000000`0oooo00<000000?oo
o`3oool0303oool600000>@0oooo1000001@0?ooo`00X@3oool5000000d0oooo00<000000?ooo`3o
ool03P3oool700000>80oooo1000001?0?ooo`00a`3oool700000>40oooo1000001=0?ooo`00bP3o
ool600000>00oooo1000001<0?ooo`00c@3oool600000=l0oooo1000001:0?ooo`00c`3oool70000
0=d0oooo100000190?ooo`00dP3oool600000=d0oooo100000170?ooo`00e@3oool600000=/0oooo
100000160?ooo`00e`3oool700000=X0oooo100000140?ooo`00fP3oool700000=P0oooo10000013
0?ooo`00g@3oool600000=P0oooo100000110?ooo`00h03oool600000=H0oooo1@00000o0?ooo`00
hP3oool700000=D0oooo1000000n0?ooo`00i@3oool600000=D0oooo1000000l0?ooo`00j03oool6
00000=<0oooo1000000k0?ooo`00jP3oool700000=80oooo1000000i0?ooo`00k@3oool700000=00
oooo1000000h0?ooo`00l03ooooI000003L0oooo003c0?ooomH00000=`3oool00?l0ooooo`3oool2
0?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`<00000
103oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00001L0?ooo`00o`3ooole
0?ooo``00000:@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo1`0000020?ooo`800000GP3oool00?l0
oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000001P0?ooo`00o`3ooolA0?ooobD000002P3`l?0400000240oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3`l?04000001l0oooo
00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000103oool4000005`0
oooo003]0?ooob@00000<@3`l?04000001d0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo07L0oooo003K0?ooob@00000A03`l?04000001`0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo07L0
oooo00390?ooobD00000E`3`l?04000001/0oooo1P00002F0?ooo`00]`3ooolU000006X0l?3`1000
002f0?ooo`00Y@3ooolU000007h0l?3`1000002d0?ooo`00T`3ooolU00000940l?3`1000002c0?oo
o`00P@3ooolU00000:D0l?3`1000002a0?ooo`00K`3ooolU00000;P0l?3`1000002`0?ooo`00G@3o
oolU00000<`0l?3`1000002^0?ooo`00C03ooolT00000=l0l?3`1000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`1D0?ooo`00>P3ooolT00000?<0l?3`1000001?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0E03oool002P0oooo9@00003o0?3`l0H0l?3`1000001?0?ooo`05
0000003oool0oooo0?ooo`000000EP3oool001H0oooo9@00003o0?3`l1X0l?3`1000000T0?ooo`D0
00000P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`<000000`3oool3000000@0oooo00H000000?ooo`3oool0oooo0000003o
ool3000000@0oooo00<000000?ooo`3oool00P3oool3000004H0oooo000=0?oooa`00000o`3`l?0]
0?3`l0@000008P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000A@3oool0
00d0oooo2P00003o0?3`l440l?3`1000000O0?ooo`030000003oool0oooo00D0oooo0P0000000`3o
ool000000?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@P3oool000l0oooo1`00003o0?3`l4<0l?3`1000000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`180?ooo`004P3oool600000?l0l?3`
@`3`l?04000001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000600000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`180?ooo`005@3oool600000?l0l?3`@@3`l?04000001/0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000G0?ooo`H00000o`3`l?110?3`l0@000006@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0?3`l1d0l?3`00<000000?3`
l03`l?002P3`l?000`000000l?3`0?3`l00B0?3`l0@00000603oool00`000000oooo0?ooo`0:0?oo
o`<00000103oool00`000000oooo00000002000000D0oooo0`0000020?ooo`@0000000<0oooo0000
003oool0103oool2000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00P3oool4
000004D0oooo000L0?ooo`L00000o`3`l?0I0?3`l0030000003`l?00l?3`00`0l?3`00<000000?3`
l03`l?004`3`l?04000001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05l0oooo000O0?ooo`H00000o`3`l?0F0?3`l0030000003`l?00l?3`00h0
l?3`00<000000?3`l03`l?004`3`l?04000001H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo000R0?ooo`H00000>`3`l?02000000@0l?3`
0P0000030?3`l0800000b@3`l?000`000000l?3`0?3`l0020?3`l0H00000203`l?000`000000l?3`
0?3`l00D0?3`l0@000005@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00
000h0?3`l0800000103`l?02000000<0l?3`0P0000380?3`l0800000103`l?03000000<0l?3`00<0
00000?3`l03`l?001@3`l?02000001H0l?3`1000002H0?ooo`009`3oool600000;H0l?3`4000o`09
0?3`l0`00?l05`3`l?03003o01H0l?3`00<000000?3`l03`l?002@3`l?02000000L0l?3`00<00000
0?3`l03`l?005P3`l?03000009L0oooo000Z0?ooo`H00000/`3`l?0@003o00T0l?3`3`00o`0D0?3`
l0D00?l04`3`l?02000000`0l?3`0P0000060?3`l0800000603`l?04000009D0oooo000/0?ooo`H0
0000S03`l?04003o00L0l?3`4000o`0^0?3`l0H00?l04@3`l?07003o0180l?3`0P00000<0?3`l080
00001P3`l?02000001T0l?3`1000002D0?ooo`00;`3oool6000008@0l?3`2@00o`070?3`l1000?l0
<@3`l?03003o00T0l?3`1000o`040?3`l0T00?l0403`l?02000000`0l?3`0P0000060?3`l0800000
6`3`l?0400000980oooo000a0?ooo`L00000?`3`l?000`000000l?3`0?3`l00:0?3`l0030000003`
l?00l?3`02d0l?3`2`00o`1G0?3`l0L00?l000<0l?3`003o0000o`002@00o`0>0?3`l08000002`3`
l?03000000H0l?3`0P00000L0?3`l0@00000T@3oool003@0oooo1P00000l0?3`l0030000003`l?00
l?3`00`0l?3`00<000000?3`l03`l?00:@3`l?09003o05l0l?3`4@00o`0=0?3`l08000002`3`l?03
000000H0l?3`0P00000N0?3`l0@00000S`3oool003L0oooo1P00000h0?3`l0030000003`l?00l?3`
00h0l?3`00<000000?3`l03`l?00:03`l?04003o06L0l?3`4000o`0;0?3`l08000002@3`l?040000
00L0l?3`0P00000O0?3`l0@00000SP3oool003T0oooo1P00000e0?3`l0030000003`l?00l?3`00@0
l?3`1P0000060?3`l0030000003`l?00l?3`01X0l?3`1000o`1e0?3`l1400?l02P3`l?000`000000
l?3`0?3`l0040?3`l0H00000203`l?000`000000l?3`0?3`l00P0?3`l0@00000S03oool003`0oooo
1P00000a0?3`l0800000203`l?02000000P0l?3`0P00000G0?3`l0P00?l0M03`l?0C003o00T0l?3`
0P0000050?3`l0@000002@3`l?02000002<0l?3`1000002;0?ooo`00?P3oool7000002h0l?3`00<0
00000?3`l03`l?001`3`l?02000000T0l?3`00<000000?3`l03`l?00203`l?05000000H0l?3`1`00
o`1g0?3`l1@00?l02@3`l?000`000000l?3`0?3`l0030?3`l08000002`3`l?000`000000l?3`0?3`
l00T0?3`l0@00000R@3oool00440oooo1P00000[0?3`l08000002@3`l?02000000T0l?3`0P000007
0?3`l0T00000103`l?03003o07/0l?3`5000o`0:0?3`l0030000003`l?00l?3`00<0l?3`00<00000
0?3`l03`l?00203`l?000`000000l?3`0?3`l00V0?3`l0@00000R03oool004@0oooo1P00000X0?3`
l08000002@3`l?02000000T0l?3`0P0000070?3`l0T00000X@3`l?000`000000l?3`0?3`l0020?3`
l0H00000103`l?000`000000l?3`0?3`l00Y0?3`l0@00000QP3oool004H0oooo1`00000U0?3`l080
00002@3`l?02000000T0l?3`0P0000060?3`l0/00000X@3`l?000`000000l?3`0?3`l0020?3`l0H0
00000P3`l?000`000000l?3`0?3`l00[0?3`l0@00000Q@3oool004T0oooo1P00000S0?3`l0800000
2@3`l?02000000T0l?3`0P0000060?3`l0/00000W03`l?05000003d0l?3`100000230?ooo`00C03o
ool600000200l?3`0P0000090?3`l08000002@3`l?02000000H0l?3`2`00002J0?3`l0T00000?03`
l?0400000880oooo001>0?ooo`H000007P3`l?02000000T0l?3`0P0000090?3`l08000001`3`l?09
000009/0l?3`2@00000n0?3`l0@00000P03oool00540oooo1P00000L0?3`l0030000003`l?00l?3`
00L0l?3`0P0000090?3`l0030000003`l?00l?3`00H0l?3`2@00002J0?3`l0/00000?P3`l?040000
07l0oooo001C0?ooo`L000006@3`l?02000000P0l?3`0P0000080?3`l08000002P3`l?05000009`0
l?3`2`0000100?3`l0@00000O@3oool005H0oooo1P00000H0?3`l0030000003`l?00l?3`00H0l?3`
0P0000080?3`l0030000003`l?00l?3`0:X0l?3`2`0000110?3`l0@00000O03oool005T0oooo1P00
000F0?3`l0030000003`l?00l?3`00D0l?3`0P0000070?3`l0030000003`l?00l?3`0:`0l?3`2@00
00140?3`l0@00000NP3oool005/0oooo1`00000D0?3`l0030000003`l?00l?3`0080l?3`10000006
0?3`l0030000003`l?00l?3`0:d0l?3`2@0000150?3`l0@00000N@3oool005h0oooo1P00000C0?3`
l0030000003`l?00l?3`00<0l?3`0P0000050?3`l0030000003`l?00l?3`0;00l?3`1@0000190?3`
l0@00000M`3oool00640oooo1P00003o0?3`l200l?3`1000001f0?ooo`00H`3oool600000?l0l?3`
803`l?04000007@0oooo001V0?ooo`H00000o`3`l?0N0?3`l0@00000L`3oool006P0oooo1`00003o
0?3`l1d0l?3`1000001a0?ooo`00J`3oool600000?l0l?3`703`l?0400000700oooo001^0?ooo`H0
0000j03`l?02000000@0l?3`0P0000030?3`l08000009@3`l?04000006h0oooo001`0?ooo`L00000
i@3`l?02000000@0l?3`0P0000030?3`l08000009P3`l?04000006d0oooo001c0?ooo`H00000o`3`
l?0I0?3`l0@00000J`3oool007H0oooo1P00003o0?3`l1L0l?3`1000001Z0?ooo`00N03oool60000
01<0l?3`0P00002X0?3`l0800000E`3`l?04000006P0oooo001k0?ooo`H00000403`l?0200000:P0
l?3`0P00001H0?3`l0@00000I`3oool007d0oooo1`00000=0?3`l0800000Z03`l?02000005X0l?3`
1000001U0?ooo`00P03oool6000000/0l?3`0P00002X0?3`l0800000F`3`l?04000006@0oooo0023
0?ooo`H00000203`l?0200000:P0l?3`0P00001M0?3`l0@00000HP3oool008D0oooo1`0000050?3`
l0800000Z03`l?02000005h0l?3`1000001Q0?ooo`00R03oool6000000<0l?3`0P00002X0?3`l080
0000H03`l?04000005l0oooo002;0?ooo`P00000Z03`l?0200000640l?3`1000001N0?ooo`00S@3o
ool600000:P0l?3`0P00001S0?3`l0@00000G03oool00900oooo1P00002U0?3`l0800000I03`l?04
000005/0oooo002A0?ooo`P00000XP3`l?02000006H0l?3`1000001I0?ooo`00T@3oool200000080
oooo1P00002P0?3`l0800000I`3`l?04000005P0oooo002A0?ooo`8000001@3oool6000009d0l?3`
0P00001Y0?3`l0@00000EP3oool00940oooo0P0000070?ooo`H00000V`3`l?02000006X0l?3`1000
001E0?ooo`00T@3oool2000000X0oooo1P00002H0?3`l0800000K03`l?04000005<0oooo002A0?oo
o`800000303oool7000009D0l?3`0P00001]0?3`l0@00000DP3oool00940oooo0P00000?0?ooo`H0
0000T`3`l?02000006l0l?3`1000001@0?ooo`00T@3oool200000180oooo1P00002@0?3`l0800000
L03`l?04000004l0oooo002A0?ooo`800000503oool7000008d0l?3`0P00001b0?3`l0@00000C@3o
ool00940oooo0P00000G0?ooo`H00000R`3`l?02000007<0l?3`1000001<0?ooo`00T@3oool20000
01X0oooo1P0000280?3`l0800000M@3`l?04000004X0oooo002A0?ooo`800000703oool6000008H0
l?3`0P00001f0?3`l0@00000B@3oool00940oooo0P00000O0?ooo`H00000P`3`l?02000007P0l?3`
100000170?ooo`00T@3oool200000240oooo1`0000200?3`l0800000N@3`l?04000004H0oooo002A
0?ooo`800000903oool6000007h0l?3`0P00001k0?3`l0@00000A03oool00940oooo0P00000W0?oo
o`H00000N`3`l?02000007`0l?3`100000130?ooo`00T@3oool2000002T0oooo1`00001h0?3`l080
0000OP3`l?0300000480oooo002A0?ooo`800000;03oool6000007H0l?3`0P00001o0?3`l0@00000
@03oool00940oooo0P00000_0?ooo`H00000L`3`l?0200000800l?3`1000000o0?ooo`00T@3oool2
00000340oooo1P00001a0?3`l0800000PP3`l?04000003d0oooo002A0?ooo`800000=03oool60000
06h0l?3`0P0000230?3`l0@00000?03oool00940oooo0P00000f0?ooo`L00000J`3`l?02000008D0
l?3`1000000j0?ooo`00T@3oool2000003T0oooo1P00001Y0?3`l0800000QP3`l?04000003T0oooo
002A0?ooo`800000?03oool6000006H0l?3`0P0000280?3`l0@00000=`3oool00940oooo0P00000n
0?ooo`L00000H`3`l?02000008T0l?3`1000000f0?ooo`00T@3oool200000440oooo1P00001Q0?3`
l0800000R`3`l?04000003@0oooo002A0?ooo`800000A03oool6000005h0l?3`0P00002<0?3`l0@0
0000<`3oool00940oooo0P0000160?ooo`H00000G03`l?02000008h0l?3`1000000a0?ooo`00T@3o
ool2000004T0oooo1P00001I0?3`l0800000S`3`l?0400000300oooo002A0?ooo`800000B`3oool7
000005H0l?3`0P00002A0?3`l0@00000;P3oool00940oooo0P00001>0?ooo`H00000E03`l?020000
0980l?3`1000000]0?ooo`00T@3oool200000540oooo1P00001A0?3`l0800000U03`l?04000002/0
oooo002A0?ooo`800000D`3oool6000004l0l?3`0P00002E0?3`l0@00000:P3oool00940oooo0P00
001F0?ooo`H00000C03`l?02000009L0l?3`1000000X0?ooo`00T@3oool2000005P0oooo1`000019
0?3`l0800000V03`l?04000002L0oooo002A0?ooo`800000F`3oool6000004L0l?3`0P00002J0?3`
l0@000009@3oool00940oooo0P00001N0?ooo`H00000A03`l?02000009/0l?3`1000000T0?ooo`00
T@3oool200000600oooo1`0000110?3`l0800000W@3`l?0400000280oooo002A0?ooo`800000H`3o
ool6000003l0l?3`0P00002N0?3`l0@000008@3oool00940oooo0P00001V0?ooo`H00000?03`l?02
00000:00l?3`1000000O0?ooo`00T@3oool2000006P0oooo1P00000j0?3`l0800000X@3`l?040000
01h0oooo002A0?ooo`800000J`3oool6000003L0l?3`0P00002S0?3`l0@00000703oool00940oooo
0P00001]0?ooo`L00000=03`l?0200000:@0l?3`1000000K0?ooo`00T@3oool200000700ooooh`00
000J0?ooo`00T@3oool2000007<0ooooh000000J0?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00
T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool2
00000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0
oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P00
00330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?oo
o`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3o
ool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool20000
0:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo
0P0000330?ooo`00T@3oool200000:P0oooo0P0000330?ooo`00T@3oool200000:P0oooo0P000033
0?ooo`00T@3oool2000008`0oooo3@00000?0?ooo`800000``3oool00940oooo0P00001i0?ooob40
00003P3oool200000<<0oooo002A0?ooo`800000I@3ooolX000000/0oooo1000000<0?ooo`800000
``3oool00940oooo0P00001B0?ooobP000007`3oool4000000/0oooo0P0000330?ooo`00T@3oool2
000003h0oooo:000000e0?ooo`@000002@3oool200000<<0oooo002A0?ooo`800000:`3ooolX0000
04T0oooo100000080?ooo`800000``3oool00940oooo0P00000G0?ooobP00000G`3oool4000000H0
oooo0P0000330?ooo`00T@3oool2000000<0oooo:@00001c0?ooo`D00000103oool200000<<0oooo
00230?ooobP00000R@3oool4000000<0oooo0P0000330?ooo`00K`3ooolX000009l0oooo10000000
0`3oool00000000000330?ooo`00G03ooolX000000P0oooo3@00002N0?ooo`H00000``3oool004P0
oooo:000000L0?ooo`d00000X03oool400000<<0oooo000e0?ooobP00000;`3oool=00000:40oooo
100000320?ooo`008@3ooolX000004<0oooo3000002S0?ooo`D00000`03oool000h0oooo:000001G
0?ooo`/00000X`3oool600000;l0oooo00040?oooah00000J`3oool;00000:<0oooo0P0000020?oo
o`@00000_@3oool000@0oooo2`00001n0?ooo`X00000Y03oool2000000<0oooo1000002l0?ooo`00
1P3oool700000840oooo2@00002T0?ooo`8000001@3oool400000;X0oooo00090?ooo`L00000OP3o
ool900000:@0oooo0P0000060?ooo`@00000^@3oool000`0oooo1P00001l0?ooo`P00000Y@3oool2
000000P0oooo1000002g0?ooo`003`3oool6000007X0oooo1`00002U0?ooo`8000002@3oool40000
0;H0oooo000A0?ooo`L00000M`3oool600000:H0oooo0P00000;0?ooo`@00000]03oool001@0oooo
1P00001e0?ooo`H00000YP3oool2000000`0oooo1@00002b0?ooo`005`3oool6000007<0oooo1@00
002V0?ooo`8000003P3oool400000;40oooo000I0?ooo`L00000L03oool400000:L0oooo0P00000@
0?ooo`@00000[`3oool001`0oooo1`00001]0?ooo`@00000Y`3oool200000140oooo1000002^0?oo
o`007`3oool6000006`0oooo0`00002W0?ooo`8000004`3oool4000002`0oooo1`0000050?ooo`<0
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000
000000001@3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000040?ooo`<0000000D0oooo
0000003oool0oooo000000050?ooo`@00000>03oool00280oooo1P00001Y0?ooo`800000Z03oool2
000001@0oooo1000000[0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool2000000D0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo000T0?ooo`L00000o`3oool;0?oo
o``000004P3oool4000002T0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000005
0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03D0oooo000W0?ooo`H00000o`3oool90?ooo``000004`3oool4000002P0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`040?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00@00000
0?ooo`3oool000001`3oool2000003P0oooo000Z0?ooo`H00000o`3oool60?ooo``000005@3oool4
000002H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool00`3oool3000000@0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`040000
003oool0oooo000000D0oooo0P00000j0?ooo`00;03oool700000?l0oooo103oool;000001H0oooo
1000000U0?ooo`L000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo03X0oooo000_0?ooo`L00000@@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo4@00o`1R0?ooo`X000006@3oool4
000002<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`00<P3oool6000003h0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0c0?ooobh00?l0C@3oool:000001X0oooo1000000R0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?oo
o`0000000P0000040?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`8000001@3oool30000
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo008000000P3oool4
000003P0oooo000e0?ooo`H00000>P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02T0oooo4P00o`0?0?ooob@00?l0@03oool9000001`0oooo1000000P0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`00=`3oool7000003H0
oooo00<000000?ooo`3oool00P3oool8000000H0oooo00<000000?ooo`3oool0803ooolB003o02`0
oooo5`00o`0h0?ooo`T000007@3oool4000001l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo000j0?ooo`H00000<`3oool2000000D0oooo
1`0000060?ooo`8000006@3ooolA003o04<0oooo4@00o`0`0?ooo`T000007`3oool4000001d0oooo
1`00000;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D`3oool003d0oooo1P00
000`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?oooa40000000<0oooo003o0000o`002`00o`1C0?ooo`l00?l0
:`3oool700000240oooo1@00002K0?ooo`00?`3oool7000002`0oooo0P0000080?ooo`030000003o
ool0oooo00T0oooo0P0000020?oooa40000000<0oooo003o0000o`000`00o`1S0?ooo`X00?l0:03o
ool7000002<0oooo1000002J0?ooo`00@P3oool7000002T0oooo0P0000080?ooo`8000002P3oool2
00000080oooo4@00001_0?ooo`L00?l0303oool3003o01H0oooo1`00000U0?ooo`@00000V03oool0
04D0oooo1P00000W0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000P3ooolA0000
0780oooo2000o`080?ooo`@00?l05P3oool6000002H0oooo1000002G0?ooo`00B03oool6000002@0
oooo0P00000:0?ooo`030000003oool0oooo00L0oooo0P0000020?oooa400000M@3oool8003o00@0
oooo1P00o`0E0?ooo`D00000:@3oool4000009D0oooo001:0?ooo`L000008@3oool2000000X0oooo
0P0000080?ooo`8000000P3ooolA000007T0oooo1`00o`000`3oool00?l0003o0005003o01@0oooo
1@00000Z0?ooo`@00000U03oool004d0oooo1P00000O0?ooo`8000002`3oool00`000000oooo0?oo
o`060?ooo`8000000P3ooolA000007`0oooo3@00o`0D0?ooo`@00000;03oool400000980oooo001@
0?ooo`H000007@3oool00`000000oooo0?ooo`090?ooo`8000001`3oool010000000oooo0?ooo`3o
oolA000007l0oooo3000o`0B0?ooo`@00000;@3oool400000940oooo001B0?ooo`L000006P3oool2
000000@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P0000030?oooa400000O`3oool=
003o0140oooo1000000_0?ooo`@00000S`3oool005D0oooo1`00000H0?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`020?oooa400000O`3oool>003o
0140oooo0P00000a0?ooo`@000008@3oool00`000000oooo0?ooo`070?ooo`<00000103oool30000
00040?ooo`00000000000?ooo`<000000P3oool3000000030?ooo`000000oooo0080oooo00<00000
0?ooo`3oool0103oool3000000@0oooo100000070?ooo`<0000000D0oooo000000000000oooo0000
00040?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`0H0?ooo`00F03oool6
000001L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000D0oooo00<0
00000?ooo`3oool00`3ooolA000007l0oooo3`00o`0@0?ooo`800000<`3oool4000001l0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000001T0oooo001K0?ooo`H000005@3o
ool010000000oooo0?ooo`3oool6000000D0oooo00<000000?ooo`3oool0103ooolA00000880oooo
3@00o`150?ooo`@000007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01L0oooo001M
0?ooo`L000004`3oool010000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool01@3o
oolA000008H0oooo2P00o`160?ooo`@00000703oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool2000000L0
oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0G0?ooo`00H03oool600000<40oooo1`00o`160?ooo`@000006`3oool00`00
0000oooo0?ooo`050?ooo`L00000103oool300000080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool700000080oooo0P00000;0?ooo`<000000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
5`3oool006<0oooo1P0000320?ooo`<00?l0B03oool4000001T0oooo1P0000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0G0?ooo`00I@3oool70000
0?l0oooo303oool5000001L0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000006@3oool006P0oooo1`00003o0?ooo`/0oooo1000000F0?ooo`030000003oool0oooo00L0
oooo0`0000040?ooo`@000000P3oool4000000030?ooo`000000oooo00<0oooo00H000000?ooo`3o
ool0oooo0000003oool2000000<0oooo0`0000040?ooo`@000001`3oool4000000<0oooo00<00000
0?ooo`0000000P0000050?ooo`<0000000<0oooo0000003oool0603oool006/0oooo1P00003o0?oo
o`/0oooo1000000D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0G0?ooo`00KP3oool600000?l0oooo2@3oool4000001<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo001`0?ooo`L00000
o`3oool80?ooo`@000004@3oool7000004`0oooo00<000000?ooo`3oool05`3oool007<0oooo1P00
003o0?ooo`L0oooo1000001m0?ooo`00MP3oool600000?l0oooo1P3oool4000007/0oooo001h0?oo
o`L00000/`3oool>00000480oooo1000001j0?ooo`00N`3oool700000;00oooo3P00000?0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool4000007P0oooo001n0?ooo`H00000
[P3oool>000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`@00000
M`3oool00840oooo1P00002[0?ooo`h000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo02H0oooo1000001>0?ooo`8000001@3oool00`000000oooo0?ooo`0M0?ooo`00P`3oool7
00000:P0oooo3P00000<0?ooo`030000003oool0oooo00D0oooo100000070?ooo`030000003oool0
oooo02H0oooo1000001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool0
08H0oooo1P00002V0?ooo`h000002`3oool2000000H0oooo00@000000?ooo`3oool0oooo0P000006
0?ooo`800000:@3oool4000004h0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00R@3oool6
00000:<0oooo3P00000;0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:03oool4000001/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00000@0?ooo`00R`3o
ool700000:00oooo3P00000:0?ooo`8000001@3oool2000000D0oooo0P0000060?ooo`800000:`3o
ool4000001T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000l0oooo
002>0?ooo`L00000W@3oool>000000X0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0P00
000/0?ooo`D000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo002A0?ooo`H00000V`3oool>000000X0oooo0P0000050?ooo`8000001@3oool2000000H0
oooo0P00000^0?ooo`@000005P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?ooo`00U03oool6
000009P0oooo3P00000:0?ooo`8000001@3oool2000000D0oooo0P0000060?ooo`800000<03oool4
000001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0B0?ooo`00UP3oool7000009D0oooo3P00000:0?ooo`80
00001@3oool3000000<0oooo0P0000070?ooo`800000<@3oool4000001<0oooo1`0000030?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000103oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool009T0oooo1P00002C0?ooo`h000002P3oool2000000D0oooo
0P0000000`3oool0000000000002000000P0oooo0P00000c0?ooo`@000004@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo008000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0
oooo002L0?ooo`H00000Z@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0<`3oool400000100oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`000000oooo00<000001@3oool3000000<0oooo00<000000?ooo`0000000P0000050?ooo`<0
00000`3oool4000000030?ooo`000000oooo00@0oooo0P000000103oool000000000000000030?oo
o`030000003oool0oooo0080oooo1000000?0?ooo`00WP3oool700000:H0oooo0P0000050?ooo`80
00002`3oool2000003L0oooo1000000>0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool00000803oool00`000000oooo0?ooo`0X0?ooo`00X@3oool700000:@0oooo00<000000?ooo`3o
ool0103oool2000000X0oooo00<000000?ooo`3oool0=`3oool4000000d0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo002T0?ooo`H0
0000X`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0>P3oool4000000/0oooo1`0000030?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool05@3oool00:L0oooo1P00002Q0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000
003oool0oooo03`0oooo1000001P0?ooo`00Z@3oool7000009l0oooo00<000000?ooo`3oool01@3o
ool300000080oooo00<000000?ooo`3oool0?`3oool4000005h0oooo002/0?ooo`H00000k@3oool4
000005d0oooo002_0?ooo`H00000k03oool4000005/0oooo002a0?ooo`L00000jP3oool4000005X0
oooo002d0?ooo`L00000j@3oool4000005P0oooo002g0?ooo`H00000j03oool5000005H0oooo002j
0?ooo`H00000i`3oool4000005D0oooo002l0?ooo`L00000iP3oool4000005<0oooo002o0?ooo`H0
0000i@3oool400000580oooo00320?ooo`H00000i03oool400000500oooo00340?ooo`L00000hP3o
ool4000004l0oooo00370?ooo`L00000h@3oool4000004d0oooo003:0?ooo`H00000h03oool40000
04`0oooo003=0?ooo`H00000g`3oool4000004X0oooo003?0?ooo`L00000g@3oool4000004T0oooo
003B0?ooo`H00000g@3oool4000004L0oooo003E0?ooo`H00000f`3oool4000004H0oooo003G0?oo
o`L00000fP3oool4000004@0oooo003J0?ooo`L00000f03oool4000004<0oooo003M0?ooo`H00000
f03oool400000440oooo003P0?ooo`H00000eP3oool5000003l0oooo003R0?ooo`L00000e@3oool4
000003h0oooo003U0?ooo`H00000e@3oool4000003`0oooo003X0?ooo`H00000d`3oool4000003/0
oooo003Z0?ooo`L00000dP3oool4000003T0oooo003]0?ooo`L00000d03oool4000003P0oooo003`
0?ooomT00000=`3oool00?<0ooooeP00000g0?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo
0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000800001Lb000`400?l00000o`00003oo`3ooooo
0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo
003o0?ooool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0
oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool0
0?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3oool00?l0ooooI@3o
ool6000000<0oooo0`0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00`3o
ool300000080oooo0`0000020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`030?ooo`<000001@3oool4000005`0oooo003o0?ooof@0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003o0?ooof@0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`8000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0F@3oool00?l0ooooI03oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`800000
G03oool00?l0oooo=@3oool<000002T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo1`000003
0?ooo`800000GP3oool00?l0oooo8`3ooolO000002D0oooo0`0000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo0P00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000H03oool00?l0oooo4@3ooolU000000X0kno_
1000000Q0?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05T0oooo003n0?ooobD000007@3_knl4
000001l0oooo00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo0080000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`P0000000<0oooo0000003oool00`3oool0
1P000000oooo0?ooo`3oool000000?ooo`8000000P3oool3000000D0oooo1000001L0?ooo`00k@3o
oolT00000340kno_1000000M0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
5`3oool00`000000oooo0?ooo`1h0?ooo`00f`3ooolT000004@0kno_1000000L0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`1h0?ooo`00b@3o
oolU000005L0kno_1000000K0?ooo`H00000UP3oool00;L0oooo9@00001Z0>o_k`@00000]P3oool0
0:D0oooo9@00001n0>o_k`@00000]03oool009<0oooo9@00002A0>o_k`@00000/`3oool00840oooo
9@00002U0>o_k`@00000/@3oool006l0oooo9@00002h0>o_k`@00000/03oool005d0oooo9@00003<
0>o_k`@00000[P3oool004`0oooo9000003O0>o_k`@00000C`3oool2000000D0oooo00<000000?oo
o`3oool0E03oool003X0oooo9000003c0>o_k`@00000C`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05@0oooo000X0?ooobD00000o`3_knl60>o_k`@00000C`3oool01@000000oooo
0?ooo`3oool0000005H0oooo000F0?ooobD00000o`3_knlJ0>o_k`@00000903oool500000080oooo
00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool3000000<0oooo0`0000040?ooo`060000003oool0oooo0?ooo`000000oooo0`000004
0?ooo`030000003oool0oooo0080oooo0`0000160?ooo`003@3ooolL00000?l0kno_;@3_knl40000
0280oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo0P0000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000004D0oooo000=0?ooo`X0
0000o`3_knm10>o_k`@000007`3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003o
ool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo000?
0?ooo`L00000o`3_knm30>o_k`@000007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0B03oool00180oooo1P00003o0>o_kd<0kno_1000
000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001P0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0B03oool001D0oooo1P00003o0>o_kb80kno_00<000000>o_k`3_knl02P3_knl00`00
0000kno_0>o_k`0?0>o_k`@000006`3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000
003oool0103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`000000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool001L0
oooo1P00003o0>o_kal0kno_00<000000>o_k`3_knl0303_knl00`000000kno_0>o_k`0@0>o_k`@0
00006@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool001X0oooo1P00003o0>o_ka/0
kno_00<000000>o_k`3_knl03P3_knl00`000000kno_0>o_k`0@0>o_k`@00000603oool00`000000
oooo0?ooo`0:0?ooo`<00000103oool00`000000oooo00000002000000D0oooo0`0000020?ooo`@0
000000<0oooo0000003oool0103oool2000000040?ooo`0000000000000000@0oooo00<000000?oo
o`3oool00P3oool4000004D0oooo000L0?ooo`L00000@03_knl2000000@0kno_0P0000030>o_k`80
0000b@3_knl00`000000kno_0>o_k`020>o_k`H00000203_knl00`000000kno_0>o_k`0A0>o_k`@0
00005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0G`3oool001l0oooo1P00000n0>o_k`800000103_knl2000000<0kno_0P0000380>o_k`800000
103_knl3000000<0kno_00<000000>o_k`3_knl01@3_knl2000001<0kno_1000000F0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1O0?ooo`008P3o
ool600000?l0kno_4@3_knl00`000000kno_0>o_k`090>o_k`8000001`3_knl00`000000kno_0>o_
k`0C0>o_k`@000005@3oool600000300oooo00<000000?ooo`3oool0B`3oool002@0oooo1`00003o
0>o_k`d0kno_0P00000<0>o_k`8000001P3_knl2000001D0kno_1000002H0?ooo`009`3oool60000
0:L0kno_1@00P14:0>o_ka00080A2@3_knl<00204AD0kno_0P00P14H0>o_k`800000303_knl20000
00H0kno_0P00000G0>o_k`<00000U`3oool002X0oooo1P00002M0>o_k``0080A2P3_knl@00204@T0
kno_3`00P14B0>o_k`@0080A5P3_knl2000000`0kno_0P0000060>o_k`800000603_knl4000009D0
oooo000/0?ooo`H00000A@3_knl00`000000kno_0>o_k`0:0>o_k`030000003_knl0kno_03D0kno_
1000P1490>o_k``0080A<P3_knl600204A00kno_1P00P14D0>o_k`8000002`3_knl3000000H0kno_
0P00000I0>o_k`@00000U03oool002l0oooo1P0000110>o_k`030000003_knl0kno_00`0kno_00<0
00000>o_k`3_knl0;`3_knl900204@T0kno_1@00P14l0>o_k`<0080A2@3_knl?00204A80kno_0P00
000;0>o_k`<000001P3_knl2000001/0kno_1000002B0?ooo`00<@3oool7000003d0kno_00<00000
0>o_k`3_knl03P3_knl00`000000kno_0>o_k`0Z0>o_k`X0080AF@3_knlA00204A00kno_0P000009
0>o_k`@000001`3_knl2000001`0kno_1000002A0?ooo`00=03oool6000003X0kno_00<000000>o_
k`3_knl0103_knl6000000H0kno_00<000000>o_k`3_knl09`3_knl700204F@0kno_3@00P14?0>o_
k`030000003_knl0kno_00@0kno_1P0000080>o_k`030000003_knl0kno_01d0kno_1000002?0?oo
o`00=`3oool6000003H0kno_0P0000080>o_k`800000203_knl2000002P0kno_0`00P15X0>o_k`h0
080A3P3_knl2000000D0kno_100000090>o_k`800000803_knl4000008h0oooo000i0?ooo`H00000
=03_knl00`000000kno_0>o_k`070>o_k`8000002@3_knl00`000000kno_0>o_k`080>o_k`D00000
303_knl400204G@0kno_4000P14=0>o_k`030000003_knl0kno_00<0kno_0P00000;0>o_k`030000
003_knl0kno_0240kno_1000002<0?ooo`00?03oool600000300kno_0P0000090>o_k`8000002@3_
knl2000000L0kno_2@0000060>o_k`P0080AM03_knlB00204@`0kno_00<000000>o_k`3_knl00`3_
knl00`000000kno_0>o_k`080>o_k`030000003_knl0kno_02<0kno_1000002;0?ooo`00?P3oool7
000002d0kno_0P0000090>o_k`8000002@3_knl2000000L0kno_2@0000040>o_k`L0080AM`3_knlD
00204@/0kno_00<000000>o_k`3_knl00P3_knl6000000@0kno_00<000000>o_k`3_knl09P3_knl4
000008T0oooo00110?ooo`H00000:`3_knl2000000T0kno_0P0000090>o_k`8000001P3_knl;0000
00<0kno_0`00P15k0>o_kaH0080A2P3_knl00`000000kno_0>o_k`020>o_k`H000000P3_knl00`00
0000kno_0>o_k`0X0>o_k`@00000R03oool004@0oooo1P00000X0>o_k`8000002@3_knl2000000T0
kno_0P0000060>o_k`/00000f`3_knl4000008H0oooo00160?ooo`L000009@3_knl2000000T0kno_
0P0000090>o_k`8000001P3_knl;00000=`0kno_100000250?ooo`00B@3oool6000002<0kno_0P00
00090>o_k`8000002@3_knl2000000L0kno_2@00002M0>o_k`D00000?@3_knl4000008<0oooo001<
0?ooo`H000008@3_knl00`000000kno_0>o_k`070>o_k`8000002@3_knl00`000000kno_0>o_k`06
0>o_k`T00000V`3_knl9000003`0kno_100000220?ooo`00CP3oool6000001l0kno_0P0000080>o_
k`800000203_knl2000000X0kno_1@00002M0>o_k`T00000?P3_knl400000800oooo001A0?ooo`H0
00007@3_knl00`000000kno_0>o_k`060>o_k`800000203_knl00`000000kno_0>o_k`2Z0>o_k`/0
0000?P3_knl4000007l0oooo001C0?ooo`L000006`3_knl00`000000kno_0>o_k`050>o_k`800000
1`3_knl00`000000kno_0>o_k`2[0>o_k`/00000@03_knl4000007d0oooo001F0?ooo`H000006P3_
knl00`000000kno_0>o_k`020>o_k`@000001P3_knl00`000000kno_0>o_k`2V0>o_k`80003D103_
knl;00000440kno_1000001l0?ooo`00F@3oool6000001P0kno_00<000000>o_k`3_knl00`3_knl2
000000D0kno_00<000000>o_k`3_knl0Y03_knl50000e0D0kno_2@0000140>o_k`@00000NP3oool0
05/0oooo1`0000360>o_k`L0003D1P3_knl9000004D0kno_1000001i0?ooo`00GP3oool600000<00
kno_2P000=@90>o_k`D00000B@3_knl4000007L0oooo001Q0?ooo`H00000^P3_knl<0000e5T0kno_
1000001f0?ooo`00H`3oool600000;D0kno_3P000=AL0>o_k`@00000M03oool006H0oooo1P00002`
0>o_k`l0003DGP3_knl4000007<0oooo001X0?ooo`L00000[@3_knl>0000e380kno_0P0000040>o_
k`8000000`3_knl200000280kno_1000001a0?ooo`00J`3oool600000:`0kno_30000=@c0>o_k`80
0000103_knl2000000<0kno_0P00000S0>o_k`@00000L03oool006h0oooo1P00002Y0>o_k`/0003D
IP3_knl4000006h0oooo001`0?ooo`L00000XP3_knl?0000e6L0kno_1000001]0?ooo`00L`3oool6
000001P0kno_0P00001D0>o_k`D00000:@3_knl70000e0030>o_k`000=@0003D00P0003D503_knl2
000005@0kno_1000001[0?ooo`00MP3oool6000001D0kno_0P00001B0>o_k`T00000903_knl70000
e0D0kno_20000=@E0>o_k`800000E@3_knl4000006X0oooo001h0?ooo`H000004`3_knl2000003T0
kno_00<000000>o_k`3_knl02P3_knl00`000000kno_0>o_k`090>o_k`8000001@3oool2000001l0
kno_20000=@:0>o_k`H0003D5P3_knl2000005L0kno_1000001X0?ooo`00N`3oool600000100kno_
0P00000h0>o_k`030000003_knl0kno_00`0kno_00<000000>o_k`3_knl01`3_knl2000000L0oooo
0P00000I0>o_k`T0003D3P3_knl50000e1L0kno_0P00001H0>o_k`@00000I`3oool007d0oooo1`00
000=0>o_k`800000=`3_knl00`000000kno_0>o_k`0>0>o_k`030000003_knl0kno_00H0kno_0P00
00070?ooo`800000503_knl:0000e1<0kno_0`000=@H0>o_k`800000FP3_knl4000006D0oooo0020
0?ooo`H000002`3_knl2000003H0kno_00<000000>o_k`3_knl0203_knl2000000H0kno_00<00000
0>o_k`3_knl01@3_knl2000000L0oooo0P00000<0>o_k`d0003D6@3_knl00`000=@0kno_0>o_k`0G
0>o_k`800000F`3_knl4000006@0oooo00230?ooo`H00000203_knl2000003D0kno_0P00000:0>o_
k`8000001P3_knl2000000L0kno_0P0000050?ooo`8000000`3_knlB0000e3P0kno_0P00001M0>o_
k`@00000HP3oool008D0oooo1`0000050>o_k`800000=@3_knl00`000000kno_0>o_k`090>o_k`80
00001`3_knl00`000000kno_0>o_k`050>o_k`T000000P3_knl;0000e400kno_0P00001N0>o_k`@0
0000H@3oool008P0oooo1P0000030>o_k`800000=03_knl2000000/0kno_0P0000070>o_k`800000
203_knl5000000@0kno_00<0003D0>o_k`3_knl0B03_knl200000600kno_1000001O0?ooo`00R`3o
ool8000003@0kno_0P0000040>o_k`/000001@3_knl2000005`0kno_0P00001Q0>o_k`@00000GP3o
ool008d0oooo1P00000d0>o_k`800000103_knl00`000000kno_0>o_k`040>o_k`8000001`3_knl2
000003d0kno_1000000K0>o_k`800000H`3_knl4000005`0oooo002@0?ooo`H00000<@3_knl20000
00D0kno_00<000000>o_k`3_knl00`3_knl2000000L0kno_0P00000m0>o_k`050000003_knl0kno_
0>o_k`0000006P3_knl2000006@0kno_1000001K0?ooo`00T@3oool8000002h0kno_0P0000060>o_
k`030000003_knl0kno_0080kno_0P0000070>o_k`800000@P3_knl00`000000kno_0>o_k`0G0>o_
k`800000IP3_knl4000005T0oooo002A0?ooo`8000000P3oool6000002`0kno_0P0000070>o_k`04
0000003_knl0kno_0>o_k`8000001`3_knl2000003l0kno_1000000I0>o_k`800000I`3_knl40000
05P0oooo002A0?ooo`8000001@3oool6000002X0kno_00<000000>o_k`3_knl01P3_knl00`000000
kno_0>o_k`02000000L0kno_00<000000>o_k`3_knl0?@3_knl200000080kno_0P00000H0>o_k`80
0000J@3_knl4000005H0oooo002A0?ooo`8000001`3oool6000002P0kno_0P0000070>o_k`030000
003_knl0kno_008000001P3_knl2000003l0kno_00<000000>o_k`3_knl00P3_knl00`000000kno_
0>o_k`0F0>o_k`800000JP3_knl4000005D0oooo002A0?ooo`8000002P3oool6000002H0kno_00<0
00000>o_k`3_knl01P3_knl010000000kno_0000000000060>o_k`030000003_knl0kno_02P0kno_
0P0000060>o_k`@0000000D0kno_000000000000kno_000000050>o_k`030000003_knl0kno_0080
kno_00<000000>o_k`3_knl05P3_knl2000006`0kno_1000001C0?ooo`00T@3oool2000000`0oooo
1`00000T0>o_k`030000003_knl0kno_00H0kno_0`0000050>o_k`030000003_knl0kno_02T0kno_
0P0000050>o_k`8000000`3_knl200000080kno_00<000000>o_k`3_knl0103_knl010000000kno_
0>o_k`3_knl2000001L0kno_0P00001]0>o_k`@00000DP3oool00940oooo0P00000?0?ooo`H00000
8`3_knl00`000000kno_0>o_k`060>o_k`800000103_knl00`000000kno_0>o_k`0Y0>o_k`040000
003_knl0kno_000000D0kno_00<000000>o_k`3_knl00P3_knl200000080kno_00<000000>o_k`3_
knl00`3_knl00`000000kno_0>o_k`020>o_k`030000003_knl0kno_01D0kno_0P00001_0>o_k`@0
0000D03oool00940oooo0P00000B0?ooo`H000008@3_knl00`000000kno_0>o_k`050>o_k`800000
0`3_knl00`000000kno_0>o_k`0Z0>o_k`030000003_knl0kno_00800000103_knl00`000000kno_
0>o_k`030>o_k`040000003_knl0kno_000000H0kno_00<000000>o_k`3_knl00P00000G0>o_k`80
0000L03_knl4000004l0oooo002A0?ooo`800000503oool7000005P0kno_00D000000>o_k`3_knl0
kno_000000050>o_k`H000000P3_knl00`000000kno_0>o_k`050>o_k`<0000000<0kno_0000003_
knl05@3_knl200000780kno_1000001=0?ooo`00T@3oool2000001L0oooo1P00001F0>o_k`030000
003_knl0kno_0080kno_00<000000>o_k`3_knl01`3_knl010000000kno_0>o_k`00000R0>o_k`80
0000L`3_knl4000004`0oooo002A0?ooo`8000006P3oool6000005<0kno_00<000000>o_k`3_knl0
0P3_knl00`000000kno_0>o_k`020>o_k`030000003_knl0kno_00<0kno_00@000000>o_k`3_knl0
00008@3_knl2000007D0kno_1000001:0?ooo`00T@3oool2000001`0oooo1P00001A0>o_k`030000
003_knl0kno_00<0kno_00D000000>o_k`3_knl0kno_000000050>o_k`030000003_knl0kno_0080
0000803_knl2000007H0kno_100000190?ooo`00T@3oool2000001l0oooo1P00000]0>o_k`80003D
7`3_knl00`000000kno_0>o_k`030>o_k`030000003_knl0kno_0080kno_1@0000030>o_k`040000
003_knl00000000001h0kno_0P00001h0>o_k`@00000A`3oool00940oooo0P00000Q0?ooo`L00000
:P3_knl20000e1l0kno_00<000000>o_k`3_knl0103_knl00`000000kno_0>o_k`0[0>o_k`800000
N@3_knl4000004H0oooo002A0?ooo`800000903oool6000002P0kno_0P000=@O0>o_k`030000003_
knl0kno_00D0kno_00<000000>o_k`3_knl0:P3_knl2000007/0kno_100000140?ooo`00T@3oool2
000002L0oooo1P00000T0>o_k`@0003D7P3_knl00`000000kno_0>o_k`050>o_k`030000003_knl0
kno_02X0kno_0P00001l0>o_k`@00000@`3oool00940oooo0P00000Y0?ooo`L000008@3_knl40000
e5<0kno_0P00001n0>o_k`<00000@P3oool00940oooo0P00000/0?ooo`H000007`3_knl40000e5<0
kno_0P00001o0>o_k`@00000@03oool00940oooo0P00000_0?ooo`H000006`3_knl50000e5<0kno_
0P0000200>o_k`@00000?`3oool00940oooo0P00000a0?ooo`H000006@3_knl60000e580kno_0P00
00220>o_k`@00000?@3oool00940oooo0P00000d0?ooo`H000005P3_knl60000e580kno_0P000023
0>o_k`@00000?03oool00940oooo0P00000f0?ooo`L000004P3_knl70000e580kno_0P0000250>o_
k`@00000>P3oool00940oooo0P00000i0?ooo`H00000403_knl80000e540kno_0P0000260>o_k`@0
0000>@3oool00940oooo0P00000l0?ooo`H000003@3_knl80000e540kno_0P0000280>o_k`@00000
=`3oool00940oooo0P00000n0?ooo`L000002@3_knl90000e540kno_0P0000290>o_k`@00000=P3o
ool00940oooo0P0000110?ooo`H000001`3_knl90000e540kno_0P00002;0>o_k`@00000=03oool0
0940oooo0P0000140?ooo`H00000103_knl:0000e500kno_0P00002<0>o_k`@00000<`3oool00940
oooo0P0000160?ooo`H0000000<0kno_0000e0000=@02@000=A@0>o_k`800000SP3_knl400000340
oooo002A0?ooo`800000B@3oool4000000/0003DD03_knl2000008l0kno_1000000`0?ooo`00T@3o
ool2000004/0oooo0P00000<0000e4l0kno_0P00002A0>o_k`@00000;P3oool00940oooo0P00001<
0?ooo`d0003DC`3_knl200000980kno_1000000]0?ooo`00T@3oool200000540oooo0P0000020000
e0800000D@3_knl2000009@0kno_1000000[0?ooo`00T@3oool2000005<0oooo0P000=@4000004l0
kno_0P00002E0>o_k`@00000:P3oool00940oooo0P00001C0?ooo`80003D00<0oooo000000000000
1000001<0>o_k`800000U`3_knl4000002P0oooo002A0?ooo`800000D`3oool20000e0<0oooo1`00
00190>o_k`800000V03_knl4000002L0oooo002A0?ooo`800000D`3oool20000e0H0oooo1P000017
0>o_k`800000VP3_knl4000002D0oooo002A0?ooo`800000D`3oool20000e0T0oooo1P0000140>o_
k`800000V`3_knl4000002@0oooo002A0?ooo`800000D`3oool20000e0/0oooo1`0000110>o_k`80
0000W@3_knl400000280oooo002A0?ooo`800000D`3oool20000e0h0oooo1P00000o0>o_k`800000
WP3_knl400000240oooo002A0?ooo`800000D`3oool20000e140oooo1P00000l0>o_k`800000X03_
knl4000001l0oooo002A0?ooo`800000D`3oool20000e1<0oooo1P00000j0>o_k`800000X@3_knl4
000001h0oooo002A0?ooo`800000D`3oool20000e1H0oooo1P00000g0>o_k`800000X`3_knl40000
01`0oooo002A0?ooo`800000D`3oool20000e1P0oooo1`00000d0>o_k`800000Y03_knl4000001/0
oooo002A0?ooo`800000D`3oool20000e1/0ooooh`00000J0?ooo`00T@3oool2000005<0oooo0P00
0=@N0?ooon0000006P3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P000033
0?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80
003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3o
ool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool2
00000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0
oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo
002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`80
0000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000
``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool2
0000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940
oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo
0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C
0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D
D`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2
000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool20000
0<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo
0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A
0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?oo
o`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000
D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3o
ool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000
e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo
0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P00
00330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?oo
o`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00
T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3o
ool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool20000
05<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0
oooo002A0?ooo`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P00
0=AC0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?oo
o`800000D`3oool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`80
0000``3oool00940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3o
ool20000e5<0oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool0
0940oooo0P00001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e5<0
oooo0P0000330?ooo`00T@3oool2000005<0oooo0P000=AC0?ooo`800000``3oool00940oooo0P00
001C0?ooo`80003DD`3oool200000<<0oooo002A0?ooo`800000D`3oool20000e3L0oooo3@00000?
0?ooo`800000``3oool00940oooo0P00001C0?ooo`80003D903ooolQ000000h0oooo0P0000330?oo
o`00T@3oool2000005<0oooo0P000=@@0?ooobP000002`3oool4000000`0oooo0P0000330?ooo`00
T@3oool200000580oooo:000000O0?ooo`@000002`3oool200000<<0oooo002A0?ooo`800000?P3o
oolX000003D0oooo100000090?ooo`800000``3oool00940oooo0P00000[0?ooobP000000P000=A7
0?ooo`@00000203oool200000<<0oooo002A0?ooo`8000005`3ooolX000001@0oooo0P000=A90?oo
o`@000001P3oool200000<<0oooo002A0?ooo`8000000`3ooolY000002L0oooo0P000=A:0?ooo`D0
0000103oool200000<<0oooo00230?ooobP00000>`3oool20000e4`0oooo100000030?ooo`800000
``3oool006l0oooo:000001?0?ooo`80003DCP3oool4000000030?ooo`00000000000<<0oooo001L
0?ooobP00000203oool;000004l0oooo0P000=A?0?ooo`H00000``3oool004P0oooo:000000L0?oo
o`/00000C`3oool20000e540oooo100000330?ooo`00=@3ooolX00000300oooo2P00001?0?ooo`80
003DDP3oool400000<80oooo000Q0?ooobP00000A03oool900000500oooo0P000=AC0?ooo`D00000
`03oool000h0oooo:000001G0?ooo`T00000D03oool20000e5<0oooo1P00002o0?ooo`00103ooolN
000006/0oooo2@00001@0?ooo`80003DD`3oool200000080oooo1000002m0?ooo`00103oool;0000
07h0oooo2000001A0?ooo`80003DD`3oool2000000<0oooo1000002l0?ooo`001P3oool700000840
oooo1`00001A0?ooo`80003DD`3oool2000000D0oooo1000002j0?ooo`002@3oool7000007h0oooo
1`00001A0?ooo`80003DD`3oool2000000H0oooo1000002i0?ooo`00303oool6000007`0oooo1`00
001A0?ooo`80003DD`3oool2000000P0oooo1000002g0?ooo`003`3oool6000007T0oooo1P00001B
0?ooo`80003DD`3oool2000000T0oooo1000002f0?ooo`004@3oool7000007L0oooo1@00001B0?oo
o`80003DD`3oool2000000/0oooo1000002d0?ooo`00503oool6000007D0oooo1@00001B0?ooo`80
003DD`3oool2000000`0oooo1@00002b0?ooo`005`3oool600000780oooo1@00001B0?ooo`80003D
D`3oool2000000h0oooo1000002a0?ooo`006@3oool7000006l0oooo1000001C0?ooo`80003DD`3o
ool200000100oooo1000000_0?ooo`L000001@3oool3000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool3000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`<00000103oool3000000050?ooo`000000oooo0?ooo`00
00001@3oool4000003T0oooo000L0?ooo`L00000K@3oool3000005<0oooo0P000=AC0?ooo`800000
4@3oool4000002h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`800000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=P3oool001l0oooo1P00001[0?ooo`<00000D`3oool20000e5<0oooo0P00
000C0?ooo`@00000;03oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03H0oooo000R0?ooo`H00000J03oool2000005@0oooo0P000=AC0?ooo`800000503oool40000
02/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`030?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000
003oool0oooo000000L0oooo0P00000i0?ooo`00903oool7000006D0oooo0P00001D0?ooo`80003D
D`3oool2000001H0oooo1000000Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool000001@3oool2000003/0oooo000W0?ooo`H00000H`3oool20000
05@0oooo0P000=AC0?ooo`8000005`3oool4000002P0oooo1`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03/0
oooo000Z0?ooo`H00000A`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0DP3oool20000e4`0oooo3000000F0?ooo`@000009P3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0f0?ooo`00;03oool7000004<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1N0?ooo`80003DC@3oool;000001L0oooo1000000U0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`0000000P0000040?ooo`@000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo1000000i0?ooo`00;`3o
ool7000003l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1M0?ooo`80003DC@3o
ool;000001T0oooo1000000S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1[0?ooo`00<P3oool6000003`0oooo00<000000?ooo`3oool00P3oool8
000000H0oooo00<000000?ooo`3oool0G03oool20000e4d0oooo2P00000K0?ooo`@000008P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool0
03D0oooo1P00000h0?ooo`8000001@3oool7000000H0oooo0P00000h0?ooob@0080A00<0oooo0000
e0000=@0CP3oool9000001d0oooo1000000P0?ooo`L000002`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo05<0oooo000g0?ooo`L00000=@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?oooch0
080AA03oool9000001h0oooo1000002O0?ooo`00>P3oool600000380oooo0P0000080?ooo`030000
003oool0oooo00T0oooo0P00000R0?oooaD0080A903ooolE00204C`0oooo2@00000P0?ooo`@00000
W@3oool003d0oooo1P00000_0?ooo`800000203oool2000000X0oooo0P0000020?ooo`l000002P3o
ool?00204C80oooo0P000=@:0?ooo`l0080A7P3oool200204AH0oooo1`00000R0?ooo`D00000V`3o
ool003l0oooo1`00000/0?ooo`8000002@3oool00`000000oooo0?ooo`080?ooo`8000000P3oool?
000000D0oooo2`00P14k0?ooo`80003D4`3oool<00204AP0oooo0`00P14E0?ooo`L00000903oool4
000009X0oooo00120?ooo`L00000:@3oool2000000X0oooo00<000000?ooo`3oool01`3oool20000
0080oooo3`0000070?ooo`80080A@P3oool20000e1X0oooo2P00P14B0?ooo`D0080A503oool70000
02H0oooo1000002H0?ooo`00A@3oool6000002L0oooo0P00000:0?ooo`800000203oool200000080
oooo3`00001;0?ooo`80003D7`3oool900204@h0oooo1P00P14D0?ooo`H000009`3oool4000009L0
oooo00180?ooo`H00000903oool2000000/0oooo00<000000?ooo`3oool01P3oool200000080oooo
3`00001;0?ooo`80003D903oool800204@T0oooo2000P14C0?ooo`D00000:P3oool4000009D0oooo
001:0?ooo`L000008P3oool00`000000oooo0?ooo`090?ooo`8000001`3oool010000000oooo0?oo
o`3oool?000004/0oooo0P000=@Y0?ooo`L0080A1@3oool900204A80oooo1@00000[0?ooo`@00000
U03oool004d0oooo1P00000P0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool2000000<0oooo3`00001;0?ooo`80003D;@3oool600204@030?ooo`00P140080A00T0080A4P3o
ool4000002d0oooo1000002B0?ooo`00D03oool6000001h0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000060?ooo`030000003oool0oooo0080oooo3`00001;0?ooo`80003D=03oool=
00204A00oooo1000000^0?ooo`@00000903oool00`000000oooo0?ooo`080?ooo`<000001@3oool3
000000030?ooo`00000000000080oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo0000
00060?ooo`<000001@3oool4000000h0oooo0`0000000`3oool00000000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000oooo00d0oooo001B
0?ooo`L00000703oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001@3o
ool00`000000oooo0?ooo`030?ooo`l00000B`3oool20000e3<0oooo3`00P14?0?ooo`<00000<@3o
ool400000280oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000h0oooo
001E0?ooo`L000006P3oool010000000oooo0?ooo`3oool6000000D0oooo00<000000?ooo`3oool0
103oool?000004/0oooo0P000=@c0?oooa00080A3`3oool200000380oooo1000000Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0<0?ooo`00F03oool6000001T0oooo
00@000000?ooo`3oool0oooo100000050?ooo`030000003oool0oooo00D0oooo3`0000050?ooo`80
003DA03oool20000e3<0oooo4@00P14>0?ooo`800000=03oool4000001l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`<0000000<0oooo0000003oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`09
0?ooo`8000003P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00`0oooo001K0?ooo`H00000:`3oool?
000000D0oooo0`000=A30?ooo`80003D=P3oool?00204@d0oooo0P00000e0?ooo`@000007P3oool0
0`000000oooo0?ooo`060?ooo`L000001@3oool3000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo000000@0oooo1`0000030?ooo`8000004P3oool3000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00`0
oooo001M0?ooo`L00000:03oool?000000L0oooo0P000=A20?ooo`80003D>`3oool;00204DD0oooo
1000000L0?ooo`H000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0<0?ooo`00H03oool6000002H0oooo3`0000080?ooo`<0003D
P`3oool600204DD0oooo1000000K0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`8000003P3oool006<0oooo1P00000S0?ooo`l000002@3oool30000e8L0oooo0P00
P1560?ooo`@000006@3oool00`000000oooo0?ooo`080?ooo`<000001@3oool4000000<0oooo1000
00000`3oool000000?ooo`030?ooo`050000003oool0oooo0000003oool00P0000030?ooo`<00000
1@3oool4000000h0oooo100000040?ooo`030000003oool00000008000001@3oool3000000030?oo
o`000000oooo00d0oooo001U0?ooo`L00000>@3oool40000e<h0oooo1@00000G0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0<0?ooo`00J03oool7
000003P0oooo10000=C>0?ooo`@000005P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0303oool006/0oooo1P00000h0?ooo`@0003DcP3oool40000
01@0oooo1`00001G0?ooo`030000003oool0oooo00`0oooo001^0?ooo`H00000=`3oool40000e<d0
oooo100000200?ooo`00L03oool7000003H0oooo1@000=@>0?ooo`80003D6@3ooolA00000980oooo
1000001n0?ooo`00L`3oool6000003L0oooo1@000=@;0?ooo`@0003D5`3ooolA000009<0oooo1000
001m0?ooo`00MP3oool6000003H0oooo1P000=@70?ooo`P0003D503oool2000000d0oooo0P00002E
0?ooo`@00000N`3oool007P0oooo1`00000g0?ooo`H0003D0`3oool:0000e180oooo0P00000=0?oo
o`800000A03oool@00000480oooo1000001j0?ooo`00N`3oool7000003L0oooo4P000=@@0?ooo`80
00003@3oool2000004@0oooo4000000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool09@3oool4000007P0oooo001n0?ooo`H00000>P3oool?0000e0h0oooo0P00000=0?ooo`800000
A03oool@000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`@00000
M`3oool00840oooo1P00000g0?oooa40003D303oool2000000d0oooo0P0000140?oooa0000003@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo1000001>0?ooo`8000001@3o
ool00`000000oooo0?ooo`0M0?ooo`00P`3oool7000003@0oooo50000=@90?ooo`8000003@3oool2
000004@0oooo4000000<0?ooo`030000003oool0oooo00D0oooo100000070?ooo`030000003oool0
oooo02H0oooo1000001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool0
08H0oooo1P00000b0?oooaH0003D1`3oool2000000d0oooo0P0000140?oooa0000002`3oool20000
00H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`800000:@3oool4000004h0oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`00R@3oool6000002l0oooo4`000=@:0?ooo`8000003@3oool2
000004@0oooo4000000;0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:03oool4000001/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00000@0?ooo`00R`3o
ool7000002`0oooo3P000=@?0?ooo`8000003@3oool2000004@0oooo4000000:0?ooo`8000001@3o
ool2000000D0oooo0P0000060?ooo`800000:`3oool4000001T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`0000000P3oool2000000<0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000l0oooo002>0?ooo`L000007P3oool00`000000oooo0?oo
o`080?ooo`P0003D5@3oool2000000d0oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0:P3oool@000000X0oooo0P0000050?ooo`8000001@3oool2000000H0oooo0P00
000/0?ooo`D000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo002A0?ooo`H00000703oool00`000000oooo0?ooo`080?ooo`<0003D6P3ooolA000000T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?oooa0000002P3oool2000000D0
oooo0P0000050?ooo`8000001P3oool2000002h0oooo1000000F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0180oooo002D0?ooo`H000006P3oool00`000000oooo0?ooo`0T0?oooa400000203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo4000000:0?ooo`8000001@3oool2
000000D0oooo0P0000060?ooo`800000<03oool4000001@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0000000<0oooo0000003oool00`3oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0B0?oo
o`00UP3oool7000001L0oooo00@000000?ooo`0000000000>`3oool010000000oooo0?ooo`3oool6
000000T0oooo00<000000?ooo`3oool09`3oool@000000X0oooo0P0000050?ooo`<000000`3oool2
000000L0oooo0P00000a0?ooo`@000004`3oool7000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo00000005
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`00V@3oool6000001H0oooo00<000000?ooo`3oool00P00000h0?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool01P3oool2000002P0oooo4000000:0?ooo`8000001@3oool20000
00030?ooo`000000000000800000203oool2000003<0oooo1000000A0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000103oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
09`0oooo1P00000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`080?ooo`800000203oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?ooo`@00000403oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0000003oool00`0000050?ooo`<000000`3oool0
0`000000oooo00000002000000D0oooo0`0000030?ooo`@0000000<0oooo0000003oool0103oool2
000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool00P3oool4000000l0oooo002N
0?ooo`L00000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo0P00000;
0?ooo`8000001`3oool200000480oooo0P0000050?ooo`8000002`3oool2000003L0oooo1000000>
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?oo
o`0X0?ooo`00WP3oool:000000030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool2000000/0oooo0P000007
0?ooo`800000@`3oool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo0?ooo`0g
0?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000200oooo00<0
00000?ooo`3oool0:03oool009d0oooo0P0000040?ooo`L000000`3oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`8000002`3oool2
000000L0oooo0P0000140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0j0?ooo`@000002`3oool7000000<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0E0?ooo`00W@3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000
00000000100000001@3oool000000000003oool0000000@0oooo0P0000020?ooo`030000003oool0
oooo03@0oooo0P00000:0?ooo`<000001`3oool2000004D0oooo00<000000?ooo`3oool0103oool2
000000H0oooo00<000000?ooo`3oool0?03oool400000600oooo002M0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0200000000`3oool000000?ooo`040?ooo`@00000=P3oool20000
00T0oooo0`0000080?ooo`800000AP3oool00`000000oooo0?ooo`050?ooo`<000000P3oool00`00
0000oooo0?ooo`0o0?ooo`@00000GP3oool00:D0oooo00<000000?ooo`3oool02P00000o0?ooo`80
00001P3oool6000000P0oooo0P00002F0?ooo`@00000G@3oool00:<0oooo0P0000030?ooo`030000
003oool0oooo00@0oooo1P00000m0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000
003oool0oooo09L0oooo1000001K0?ooo`00W`3oool5000000D0oooo00<000000?ooo`3oool00`3o
ool9000003X0oooo0P0000090?ooo`030000003oool0oooo00H0oooo0P00002J0?ooo`@00000FP3o
ool009h0oooo0P00000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?oo
o`07000003P0oooo00<000000?ooo`3oool01`3oool2000000L0oooo00<000000?ooo`3oool0V`3o
ool4000005P0oooo002N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool4
000000<0oooo00<000000?ooo`3oool00P3oool6000003L0oooo00@000000?ooo`3oool000001@3o
ool2000000H0oooo00<000000?ooo`3oool0W@3oool5000005H0oooo002N0?ooo`8000001P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo1P00000e0?ooo`040000003oool0
oooo000000<0oooo0`0000050?ooo`030000003oool0oooo0:00oooo1000001E0?ooo`00W`3oool2
000000@0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo1`00000c0?ooo`030000003oool0
oooo00D000001@3oool00`000000oooo0?ooo`2S0?ooo`@00000D`3oool00:40oooo1@00000=0?oo
o`030000003oool0oooo00T0oooo1P00003U0?ooo`@00000DP3oool00<80oooo1P00003T0?ooo`@0
0000D03oool00<@0oooo1`00003R0?ooo`@00000C`3oool00<L0oooo1`00003Q0?ooo`@00000C@3o
ool00<X0oooo1P00003P0?ooo`@00000C03oool00<d0oooo1P00003O0?ooo`@00000BP3oool00<l0
oooo1`00003M0?ooo`@00000B@3oool00=80oooo1P00003M0?ooo`@00000A`3oool00=D0oooo1P00
003K0?ooo`@00000AP3oool00=L0oooo1`00003J0?ooo`@00000A03oool00=X0oooo1`00003H0?oo
o`@00000@`3oool00=d0oooo1P00003H0?ooo`@00000@@3oool00>00oooo1P00003F0?ooo`D00000
?`3oool00>80oooo1`00003E0?ooo`@00000?P3oool00>D0oooo1P00003E0?ooo`@00000?03oool0
0>P0oooo1P00003C0?ooo`@00000>`3oool00>X0oooo1`00003B0?ooo`@00000>@3oool00>d0oooo
1`00003@0?ooo`@00000>03oool00?00oooof@00000g0?ooo`00l`3ooooF000003L0oooo003o0?oo
ool0oooo0P3oool00?l0ooooo`3oool20?ooo`00o`3ooooo0?ooo`80oooo003o0?ooool0oooo0P3o
ool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{512, 371.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->-8,
  AnimationCycleRepetitions->Infinity]
}, Closed]],

Cell[TextData[{
  "Selection and Variation: Evolution of populations as a two-level process \
of phenotypic selection ",
  Cell[BoxData[
      \(TraditionalForm\`\((Sel\_p\)\)]],
  ") and genotypic variation ",
  Cell[BoxData[
      \(TraditionalForm\`\((Var\_g\)\)]],
  ")\n\n",
  StyleBox["Double-click on the graphics to start the animation.",
    FontWeight->"Bold"]
}], "NumberedFigure",
  CellTags->"Figure: selection and variation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["A General Model for Adaptive Systems", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Definition: ",
  ButtonBox["Adaptation",
    ButtonData:>"Adaptation definition",
    ButtonStyle->"Hyperlink"]
}], "Subsubsection"],

Cell[TextData[{
  "In general, ",
  StyleBox["adaptation",
    FontWeight->"Bold"],
  " (",
  StyleBox["ad + aptare",
    FontSlant->"Italic"],
  ", to fit) can be defined as "
}], "Text",
  CellTags->"Adaptation definition"],

Cell[TextData[{
  StyleBox[
  " a process of progressive modification of (general) structures, that lead \
to an   \[NonBreakingSpace]improved behavior in interaction with an \
environment",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellMargins->{{161, 100}, {20, 20}}],

Cell["\<\
Hence, we can identify two basic components of adaptive feedback \
systems:\
\>", "Text"],

Cell[TextData[{
  StyleBox["Environment",
    FontWeight->"Bold"],
  ": An environment defines the conditions of a milieu, in which adaptive \
components are embedded and with which they interact, thus being implicitly \
evaluated by their behavior (fitness)."
}], "Text"],

Cell[TextData[{
  StyleBox["Structures as adaptive components",
    FontWeight->"Bold"],
  ": The actual modifiable units are represented as structures separated from \
their environment. These structures may be expressed in various forms:"
}], "Text"],

Cell["\t\:f2a5 Genetics: chromosomes", "Text"],

Cell[TextData["\t\:f2a5 Economic planning: mixes of goods"], "Text"],

Cell[TextData["\t\:f2a5 Physiology: cell assemblies"], "Text"],

Cell[TextData["\t\:f2a5 Game theory: strategies"], "Text"],

Cell[TextData["\t\:f2a5 Artificial intelligence: programs"], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["ability for adaptation",
    FontWeight->"Bold"],
  " is ",
  StyleBox["the",
    FontSlant->"Italic"],
  " central mechanism for any \"learning system\"."
}], "Text"],

Cell[TextData[{
  "For a more detailed discussion of adaptive systems, we need a few more \
definitions ",
  ButtonBox["(Holland, 1992a (pp. 22ff. Figure 7)):",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Holland 1992a"},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  StyleBox["Environment",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[", \[ScriptCapitalE]\nThe environment of the adaptive system.",
    FontSlant->"Plain"]
}], "ListSquare"],

Cell[TextData[{
  "Structures",
  StyleBox[
  ", \[ScriptCapitalS]\nA (finite) set of structures as genotypes, the \
phenotypic interpretations \[Pi](\[ScriptCapitalS]), interacting with their \
environment \[ScriptCapitalE]:",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell["\[Pi](\[ScriptCapitalS]): \[ScriptCapitalS] \[Rule] \
\[ScriptCapitalE].", "NumberedEquation"],

Cell[TextData[{
  "Operators",
  StyleBox[
  ", \[ScriptCapitalO], for structure modification\nA (finite) set of \
structure modifying operators",
    FontWeight->"Plain"]
}], "ListSquare",
  FontWeight->"Bold"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalO] = {\[Omega] : \[ScriptCapitalS]\
\[Cross]\[ScriptCapitalS]\^m \[Rule] \[ScriptCapitalS]}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Element] {1, \[Ellipsis], \(\(\
\[VerticalSeparator]\)\(\(\[ScriptCapitalS]\)\(\[VerticalSeparator]\)\)\)}\)]]\
,
  "."
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["Evaluation function",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Mu]\_\[ScriptCapitalE]\),
          FontWeight->"Plain"], TraditionalForm]]],
  "\n",
  StyleBox[
  "The \[RightGuillemet]fitness\[LeftGuillemet] or evaluation function ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\_\[ScriptCapitalE]\)]],
  " returns a fitness value ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Mu]\_\[ScriptCapitalE]\)(s) \[Element] 
        \[DoubleStruckCapitalR]\)]],
  " for each structure ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Element] \[ScriptCapitalS]\)]],
  ". The fitness evaluation takes environmental signals, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CurlyPhi](\[Pi](s)) \[Element] 
        \[ScriptCapitalI]\_\[ScriptCapitalE]\)]],
  ", into account which the phenotype \[Pi](s) receives."
}], "ListSquare"],

Cell[TextData[{
  StyleBox["Adaptation algorithm",
    FontWeight->"Bold"],
  ", \[Alpha]\nAn algorithm that determines the modifications of the \
structures \[ScriptCapitalS] by operators \[Omega]\[Element]\[ScriptCapitalO] \
in reaction to environmental signals ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalI]\_\[ScriptCapitalE]\)]],
  "."
}], "ListSquare"],

Cell["\<\
The following table displays a few adaptive systems together with \
their structures, operators, and performance measures:
\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox["Field",
              FontWeight->"Bold"], 
            StyleBox["Structures",
              FontWeight->"Bold"], 
            StyleBox["Operators",
              FontSize->14,
              FontWeight->"Bold"], 
            StyleBox[\(Performance\ Measure\),
              FontSize->14,
              FontWeight->"Bold"]},
          {
            StyleBox["Genetics",
              FontSize->14], 
            StyleBox["chromosomes",
              FontSize->14], 
            
            StyleBox[\(mutation, \ \[IndentingNewLine]recombination, \ \n
              gene\ regulation\),
              FontSize->14], 
            StyleBox["fitness",
              FontSize->14]},
          {
            StyleBox["Economics",
              FontSize->14], 
            StyleBox[\(mixes\ of\ goods\),
              FontSize->14], 
            StyleBox[\(production\ \n
              activities\),
              FontSize->14], 
            StyleBox[\(profit, \ GNP\),
              FontSize->14]},
          {
            StyleBox["Physiology",
              FontSize->14], 
            StyleBox[\(cell\ assemblies\),
              FontSize->14], 
            StyleBox[\(synapse\ \n
              modification\),
              FontSize->14], 
            StyleBox[\(performance\ rate, \n\terror\),
              FontSize->14]},
          {
            StyleBox[\(Game\ theory\),
              FontSize->14], 
            StyleBox["strategies",
              FontSize->14], 
            StyleBox[\(rules\ for\ \n
              optimal\ strategies\),
              FontSize->14], 
            StyleBox["payoff",
              FontSize->14]},
          {
            StyleBox[\(Artificial\ \[IndentingNewLine]
              intelligence\),
              FontSize->14], 
            StyleBox["programs",
              FontSize->14], 
            StyleBox[\(learning\ rules\),
              FontSize->14], 
            StyleBox[
              RowBox[{
                StyleBox["efficiency",
                  FontSize->14], 
                StyleBox[",",
                  FontSize->14], 
                StyleBox["\n",
                  FontSize->14], 
                StyleBox[\(classification\ error\),
                  FontSize->14], 
                StyleBox[",",
                  FontSize->14], 
                StyleBox["\n",
                  FontSize->14], 
                RowBox[{
                  StyleBox["generalization",
                    FontSize->14], " ", 
                  StyleBox["ability",
                    FontSize->14]}]}],
              FontSize->17]}
          },
        RowLines->True,
        ColumnLines->True],
      FontSize->15]]]], "Text",
  CellMargins->{{99, Inherited}, {Inherited, Inherited}},
  FontSize->11],

Cell["\<\

\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Performing an Adaptation Step (",
  ButtonBox["Animation",
    ButtonData:>"Adaptation step animation",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Subsubsection"],

Cell[TextData[{
  "We consider adaptation as a discrete process. We are interested in the \
states of the system at time steps ",
  Cell[BoxData[
      \(TraditionalForm\`t, t + 1, t + 2, \[Ellipsis]\)]],
  " "
}], "Text"],

Cell[TextData[{
  "An adaptation step leading from a structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t)\)]],
  " to a structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t + 1)\)]],
  " is then performed as follows (Figure ",
  CounterBox["NumberedFigure", "AdaptationStep"],
  "):"
}], "Text"],

Cell[TextData[{
  "1.\t",
  StyleBox["Expression",
    FontWeight->"Bold"],
  ": A structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t) \[Element] \[ScriptCapitalS]\)]],
  " is mapped into its phenotypic representation ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptP](t) := \[Pi](s(t))\)]],
  " in the environment."
}], "ListNumbered"],

Cell[TextData[{
  "2.\t",
  StyleBox["Interaction",
    FontWeight->"Bold"],
  " with the environment: In response to the ",
  Cell[BoxData[
      \(TraditionalForm\`phenotype\^\[Prime]\)]],
  "s behavior, the environment returns a set of feedback signals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalI]\_\[ScriptCapitalE]\)(t)\)]],
  " which contains (among others) specific signals for \[ScriptP](t):"
}], "ListNumbered"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\_\[ScriptCapitalE]\)(\[ScriptP](
            t)) = \(\(\[ScriptCapitalI]\_\(\[ScriptCapitalE], \[ScriptP]\)\)(
            t) = \(\[ScriptCapitalI]\_\[ScriptCapitalE]\)(t)\)\)]],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "3.\t",
  StyleBox["Evaluation",
    FontWeight->"Bold"],
  ": On the basis of the environmental signals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\_\[ScriptCapitalE]\)(\[ScriptP](
          t))\)]],
  " a fitness "
}], "ListNumbered"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Mu]\_\[ScriptCapitalE]\)(
        s(t)) = \(\[Mu]\_\[ScriptCapitalE]\)(\[ScriptP](
          t), \(\[CurlyPhi]\_\[ScriptCapitalE]\)(\[ScriptP](
            t)))\)]]], "NumberedEquation"],

Cell[TextData[{
  "\tfor the phenotype ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptP](t) = \[Pi](s(t))\)]],
  " is calculated, which is an implicit fitness for the genotype structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t)\)]],
  ":"
}], "ListNumbered"],

Cell[TextData[{
  "4.\t",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ": Depending on the fitness ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Mu]\_\[ScriptCapitalE]\)(s(t))\)]],
  " of structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t)\)]],
  " the adaptive plan \[Alpha] selects a structure modifying operator \
\[Omega]\[Element]\[ScriptCapitalO] from the operator set \[ScriptCapitalO]."
}], "ListNumbered"],

Cell[TextData[{
  "5.\t",
  StyleBox["Variation",
    FontWeight->"Bold"],
  ": Applying operator \[Omega] to structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t)\)]],
  " results in a generally modified structure ",
  Cell[BoxData[
      \(TraditionalForm\`s(t + 1) = \[Omega](s(t))\)]],
  "."
}], "ListNumbered"],

Cell[" ", "Text",
  CellTags->"Adaptation step animation"],

Cell[CellGroupData[{

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00aP3oool700000>80oooo00340?ooo`/00000h03oool00<80oooo100000070?ooo`@00000
gP3oool00<40oooo0`00000;0?ooo`<00000g@3oool00<00oooo0`0000040?ooo`0507MgM`0R8R80
MgMg06IVIP2IVIT0103oool300000=`0oooo00300?ooo`8000001@3oool01P0c<c<0k^k^0?ooo`3o
ool0MgMg03<c<`@0oooo0P00003L0?ooo`00_`3oool2000000X0oooo00<0gMgM0000001gMgL0103o
ool200000=/0oooo002o0?ooo`8000002`3oool00`0000004A4A0?ooo`030?ooo`800000f`3oool0
0;h0oooo0P00000;0?ooo`030<c<c0000000000000D0oooo0P00000g0?ooo`<00000X03oool00;h0
oooo0P0000080?ooo`060>k^kP3oool0k^k^04A4A0000000<c<c1@3oool2000003P0oooo00<00000
0?ooo`3oool0W`3oool00;h0oooo0P0000080?ooo`0609VIV@0A4A4000000000000c<c<0c<c<1@3o
ool2000003P0oooo00<000000?ooo`3oool0W`3oool00;h0oooo0P0000090?ooo`030>k^kP1EEED0
IVIV00L0oooo0P00000h0?ooo`030000003oool0oooo09l0oooo002n0?ooo`8000002`3oool00`0A
4A40MgMg0?ooo`050?ooo`800000703oool3000000D0oooo0`0000030?ooo`80000000<0oooo0000
003oool00P3oool500000080oooo100000060?ooo`D00000103oool00`000000oooo0?ooo`040?oo
o`<000001`3oool3000000H0oooo0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`03
000006<0oooo002n0?ooo`8000001`3oool0103^k^h0oooo0?ooo`3oool2014A4@H0oooo0P00000M
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000<0
oooo0000003oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1R0?ooo`00_`3oool2
000000H0oooo00H0VIVI07MgM`2k^k/0EEEE0000000A4A450?ooo`8000007`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0HP3oool00;l0oooo0P0000070?ooo`050:ZZ
ZP0R8R80000003<c<`3<c<`01@3oool2000001l0oooo1`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`<000000`3oool01@000000oooo0?ooo`3oool0000006@0oooo00300?ooo`8000003`3oool20000
0240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`06000000L0
oooo1P0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0680oooo00300?ooo`<000003@3oool300000240oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool0HP3oool00<40oooo0`00000;0?ooo`<0
00008P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000000`3oool000000?ooo`020?oo
o`<00000103oool010000000oooo0000000000040?ooo`@0000000@0oooo0000003oool0oooo0`00
0000103oool000000000000000030?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo0`0000040?ooo`040000003oool00000000006D0oooo00320?ooo`@0
00001`3oool4000002@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00a03oool;000002H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00aP3oool7000002P0oooo00<000000?ooo`0000002@3oool2000002l0oooo00<000000?ooo`3o
ool00`3oool010000000oooo00000000001c0?ooo`00mP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<000000?ooo`3o
ool0L@3oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool007H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0f0?ooo`00N03oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000000j0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001b0?ooo`3o0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000040?oo
o`000000oooo000003X0oooo001`0?ooool000001@0000000`3oool000000000000h0?ooo`00L03o
oooo000000@0000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`
l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`800000E03`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00d0l?3`00<000000?3`
l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00D0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000403`l?000`000000
l?3`0?3`l0030?3`l0L000000P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00@0l?3`0P0000020?3`l0800000
0P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?00
1`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000>0?3`l0@000001@3`l?02000000D0l?3`00@000000?3`l03`l?00l?3`0P0000030?3`l0<00000
0P3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
0`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000=0?3`l0060000003`l?00l?3`0000003`l?000000103`l?02000000030?3`l000000000000080
l?3`00<000000?3`l03`l?000`3`l?001P000000l?3`0?3`l0000000l?3`00000080l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?000`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool0
0700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`
l?0500000080l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000040?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000
003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`l03`l?00
l?3`0P0000000`3`l?000000000000020?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`
l?000000103`l?000`000000l?3`0?3`l0050?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo
03T0oooo001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`
l03`l?00l?3`0P0000020?3`l080000000<0l?3`0000003`l?00103`l?0010000000l?3`0?3`l000
00040?3`l0030000003`l?00l?3`00<0l?3`0P0000040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000`3`l?04000003L0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?000`000000l?3`0?3`
l007000000030?3`l0000000l?3`0080l?3`00<000000?3`l00000000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`8000003@3`l?03000000030?3`l0000000000000/0l?3`00<00000
0?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?05000003H0l?3`>@3ooolg
0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000N0?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?000`3`l?0400000080l?3`00@000000?3`l03`l?00l?3`10000004
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l003
0?3`l0D00000=P3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
01l0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`
0?3`l00000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?00103`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool0
0700oooo0P00000O0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?001@00
0000l?3`0?3`l03`l?00000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00@0l?3`1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo001`0?ooo`800000803`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`
00T0l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?001@3`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo0000
000000003`3oool6000002<0oooo001`0?ooo`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`80
000000<0oooo0000003oool03@3oool<00000200oooo001`0?ooo`800000E03`l?07000003@0l?3`
>@3ooolg0<o?c`<0000000<0oooo0000000000002`3oool4000000H0oooo1000000O0?ooo`00L03o
ool2000005@0l?3`1`00000d0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo00/0oooo0`00
000:0?ooo`<000007P3oool00700oooo0P00001D0?3`l0L000001`3`l?000`000000l?3`0?3`l005
0?3`l0L00000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0100l?3`>@3ooolO
0<o?c`030000003?cll0clo?00<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000
000000T0oooo0`0000070?ooo`0303<c<`000000oooo0080oooo0`00000M0?ooo`00L03oool20000
05@0l?3`1`0000070?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l08000000`3`l?000`00
0000l?3`0?3`l0060?3`l0030000003`l?00l?3`00/0l?3`0`0000000`3`l?00oooo0?ooo`0D0?oo
o`D00000103oool2000001D0oooo0`00000N0<o?c`030000003?cll0clo?00D0clo?00<000000<o?
c`3?cll03P3?cll2000000030?ooo`000000oooo00T0oooo0`0000080?ooo`0303<c<`000000oooo
00<0oooo0`00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000003`l?00l?3`00H0
l?3`0P0000070?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?002`3`l?04000001D0
oooo0`0000030?ooo`8000000P3oool3000001@0oooo1000000L0<o?c`030000003?cll0clo?00L0
clo?00<000000<o?c`3?cll03@3?cll3000000030?ooo`000000000000P0oooo0P0000090?ooo`03
03<c<`000000oooo00@0oooo0P00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0@00000
0P3`l?02000000040?3`l000000000000?3`l08000000`3`l?000`000000l?3`0?3`l0020?3`l0<0
00000`3`l?000`000000l?3`0?3`l00:0?3`l0H000004P3oool3000000D0oooo100000000`3oool0
00000?ooo`0C0?ooo`D000004@3?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?
c`3?cll0clo?0`0000030<o?c`030000003?cll0clo?00d0clo?0P0000000`3oool000000?ooo`09
0?ooo`800000103oool507MgM`04014A4@000000MgMg0=gMg@<0oooo0P00000L0?ooo`00L03oool2
000005@0l?3`200000060?3`l0040000003`l?00l?3`0?3`l08000000`3`l?05000000<0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`1`00
000A0?ooo`8000001P3oool3000001L0oooo1`00000>0<o?c`030000003?cll0clo?008000000`3?
cll00`000000clo?000000040<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?
cll3000000030?ooo`000000000000L0oooo0P0000050?ooo`P0000000<0^k^k0?ooo`3oool00P3o
ool2000001/0oooo001`0?ooo`800000E03`l?09000000D0l?3`00@000000?3`l03`l?00l?3`0P00
00030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002P3`l?09000000h0oooo0`0000070?ooo`8000005`3o
ool8000000d0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`80000000<0oooo0000003oool0
203oool2000000D0oooo00<0c<c<05EEE@3oool00P3oool00`0c<c<000000?ooo`050?ooo`800000
6`3oool00700oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0040000003`
l?00l?3`0?3`l08000000P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`2P00000=0?ooo`<000001`3oool2000001L0oooo
2@00000<0<o?c`050000003?cll0clo?0<o?c`0000000`3?cll00`000000clo?000000040<o?c`03
0000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?cll3000000030?ooo`000000000000L0
oooo0P0000060?ooo`0609VIV@28R8P0oooo0?ooo`0c<c<000001P3oool2000001/0oooo001`0?oo
o`800000E03`l?09000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0070000
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?000000
01D00000303oool3000000L0oooo0`00000:0?oooaH000002`3?cll01@000000clo?0<o?c`3?cll0
000000<0clo?00<000000<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0
clo?00`0clo?0P0000000`3oool000000?ooo`080?ooo`8000001`3oool01@1EEED0^k^k0?ooo`0c
<c<0000000H0oooo0P00000K0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00<0l?3`00<000000?3`l00000005@00000<0?ooo`<000001`3oool3000000X0oooo5P00000;
0<o?c`8000000P3?cll00`000000clo?0<o?c`02000000030<o?c`000000clo?00<0clo?00<00000
0<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo0000000000001`3oool2
000000P0oooo00@0<c<c0<c<c00c<c<000001P3oool2000001/0oooo001`0?ooo`800000E03`l?09
000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003`3oool2
000000H0oooo00@000000?ooo`00000000005P3oool8000000h0clo?0P0000030<o?c`8000000`3?
cll01@000000clo?0<o?c`3?cll0000000D0clo?00<000000<o?c`3?cll03@3?cll2000000030?oo
o`000000oooo00P0oooo0P0000080?ooo`040>k^kP0c<c<08R8R000000H0oooo0P00000K0?ooo`00
L03oool2000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?000`000000
l?3`0?3`l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool70000
01T0clo?00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3o
ool00000000000080?ooo`800000203oool00`3<c<`00000000000050?ooo`800000703oool00700
oooo0P00001D0?3`l0P00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`
l03`l?002`3`l?05000001@0oooo0`0000030?ooo`030000003oool0oooo00<000005@3oool50000
01`0clo?00@000000<o?c`3?cll00000103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo
0000003oool02@3oool2000000T0oooo00<0VIVI0000003oool0103oool2000001`0oooo001`0?oo
o`800000E03`l?08000001P0l?3`00D000000?3`l03`l?00l?3`000000040?3`l0030000003`l?00
l?3`00/0l?3`1000000G0?ooo`@000000`3oool3000001D0oooo0`00000O0<o?c`030000003?cll0
000000<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000000000P0oooo0`00000>
0?ooo`<00000703oool00700oooo0P00001D0?3`l0L000006P3`l?000`000000l?3`0?3`l0040?3`
l0030000003`l?00l?3`00`0l?3`0P0000020?3`l3H0oooo0P0000000`3oool0clo?0<o?c`0e0<o?
c`80000000<0oooo0000003oool02P3oool3000000`0oooo0`00000M0?ooo`00L03oool2000005@0
l?3`1`00000d0?3`l3T0oooo=`3?cll3000000030?ooo`000000000000X0oooo0`00000:0?ooo`<0
00007P3oool00700oooo0P00001D0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0<0?ooo`@000001P3oool4000001l0oooo001`0?ooo`800000E03`l?07000003@0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000303oool<00000200oooo001`0?ooo`800000E03`l?06
000003D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0403oool6000002<0oooo001`0?oo
o`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000`0?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000
003`l?00l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<0
00000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3o
ool00700oooo0P00000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?00
0`000000l?3`0?3`l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?
c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0
l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000
:P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i
0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000X0?3`l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00000_0?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0
l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000
l?3`0?3`l0050?3`l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
000/0?ooo`<00000@@3oool2000000T0l?3`0`0000230?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo000[0?ooo`050000003oool0oooo0?ooo`000000@03oool2000000L0l?3`1@00
00230?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000`0?ooo`030000003oool0
oooo03d0oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`008@3oool6000000030?ooo`000000oooo00<0oooo0P000000103oool000000?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000000`3oool00000000000030?ooo`@000009`3oool2
00000080l?3`2@0000240?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000P0?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo0000
003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0903oool=000008@0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00200oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool2
000000L0oooo00<000000?ooo`3oool0903oool<000008D0l?3`>@3ooolg0<o?c`80000000<0oooo
0000003oool0>@3oool002L0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`8000009P3oool<
000008H0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool002D0oooo0P0000001@3o
ool000000?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`H000000`3oool2000002P0oooo300000260?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo000Q0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool0:@3oool:
000008L0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool00200oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool0000000000003
0?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0T0?ooool000001000000l0?ooo`00803oool00`000000oooo0?ooo`04
0?ooo`800000103oool2000000050?ooo`000000oooo0000003oool00`0000050?ooo`@0000000<0
oooo0000003oool00P3oool4000002L0ooooo`000004000003`0oooo000P0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`P00000o`3ooolh
0?ooo`008@3oool6000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool0:`3oool30000
0080oooo1000003o0?ooocP0oooo001^0?ooo`<00000103oool2000002h0oooo0P00o`3o0?ooo`T0
oooo001]0?ooo`<00000=@3oool2003o0?l0oooo2@3oool006`0oooo0`00000f0?ooo`800?l0o`3o
ool90?ooo`00J`3oool3000003H0oooo1000o`3o0?ooo`P0oooo000;0?ooo`L0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo008000000`3oool3000000040?ooo`0000000000000000`0oooo
0`00000g0?ooo`@00?l0o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3o
ool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000003oool02P3oool3000003P0oooo1000o`3o0?oo
o`P0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0
oooo1000000i0?ooo`D00?l0o`3oool70?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000080?ooo`@00000>P3oool5003o0?l0oooo1`3oool000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo1@00
00000`3oool000000?ooo`060?ooo`<00000>`3oool6003o0:L0oooo0`3o001L0?ooo`002`3oool7
000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000080?ooo`030000003oool0
000000H0oooo0`00000l0?ooo`H00?l0YP3oool40?l005`0oooo000;0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`8000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool3000003d0oooo1`00o`2T0?ooo`<0o`00GP3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P00
00020?ooo`050000003oool000000000003oool00`0000050?ooo`800000103oool00`000000oooo
0000000200000080oooo0`0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`<00000
?P3oool7003o0:<0oooo0`3o001O0?ooo`002`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00000o0?ooo`L00?l0XP3oool30?l00600oooo
000;0?ooo`L000003`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`00000o0?ooo`T00?l0X@3oool20?l00640oooo001O0?ooo`<00000@03oool9
003o0?l0oooo1@3oool005h0oooo0`0000110?ooo`T00?l0o`3oool50?ooo`00GP3oool200000480
oooo1`00o`3o0?ooo`L0oooo001M0?ooo`<00000AP3oool2003o0?l0oooo203oool005d0oooo0P00
00170?ooo`800?l0o`3oool80?ooo`00G03oool3000004L0oooo0P00o`3o0?ooo`P0oooo001K0?oo
o`<00000B03oool2003o09h0oooo0P3o001W0?ooo`00F`3oool2000004T0oooo0P00o`2M0?ooo`<0
o`00I`3oool005X0oooo0`0000190?ooo`800?l0W03oool30?l006P0oooo001J0?ooo`800000i`3o
ool30?l006T0oooo001I0?ooo`<00000iP3oool30?l006X0oooo001I0?ooo`800000iP3oool30?l0
06/0oooo001H0?ooo`<00000i@3oool30?l006`0oooo001G0?ooo`<00000i@3oool30?l006d0oooo
001G0?ooo`800000iP3oool20?l006h0oooo001F0?ooo`<00000o`3ooomG0?ooo`00EP3oool20000
0500oooo0P00o`3o0?ooo`H0oooo001E0?ooo`<00000D03oool2003o0?l0oooo1P3oool005D0oooo
0P00001A0?ooo`800?l0o`3oool60?ooo`00E03oool300000540oooo0P00o`3o0?ooo`H0oooo001D
0?ooo`800000DP3oool2003o06/0oooo1`00002C0?ooo`00D`3oool300000580oooo0P00o`1Y0?oo
o`/000006`3oool20?l007@0oooo001B0?ooo`<00000D`3oool2003o06L0oooo100000070?ooo`@0
00006@3oool20?l007@0oooo001B0?ooo`800000E03oool2003o06H0oooo0`00000;0?ooo`<00000
5`3oool30?l007@0oooo001A0?ooo`<00000E03oool2003o06D0oooo0`0000030?ooo`060=gMg@0R
8R80EEEE08R8R01gMgL0gMgM103oool3000001D0oooo0`3o001e0?ooo`00D@3oool2000005D0oooo
0P00o`1U0?ooo`800000103oool01`3<c<`0VIVI0?ooo`3oool0k^k^028R8P3<c<`0103oool20000
01@0oooo0`3o001f0?ooo`00D03oool3000005D0oooo0P00o`1T0?ooo`8000002P3oool00`1gMgL0
A4A40?ooo`040?ooo`8000004P3oool30?l007L0oooo001@0?ooo`800000EP3oool2003o06@0oooo
0P00000:0?ooo`0305EEE@000000oooo00@0oooo0P00000A0?ooo`<0o`00N03oool004l0oooo0`00
001F0?ooo`800?l0H`3oool2000000X0oooo00<0c<c<0000000R8R801P3oool2000000l0oooo0`3o
001i0?ooo`00C`3oool2000005L0oooo0P00o`1S0?ooo`800000203oool01@3^k^h0MgMg00000000
0000VIVI00H0oooo0P00000>0?ooo`<0o`00NP3oool004l0oooo0P00002l0?ooo`8000001`3oool0
1@2ZZZX00000000000000000MgMg00L0oooo0P00000=0?ooo`<0o`00N`3oool004h0oooo0`00002l
0?ooo`8000001`3oool0103^k^h0000008R8R03MgMd80?ooo`8000003@3oool20?l007`0oooo001>
0?ooo`800000_@3oool2000000P0oooo00<0IVIV0?ooo`3oool0203oool2000008/0oooo001=0?oo
o`<00000_@3oool2000000P0oooo00<0VIVI03<c<`0c<c<00P0c<c<00`3^k^h0oooo0?ooo`030?oo
o`800000R`3oool004d0oooo0P00002o0?ooo`8000001`3oool00`3^k^h000000000000200000003
09VIV@3oool0oooo0080oooo0P00002<0?ooo`00C03oool300000;l0oooo0P00000A0?ooo`800000
S03oool004`0oooo0P0000310?ooo`8000003`3oool2000008d0oooo001;0?ooo`<00000F`3oool2
003o06@0oooo0`00000=0?ooo`<000002@3oool20?l00880oooo001;0?ooo`800000G03oool2003o
06D0oooo0`00000;0?ooo`<000002P3oool20?l00880oooo001;0?ooo`800000G03oool2003o06H0
oooo100000070?ooo`@000002P3oool30?l00880oooo001:0?ooo`<00000G03oool2003o06P0oooo
2`00000;0?ooo`<0o`00P`3oool004X0oooo0P00001M0?ooo`<00?l0J@3oool7000000`0oooo0`3o
00240?ooo`00B@3oool3000005h0oooo0P00o`1k0?ooo`<0o`00Q@3oool004T0oooo0P00001O0?oo
o`800?l0N`3oool20?l008H0oooo00180?ooo`<00000G`3oool2003o07X0oooo0`3o00260?ooo`00
B03oool200000600oooo0P00o`1i0?ooo`<0o`00Q`3oool004P0oooo0P00001P0?ooo`800?l0N03o
ool30?l008P0oooo00170?ooo`<00000H03oool3003o07L0oooo0P3o00290?ooo`00A`3oool20000
0680oooo0P00o`3o0?ooo`<0oooo00160?ooo`<00000HP3oool2003o0?l0oooo0`3oool004H0oooo
0P00001S0?ooo`800?l0o`3oool30?ooo`00AP3oool200000?l0ooooJ03oool004H0oooo0P00003o
0?ooofP0oooo000Y0?ooo`H000005P3oool300000?l0ooooJ03oool002H0oooo3000000C0?ooo`80
0000e`3oool20?l008l0oooo000U0?ooo`@000001P3oool400000180oooo0P00003G0?ooo`80o`00
S`3oool002@0oooo0`0000020?ooo`L0000000@0A4A400000000000000004@3oool200000=H0oooo
0`3o002?0?ooo`008`3oool3000000<0oooo00<0VIVI000000000000100c<c<00`14A4@0oooo0000
000200000100oooo0P00003E0?ooo`<0o`00T03oool00280oooo0`0000050?ooo`030<c<c0000000
^k^k00<0oooo00<0R8R80?ooo`3oool00`00000?0?ooo`800000e03oool30?l00940oooo000R0?oo
o`8000001`3oool00`3<c<`04A4A0<c<c0060?ooo`8000003`3oool200000=<0oooo0`3o002B0?oo
o`008P3oool2000000P0oooo00<0^k^k0000003^k^h01@3oool2000000h0oooo0`00001U0?ooo`80
0?l0J`3oool30?l009<0oooo000Q0?ooo`8000002P3oool00`1VIVH0<c<c0?ooo`050?ooo`800000
3@3oool2000006H0oooo0P00o`1Z0?ooo`<0o`00U03oool00240oooo0P00000:0?ooo`030=gMg@00
0000^k^k00D0oooo0P00000=0?ooo`800000IP3oool2003o06T0oooo0`3o002E0?ooo`008@3oool2
000000/0oooo00<08R8R04A4A03oool0103oool2000000d0oooo0P00001V0?ooo`800?l0J03oool3
0?l000/0oooo3000001o0?ooo`008@3oool2000000/0oooo0P0A4A450?ooo`8000003@3oool20000
06H0oooo0P00o`1S0?ooo`D000000P3o000I000007h0oooo000Q0?ooo`8000001P3oool01`2ZZZX0
c<c<0?ooo`3oool0^k^k0000000A4A401@3oool2000000d0oooo0P00001V0?ooo`800?l0D@3ooolV
000000X0l?3`1000001l0?ooo`008@3oool2000000L0oooo00<0<c<c06IVIP1VIVH00P0000000`1E
EED0oooo0?ooo`030?ooo`8000003@3oool2000006H0oooo0P00o`0n0?ooobH000007P3`l?040000
07/0oooo000R0?ooo`8000001P3oool01P3^k^h0MgMg000000000000EEEE0>k^kP@0oooo0P00000=
0?ooo`<00000IP3oool2003o02/0oooo9`00000b0?3`l0@00000N@3oool00280oooo0P00000@0?oo
o`8000003@3oool2000006L0oooo0P00o`0I0?ooobH00000AP3`l?04000007P0oooo000R0?ooo`<0
00003P3oool3000000d0oooo0P00001W0?ooo`800?l01P3ooolV000005/0l?3`1000001f0?ooo`00
8`3oool3000000`0oooo0`00000>0?ooo`800000G@3oool:000000800?l06P0000170?3`l080o`00
9@3`l?04000007D0oooo000T0?ooo`<000002P3oool3000000l0oooo0P00001:0?oooad000000P00
o`07000005T0l?3`0`3o000W0?3`l0@00000L`3oool002D0oooo100000060?ooo`@00000403oool2
000003L0oooo9`00001Z0?3`l0<0o`00:@3`l?0400000780oooo000V0?ooo``000004@3oool20000
02D0oooo9P00001l0?3`l0<0o`00;03`l?0300000740oooo000Y0?ooo`H000004`3oool300000180
oooo9P00002>0?3`l0<0o`00;P3`l?04000006l0oooo00120?ooo`8000002P3ooolM000009l0l?3`
0`3o000`0?3`l0@00000;03oool2000000030?ooo`000000000000800000>`3oool00480oooo0P00
000:0?ooo`X00000/@3`l?030?l003<0l?3`1000000Z0?ooo`@000000P3oool2000003X0oooo0012
0?ooo`800000303oool700000;40l?3`0`3o000e0?3`l0@00000:@3oool3000000<0oooo0`00000i
0?ooo`00@P3oool2000000l0oooo1P00002^0?3`l0<0o`00>03`l?04000002L0oooo0P0000040?oo
o`<00000>@3oool00480oooo0P00000B0?ooo`H00000Z`3`l?020?l003X0l?3`1000000[0?ooo`@0
0000>@3oool00480oooo0P00000D0?ooo`H00000<`3`l?0@000000P0l?3`0P0000030?3`l0800?l0
U@3`l?04000002L0oooo1@00000j0?ooo`00@P3oool2000001L0oooo1P00000Q0?3`l08000000`3`
l?0200000080l?3`0P0000040?3`l1<00000103`l?03000000<0l?3`0P00o`2F0?3`l0@00000903o
ool6000003/0oooo00120?ooo`8000006@3oool7000001h0l?3`0P0000030?3`l08000000P3`l?02
000001<0l?3`300000020?3`l0800?l0V03`l?0400000240oooo1@00000m0?ooo`00@P3oool20000
01`0oooo1P00000m0?3`l0T000000P3`l?02003o09T0l?3`1000000P0?ooo`<00000103oool20000
03T0oooo00110?ooo`<000007`3oool6000003d0l?3`1P0000020?3`l0800?l0V`3`l?04000001h0
oooo0`0000030?ooo`<00000>@3oool00440oooo0P00000R0?ooo`H00000>P3`l?08000000030?3`
l000o`000?l00540l?3`0P3o00190?3`l0@000007P3oool200000080oooo1000000i0?ooo`00@@3o
ool2000002D0oooo1P00000g0?3`l0P0000000<0l?3`003o0000o`00D@3`l?020?l004/0l?3`1000
000M0?ooo`@0000000<0oooo000000000000>@3oool00440oooo0P00000W0?ooo`L00000=03`l?08
000005<0l?3`0`3o001<0?3`l0@00000G03oool00440oooo0P00000Z0?ooo`H00000=@3`l?060000
02L0l?3`00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00J0?3`l080o`000`3`l?030?l0
04l0l?3`1000001J0?ooo`00@@3oool2000002d0oooo1P00000e0?3`l0<000009P3`l?000`2`/;00
H61P0?3`l0060?3`l0030=3@d01@D500l?3`01X0l?3`0`3o0000103`l?00o`000?l0003o001A0?3`
l0@00000F@3oool00440oooo0P00000_0?ooo`H000009P3`l?000`3Ph>00l?3`0?3`l00c0?3`l003
010@4030`<00l?3`00L0l?3`00<0820P0=3@d03`l?00603`l?070?l005@0l?3`1000001G0?ooo`00
@@3oool200000380oooo1P00000R0?3`l0030=3@d00P8200l?3`00L0l?3`00<0L71`0=3@d03`l?00
1@3`l?05000001H0l?3`0`000000103`l?0000000000000000020?3`l0030;2`/00@4100l?3`0080
l?3`00@0L71`0000000`<300h>3P0P3`l?000`1`L700H61P0?3`l00H0?3`l0P0o`00E03`l?040000
05H0oooo00110?ooo`800000=03oool7000001l0l?3`00<0D51@092@T03`l?001`3`l?000`2`/;00
D51@0?3`l0040?3`l0L00000503`l?000`000000l?3`0?3`l002000000<0l?3`00@000000?3`l01P
H600H61P0`3`l?0010000000410@0;2`/02`/;020?3`l0030;2`/00P8200l?3`01L0l?3`2P3o001E
0?3`l0@00000E03oool00440oooo0P00000g0?ooo`H00000703`l?000`3@d=0000000>3Ph0090?3`
l003010@403@d=00l?3`00<0l?3`1`00000D0?3`l0050000003`l?00l?3`0?3`l00000000`3`l?00
10000000l?3`020P802@T9030?3`l0030000000`<300l?3`00<0l?3`00<0h>3P0000003`l?005`3`
l?0:0?l005H0l?3`1000001C0?ooo`00@@3oool2000003X0oooo1P00000B0?3`l005030`<01@D500
H61P030`<030`<000P3`l?000`20P800<30`0?3`l0020?3`l004071`L0000000<30`0<30`0<0l?3`
00<0H61P071`L03`l?000`3`l?07000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l004
0000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000`<300?3`l00E0?3`
l0T0o`00FP3`l?0300000580oooo00110?ooo`800000?03oool600000100l?3`00D0D51@0?3`l03`
l?00L71`020P80020?3`l003030`<01`L700l?3`0080l?3`00@00000010@402`/;00X:2P0`3`l?00
0`2PX:00820P0?3`l0030?3`l0L000000`3`l?03000000h0l?3`00D000000?3`l03`l?00l?3`0000
00030?3`l0040000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000d=3@
0?3`l00E0?3`l0P0o`00G03`l?0400000500oooo00110?ooo`800000?`3oool6000000d0l?3`00<0
d=3@0?3`l02@T9000P0000020?3`l003010@402PX:00l?3`0080l?3`00<00000030`<03`l?00103`
l?000`3@d=0000000?3`l0040?3`l0D00000103`l?05000000`0l?3`0P0000020?3`l0030000003`
l?00l?3`0080000000<0l?3`0000002`/;000`3`l?000`000000<30`0?3`l0030?3`l0030;2`/000
0000l?3`01H0l?3`1`3o001N0?3`l0@00000C`3oool00440oooo0P0000110?ooo`L000002P3`l?00
1@2`/;00410@0000000@4100`<300080l?3`00<000000;2`/03`l?000P3`l?000`000000<30`0?3`
l0050?3`l0030000002`/;00l?3`00h0l?3`1@00000;0?3`l08000000`3`l?0200000080l?3`00D0
<30`092@T03`l?00l?3`061PH00200000006030`<02@T900l?3`0?3`l02@T900<30`5P3`l?060?l0
0680l?3`1000001=0?ooo`00@@3oool2000004@0oooo1P0000080?3`l080000000<0/;2`0?3`l03`
l?000P3`l?000`000000/;2`0?3`l0020?3`l0030000000`<300l?3`00D0l?3`00<000000;2`/03`
l?00403`l?0500000180l?3`00<0L71`061PH03`l?000P3`l?000`1@D500<30`0?3`l0030?3`l003
051@D020P800l?3`01D0l?3`1@3o001T0?3`l0@00000C03oool00400oooo0`0000170?ooo`H00000
1@3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0410@0:2PX03`l?000P3`l?000`000000
<30`0?3`l0050?3`l00300000030`<00l?3`0180l?3`1@00000@0?3`l0030=3@d00@4100l?3`00<0
l?3`00<0T92@0?3`l03`l?000P3`l?000`000000h>3P0?3`l00D0?3`l0D0o`00I`3`l?04000004X0
oooo00100?ooo`800000BP3oool6000000<0l?3`00D0`<300410@01`L700D51@0410@0020?3`l005
0410@01`L700l?3`0?3`l00`<3000`0000001P0`<300l?3`0?3`l03`l?00/;2`000001H0l?3`1@00
000?0?3`l0030410@03@d=00l?3`00H0l?3`00<0X:2P061PH03`l?005@3`l?030?l006X0l?3`1000
00190?ooo`00@03oool2000004d0oooo1P0000070?3`l003092@T00`<300l?3`0080l?3`00<0D51@
030`<03`l?00103`l?000`20P800820P0?3`l00G0?3`l0D000003@3`l?000`3@d=00H61P0?3`l006
0?3`l0030<30`03Ph>00l?3`01@0l?3`0`3o001]0?3`l0@00000A`3oool00400oooo0P00001?0?oo
o`L000001@3`l?000`000000h>3P0?3`l0020?3`l003092@T03`l?00l?3`00<0l?3`00<0<30`0820
P03`l?006@3`l?05000000`0l?3`00<0h>3P0?3`l03`l?00703`l?020?l006l0l?3`100000160?oo
o`00@03oool200000580oooo1P0000030?3`l003071`L02@T900l?3`00L0l?3`00<0h>3P0000003P
h>00703`l?05000009`0l?3`100000140?ooo`00@03oool2000005D0oooo1P0000000`3Ph>00@410
0?3`l0070?3`l0030820P01`L700l?3`01h0l?3`1P00002J0?3`l0@00000@`3oool00400oooo0P00
001G0?ooo`H00000203`l?000`2`/;00l?3`0?3`l00P0?3`l0L00000V@3`l?0400000440oooo0010
0?ooo`800000FP3oool6000002/0l?3`2000000G0?3`l0D00000NP3`l?0400000400oooo00100?oo
o`800000G03oool7000002/0l?3`200000080?3`l0<00000203`l?07000007/0l?3`1000000n0?oo
o`00@03oool2000005l0oooo1P00000]0?3`l0P00000103`l?05000000H0l?3`1`00001l0?3`l0@0
0000?@3oool00400oooo0P00001R0?ooo`H00000;@3`l?08000000030?3`l0000000000000@00000
1@3`l?07000007h0l?3`1000000k0?ooo`00@03oool300000600oooo0P0000000`3oool000000000
0004000002l0l?3`300000040?3`l0L00000O`3`l?04000003X0oooo00110?ooo`800000H03oool2
000000@0oooo1P00000_0?3`l0T000001@3`l?0500000880l?3`1000000h0?ooo`00@@3oool20000
0600oooo0P0000060?ooo`L00000;@3`l?06000008l0l?3`1000000g0?ooo`00@@3oool200000600
oooo0P0000090?ooo`H00000:`3`l?04000009<0l?3`1000000e0?ooo`00@@3oool2000005l0oooo
0`00000<0?ooo`H00000:03`l?02000009H0l?3`1000000d0?ooo`00@@3oool2000005l0oooo0P00
000?0?ooo`H00000`03`l?03000003<0oooo00110?ooo`<00000GP3oool200000180oooo1P00002n
0?3`l0@00000<@3oool00480oooo0P00001N0?ooo`800000503oool700000;`0l?3`1000000`0?oo
o`00@P3oool2000007L0oooo1P00000^0?3`l0030820P03`l?00l?3`01T0l?3`00<0H61P0=3@d03`
l?00K`3`l?04000002h0oooo00120?ooo`800000NP3oool6000002X0l?3`00<0X:2P051@D03`l?00
6P3`l?000`2`/;00D51@0?3`l01`0?3`l0@00000;@3oool00480oooo0P00000o0?ooo`H00000=`3o
ool6000002P0l?3`00<0820P0:2PX03`l?006`3`l?000`0@4100h>3P0?3`l01a0?3`l0@00000:`3o
ool001h0oooo2000000L0?ooo`800000?03oool<000003L0oooo1P00000N0?3`l008030`<01@D500
H61P0410@030`<00l?3`0<30`00000040?3`l004071`L0000000<30`0<30`0<0l?3`00<0L71`0000
003`l?001@3`l?001P2@T900@410000000000000D51@092@T0@0l?3`00<0D51@0820P03`l?00LP3`
l?04000002X0oooo000O0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0<0?ooo`<00000>P3oool4000000H0oooo1000000h0?ooo`L000006`3`l?00
201@D500l?3`0?3`l01PH600820P0?3`l01PH600@410103`l?0200000080X:2P0`3`l?000`1`L700
00000?3`l0070?3`l08000001P3`l?000`2@T900820P0?3`l01d0?3`l0@00000:03oool001l0oooo
0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool2000003T0oooo
0`0000040?ooo`0607MgM`14A4@000000000001EEED0VIVI0`00000j0?ooo`H000006@3`l?000`3@
d=00l?3`0;2`/002000000030?3`l00`<300L71`00@0l?3`00<00000030`<03`l?00103`l?000`1`
L70000000?3`l0070?3`l08000001P3`l?000`3@d=0000000?3`l01e0?3`l0@000009`3oool001l0
oooo0P0000080?ooo`8000002@3oool2000000d0oooo0P00000h0?ooo`<000001`3oool2000000<0
oooo0`00000l0?ooo`H000005P3`l?00203Ph>00@410000000000000D51@0?3`l0000000/;2`103`
l?001@000000<30`0?3`l03`l?00T92@0080L71`00<0<30`0000001`L7000P1`L7000`2`/;00l?3`
0?3`l0020?3`l08000001`3`l?000`000000/;2`0?3`l01f0?3`l0@000009@3oool001l0oooo0P00
00000`3oool00000000000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3o
ool2000003L0oooo0`0000080?ooo`800000103oool3000000`0oooo0P00000_0?ooo`H00000503`
l?00201@D50000000000001@D500h>3P0?3`l0000000/;2`103`l?001@000000<30`0?3`l03`l?00
<30`00L0000000<0L71`0?3`l03`l?000P3`l?02000000L0l?3`00<000000;2`/03`l?00M`3`l?04
000002@0oooo000G0?ooo`D000000`3oool5000000@0oooo0P0000050?ooo`800000103oool20000
00`0oooo0P00000g0?ooo`8000002@3oool2000000D0oooo0P00000<0?ooo`800000<P3oool60000
0140l?3`0P0000001P30`<00l?3`0?3`l03`l?0000000;2`/0@0l?3`00<00000030`<03`l?00103`
l?000`1`L70000000?3`l0070?3`l08000001`3`l?000`000000/;2`0?3`l01i0?3`l0@000008P3o
ool001P0oooo0`0000040?ooo`80000000<0oooo000000000000103oool2000000@0oooo0`000004
0?ooo`800000303oool2000003L0oooo0P0000090?ooo`8000001@3oool2000000/0oooo0`00000d
0?ooo`L000003P3`l?00100@4100L71`0?3`l01PH6020?3`l003020P802PX:00l?3`00<0l?3`00<0
0000030`<03`l?00103`l?000`1`L70000000?3`l0070?3`l08000001P3`l?000`30`<0000000?3`
l01k0?3`l0@000008@3oool001P0oooo0`0000040?ooo`8000001`3oool2000000@0oooo0P000005
0?ooo`800000303oool3000003D0oooo0P00000:0?ooo`8000001P3oool2000000X0oooo0P00000h
0?ooo`H00000303`l?001030`<00<30`071`L010@4020?3`l003051@D01`L700l?3`0080l?3`00D0
<30`0000000000000000030`<0030?3`l003071`L0000000l?3`00L0l?3`0P0000060?3`l003092@
T00@4100l?3`07d0l?3`1000000O0?ooo`00603oool3000000@0oooo0P0000030?ooo`8000000P3o
ool2000000@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3o
ool2000000T0oooo0`00000k0?ooo`H000003`3`l?000`2@T900820P0?3`l0030?3`l003051@D00`
<300l?3`00@0l?3`00<0/;2`071`L03`l?001`3`l?02000000H0l?3`00<0D51@061PH03`l?00OP3`
l?04000001h0oooo000H0?ooo`<000000`3oool800000080oooo0P0000040?ooo`8000001@3oool2
000000d0oooo0P00000e0?ooo`8000002P3oool2000000H0oooo0P0000090?ooo`800000?P3oool6
000000h0l?3`00<000000>3Ph03`l?000`3`l?000`2@T900l?3`0?3`l00:0?3`l0030<30`01@D500
/;2`008000001P3`l?000`000000d=3@0?3`l0200?3`l0@00000703oool001P0oooo0`00000=0?oo
o`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000X0oooo0P0000060?oo
o`800000203oool300000440oooo1P00000;0?3`l003071`L02@T900l?3`0140l?3`00@0h>3P061P
H000000000001@3`l?000`2PX:00<30`0?3`l0220?3`l0@000006`3oool001P0oooo0`00000=0?oo
o`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000L0oooo00<0c<c<05EE
E@2k^k/00P0000060?ooo`8000001`3oool3000004@0oooo1`0000080?3`l0030>3Ph010@400l?3`
01<0l?3`00<0/;2`010@403`l?00103`l?000`1`L700d=3@0?3`l0240?3`l0@000006@3oool001P0
oooo0`00000=0?ooo`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000P0
oooo00@0k^k^06IVIP00000000001P3oool2000000L0oooo0P0000180?ooo`H000001`3`l?000`3@
d=00l?3`0?3`l02Q0?3`l0@00000603oool001P0oooo0`00000=0?ooo`8000000`3oool4000000@0
oooo0P00000=0?ooo`<00000=@3oool2000000T0oooo00<0^k^k014A4@3oool0103oool2000000L0
oooo0`00001;0?ooo`H00000ZP3`l?04000001H0oooo000H0?ooo`<000003P3oool010000000oooo
0?ooo`3oool4000000@0oooo00<000000?ooo`3oool03@3oool2000003D0oooo0P00000@0?ooo`80
00001`3oool2000004h0oooo1P00002Y0?3`l0@000005@3oool001P0oooo0`00000>0?ooo`800000
0`3oool2000000@0oooo0P00000?0?ooo`800000=@3oool3000000h0oooo0`0000060?ooo`<00000
D@3oool600000:P0l?3`0`00000D0?ooo`005`3oool5000000h0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`030000003oool0oooo00h0oooo0P00000f0?ooo`<00000303oool3000000L0oooo
0P00001D0?ooo`L00000YP3`l?0400000180oooo000[0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03`3oool3000003H0oooo0`00000:0?ooo`<00000H@3oool600000:D0l?3`1000
000A0?ooo`00AP3oool2000003L0oooo100000060?ooo`@00000I@3oool600000:@0l?3`1000000?
0?ooo`00AP3oool2000003P0oooo3000001X0?ooo`H00000X`3`l?04000000h0oooo00160?ooo`<0
0000>P3oool6000006h0oooo1P00002R0?3`l0@00000303oool004L0oooo0P00002`0?ooo`L00000
X03`l?04000000/0oooo00170?ooo`800000/`3oool600000:00l?3`100000090?ooo`00A`3oool3
00000;D0oooo1P00002N0?3`l0@00000203oool004P0oooo0P0000170?ooo`800000KP3ooonW0000
00L0oooo00180?ooo`800000A`3oool200000740ooooY00000070?ooo`00B03oool3000004D0oooo
0`00003o0?oooad0oooo00190?ooo`800000A03oool300000?l0oooo7P3oool004T0oooo0P000014
0?ooo`800000o`3ooolO0?ooo`00B@3oool300000480oooo0`00003o0?oooal0oooo001:0?ooo`80
0000@P3oool200000?l0oooo803oool004X0oooo0`0000100?ooo`<00000f03oool600000080oooo
0P0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00P3oool2000000@0oooo
0P0000020?ooo`<0000000@0oooo0000003oool000001P3oool3000000<0oooo1000000=0?ooo`00
B`3oool2000003l0oooo0`00003H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool000000?ooo`04
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo
001;0?ooo`800000?`3oool200000=T0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool004/0oooo0`00
000m0?ooo`<000002@3oool2000000<0oooo0`00003?0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo000000040?ooo`030000003oool0oooo00L0oooo
0P00000=0?ooo`00C03oool2000003d0oooo0P00000<0?ooo`060000003oool0oooo0000003oool0
0000c@3oool200000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo00000004
0?ooo`H000000P3oool2000000l0oooo001<0?ooo`800000B`3oool010000000oooo0?ooo`00003;
0?ooo`@00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool000000140oooo
001<0?ooo`<00000BP3oool010000000oooo0?ooo`00003:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`0000000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool004d0oooo0P00001:0?ooo`040000003oool0oooo00000<X0oooo00<0
00000?ooo`3oool0103oool4000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool300000080oooo0`0000000`3oool000000?ooo`030?ooo`05
0000003oool000000?ooo`000000103oool2000000@0oooo1000000=0?ooo`00C@3oool2000004P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0U0?ooo`00C@3oool3000004P0oooo
1`0000390?ooo`H000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0oooo
001>0?ooo`800000o`3ooomP0?ooo`00CP3oool200000?l0ooooH03oool004h0oooo0`00000d0?oo
o`800000o`3ooolY0?ooo`00C`3oool2000003@0oooo0P00003o0?ooobT0oooo001?0?ooo`<00000
<P3oool300000?l0oooo:@3oool00500oooo0P00000b0?ooo`800000o`3ooolZ0?ooo`00D03oool3
00000300oooo0`00003o0?ooobX0oooo001A0?ooo`<00000;`3oool200000?l0oooo:`3oool00580
oooo0P00000^0?ooo`<00000o`3oool[0?ooo`00DP3oool3000002`0oooo0`00003o0?ooob`0oooo
001C0?ooo`800000;03oool200000?l0oooo;@3oool005<0oooo0`00000Z0?ooo`<00000o`3oool]
0?ooo`00E03oool2000002X0oooo0P00003o0?ooobh0oooo001D0?ooo`<00000:03oool300000?l0
oooo;P3oool005D0oooo0P00000X0?ooo`800000o`3oool_0?ooo`00E@3oool300000?l0ooooF03o
ool005H0oooo0`00003o0?oooeL0oooo001G0?ooo`800000o`3ooomG0?ooo`00E`3oool300000?l0
ooooEP3oool005P0oooo0P00003o0?oooeH0oooo001H0?ooo`<00000o`3ooomE0?ooo`00F@3oool2
00000?l0ooooE@3oool005T0oooo0`00000O0?ooo`800000o`3ooolc0?ooo`00FP3oool2000001l0
oooo0P00003o0?oooc<0oooo001J0?ooo`<000007@3oool300000?l0oooo<`3oool005/0oooo0`00
000K0?ooo`<00000o`3ooold0?ooo`00G03oool2000001D0oooo2000001V0?ooo`h00000`03oool0
05`0oooo0`00000D0?ooo`P00000D@3ooolT00000;l0oooo001M0?ooo`800000503oool9000003/0
oooo:`00000<0?ooo`@00000_@3oool005d0oooo0`00000B0?ooo`/000009@3oool[00000280oooo
1000002l0?ooo`00GP3oool200000180oooo2`00000@0?ooob/00000>@3oool400000;X0oooo001b
0?oooc400000C`3oool500000;P0oooo001R0?ooob`00000IP3oool400000;L0oooo001=0?ooob`0
0000O@3oool400000;D0oooo000h0?ooob/000003P3oool7000007l0oooo1000002d0?ooo`008`3o
ool[000002<0oooo1P0000220?ooo`@00000/P3oool001P0oooo8@00000h0?ooo`D00000Q03oool4
00000;40oooo000H0?ooo``00000C@3oool4000008L0oooo1000002_0?ooo`006P3oool7000004l0
oooo100000290?ooo`D00000[@3oool001d0oooo1P00001=0?ooo`<00000S03oool400000:`0oooo
000P0?ooo`H00000BP3oool2000008l0oooo1000002Z0?ooo`008P3oool700000=T0oooo1000002Y
0?ooo`009@3oool600000=T0oooo1000002W0?ooo`00:03oool600000=L0oooo1000002V0?ooo`00
:P3oool700000=H0oooo1000000_0?ooo`X00000J`3oool002d0oooo1P00003E0?ooo`@00000;`3o
ool3000000<0oooo0`00001[0?ooo`00<03oool6000002h0oooo3000002J0?ooo`@00000;@3oool3
000000@0oooo0P00001[0?ooo`00<P3oool7000002/0oooo3000002K0?ooo`D00000:`3oool30000
0740oooo000e0?ooo`H00000:@3oool2000000P0oooo0P00002M0?ooo`@00000:P3oool300000740
oooo000h0?ooo`H000009P3oool2000000P0oooo0P0000050?ooo`D00000U@3oool4000002P0oooo
0`0000030?ooo`800000K03oool003X0oooo1`00000S0?ooo`800000203oool2000000H0oooo0`00
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q03oool4000002L0oooo2000
001/0?ooo`00?@3oool600000240oooo0P0000080?ooo`8000001P3oool3000000P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`250?ooo`@000009@3oool3000000<0oooo0P00001/
0?ooo`00@03oool6000001h0oooo0P0000080?ooo`8000001P3oool3000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`260?ooo`@00000903oool300000740oooo00120?ooo`L0
00006`3oool2000000P0oooo0P0000060?ooo`H00000103oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool00`000000oooo0?ooo`270?ooo`@000008P3oool3000000@0oooo0P00001[0?ooo`00
A@3oool7000001P0oooo300000060?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0R03oool400000240oooo0`0000030?ooo`<00000
J`3oool004P0oooo1P00000F0?ooo``000001P3oool3000000030?ooo`0000000000008000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0RP3o
ool4000001h0oooo2P00001[0?ooo`00B`3oool6000002D0oooo0`0000020?ooo`<000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0R`3oool5
00000940oooo001=0?ooo`L000008P3oool300000080oooo0`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2=0?ooo`@00000T03oool00500
oooo1P00000P0?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo08l0oooo1000002>0?ooo`00D`3oool6000001`0oooo
1@0000000`3oool00000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2@0?ooo`@00000S@3oool005D0oooo1`00000K0?ooo`D00000103o
ool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool0TP3oool4000008/0oooo
001H0?ooo`H000008`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
U03oool4000008X0oooo001K0?ooo`H00000803oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0UP3oool4000008P0oooo001M0?ooo`L000007P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo09P0oooo1@0000260?ooo`00H03oool600000<00oooo10000025
0?ooo`00H`3oool600000;l0oooo100000230?ooo`00I@3oool700000;d0oooo100000220?ooo`00
J03oool600000;d0oooo100000200?ooo`00J`3oool600000;/0oooo1000001o0?ooo`00K@3oool7
00000;X0oooo1000001m0?ooo`00L03oool600000;T0oooo1000001l0?ooo`00L`3oool600000;P0
oooo1000001j0?ooo`00M@3oool700000;H0oooo1@00001h0?ooo`00N03oool600000;H0oooo1000
001g0?ooo`00N`3oool600000;D0oooo1000001e0?ooo`00O@3oool700000;<0oooo1000001d0?oo
o`00P03oool600000;<0oooo1000001b0?ooo`00P`3oool600000;40oooo1000001a0?ooo`00Q@3o
ool700000;00oooo1000001_0?ooo`00R03oool600000:l0oooo1000001^0?ooo`00R`3oool60000
0:h0oooo1000001/0?ooo`00S@3oool700000:`0oooo1@00001Z0?ooo`00T03oool600000:`0oooo
1000001Y0?ooo`00T`3oool600000:/0oooo1000001W0?ooo`00U@3oool700000:T0oooo1000001V
0?ooo`00V03oool700000:P0oooo1000001T0?ooo`00V`3oool600000:L0oooo1000001S0?ooo`00
WP3oool600000:H0oooo1000001Q0?ooo`00X03oool700000:@0oooo1@00001O0?ooo`00X`3oool6
00000:@0oooo1000001N0?ooo`00YP3oool600000:<0oooo1000001L0?ooo`00Z03oool700000:40
oooo1000001K0?ooo`00Z`3oool600000:40oooo1000001I0?ooo`00[P3oool6000009l0oooo1000
001H0?ooo`00/03oool7000009h0oooo1000001F0?ooo`00/`3oool6000009d0oooo1000001E0?oo
o`00]P3oool6000009`0oooo1000001C0?ooo`00^03oool7000009X0oooo1@00001A0?ooo`00^`3o
ool6000009X0oooo1000001@0?ooo`00_P3oool6000009T0oooo1000001>0?ooo`00`03oool70000
09L0oooo1000001=0?ooo`00``3ooonP000004`0oooo00360?oooid00000C03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo5@3oool7000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`000000103oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0200000580oooo003o0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000005<0oooo003o0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool600000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`L0
000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo
00<000000?ooo`3oool01@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo0P0000030?oo
o`040000003oool0000000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000<0oooo0P0000030?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo
00<000000?ooo`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000P0000020?ooo`050000003oool000000000003oool00`0000050?ooo`800000103oool0
0`000000oooo0000000200000080oooo0`00001B0?ooo`00o`3ooolE0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0D@3oool00?l0oooo5@3oool7000000l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1A0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00\
\>"], "Graphics",
  CellMargins->{{Inherited, 241}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001h0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003X0oooo001f0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0=P3oool00780oooo0?l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`00000000@0oooo0000003oool00000>P3oool00700ooooo`00
0005000000030?ooo`000000000003P0oooo001`0?ooool00000100000000`3oool000000?ooo`0i
0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool200000100
l?3`00<000000?3`l03`l?003@3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?02000003T0l?3`>@3ooolg0<o?c`80000000<0oooo0000003o
ool0>@3oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`0000020?3`l0030000
003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0800000
>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool200000100l?3`00<0
00000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`00/0l?3`00<0
00000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>03`l?0i0?ooocL0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00L03oool2000000h0l?3`100000050?3`l08000001@3`l?00
10000000l?3`0?3`l03`l?02000000<0l?3`0`0000020?3`l0030000003`l?00l?3`00<0l?3`1000
00020?3`l0030000003`l?00l?3`0080l?3`0`0000040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0<00000>03`l?0i0?ooocL0clo?0`00
00000`3oool000000000000h0?ooo`00L03oool2000000d0l?3`00H000000?3`l03`l?0000000?3`
l00000040?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`0?3`l0030?3`l0060000
003`l?00l?3`0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0<00000>03`l?0i0?oo
ocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000000`0l?3`00D000000?3`l03`
l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l0D000000P3`l?000`000000l?3`0?3`l003
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04000003L0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000<0?3`l0050000003`l?00
l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`l?02000000030?3`l000000000000080l?3`
00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000040?3`l0030000003`l?00l?3`00D0
l?3`0P0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04000003L0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000<0?3`l0050000
003`l?00l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`l?0200000080l?3`0P0000000`3`
l?0000000?3`l0040?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02
000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0@00000=`3`l?0i
0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000000`0l?3`00D000000?3`
l03`l?00l?3`000000020?3`l0030000003`l?00l?3`00L0000000<0l?3`0000003`l?000P3`l?00
0`000000l?3`000000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04
000003L0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000=0?3`
l0<0000000<0l?3`0000000000002`3`l?000`000000l?3`0?3`l0020?3`l0L000000P3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000103`l?000`00
0000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0030?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?oo
o`00L03oool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`1@00000f0?3`l3T0oooo=`3?cll20000
00030?ooo`000000oooo03T0oooo001`0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l003
0000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0D00000=P3`l?0i0?oo
ocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000001l0l?3`00<000000?3`l03`
l?002`3`l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?060000
03D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000P0?3`l003
0000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0050?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0H0
0000=@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`
1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`
l?07000003@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D
0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
05@0l?3`1`0000070?3`l0030000003`l?00l?3`00D0l?3`1`0000040?3`l0030000003`l?00l?3`
00@0l?3`00<000000?3`l03`l?00403`l?0i0?oooal0clo?00<000000<o?c`3?cll00`3?cll00`00
0000clo?0<o?c`0?0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0L0
00001`3`l?000`000000l?3`0?3`l0060?3`l08000000P3`l?02000000<0l?3`00<000000?3`l03`
l?001P3`l?000`000000l?3`0?3`l00;0?3`l0<0000000<0l?3`0?ooo`3oool0503oool5000000@0
oooo0P00000E0?ooo`<000007P3?cll00`000000clo?0<o?c`050<o?c`030000003?cll0clo?00h0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000
003`l?00l?3`00H0l?3`0P0000070?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?00
2`3`l?04000001D0oooo0`0000030?ooo`8000000P3oool3000001@0oooo1000000L0<o?c`030000
003?cll0clo?00L0clo?00<000000<o?c`3?cll03@3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000E03`l?08000000H0l?3`100000020?3`l080000000@0l?3`000000000000l?3`
0P0000030?3`l0030000003`l?00l?3`0080l?3`0`0000030?3`l0030000003`l?00l?3`00X0l?3`
1P00000B0?ooo`<000001@3oool4000000030?ooo`000000oooo01<0oooo1@00000A0<o?c`<00000
00@0clo?00000000000000000`3?cll010000000clo?0<o?c`3?cll3000000<0clo?00<000000<o?
c`3?cll03@3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?08000000H0
l?3`00@000000?3`l03`l?00l?3`0P0000030?3`l0D000000`3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002P3`l?0700000140oooo0P0000060?oo
o`<000005`3oool7000000h0clo?00<000000<o?c`3?cll00P0000030<o?c`030000003?cll00000
00@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo0000
00000000>03oool00700oooo0P00001D0?3`l0T000001@3`l?0010000000l?3`0?3`l03`l?020000
00<0l?3`0P0000000`3`l?000000000000030?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003P3oool3000000L0oooo0P00000G0?oo
o`P000003@3?cll01@000000clo?0<o?c`3?cll0000000<0clo?00<000000<o?c`000000103?cll0
0`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0P0000000`3oool000000?ooo`0i
0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`0080l?3`00@000000?3`
l03`l?00l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00<0l?3`00<000000?3`l03`l?002P3`l?0:000000d0oooo0`0000070?ooo`8000005`3oool9
000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<0
00000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00L000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`00<00000
0?3`l00000005@00000<0?ooo`<000001`3oool3000000X0oooo5P00000;0<o?c`050000003?cll0
clo?0<o?c`0000000`3?cll00`000000clo?000000040<o?c`030000003?cll0clo?00@0clo?00<0
00000<o?c`3?cll0303?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?09
000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0000000E000000`0oooo0`000007
0?ooo`<000002P3ooolF000000/0clo?0P0000020<o?c`030000003?cll0clo?0080000000<0clo?
0000003?cll00`3?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0`000000
0`3oool000000000000h0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
00<0l?3`00<000000?3`l03`l?002P3`l?09000000l0oooo0P0000060?ooo`040000003oool00000
000001H0oooo2000000>0<o?c`8000000`3?cll2000000<0clo?00D000000<o?c`3?cll0clo?0000
00050<o?c`030000003?cll0clo?00d0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2
000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?000`000000l?3`0?3`
l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool7000001T0clo?
00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3oool00000
0000000h0?ooo`00L03oool2000005@0l?3`2000000H0?3`l0050000003`l?00l?3`0?3`l0000000
103`l?000`000000l?3`0?3`l00;0?3`l0D00000503oool3000000<0oooo00<000000?ooo`3oool0
0`00000E0?ooo`D00000703?cll010000000clo?0<o?c`0000040<o?c`030000003?cll0clo?00h0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2000000H0?3`l0050000
003`l?00l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l0@000005`3oool4000000<0
oooo0`00000E0?ooo`<000007`3?cll00`000000clo?000000030<o?c`030000003?cll0clo?00l0
clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1`00000J0?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?00303`l?0200000080l?3`=P3oool2000000030?oo
o`3?cll0clo?03D0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`1`00
000d0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?07
000003@0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0L00000=03`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0
l?3`1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
E03`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000`0?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000003`l?00
l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<000000?3`
l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000
l?3`0?3`l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00
L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?c`800000
00<0oooo0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0l?3`1000
000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000:P3`l?02
00000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?oo
o`800000:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`
l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`0000000000
03P0oooo001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i0?ooocL0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?00
5`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000X0?3`l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?00
5`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000_0?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`l0800000
>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0l?3`00D0
00000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`l3T0oooo
=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000l?3`0?3`
l0050?3`l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?oo
o`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo
=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo
03T0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000?ooo`0h0?ooo`00
L03oool2000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
002?0?3`l3T0oooo=`3?cll3000000030?ooo`000000oooo03P0oooo001`0?ooool000001000000l
0?ooo`00L03ooooo000000@00000?03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo9@3oool<000007l0oooo003o0?oooa80oooo8000001n0?ooo`00
o`3ooolV000000X0l?3`1000001l0?ooo`00k03ooolV000001h0l?3`1000001k0?ooo`00f@3ooolW
00000380l?3`1000001i0?ooo`00a`3ooolV000004H0l?3`1000001h0?ooo`00]03ooolV000005/0
l?3`1000001f0?ooo`00XP3ooolV000006h0l?3`1000001e0?ooo`00S`3ooolV000008<0l?3`1000
001c0?ooo`00O03ooolW000009H0l?3`1000001b0?ooo`00JP3ooolV00000:/0l?3`0`00001a0?oo
o`00E`3ooolV00000;l0l?3`1000001_0?ooo`00CP3ooolM00000=80l?3`1000000/0?ooo`800000
00<0oooo0000000000000P00000k0?ooo`00CP3oool:00000>L0l?3`1000000Z0?ooo`@000000P3o
ool2000003X0oooo001@0?ooo`L00000j@3`l?04000002T0oooo0`0000030?ooo`<00000>@3oool0
05<0oooo1P00003Y0?3`l0@000009`3oool2000000@0oooo0`00000i0?ooo`00EP3oool600000>L0
l?3`1000000[0?ooo`@00000>@3oool005P0oooo1P00000c0?3`l1000000203`l?02000009X0l?3`
1000000W0?ooo`D00000>P3oool005/0oooo1P00000Q0?3`l08000000`3`l?0200000080l?3`0P00
00040?3`l1<00000103`l?03000009/0l?3`1000000T0?ooo`H00000>`3oool005d0oooo1`00000N
0?3`l08000000`3`l?0200000080l?3`0P00000C0?3`l0`00000W03`l?0400000240oooo1@00000m
0?ooo`00H03oool6000003d0l?3`2@00002M0?3`l0@00000803oool3000000@0oooo0P00000i0?oo
o`00H`3oool6000003d0l?3`1P00002O0?3`l0@000007P3oool3000000<0oooo0`00000i0?ooo`00
I@3oool6000003X0l?3`2000002O0?3`l0@000007P3oool200000080oooo1000000i0?ooo`00J03o
ool6000003L0l?3`2000002Q0?3`l0@000007@3oool4000000030?ooo`000000000003T0oooo001Z
0?ooo`L00000=03`l?0800000:80l?3`1000001L0?ooo`00K@3oool6000003D0l?3`1P00002S0?3`
l0@00000FP3oool00700oooo1P00000e0?3`l0<00000Y03`l?04000005T0oooo001b0?ooo`H00000
9P3`l?000`3Ph>00l?3`0?3`l02c0?3`l0@00000E`3oool007D0oooo1P00000R0?3`l0030=3@d00P
8200l?3`00L0l?3`00<0L71`0=3@d03`l?001@3`l?0500000:40l?3`1000001F0?ooo`00M`3oool7
000001l0l?3`00<0D51@092@T03`l?001`3`l?000`2`/;00D51@0?3`l0040?3`l0L00000XP3`l?04
000005@0oooo001j0?ooo`H00000703`l?000`3@d=0000000>3Ph0090?3`l003010@403@d=00l?3`
00<0l?3`1`00002S0?3`l0@00000D`3oool007d0oooo1P00000B0?3`l005030`<01@D500H61P030`
<030`<000P3`l?000`20P800<30`0?3`l0020?3`l004071`L0000000<30`0<30`0<0l?3`00<0H61P
071`L03`l?000`3`l?0700000:D0l?3`0`00001B0?ooo`00O`3oool600000100l?3`00D0D51@0?3`
l03`l?00L71`020P80020?3`l003030`<01`L700l?3`0080l?3`00@00000010@402`/;00X:2P0`3`
l?000`2PX:00820P0?3`l0030?3`l0L00000YP3`l?0400000500oooo00220?ooo`H000003@3`l?00
0`3@d=00l?3`092@T00200000080l?3`00<0410@0:2PX03`l?000P3`l?000`000000<30`0?3`l004
0?3`l0030=3@d0000000l?3`00@0l?3`1@00002X0?3`l0@00000C`3oool008@0oooo1`00000:0?3`
l0050;2`/00@41000000010@4030`<000P3`l?000`000000/;2`0?3`l0020?3`l0030000000`<300
l?3`00D0l?3`00<000000;2`/03`l?00/P3`l?04000004d0oooo00270?ooo`H00000203`l?020000
00030;2`/03`l?00l?3`0080l?3`00<000000;2`/03`l?000P3`l?000`000000<30`0?3`l0050?3`
l0030000002`/;00l?3`0;<0l?3`1000001<0?ooo`00RP3oool6000000D0l?3`00D0410@071`L03`
l?00l?3`051@D0020?3`l003010@402PX:00l?3`0080l?3`00<00000030`<03`l?001@3`l?000`00
0000`<300?3`l02e0?3`l0@00000BP3oool008`0oooo1P0000030?3`l0050<30`010@400L71`051@
D010@4000P3`l?001@10@400L71`0?3`l03`l?00<30`00<0000000H0<30`0?3`l03`l?00l?3`0;2`
/000002h0?3`l0@00000B@3oool008l0oooo1P0000070?3`l003092@T00`<300l?3`0080l?3`00<0
D51@030`<03`l?00103`l?000`20P800820P0?3`l02i0?3`l0@00000A`3oool00940oooo1`000005
0?3`l0030000003Ph>00l?3`0080l?3`00<0T92@0?3`l03`l?000`3`l?000`0`<300P8200?3`l02j
0?3`l0@00000AP3oool009@0oooo1P0000030?3`l003071`L02@T900l?3`00L0l?3`00<0h>3P0000
003Ph>00_@3`l?04000004@0oooo002G0?ooo`H0000000<0h>3P0410@03`l?001`3`l?000`20P800
L71`0?3`l02n0?3`l0@00000@`3oool009T0oooo1P0000080?3`l0030;2`/03`l?00l?3`0<00l?3`
100000110?ooo`00W03oool600000<T0l?3`100000100?ooo`00WP3oool700000<P0l?3`1000000n
0?ooo`00X@3oool600000<L0l?3`1000000m0?ooo`00Y03oool600000<H0l?3`1000000k0?ooo`00
X`3oool2000000030?ooo`000000000000@00000a@3`l?04000003X0oooo002S0?ooo`800000103o
ool600000<@0l?3`1000000h0?ooo`00X`3oool2000000H0oooo1`0000320?3`l0@00000=`3oool0
0:<0oooo0P0000090?ooo`H00000`P3`l?04000003D0oooo002R0?ooo`<00000303oool600000<00
l?3`1000000d0?ooo`00XP3oool2000000l0oooo1P0000300?3`l0<00000<`3oool00:80oooo0P00
000B0?ooo`H00000_P3`l?0400000340oooo002R0?ooo`800000503oool700000;`0l?3`1000000`
0?ooo`00^`3oool600000;`0l?3`1000000^0?ooo`00_P3oool600000;X0l?3`1000000]0?ooo`00
P`3oool6000003L0oooo1P00002j0?3`l0@00000:`3oool00800oooo3000000g0?ooo`H00000^03`
l?04000002X0oooo001o0?ooo`@000001P3oool4000003P0oooo1`00002g0?3`l0@00000:03oool0
07h0oooo0`0000040?ooo`0607MgM`14A4@000000000001EEED0VIVI0`00000j0?ooo`H00000]P3`
l?04000002L0oooo001m0?ooo`<000001`3oool2000000<0oooo0`00000l0?ooo`H00000]@3`l?04
000002D0oooo001l0?ooo`<00000203oool2000000@0oooo0`00000<0?ooo`800000;`3oool60000
0;@0l?3`1000000T0?ooo`00O03oool2000000T0oooo0P0000050?ooo`800000303oool200000380
oooo1P00002c0?3`l0@000008P3oool007`0oooo0P0000090?ooo`8000001@3oool2000000/0oooo
0`00000d0?ooo`L00000/@3`l?0400000240oooo001k0?ooo`8000002P3oool2000000H0oooo0P00
000:0?ooo`800000>03oool600000;40l?3`1000000O0?ooo`00N`3oool2000000X0oooo0P000006
0?ooo`8000002@3oool3000003/0oooo1P00002_0?3`l0@000007P3oool007/0oooo0P00000:0?oo
o`8000001P3oool2000000T0oooo0P00000n0?ooo`H00000[`3`l?04000001`0oooo001k0?ooo`80
00002P3oool2000000H0oooo0P0000080?ooo`<00000@@3oool600000:d0l?3`1000000K0?ooo`00
N`3oool2000000L0oooo00<0c<c<05EEE@2k^k/00P0000060?ooo`8000001`3oool3000004@0oooo
1`00002/0?3`l0@000006@3oool007/0oooo0P0000080?ooo`040>k^kP1VIVH00000000000H0oooo
0P0000070?ooo`800000B03oool600000:/0l?3`1000000H0?ooo`00O03oool2000000T0oooo00<0
^k^k014A4@3oool0103oool2000000L0oooo0`00001;0?ooo`H00000ZP3`l?04000001H0oooo001l
0?ooo`800000403oool2000000L0oooo0P00001>0?ooo`H00000Z@3`l?04000001D0oooo001l0?oo
o`<000003P3oool3000000H0oooo0`00001A0?ooo`H00000Z03`l?03000001@0oooo001m0?ooo`<0
0000303oool3000000L0oooo0P00001D0?ooo`L00000YP3`l?0400000180oooo001n0?ooo`<00000
2P3oool300000640oooo1P00002U0?3`l0@000004@3oool007l0oooo100000060?ooo`@00000I@3o
ool600000:@0l?3`1000000?0?ooo`00P03oool<000006P0oooo1P00002S0?3`l0@000003P3oool0
08<0oooo1P00001^0?ooo`H00000XP3`l?04000000`0oooo003i0?ooo`L00000X03`l?04000000/0
oooo003l0?ooo`H00000X03`l?04000000T0oooo003o0?ooo`H00000WP3`l?04000000P0oooo002A
0?ooo`800000KP3ooonW000000L0oooo002A0?ooo`800000L@3ooonT000000L0oooo002@0?ooo`<0
0000o`3ooolM0?ooo`00S`3oool300000?l0oooo7P3oool008l0oooo0P00003o0?oooal0oooo002>
0?ooo`<00000o`3ooolO0?ooo`00SP3oool200000?l0oooo803oool008d0oooo0`00003H0?ooo`H0
00000P3oool2000000030?ooo`000000oooo00@0oooo0`0000000`3oool000000?ooo`020?ooo`80
0000103oool200000080oooo0`000000103oool000000?ooo`0000060?ooo`<000000`3oool40000
00d0oooo002<0?ooo`<00000f03oool00`000000oooo0?ooo`040?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`80000000<0oooo0000003oool0103o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`00
S03oool200000=T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool008/0oooo0`0000090?ooo`800000
0`3oool300000<l0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool01`3oool2000000d0oooo002;0?ooo`800000
303oool01P000000oooo0?ooo`000000oooo00000<d0oooo0P0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`000000103oool600000080oooo0P00000?0?ooo`00V@3oool0
10000000oooo0?ooo`00003;0?ooo`@00000103oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool000000140oooo002I0?ooo`040000003oool0oooo00000<X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0000000000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`00V@3oool010000000oooo0?ooo`00003:0?ooo`030000
003oool0oooo00@0oooo10000000103oool000000?ooo`0000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<0000000<0oooo0000003oool00`3oool01@00
0000oooo0000003oool0000000@0oooo0P0000040?ooo`@000003@3oool009L0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000005P3oool00`000000oooo0?ooo`0U0?ooo`00V03oool700000<T0oooo1P0000020?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool09@3oool00?l0oooo/03oool00?l0oooo/03o
ool008D0oooo0P00003o0?ooobT0oooo00250?ooo`800000o`3ooolY0?ooo`00Q03oool300000?l0
oooo:@3oool008@0oooo0P00003o0?ooobX0oooo00230?ooo`<00000o`3ooolZ0?ooo`00P`3oool2
00000?l0oooo:`3oool00880oooo0`00003o0?ooob/0oooo00210?ooo`<00000o`3oool/0?ooo`00
P@3oool200000?l0oooo;@3oool00800oooo0`00003o0?ooobd0oooo00200?ooo`800000o`3oool^
0?ooo`00O`3oool300000?l0oooo;P3oool007l0oooo0P00003o0?ooobl0oooo003o0?oook00oooo
003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo
003o0?oook00oooo001k0?ooo`800000o`3ooolc0?ooo`00N`3oool200000?l0oooo<`3oool007X0
oooo0`00003o0?oooc<0oooo001i0?ooo`<00000o`3ooold0?ooo`00L`3oool8000006H0oooo3P00
00300?ooo`00L`3oool800000540oooo9000002o0?ooo`00L`3oool9000003/0oooo:`00000<0?oo
o`@00000_@3oool00780oooo2`00000U0?ooob/000008P3oool400000;`0oooo001b0?ooo`/00000
403oool[000003T0oooo1000002j0?ooo`00LP3ooola000004l0oooo1@00002h0?ooo`00HP3oool/
000006H0oooo1000002g0?ooo`00C@3oool/000007d0oooo1000002e0?ooo`00>03oool[000000h0
oooo1`00001o0?ooo`@00000]03oool002<0oooo:`00000S0?ooo`H00000PP3oool400000;80oooo
000H0?ooob400000>03oool5000008@0oooo1000002a0?ooo`00603oool<000004d0oooo10000027
0?ooo`@00000[`3oool001X0oooo1`00001?0?ooo`@00000R@3oool500000:d0oooo000M0?ooo`H0
0000C@3oool3000008`0oooo1000002/0?ooo`00803oool6000004X0oooo0P00002?0?ooo`@00000
ZP3oool00280oooo1`00003I0?ooo`@00000Z@3oool002D0oooo1P00003I0?ooo`@00000Y`3oool0
02P0oooo1P00003G0?ooo`@00000YP3oool002X0oooo1`00003F0?ooo`@00000;`3oool:000006/0
oooo000]0?ooo`H00000e@3oool4000002l0oooo0`0000030?ooo`<00000J`3oool00300oooo1P00
000^0?ooo``00000VP3oool4000002d0oooo0`0000040?ooo`800000J`3oool00380oooo1`00000[
0?ooo``00000V`3oool5000002/0oooo0`00001a0?ooo`00=@3oool6000002T0oooo0P0000080?oo
o`800000W@3oool4000002X0oooo0`00001a0?ooo`00>03oool6000002H0oooo0P0000080?ooo`80
00001@3oool5000009D0oooo1000000X0?ooo`<000000`3oool2000006`0oooo000j0?ooo`L00000
8`3oool2000000P0oooo0P0000060?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08@0oooo1000000W0?ooo`P00000K03oool003d0oooo1P00000Q0?ooo`800000203o
ool2000000H0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Q@3o
ool4000002D0oooo0`0000030?ooo`800000K03oool00400oooo1P00000N0?ooo`800000203oool2
000000H0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0QP3oool4
000002@0oooo0`00001a0?ooo`00@P3oool7000001/0oooo0P0000080?ooo`8000001P3oool60000
00@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0Q`3oool40000
0280oooo0`0000040?ooo`800000J`3oool004D0oooo1`00000H0?ooo``000001P3oool7000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08P0
oooo1000000Q0?ooo`<000000`3oool3000006/0oooo00180?ooo`H000005P3oool<000000H0oooo
0`0000000`3oool000000000000200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo08X0oooo1000000N0?ooo`X00000J`3oool004/0oooo1P00
000U0?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo08/0oooo1@00002A0?ooo`00C@3oool700000280oooo0`000002
0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0S@3oool400000900oooo001@0?ooo`H00000803oool300000080oooo0`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2?0?oo
o`@00000SP3oool005<0oooo1P00000L0?ooo`D0000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0T03oool4000008d0
oooo001E0?ooo`L000006`3oool5000000@0oooo00@000000?ooo`3oool0oooo100000030?ooo`03
0000003oool0oooo0980oooo1000002;0?ooo`00F03oool6000002<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo09@0oooo1000002:0?ooo`00F`3oool600000200oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09H0oooo100000280?ooo`00
G@3oool7000001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2H0?ooo`D00000
QP3oool00600oooo1P0000300?ooo`@00000Q@3oool006<0oooo1P00002o0?ooo`@00000P`3oool0
06D0oooo1`00002m0?ooo`@00000PP3oool006P0oooo1P00002m0?ooo`@00000P03oool006/0oooo
1P00002k0?ooo`@00000O`3oool006d0oooo1`00002j0?ooo`@00000O@3oool00700oooo1P00002i
0?ooo`@00000O03oool007<0oooo1P00002h0?ooo`@00000NP3oool007D0oooo1`00002f0?ooo`D0
0000N03oool007P0oooo1P00002f0?ooo`@00000M`3oool007/0oooo1P00002e0?ooo`@00000M@3o
ool007d0oooo1`00002c0?ooo`@00000M03oool00800oooo1P00002c0?ooo`@00000LP3oool008<0
oooo1P00002a0?ooo`@00000L@3oool008D0oooo1`00002`0?ooo`@00000K`3oool008P0oooo1P00
002_0?ooo`@00000KP3oool008/0oooo1P00002^0?ooo`@00000K03oool008d0oooo1`00002/0?oo
o`D00000JP3oool00900oooo1P00002/0?ooo`@00000J@3oool009<0oooo1P00002[0?ooo`@00000
I`3oool009D0oooo1`00002Y0?ooo`@00000IP3oool009P0oooo1`00002X0?ooo`@00000I03oool0
09/0oooo1P00002W0?ooo`@00000H`3oool009h0oooo1P00002V0?ooo`@00000H@3oool00:00oooo
1`00002T0?ooo`D00000G`3oool00:<0oooo1P00002T0?ooo`@00000GP3oool00:H0oooo1P00002S
0?ooo`@00000G03oool00:P0oooo1`00002Q0?ooo`@00000F`3oool00:/0oooo1P00002Q0?ooo`@0
0000F@3oool00:h0oooo1P00002O0?ooo`@00000F03oool00;00oooo1`00002N0?ooo`@00000EP3o
ool00;<0oooo1P00002M0?ooo`@00000E@3oool00;H0oooo1P00002L0?ooo`@00000D`3oool00;P0
oooo1`00002J0?ooo`D00000D@3oool00;/0oooo1P00002J0?ooo`@00000D03oool00;h0oooo1P00
002I0?ooo`@00000CP3oool00<00oooo1`00002G0?ooo`@00000C@3oool00<<0ooooX000001<0?oo
o`00aP3ooonM000004`0oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oo
ok00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oooaD0oooo1`000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo0`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P00001B0?ooo`00o`3ooolE0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000005<0oooo003o0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000D`3o
ool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo1P0000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000D`3oool00?l0oooo5@3oool7000000030?ooo`000000oooo00<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool010000000
oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00000P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0
000000<0oooo0`0000030?ooo`030000003oool00000008000000P3oool01@000000oooo00000000
0000oooo00<000001@3oool2000000@0oooo00<000000?ooo`0000000P0000020?ooo`<00000DP3o
ool00?l0oooo5@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0540oooo003o0?oo
oaD0oooo1`00000?0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0D@3oool00?l0
oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0
oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0
oooo/03oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001h0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003X0oooo001f0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0=P3oool00780oooo0?l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`00000000@0oooo0000003oool00000>P3oool00700ooooo`00
0005000000030?ooo`000000000003P0oooo001`0?ooool00000100000000`3oool000000?ooo`0i
0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0
l?3`0P00000i0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
5P3`l?07000003L0l?3`0P00000i0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000403`l?000`000000l?3`0?3`l0040?3`l08000000P3`l?02000000<0l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00D0l?3`0`00
000h0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000403`l?00
0`000000l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00
l?3`00T0l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00@0l?3`0P0000000`3`
l?000000000000030?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`00
0000l?3`0?3`l0070?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0040?3`l0<00000>03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?oo
o`00L03oool2000000h0l?3`100000050?3`l0D000000P3`l?0010000000l?3`0?3`l03`l?020000
00<0l?3`0`0000020?3`l0030000003`l?00l?3`00<0l?3`100000020?3`l0030000003`l?00l?3`
0080l?3`0`0000040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0030?3`l0@00000=`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?oo
o`00L03oool2000000d0l?3`00H000000?3`l03`l?0000000?3`l00000040?3`l080000000<0l?3`
0000000000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`0000003`l?000000
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000
103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0030?3`l0@00000=`3`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0i0?ooo`00L03oool2000000`0l?3`00D000000?3`l03`l?00l?3`000000020?3`l0040000
003`l?00l?3`0?3`l08000000P3`l?02000000030?3`l0000000l?3`00@0l?3`00@000000?3`l03`
l?000000103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0@00000=`3`l?0i0?ooocL0clo?0`0000000`3o
ool000000000000h0?ooo`00L03oool2000000`0l?3`00D000000?3`l03`l?00l?3`000000020?3`
l0030000003`l?00l?3`00L0000000<0l?3`0000003`l?00103`l?0010000000l?3`0?3`l0000004
0?3`l0030000003`l?00l?3`00D0l?3`0P0000020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?000`3`l?04000003L0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool0
0700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?000`000000l?3`0?3`l008
0?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`
l0030?3`l0800000103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`1@00
000f0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000303`l?00
1@000000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`
l03`l?0000000?3`l00000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0
l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0
l?3`1@00000f0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
3@3`l?03000000030?3`l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`
00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000`3`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000
>03oool00700oooo0P00000N0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?000`3`
l?0400000080l?3`00@000000?3`l03`l?00l?3`100000040?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0H00000=@3`l?0i0?ooocL0clo?
0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000001l0l?3`00<000000?3`l03`l?002`3`
l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?06000003D0l?3`
>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000O0?3`l0030000003`
l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?001@000000l?3`0?3`l03`l?00000000D0l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`
1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000803`
l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?001@3`
l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?001@3`
l?07000003@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D
0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
05@0l?3`1`00000?0?3`l0L000007P3`l?0i0?oooal0clo?00<000000<o?c`3?cll00`3?cll00`00
0000clo?0<o?c`0?0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0L0
00001`3`l?000`000000l?3`0?3`l0060?3`l08000000P3`l?02000000@0l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l00@0?3`l1H0oooo1@0000040?ooo`800000603ooolN0<o?c`03
0000003?cll0clo?00D0clo?00<000000<o?c`3?cll03P3?cll2000000030?ooo`000000oooo03T0
oooo001`0?ooo`800000E03`l?08000000H0l?3`00<000000?3`l03`l?001P3`l?02000000L0l?3`
00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00?0?3`l1D0oooo0`0000030?ooo`800000
0P3oool3000001L0oooo7@3?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00d0clo?
0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000003`
l?00l?3`00H0l?3`0P0000000`3`l?000000000000040?3`l0030000003`l?00l?3`00H0l?3`00<0
00000?3`l03`l?002`3`l?03000000030?3`l03oool0oooo0180oooo0`0000050?ooo`@0000000<0
oooo0000003oool04`3oool3000001<0clo?0`000000103?cll000000000000000030<o?c`040000
003?cll0clo?0<o?c`<000000`3?cll00`000000clo?0<o?c`0=0<o?c`80000000<0oooo0000003o
ool0>@3oool00700oooo0P00001D0?3`l0P000001P3`l?0400000080l?3`0P0000000`3`l?000000
00000003000000<0l?3`00<000000?3`l03`l?000P3`l?03000000<0l?3`00<000000?3`l03`l?00
2P3`l?05000001<0oooo0P0000060?ooo`<000005`3oool500000100clo?00<000000<o?c`3?cll0
0P0000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?
0<o?c`0<0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0T000001@3`
l?0010000000l?3`0?3`l03`l?02000000<0l?3`0P0000000`3`l?000000000000030?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0P00000
3`3oool3000000L0oooo0P00000G0?ooo`L000003P3?cll01@000000clo?0<o?c`3?cll0000000<0
clo?00<000000<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0040000
003`l?00l?3`0?3`l08000000`3`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0X000003@3oool3000000L0
oooo0P00000G0?ooo`T00000303?cll01@000000clo?0<o?c`3?cll0000000<0clo?00<000000<o?
c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0`0000000`3o
ool000000000000h0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?000`3`l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolF000000/0
clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?
c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D0
0000303oool3000000L0oooo0`00000:0?oooaH000002`3?cll200000080clo?00<000000<o?c`3?
cll00P0000000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?
cll0303?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?09000000D0l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003`3oool2000000H0oooo
00@000000?ooo`00000000005P3oool8000000h0clo?0P0000030<o?c`8000000`3?cll01@000000
clo?0<o?c`3?cll0000000D0clo?00<000000<o?c`3?cll03@3?cll2000000030?ooo`000000oooo
03T0oooo001`0?ooo`800000E03`l?08000000H0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0090?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000
l?3`0?3`l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool70000
01T0clo?00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3o
ool000000000000h0?ooo`00L03oool2000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`
l0@000000`3`l?000`000000l?3`0?3`l00:0?3`l0D00000503oool3000000<0oooo00<000000?oo
o`3oool00`00000E0?ooo`D00000703?cll010000000clo?0<o?c`0000040<o?c`030000003?cll0
clo?00h0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2000000H0?3`
l0050000003`l?00l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l0@000005`3oool4
000000<0oooo0`00000E0?ooo`<000007`3?cll00`000000clo?000000030<o?c`030000003?cll0
clo?00l0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1`00000I0?3`
l0050000003`l?00l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l08000000P3`l?0f
0?ooo`80000000<0oooo0<o?c`3?cll0=@3?cll2000000030?ooo`000000oooo03T0oooo001`0?oo
o`800000E03`l?07000001X0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00@0?3`
l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?07000003@0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`l0L00000
=03`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1P00
000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?06
000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000`0?3`
l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0l?3`>@3ooolg0<o?
c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0
l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<000000?3`l03`l?00
603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`
l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000003`l?00
l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?c`80000000<0oooo
0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`
l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000:P3`l?0200000080
l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0
l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i0?ooocL0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?03
000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000X0?3`
l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?005`3`l?03
000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`
l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`l0800000>@3`l?0i
0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0l?3`00D000000?3`
l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`l3T0oooo=`3?cll2
000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000l?3`0?3`l0050?3`
l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000/0?ooo`<00000
@@3oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool002/0oooo00D0
00000?ooo`3oool0oooo000000100?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0i0?ooo`00<03oool00`000000oooo0?ooo`0m0?ooo`800000203`l?04000008<0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000>03oool00240oooo1P0000000`3oool000000?ooo`03
0?ooo`80000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`<0000000<0
oooo0000000000000`3oool4000002L0oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool0
0`000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo0P00
00020?3`l0X00000P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00803oool0
0`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000001`3oool00`000000oooo0?oo
o`0T0?ooo`d00000Q03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`009`3oool2
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool2000000D0oooo0P00000V0?ooo`d00000Q@3`l?0i0?ooocL0clo?0`00
00000`3oool000000?ooo`0h0?ooo`009@3oool2000000050?ooo`000000oooo0?ooo`000000103o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo1P0000030?ooo`800000:03o
ool=000008D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00240oooo10000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`060?ooo`8000000P3oool00`000000oooo0?ooo`0Y0?ooo`/00000QP3`l?0i0?ooocL0clo?0`00
00000`3oool000000?ooo`0h0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000000P3oool2000000030?ooo`000000000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo
o`000004000003`0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80000000D0
oooo0000003oool000000?ooo`03000000D0oooo100000000`3oool000000?ooo`020?ooo`@00000
9`3ooooo000000@00000?03oool00200oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocL0oooo000Q0?ooo`H0000000<0oooo
0000003oool05`3oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000000000000P00003o
0?ooocP0oooo001_0?ooo`<000000`3oool200000?l0oooo>@3oool006h0oooo0`00003o0?ooocl0
oooo001]0?ooo`<00000o`3ooom00?ooo`00K03oool300000?l0oooo@@3oool000/0oooo1`000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo0`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`<0000000@0oooo000000000000
00003@3oool300000?l0oooo@P3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000oooo00/0oooo0`00003o0?oood<0oooo000;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo0`00003o0?oo
od@0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000X0
oooo0`00003o0?ooodD0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool600000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`D0000000<0oooo0000003oool0203oool300000?l0oooo
AP3oool000/0oooo1`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`00
0000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo000000080?ooo`<00000o`3ooom70?ooo`002`3oool00`000000oooo0?ooo`05
0?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo0P00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00@000000?ooo`000000
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool2
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000L0oooo0`00003o0?ooodP0oooo000;0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`0000000P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo0`0000030?ooo`030000003oool00000008000000P3oool01@000000oooo
000000000000oooo00<000001@3oool2000000@0oooo00<000000?ooo`0000000P0000020?ooo`<0
00000`3oool400000080oooo00<000000?ooo`3oool0103oool300000?l0ooooB@3oool000/0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
0`00003o0?ooodX0oooo000;0?ooo`L000003`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool300000?l0ooooB`3oool00640oooo0`00003o
0?oood`0oooo001P0?ooo`<00000o`3ooom=0?ooo`00G`3oool300000?l0ooooCP3oool005h0oooo
0`00003o0?ooodl0oooo001N0?ooo`800000o`3ooom@0?ooo`00G@3oool300000?l0ooooD03oool0
05d0oooo0P00003o0?oooe40oooo001L0?ooo`<00000o`3ooomA0?ooo`00F`3oool300000?l0oooo
DP3oool005/0oooo0P00003o0?oooe<0oooo001J0?ooo`<00000o`3ooomC0?ooo`00FP3oool20000
0?l0ooooE03oool005T0oooo0`00003o0?oooe@0oooo001H0?ooo`<00000o`3ooomE0?ooo`00F03o
ool200000?l0ooooEP3oool005L0oooo0`00003o0?oooeH0oooo001G0?ooo`800000o`3ooomG0?oo
o`00EP3oool300000?l0ooooE`3oool005D0oooo0`00003o0?oooeP0oooo001E0?ooo`800000o`3o
oomI0?ooo`00E03oool300000?l0ooooF@3oool005@0oooo0P00003o0?oooeX0oooo001C0?ooo`<0
0000o`3ooomJ0?ooo`00DP3oool300000?l0ooooF`3oool00580oooo0P00003o0?oooe`0oooo001A
0?ooo`<00000o`3ooomL0?ooo`00D@3oool200000?l0ooooG@3oool00500oooo0`00003o0?oooed0
oooo001@0?ooo`800000o`3ooomN0?ooo`00C`3oool300000?l0ooooGP3oool004l0oooo0P00003o
0?oooel0oooo001>0?ooo`<00000o`3ooomO0?ooo`00CP3oool200000?l0ooooH03oool004h0oooo
0P00003o0?ooof00oooo001=0?ooo`<00000o`3ooomP0?ooo`00C@3oool200000?l0ooooH@3oool0
04`0oooo0`00003o0?ooof40oooo001<0?ooo`800000o`3ooomR0?ooo`00B`3oool300000?l0oooo
HP3oool004/0oooo0P00003o0?ooof<0oooo001:0?ooo`<00000o`3ooomS0?ooo`00BP3oool20000
0?l0ooooI03oool004T0oooo0`00003o0?ooof@0oooo00190?ooo`800000o`3ooomU0?ooo`00B@3o
ool200000?l0ooooI@3oool004P0oooo0`00003o0?ooofD0oooo00180?ooo`800000o`3ooomV0?oo
o`00A`3oool300000?l0ooooIP3oool004L0oooo0P00003o0?ooofL0oooo00160?ooo`<00000o`3o
oomW0?ooo`00AP3oool200000?l0ooooJ03oool004H0oooo0P00003o0?ooofP0oooo00160?ooo`80
0000o`3ooomX0?ooo`00:@3oool6000001H0oooo0`00003o0?ooofP0oooo000V0?ooo``000004`3o
ool200000?l0ooooJ@3oool002D0oooo100000060?ooo`@000004P3oool200000?l0ooooJ@3oool0
02@0oooo0`0000020?ooo`L0000000@0A4A400000000000000004@3oool200000?l0ooooJ@3oool0
02<0oooo0`0000030?ooo`030:ZZZP000000000000@0<c<c00<0A4A40?ooo`0000000P00000@0?oo
o`800000o`3ooomY0?ooo`008P3oool3000000D0oooo00<0c<c<0000002IVIT00`3oool00`2ZZZX0
oooo0?ooo`03000000l0oooo0P00003o0?ooofT0oooo000R0?ooo`8000001`3oool00`3<c<`00000
09VIV@060?ooo`8000003`3oool200000?l0ooooJ@3oool00280oooo0P0000080?ooo`030<c<c000
0000ZZZZ00D0oooo0P00000>0?ooo`<00000o`3ooomY0?ooo`008@3oool2000000X0oooo00<0R8R8
0000003^k^h01@3oool2000000d0oooo0P00003o0?ooofX0oooo000Q0?ooo`8000002`3oool00`00
0000IVIV0?ooo`040?ooo`8000003@3oool200000?l0ooooJP3oool00240oooo0P00000;0?ooo`80
8R8R1@3oool2000000d0oooo0P00003N0?ooo``00000O`3oool00240oooo0P0000060?ooo`050:ZZ
ZP3<c<`0oooo0?ooo`3<c<`00P0000050?ooo`8000003@3oool200000</0oooo8000001n0?ooo`00
8@3oool2000000L0oooo00<0<c<c06IVIP1VIVH00P0000000`1EEED0oooo0?ooo`030?ooo`800000
3@3oool200000;T0oooo9P00000:0?3`l0@00000O03oool00240oooo0P0000070?ooo`060>k^kP1g
MgL04A4A0000001EEED0k^k^1@3oool2000000d0oooo0P00002V0?ooobH000007P3`l?04000007/0
oooo000R0?ooo`800000403oool2000000d0oooo0`00002C0?ooobL00000<P3`l?04000007T0oooo
000R0?ooo`800000403oool2000000d0oooo0P0000220?ooobH00000AP3`l?04000007P0oooo000R
0?ooo`<000003P3oool3000000d0oooo0P00001_0?ooobH00000F`3`l?04000007H0oooo000S0?oo
o`<00000303oool3000000h0oooo0P00001M0?ooobH00000KP3`l?04000007D0oooo000T0?ooo`<0
00002P3oool3000000l0oooo0P00001:0?ooobH00000P`3`l?04000007<0oooo000U0?ooo`@00000
1P3oool400000100oooo0P00000g0?ooobL00000UP3`l?0400000780oooo000V0?ooo``000004@3o
ool2000002D0oooo9P00002[0?3`l0<00000L@3oool002T0oooo1P00000C0?ooo`<000004P3ooolV
00000;l0l?3`1000001_0?ooo`00@P3oool2000000X0oooo7@00003B0?3`l0@00000KP3oool00480
oooo0P00000:0?ooo`X00000i`3`l?04000002X0oooo0P0000000`3oool0000000000002000003/0
oooo00120?ooo`800000303oool700000>T0l?3`1000000Y0?ooo`@000000P3oool2000003X0oooo
00120?ooo`8000003`3oool600000>T0l?3`1000000W0?ooo`<000000`3oool3000003T0oooo0012
0?ooo`8000004P3oool600000>L0l?3`1000000V0?ooo`800000103oool3000003T0oooo00120?oo
o`800000503oool6000003<0l?3`400000080?3`l0800000VP3`l?04000002T0oooo1000000i0?oo
o`00@P3oool2000001L0oooo1P00000`0?3`l1<00000103`l?03000009/0l?3`1000000V0?ooo`D0
0000>P3oool00480oooo0P00000I0?ooo`L000007P3`l?02000000<0l?3`0P0000020?3`l0800000
4`3`l?0<000009`0l?3`1000000R0?ooo`H00000>`3oool00480oooo0P00000L0?ooo`H00000703`
l?02000000<0l?3`0P0000020?3`l08000005P3`l?09000009d0l?3`1000000P0?ooo`D00000?@3o
ool00480oooo0P00000O0?ooo`H00000?@3`l?06000009l0l?3`1000000N0?ooo`<00000103oool2
000003T0oooo00110?ooo`<000008@3oool6000003X0l?3`2000002O0?3`l0@000007@3oool30000
00<0oooo0`00000i0?ooo`00@@3oool2000002D0oooo1P00000g0?3`l0P00000X@3`l?04000001`0
oooo0P0000020?ooo`@00000>@3oool00440oooo0P00000W0?ooo`L00000=03`l?0800000:80l?3`
1000000L0?ooo`@0000000<0oooo000000000000>@3oool00440oooo0P00000Z0?ooo`H00000=@3`
l?0600000:<0l?3`1000001J0?ooo`00@@3oool2000002d0oooo1P00000e0?3`l0<00000Y03`l?04
000005T0oooo00110?ooo`800000;`3oool600000=`0l?3`1000001G0?ooo`00@@3oool200000380
oooo1P00000S0?3`l0030820P03`l?00l?3`00H0l?3`00<0H61P0=3@d03`l?001@3`l?0500000:40
l?3`1000001F0?ooo`00@@3oool2000003@0oooo1`00000O0?3`l0030:2PX01@D500l?3`00L0l?3`
00<0/;2`051@D03`l?00103`l?0700000:80l?3`1000001D0?ooo`00@@3oool2000003L0oooo1P00
000M0?3`l003020P802PX:00l?3`00P0l?3`00<0410@0>3Ph03`l?000`3`l?0700000:<0l?3`1000
001C0?ooo`00@@3oool2000003X0oooo1P00000B0?3`l005030`<01@D500H61P0410@030`<000P3`
l?000`30`<0000000?3`l0020?3`l004071`L0000000<30`0<30`0<0l?3`00<0D51@0820P03`l?00
0`3`l?0700000:D0l?3`0`00001B0?ooo`00@@3oool2000003`0oooo1P00000@0?3`l005051@D03`
l?00l?3`061PH00P82000P3`l?000`1PH600@4100?3`l0020?3`l08000000P2PX:030?3`l003092@
T00P8200l?3`00<0l?3`1`00002V0?3`l0@00000D03oool00440oooo0P00000o0?ooo`H000003@3`
l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000P3`l?000`000000<30`0?3`
l0040?3`l0030<30`0000000l?3`00@0l?3`1@00002X0?3`l0@00000C`3oool00440oooo0P000011
0?ooo`L000002P3`l?001@3Ph>00@410000000000000D51@0080l?3`00<000000;2`/03`l?000P3`
l?000`000000<30`0?3`l0050?3`l0030000002`/;00l?3`0;80l?3`1000001=0?ooo`00@@3oool2
000004@0oooo1P0000080?3`l005051@D00000000000051@D03Ph>000P3`l?000`000000/;2`0?3`
l0020?3`l0030000000`<300l?3`00D0l?3`00<000000;2`/03`l?00/`3`l?04000004`0oooo0011
0?ooo`800000A`3oool6000000D0l?3`0P0000000`30`<00l?3`0?3`l0020?3`l0030000002`/;00
l?3`0080l?3`00<00000030`<03`l?001@3`l?000`000000/;2`0?3`l02e0?3`l0@00000BP3oool0
0400oooo0`0000190?ooo`H000000`3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0820P
0:2PX03`l?000P3`l?000`000000<30`0?3`l0040?3`l0030<30`0000000l?3`0;L0l?3`10000019
0?ooo`00@03oool2000004d0oooo1P0000001@30`<00@410071`L01@D500@4100080l?3`00D0D51@
071`L03`l?00l?3`030`<00300000006030`<03`l?00l?3`0?3`l02@T900410@^P3`l?04000004L0
oooo00100?ooo`800000C`3oool7000000@0l?3`00<0T92@030`<03`l?000P3`l?000`1@D500<30`
0?3`l0040?3`l003051@D01PH600l?3`0;X0l?3`100000160?ooo`00@03oool200000580oooo1P00
00030?3`l0030000003Ph>00l?3`0080l?3`00<0T92@0?3`l03`l?000`3`l?000`000000d=3@0?3`
l02l0?3`l0@00000A03oool00400oooo0P00001E0?ooo`H0000000<0L71`092@T03`l?001`3`l?00
0`2PX:00<30`0?3`l02n0?3`l0@00000@`3oool00400oooo0P00001G0?ooo`H00000203`l?000`1`
L700d=3@0?3`l0300?3`l0@00000@@3oool00400oooo0P00001J0?ooo`H00000b@3`l?0400000400
oooo00100?ooo`800000G03oool700000<P0l?3`1000000n0?ooo`00@03oool2000005l0oooo1P00
00370?3`l0@00000?@3oool00400oooo0P00001R0?ooo`H00000aP3`l?04000003/0oooo00100?oo
o`800000I03oool600000<D0l?3`1000000j0?ooo`00@03oool3000006H0oooo1P0000340?3`l0@0
0000>03oool00440oooo0P00001P0?ooo`8000001P3oool700000<80l?3`1000000g0?ooo`00@@3o
ool200000600oooo0P0000090?ooo`H00000`P3`l?04000003D0oooo00110?ooo`800000H03oool2
000000`0oooo1P0000300?3`l0@00000=03oool00440oooo0P00001O0?ooo`<000003P3oool60000
0<00l?3`0`00000c0?ooo`00@@3oool2000005l0oooo0P00000B0?ooo`H00000_P3`l?0400000340
oooo00110?ooo`<00000GP3oool2000001@0oooo1`00002l0?3`l0@00000<03oool00480oooo0P00
001g0?ooo`H00000_03`l?04000002h0oooo00120?ooo`800000NP3oool600000;X0l?3`1000000]
0?ooo`00@P3oool2000003l0oooo1P00000g0?ooo`H00000^P3`l?04000002/0oooo000N0?ooo`P0
0000703oool2000003`0oooo3000000g0?ooo`H00000^03`l?04000002X0oooo000O0?ooo`800000
0`3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`800000
>`3oool4000000H0oooo1000000h0?ooo`L00000]`3`l?04000002P0oooo000O0?ooo`8000002@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo0`00000i0?ooo`<000002P3o
ool3000003X0oooo1P00002f0?3`l0@000009`3oool001l0oooo0P0000080?ooo`8000002@3oool2
000000d0oooo0P00000h0?ooo`<000001@3oool01`1gMgL0A4A4000000000000EEEE09VIV@3oool0
0`00000l0?ooo`H00000]@3`l?04000002D0oooo000O0?ooo`80000000<0oooo0000000000001@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo0P00000g0?ooo`<00000203o
ool2000000@0oooo0`00000<0?ooo`800000;`3oool600000;@0l?3`1000000T0?ooo`005`3oool5
000000<0oooo1@0000040?ooo`8000001@3oool2000000@0oooo0P00000<0?ooo`800000=`3oool2
000000T0oooo0P0000050?ooo`800000303oool200000380oooo1P00002c0?3`l0@000008P3oool0
01P0oooo0`0000040?ooo`80000000<0oooo000000000000103oool2000000@0oooo0`0000040?oo
o`800000303oool2000003L0oooo0P0000090?ooo`8000001@3oool2000000/0oooo0`00000d0?oo
o`L00000/@3`l?0400000240oooo000H0?ooo`<00000103oool2000000L0oooo0P0000040?ooo`80
00001@3oool2000000`0oooo0P00000f0?ooo`8000002P3oool2000000H0oooo0P00000:0?ooo`80
0000>03oool600000;40l?3`1000000O0?ooo`00603oool3000000@0oooo0P0000030?ooo`800000
0P3oool2000000@0oooo0P0000050?ooo`800000303oool3000003D0oooo0P00000:0?ooo`800000
1P3oool2000000T0oooo0`00000k0?ooo`H00000[`3`l?04000001h0oooo000H0?ooo`<000000`3o
ool800000080oooo0P0000040?ooo`8000001@3oool2000000d0oooo0P00000e0?ooo`8000002P3o
ool2000000H0oooo0P0000090?ooo`800000?P3oool600000:l0l?3`1000000L0?ooo`00603oool3
000000d0oooo0P0000040?ooo`8000001@3oool2000000d0oooo0P00000e0?ooo`8000002P3oool2
000000H0oooo0P0000080?ooo`<00000@@3oool600000:d0l?3`1000000K0?ooo`00603oool30000
00d0oooo0P0000040?ooo`8000001@3oool2000000d0oooo0P00000e0?ooo`8000002P3oool20000
00H0oooo0P0000070?ooo`<00000A03oool700000:`0l?3`1000000I0?ooo`00603oool3000000d0
oooo0P0000040?ooo`8000001@3oool2000000d0oooo0P00000e0?ooo`8000001`3oool00`3<c<`0
EEEE0;^k^`02000000H0oooo0P0000070?ooo`800000B03oool600000:/0l?3`1000000H0?ooo`00
603oool3000000d0oooo0P0000030?ooo`@00000103oool2000000d0oooo0P00000f0?ooo`800000
1`3oool0103^k^h0IVIV0000000000050?ooo`8000001`3oool3000004/0oooo1P00002Z0?3`l0@0
00005P3oool001P0oooo0`00000>0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000
oooo0?ooo`0<0?ooo`<00000=@3oool2000000T0oooo00<0^k^k014A4@3oool0103oool2000000L0
oooo0P00001>0?ooo`H00000Z@3`l?04000001D0oooo000H0?ooo`<000003P3oool2000000<0oooo
0P0000040?ooo`8000003`3oool2000003D0oooo0`00000>0?ooo`<000001P3oool300000540oooo
1P00002X0?3`l0<00000503oool001L0oooo1@00000>0?ooo`040000003oool0oooo0?ooo`800000
103oool00`000000oooo0?ooo`0>0?ooo`800000=P3oool3000000`0oooo0`0000070?ooo`800000
E03oool700000:H0l?3`1000000B0?ooo`00:`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo0P00000g0?ooo`<000002P3oool300000640oooo1P00002U0?3`l0@000004@3o
ool004D0oooo0`00000g0?ooo`@000001P3oool4000006D0oooo1P00002T0?3`l0@000003`3oool0
04H0oooo0P00000h0?ooo``00000J03oool600000:<0l?3`1000000>0?ooo`00AP3oool2000003/0
oooo1P00001^0?ooo`H00000XP3`l?04000000`0oooo00160?ooo`<00000/03oool700000:00l?3`
1000000;0?ooo`00A`3oool200000;<0oooo1P00002P0?3`l0@000002@3oool004L0oooo0P00002f
0?ooo`H00000WP3`l?04000000P0oooo00170?ooo`<00000A`3oool2000006h0ooooY`0000070?oo
o`00B03oool2000004L0oooo0P00001a0?oooj@000001`3oool004P0oooo0P0000160?ooo`<00000
o`3ooolM0?ooo`00B03oool3000004@0oooo0`00003o0?oooah0oooo00190?ooo`800000A03oool2
00000?l0oooo7`3oool004T0oooo0P0000130?ooo`<00000o`3ooolO0?ooo`00B@3oool300000480
oooo0P00003o0?ooob00oooo001:0?ooo`800000@@3oool300000=P0oooo1P0000020?ooo`800000
00<0oooo0000003oool0103oool3000000030?ooo`000000oooo0080oooo0P0000040?ooo`800000
0P3oool3000000040?ooo`000000oooo000000H0oooo0`0000030?ooo`@000003@3oool004X0oooo
0P0000100?ooo`<00000f03oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`80000000<0oooo0000003oool0103oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`00BP3o
ool3000003l0oooo0P00003I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo001;0?ooo`800000?P3o
ool3000000T0oooo0P0000030?ooo`<00000c`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`800000
3@3oool004/0oooo0P00000n0?ooo`800000303oool01P000000oooo0?ooo`000000oooo00000<d0
oooo0P0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000103oool6
00000080oooo0P00000?0?ooo`00B`3oool3000004/0oooo00@000000?ooo`3oool00000b`3oool4
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000A0?ooo`00C03o
ool2000004/0oooo00@000000?ooo`3oool00000bP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo008000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool00000
000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo001<0?ooo`800000B`3oool010000000oooo0?ooo`00003:0?ooo`030000003o
ool0oooo00@0oooo10000000103oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo0`0000020?ooo`<0000000<0oooo0000003oool00`3oool01@000000
oooo0000003oool0000000@0oooo0P0000040?ooo`@000003@3oool004`0oooo0`0000180?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000001H0oooo00<000000?ooo`3oool09@3oool004d0oooo0P0000190?ooo`L00000
b@3oool600000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`00C@3o
ool200000?l0ooooH@3oool004d0oooo0`00003o0?ooof00oooo001>0?ooo`800000=@3oool20000
0?l0oooo:@3oool004h0oooo0P00000e0?ooo`800000o`3ooolY0?ooo`00CP3oool3000003<0oooo
0`00003o0?ooobT0oooo001?0?ooo`800000<`3oool200000?l0oooo:P3oool004l0oooo0`00000a
0?ooo`<00000o`3ooolZ0?ooo`00D03oool300000300oooo0P00003o0?ooob/0oooo001A0?ooo`80
0000;`3oool300000?l0oooo:`3oool00540oooo0`00000]0?ooo`<00000o`3oool/0?ooo`00DP3o
ool2000002d0oooo0P00003o0?ooobd0oooo001B0?ooo`<00000:`3oool300000?l0oooo;@3oool0
05<0oooo0`00000Z0?ooo`800000o`3oool^0?ooo`00E03oool2000002T0oooo0`00003o0?ooobh0
oooo001D0?ooo`<00000:03oool200000?l0oooo;`3oool005D0oooo0P00003o0?oooeT0oooo001E
0?ooo`<00000o`3ooomH0?ooo`00EP3oool300000?l0ooooE`3oool005L0oooo0P00003o0?oooeL0
oooo001G0?ooo`<00000o`3ooomF0?ooo`00F03oool200000?l0ooooEP3oool005P0oooo0`00003o
0?oooeD0oooo001I0?ooo`<000007`3oool200000?l0oooo<`3oool005X0oooo0P00000O0?ooo`80
0000o`3ooolc0?ooo`00FP3oool3000001d0oooo0`00003o0?oooc<0oooo001K0?ooo`800000703o
ool300000?l0oooo=03oool005/0oooo0`00000E0?ooo`D0000000<0oooo000000000000IP3oool>
00000<00oooo001L0?ooo`<00000503oool800000540oooo9000002o0?ooo`00G@3oool2000001@0
oooo2@00000k0?ooob/00000303oool400000;d0oooo001M0?ooo`<000004P3oool;000002D0oooo
:`00000R0?ooo`@00000_03oool005h0oooo0P00000B0?ooo`/00000403oool[000003T0oooo1000
002j0?ooo`00LP3ooola000004l0oooo1000002i0?ooo`00HP3oool/000006H0oooo1000002g0?oo
o`00C@3oool/000007`0oooo1@00002e0?ooo`00>03oool[000000h0oooo1`00001o0?ooo`@00000
]03oool002<0oooo:`00000S0?ooo`H00000PP3oool400000;80oooo000H0?ooob400000>03oool5
000008@0oooo1000002a0?ooo`00603oool<000004d0oooo100000270?ooo`@00000[`3oool001X0
oooo1`00001?0?ooo`@00000R@3oool400000:h0oooo000M0?ooo`H00000C@3oool3000008`0oooo
1000002/0?ooo`00803oool6000004X0oooo0P00002>0?ooo`@00000Z`3oool00280oooo1`00003I
0?ooo`@00000Z@3oool002D0oooo1P00003H0?ooo`@00000Z03oool002P0oooo1P00003G0?ooo`@0
0000YP3oool002X0oooo1P00003F0?ooo`@00000<03oool:000006/0oooo000]0?ooo`H00000e@3o
ool4000002l0oooo0`0000030?ooo`<00000J`3oool002l0oooo1`00003C0?ooo`D00000;@3oool3
000000@0oooo0P00001[0?ooo`00<P3oool6000002`0oooo3000002K0?ooo`@00000;03oool30000
0740oooo000e0?ooo`H00000:@3oool<000009d0oooo1000000Z0?ooo`<00000L@3oool003L0oooo
1`00000V0?ooo`800000203oool2000000D0oooo1@00002D0?ooo`@00000:@3oool3000000<0oooo
0P00001/0?ooo`00>P3oool6000002@0oooo0P0000080?ooo`8000001P3oool3000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`240?ooo`@000009`3oool8000006`0oooo000m
0?ooo`H000008@3oool2000000P0oooo0P0000060?ooo`<00000203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08@0oooo1000000V0?ooo`<000000`3oool2000006`0oooo000o0?oo
o`L000007P3oool2000000P0oooo0P0000060?ooo`<00000203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08H0oooo1000000T0?ooo`<00000L@3oool00480oooo1P00000L0?ooo`80
0000203oool2000000H0oooo1P0000040?ooo`030000003oool0oooo0080oooo0`0000030?ooo`03
0000003oool0oooo08H0oooo1000000S0?ooo`<00000103oool2000006/0oooo00150?ooo`H00000
6@3oool<000000H0oooo1`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`280?ooo`@000008@3oool3000000<0oooo0`00001[0?ooo`00A`3o
ool6000001L0oooo300000060?ooo`<0000000<0oooo0000000000000P0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`290?ooo`@000007`3o
ool:000006/0oooo001:0?ooo`H000009P3oool300000080oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2;0?ooo`@00000TP3oool0
04`0oooo1`00000S0?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo08`0oooo1000002A0?ooo`00C`3oool600000240
oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0SP3oool4000008l0oooo001B0?ooo`H000007@3oool5000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo08l0oooo1@00002=0?ooo`00E03oool7000001`0oooo1@0000040?ooo`040000003o
ool0oooo0?ooo`@000000`3oool00`000000oooo0?ooo`2A0?ooo`@00000S03oool005L0oooo1P00
000T0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2D0?ooo`@00000
RP3oool005X0oooo1P00000Q0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`2E0?ooo`@00000R@3oool005`0oooo1`00000O0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0V03oool4000008L0oooo001O0?ooo`H00000`03oool4000008H0oooo001R0?oo
o`H00000_`3oool4000008@0oooo001T0?ooo`H00000_P3oool4000008<0oooo001W0?ooo`H00000
_@3oool400000840oooo001Y0?ooo`L00000^`3oool400000800oooo001/0?ooo`H00000^`3oool4
000007h0oooo001_0?ooo`H00000^@3oool5000007`0oooo001a0?ooo`L00000^03oool4000007/0
oooo001d0?ooo`H00000^03oool4000007T0oooo001g0?ooo`H00000]P3oool4000007P0oooo001i
0?ooo`L00000]@3oool4000007H0oooo001l0?ooo`H00000]03oool4000007D0oooo001o0?ooo`H0
0000/`3oool4000007<0oooo00210?ooo`H00000/P3oool400000780oooo00240?ooo`H00000/@3o
ool400000700oooo00260?ooo`L00000[`3oool4000006l0oooo00290?ooo`H00000[`3oool40000
06d0oooo002<0?ooo`H00000[@3oool4000006`0oooo002>0?ooo`L00000[03oool4000006X0oooo
002A0?ooo`H00000Z`3oool5000006P0oooo002D0?ooo`H00000ZP3oool4000006L0oooo002F0?oo
o`L00000Z@3oool4000006D0oooo002I0?ooo`H00000Z03oool4000006@0oooo002L0?ooo`H00000
Y`3oool400000680oooo002N0?ooo`H00000YP3oool400000640oooo002Q0?ooo`H00000Y@3oool4
000005l0oooo002S0?ooo`L00000X`3oool4000005h0oooo002V0?ooo`H00000X`3oool4000005`0
oooo002Y0?ooo`H00000X@3oool4000005/0oooo002[0?ooo`L00000X03oool4000005T0oooo002^
0?ooo`H00000W`3oool4000005P0oooo002a0?ooo`H00000WP3oool4000005H0oooo002c0?ooo`L0
0000W03oool5000005@0oooo002f0?ooo`H00000W03oool4000005<0oooo002i0?ooo`H00000V`3o
ool400000540oooo002k0?ooo`H00000VP3oool400000500oooo002n0?ooo`H00000V@3oool40000
04h0oooo00300?ooo`L00000U`3oool4000004d0oooo00330?oooj000000C03oool00<H0ooooW@00
001<0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3o
oon`0?ooo`00o`3ooon`0?ooo`00o`3ooolE0?ooo`L0000000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00800000DP3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3o
oolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`H0
00000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0
oooo1`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000D`3oool00?l0oooo
5@3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool000000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool20000
00<0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool2000000<0oooo00@000000?ooo`3oool00000D`3oool00?l0oooo
5@3oool00`000000oooo0?ooo`050?ooo`030000003oool00000008000000`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`<000000`3oool00`00
0000oooo0000000200000080oooo00D000000?ooo`00000000000?ooo`03000000D0oooo0P000004
0?ooo`030000003oool00000008000000P3oool300000580oooo003o0?oooaD0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`1A0?ooo`00o`3ooolE0?ooo`L000003`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0540oooo003o0?oook00oooo003o0?oook00oooo003o
0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o
0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001h0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003X0oooo001f0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0=P3oool00780oooo0?l000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`00000000@0oooo0000003oool00000>P3oool00700ooooo`00
0005000000030?ooo`000000000003P0oooo001`0?ooool00000100000000`3oool000000?ooo`0i
0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool200000100
l?3`00<000000?3`l03`l?003@3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?02000003T0l?3`>@3ooolg0<o?c`80000000<0oooo0000003o
ool0>@3oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`0000020?3`l0030000
003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0800000
>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool200000100l?3`00<0
00000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`00/0l?3`00<0
00000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>03`l?0i0?ooocL0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00L03oool2000000h0l?3`100000050?3`l08000001@3`l?00
10000000l?3`0?3`l03`l?02000000<0l?3`0`0000020?3`l0030000003`l?00l?3`00<0l?3`1000
00020?3`l0030000003`l?00l?3`0080l?3`0`0000040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0<00000>03`l?0i0?ooocL0clo?0`00
00000`3oool000000000000h0?ooo`00L03oool2000000d0l?3`00H000000?3`l03`l?0000000?3`
l00000040?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`0?3`l0030?3`l0060000
003`l?00l?3`0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0<00000>03`l?0i0?oo
ocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000000`0l?3`00D000000?3`l03`
l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l0D000000P3`l?000`000000l?3`0?3`l003
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04000003L0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000<0?3`l0050000003`l?00
l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`l?02000000030?3`l000000000000080l?3`
00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000040?3`l0030000003`l?00l?3`00D0
l?3`0P0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04000003L0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000<0?3`l0050000
003`l?00l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`l?0200000080l?3`0P0000000`3`
l?0000000?3`l0040?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02
000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0@00000=`3`l?0i
0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000000`0l?3`00D000000?3`
l03`l?00l?3`000000020?3`l0030000003`l?00l?3`00L0000000<0l?3`0000003`l?000P3`l?00
0`000000l?3`000000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?04
000003L0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000=0?3`
l0<0000000<0l?3`0000000000002`3`l?000`000000l?3`0?3`l0020?3`l0L000000P3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000103`l?000`00
0000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0030?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?oo
o`00L03oool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`1@00000f0?3`l3T0oooo=`3?cll20000
00030?ooo`000000oooo03T0oooo001`0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l003
0000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0D00000=P3`l?0i0?oo
ocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000001l0l?3`00<000000?3`l03`
l?002`3`l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`00
0000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?060000
03D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000P0?3`l003
0000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0050?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0H0
0000=@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`
1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`
l?07000003@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D
0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
05@0l?3`1`0000070?3`l0030000003`l?00l?3`00D0l?3`1`0000040?3`l0030000003`l?00l?3`
00@0l?3`00<000000?3`l03`l?00403`l?0i0?oooal0clo?00<000000<o?c`3?cll00`3?cll00`00
0000clo?0<o?c`0?0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0L0
00001`3`l?000`000000l?3`0?3`l0060?3`l08000000P3`l?02000000<0l?3`00<000000?3`l03`
l?001P3`l?000`000000l?3`0?3`l00;0?3`l0<0000000<0l?3`0?ooo`3oool0503oool5000000@0
oooo0P00000E0?ooo`<000007P3?cll00`000000clo?0<o?c`050<o?c`030000003?cll0clo?00h0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000
003`l?00l?3`00H0l?3`0P0000070?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?00
2`3`l?04000001D0oooo0`0000030?ooo`8000000P3oool3000001@0oooo1000000L0<o?c`030000
003?cll0clo?00L0clo?00<000000<o?c`3?cll03@3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000E03`l?08000000H0l?3`100000020?3`l080000000@0l?3`000000000000l?3`
0P0000030?3`l0030000003`l?00l?3`0080l?3`0`0000030?3`l0030000003`l?00l?3`00X0l?3`
1P00000B0?ooo`<000001@3oool4000000030?ooo`000000oooo01<0oooo1@00000A0<o?c`<00000
00@0clo?00000000000000000`3?cll010000000clo?0<o?c`3?cll3000000<0clo?00<000000<o?
c`3?cll03@3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?08000000H0
l?3`00@000000?3`l03`l?00l?3`0P0000030?3`l0D000000`3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002P3`l?0700000140oooo0P0000060?oo
o`<000005`3oool7000000h0clo?00<000000<o?c`3?cll00P0000030<o?c`030000003?cll00000
00@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo0000
00000000>03oool00700oooo0P00001D0?3`l0T000001@3`l?0010000000l?3`0?3`l03`l?020000
00<0l?3`0P0000000`3`l?000000000000030?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003P3oool3000000L0oooo0P00000G0?oo
o`P000003@3?cll01@000000clo?0<o?c`3?cll0000000<0clo?00<000000<o?c`000000103?cll0
0`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0P0000000`3oool000000?ooo`0i
0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`0080l?3`00@000000?3`
l03`l?00l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00<0l?3`00<000000?3`l03`l?002P3`l?0:000000d0oooo0`0000070?ooo`8000005`3oool9
000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<0
00000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00L000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`00<00000
0?3`l00000005@00000<0?ooo`<000001`3oool3000000X0oooo5P00000;0<o?c`050000003?cll0
clo?0<o?c`0000000`3?cll00`000000clo?000000040<o?c`030000003?cll0clo?00@0clo?00<0
00000<o?c`3?cll0303?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?09
000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0000000E000000`0oooo0`000007
0?ooo`<000002P3ooolF000000/0clo?0P0000020<o?c`030000003?cll0clo?0080000000<0clo?
0000003?cll00`3?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0`000000
0`3oool000000000000h0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
00<0l?3`00<000000?3`l03`l?002P3`l?09000000l0oooo0P0000060?ooo`040000003oool00000
000001H0oooo2000000>0<o?c`8000000`3?cll2000000<0clo?00D000000<o?c`3?cll0clo?0000
00050<o?c`030000003?cll0clo?00d0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2
000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?000`000000l?3`0?3`
l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool7000001T0clo?
00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3oool00000
0000000h0?ooo`00L03oool2000005@0l?3`2000000H0?3`l0050000003`l?00l?3`0?3`l0000000
103`l?000`000000l?3`0?3`l00;0?3`l0D00000503oool3000000<0oooo00<000000?ooo`3oool0
0`00000E0?ooo`D00000703?cll010000000clo?0<o?c`0000040<o?c`030000003?cll0clo?00h0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2000000H0?3`l0050000
003`l?00l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l0@000005`3oool4000000<0
oooo0`00000E0?ooo`<000007`3?cll00`000000clo?000000030<o?c`030000003?cll0clo?00l0
clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1`00000J0?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?00303`l?0200000080l?3`=P3oool2000000030?oo
o`3?cll0clo?03D0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`1`00
000d0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?07
000003@0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0L00000=03`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0
l?3`1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
E03`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000`0?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000003`l?00
l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<000000?3`
l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000
l?3`0?3`l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00
L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?c`800000
00<0oooo0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0l?3`1000
000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000:P3`l?02
00000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?oo
o`800000:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`
l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`0000000000
03P0oooo001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i0?ooocL0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?00
5`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000X0?3`l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?00
5`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000_0?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`l0800000
>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0l?3`00D0
00000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`l3T0oooo
=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000l?3`0?3`
l0050?3`l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000/0?oo
o`<00000@@3oool2000000T0l?3`0`0000230?3`l3T0oooo=`3?cll3000000030?ooo`0000000000
03P0oooo000[0?ooo`050000003oool0oooo0?ooo`000000@03oool2000000L0l?3`1@0000230?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000`0?ooo`030000003oool0oooo03d0
oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00
8@3oool6000000030?ooo`000000oooo00<0oooo0P000000103oool000000?ooo`0000040?ooo`03
0000003oool0oooo0080oooo0`0000000`3oool00000000000030?ooo`@000009`3oool200000080
l?3`2@0000240?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000P0?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo0000003oool0
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0903oool=000008@0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00200oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool2000000L0
oooo00<000000?ooo`3oool0903oool<000008D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003o
ool0>@3oool002L0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`8000009P3oool<000008H0
l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool002D0oooo0P0000001@3oool00000
0?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`H0
00000`3oool2000002P0oooo300000260?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0
oooo000Q0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool0:@3oool:000008L0
l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool00200oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool00000000000030?ooo`05
0000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0T0?ooool000001000000l0?ooo`00803oool00`000000oooo0?ooo`040?ooo`80
0000103oool2000000050?ooo`000000oooo0000003oool00`0000050?ooo`@0000000<0oooo0000
003oool00P3oool4000002L0ooooo`000004000003`0oooo000P0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`P00000o`3ooolh0?ooo`00
8@3oool6000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool0:`3oool300000080oooo
1000003o0?ooocP0oooo001^0?ooo`<00000103oool2000002h0oooo0P3o003o0?ooo`T0oooo001]
0?ooo`<00000=@3oool20?l00?l0oooo2@3oool006`0oooo0`00000f0?ooo`80o`00o`3oool90?oo
o`00J`3oool3000003H0oooo103o003o0?ooo`P0oooo000;0?ooo`L0000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo008000000`3oool3000000040?ooo`0000000000000000`0oooo0`00000g
0?ooo`@0o`00o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000003oool02P3oool3000003P0oooo103o003o0?ooo`P0oooo
000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0oooo1000
000i0?ooo`D0o`00o`3oool70?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000080?ooo`@00000>P3oool50?l00?l0oooo1`3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`H0
00000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo1@0000000`3o
ool000000?ooo`060?ooo`<00000>`3oool60?l00?l0oooo1`3oool000/0oooo1`0000000`3oool0
00000?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000203oool00`000000oooo000000060?ooo`<0
0000?03oool60?l00?l0oooo1`3oool000/0oooo00<000000?ooo`3oool01@3oool2000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`8000000`3oool01@000000
oooo0?ooo`3oool000000080oooo0P0000030?ooo`040000003oool0000000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`<0
0000?@3oool70?l00?l0oooo1P3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
00000002000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?oo
o`0000000`3oool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003oool00000
0000003oool00`0000050?ooo`800000103oool00`000000oooo0000000200000080oooo0`000003
0?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`<00000?P3oool70?l00?l0oooo1P3oool0
00/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
0?ooo`<00000?`3oool70?l00?l0oooo1P3oool000/0oooo1`00000?0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03000003l0oooo2@3o003o0?oo
o`D0oooo001O0?ooo`<00000@03oool90?l00?l0oooo1@3oool005h0oooo0`0000110?ooo`T0o`00
o`3oool50?ooo`00GP3oool200000480oooo1`3o003o0?ooo`L0oooo001M0?ooo`<00000AP3oool2
0?l00?l0oooo203oool005d0oooo0P0000170?ooo`80o`00o`3oool80?ooo`00G03oool3000004L0
oooo0P3o003o0?ooo`P0oooo001K0?ooo`<00000B03oool20?l00?l0oooo203oool005/0oooo0P00
00190?ooo`80o`00o`3oool80?ooo`00FP3oool3000004T0oooo0P3o003o0?ooo`P0oooo001J0?oo
o`800000o`3ooomD0?ooo`00F@3oool300000?l0ooooE03oool005T0oooo0P00003o0?oooeD0oooo
001H0?ooo`<00000o`3ooomE0?ooo`00E`3oool300000?l0ooooEP3oool005L0oooo0P00003o0?oo
oeL0oooo001F0?ooo`<00000o`3ooomG0?ooo`00EP3oool200000500oooo0P3o003o0?ooo`H0oooo
001E0?ooo`<00000D03oool20?l00?l0oooo1P3oool005D0oooo0P00001A0?ooo`80o`00o`3oool6
0?ooo`00E03oool300000540oooo0P3o003o0?ooo`H0oooo001D0?ooo`800000DP3oool20?l00?l0
oooo1P3oool005<0oooo0`00001B0?ooo`80o`00o`3oool60?ooo`00DP3oool3000005<0oooo0P3o
003o0?ooo`H0oooo001B0?ooo`800000E03oool20?l00?l0oooo1P3oool00540oooo0`00001D0?oo
o`80o`00o`3oool60?ooo`00D@3oool2000005D0oooo0P3o003o0?ooo`H0oooo001@0?ooo`<00000
E@3oool20?l00?l0oooo1P3oool00500oooo0P00001F0?ooo`80o`00o`3oool60?ooo`00C`3oool3
000005H0oooo0P3o003o0?ooo`H0oooo001?0?ooo`800000E`3oool20?l00?l0oooo1P3oool004l0
oooo0P00003o0?oooel0oooo001>0?ooo`<00000o`3ooomO0?ooo`00CP3oool200000?l0ooooH03o
ool004d0oooo0`00003o0?ooof00oooo001=0?ooo`800000o`3ooomQ0?ooo`00C03oool300000?l0
ooooH@3oool004`0oooo0P00003o0?ooof80oooo001;0?ooo`<00000F`3oool20?l00?l0oooo1@3o
ool004/0oooo0P00001L0?ooo`80o`00o`3oool50?ooo`00B`3oool2000005`0oooo0P3o003o0?oo
o`D0oooo001:0?ooo`<00000G03oool20?l00?l0oooo1@3oool004X0oooo0P00001M0?ooo`<0o`00
o`3oool40?ooo`00B@3oool3000005h0oooo0P3o003o0?ooo`@0oooo00190?ooo`800000G`3oool2
0?l00?l0oooo103oool004P0oooo0`00001O0?ooo`80o`00o`3oool40?ooo`00B03oool200000600
oooo0P3o003o0?ooo`@0oooo00180?ooo`800000H03oool20?l00?l0oooo103oool004L0oooo0`00
001P0?ooo`<0o`00o`3oool30?ooo`00A`3oool200000680oooo0P3o003o0?ooo`<0oooo00160?oo
o`<00000HP3oool20?l00?l0oooo0`3oool004H0oooo0P00001S0?ooo`80o`00o`3oool30?ooo`00
AP3oool200000?l0ooooJ03oool004H0oooo0P00003o0?ooofP0oooo000Y0?ooo`H000005P3oool3
00000?l0ooooJ03oool002H0oooo3000000C0?ooo`800000o`3ooomY0?ooo`009@3oool4000000H0
oooo1000000B0?ooo`800000o`3ooomY0?ooo`00903oool300000080oooo1`0000001014A4@00000
00000000000A0?ooo`800000o`3ooomY0?ooo`008`3oool3000000<0oooo00<0VIVI000000000000
100c<c<00`14A4@0oooo0000000200000100oooo0P00003o0?ooofT0oooo000R0?ooo`<000001@3o
ool00`3<c<`000000;^k^`030?ooo`0308R8R03oool0oooo00<000003`3oool200000?l0ooooJ@3o
ool00280oooo0P0000070?ooo`030<c<c00A4A40c<c<00H0oooo0P00000?0?ooo`800000o`3ooomY
0?ooo`008P3oool2000000P0oooo00<0^k^k0000003^k^h01@3oool2000000h0oooo0`00001U0?oo
o`80o`00o`3oool20?ooo`008@3oool2000000X0oooo00<0IVIV03<c<`3oool01@3oool2000000d0
oooo0P00001V0?ooo`80o`00o`3oool20?ooo`008@3oool2000000X0oooo00<0gMgM0000002k^k/0
1@3oool2000000d0oooo0P00001V0?ooo`80o`00o`3oool20?ooo`008@3oool2000000/0oooo00<0
8R8R04A4A03oool0103oool2000000d0oooo0P00001V0?ooo`80o`00MP3oool<000007l0oooo000Q
0?ooo`8000002`3oool2014A4@D0oooo0P00000=0?ooo`800000IP3oool20?l006<0oooo8000001n
0?ooo`008@3oool2000000H0oooo00L0ZZZZ0<c<c03oool0oooo0;^k^`0000004A4A00D0oooo0P00
000=0?ooo`800000IP3oool20?l00540oooo9P00000:0?3`l0@00000O03oool00240oooo0P000007
0?ooo`0303<c<`1VIVH0IVIV0080000000<0EEEE0?ooo`3oool00`3oool2000000d0oooo0P00001V
0?ooo`80o`00?P3ooolV000001h0l?3`1000001k0?ooo`008P3oool2000000H0oooo00H0k^k^07Mg
M`000000000005EEE@3^k^h40?ooo`8000003@3oool3000006H0oooo0P3o000[0?ooobL00000<P3`
l?04000007T0oooo000R0?ooo`800000403oool2000000d0oooo0P00001W0?ooo`80o`006@3ooolV
000004H0l?3`1000001h0?ooo`008P3oool3000000h0oooo0`00000=0?ooo`800000I`3oool20?l0
00H0oooo9P00001K0?3`l0@00000MP3oool002<0oooo0`00000<0?ooo`<000003P3oool2000005d0
oooo2P0000020?l001X00000KP3`l?04000007D0oooo000T0?ooo`<000002P3oool3000000l0oooo
0P00001:0?oooad000000P3o0007000008<0l?3`1000001c0?ooo`009@3oool4000000H0oooo1000
000@0?ooo`800000=`3ooolW000009H0l?3`1000001b0?ooo`009P3oool<00000140oooo0P00000U
0?ooobH00000Z`3`l?0300000740oooo000Y0?ooo`H000004`3oool300000180oooo9P00002o0?3`
l0@00000K`3oool00480oooo0P00000:0?oooad00000dP3`l?04000002`0oooo0P0000000`3oool0
000000000002000003/0oooo00120?ooo`8000002P3oool:00000>L0l?3`1000000Z0?ooo`@00000
0P3oool2000003X0oooo00120?ooo`800000303oool700000>T0l?3`1000000Y0?ooo`<000000`3o
ool3000003T0oooo00120?ooo`8000003`3oool600000>T0l?3`1000000W0?ooo`800000103oool3
000003T0oooo00120?ooo`8000004P3oool600000>L0l?3`1000000[0?ooo`@00000>@3oool00480
oooo0P00000D0?ooo`H00000<`3`l?0@000000P0l?3`0P0000030?3`l080o`00U@3`l?04000002L0
oooo1@00000j0?ooo`00@P3oool2000001L0oooo1P00000Q0?3`l08000000`3`l?0200000080l?3`
0P0000040?3`l1<00000103`l?03000000<0l?3`0P3o002F0?3`l0@00000903oool6000003/0oooo
00120?ooo`8000006@3oool7000001h0l?3`0P0000030?3`l08000000P3`l?02000001<0l?3`3000
00020?3`l080o`00V03`l?0400000240oooo1@00000m0?ooo`00@P3oool2000001`0oooo1P00000m
0?3`l0T000000P3`l?020?l009T0l?3`1000000P0?ooo`<00000103oool2000003T0oooo00110?oo
o`<000007`3oool6000003d0l?3`1P0000020?3`l080o`00V`3`l?04000001h0oooo0`0000030?oo
o`<00000>@3oool00440oooo0P00000R0?ooo`H00000>P3`l?08000000030?3`l03o0000o`0009`0
l?3`1000000N0?ooo`8000000P3oool4000003T0oooo00110?ooo`8000009@3oool6000003L0l?3`
200000000`3`l?00o`000?l0002N0?3`l0@000007@3oool4000000030?ooo`000000000003T0oooo
00110?ooo`8000009`3oool7000003@0l?3`2000002R0?3`l0@00000G03oool00440oooo0P00000Z
0?ooo`H00000=@3`l?0600000:<0l?3`1000001J0?ooo`00@@3oool2000002d0oooo1P00000e0?3`
l0<00000Y03`l?04000005T0oooo00110?ooo`800000;`3oool6000002H0l?3`00<0h>3P0?3`l03`
l?00/`3`l?04000005L0oooo00110?ooo`800000<P3oool600000280l?3`00<0d=3@020P803`l?00
1`3`l?000`1`L700d=3@0?3`l0050?3`l0D00000X@3`l?04000005H0oooo00110?ooo`800000=03o
ool7000001l0l?3`00<0D51@092@T03`l?001`3`l?000`2`/;00D51@0?3`l0040?3`l0L00000XP3`
l?04000005@0oooo00110?ooo`800000=`3oool6000001`0l?3`00<0d=3@0000003Ph>002@3`l?00
0`0@4100d=3@0?3`l0030?3`l0L00000X`3`l?04000005<0oooo00110?ooo`800000>P3oool60000
0180l?3`00D0<30`051@D01PH600<30`0<30`0020?3`l0030820P00`<300l?3`0080l?3`00@0L71`
0000000`<300`<300`3`l?000`1PH600L71`0?3`l0030?3`l0L00000Y@3`l?0300000580oooo0011
0?ooo`800000?03oool600000100l?3`00D0D51@0?3`l03`l?00L71`020P80020?3`l003030`<01`
L700l?3`0080l?3`00@00000010@402`/;00X:2P0`3`l?000`2PX:00820P0?3`l0030?3`l0L00000
YP3`l?0400000500oooo00110?ooo`800000?`3oool6000000d0l?3`00<0d=3@0?3`l02@T9000P00
00020?3`l003010@402PX:00l?3`0080l?3`00<00000030`<03`l?00103`l?000`3@d=0000000?3`
l0040?3`l0D00000Z03`l?04000004l0oooo00110?ooo`800000@@3oool7000000X0l?3`00D0/;2`
010@40000000410@0<30`0020?3`l0030000002`/;00l?3`0080l?3`00<00000030`<03`l?001@3`
l?000`000000/;2`0?3`l02b0?3`l0@00000C@3oool00440oooo0P0000140?ooo`H00000203`l?02
000000030;2`/03`l?00l?3`0080l?3`00<000000;2`/03`l?000P3`l?000`000000<30`0?3`l005
0?3`l0030000002`/;00l?3`0;<0l?3`1000001<0?ooo`00@03oool3000004L0oooo1P0000050?3`
l005010@401`L700l?3`0?3`l01@D5000P3`l?000`0@4100X:2P0?3`l0020?3`l0030000000`<300
l?3`00D0l?3`00<000000<30`03`l?00]@3`l?04000004X0oooo00100?ooo`800000BP3oool60000
00<0l?3`00D0`<300410@01`L700D51@0410@0020?3`l0050410@01`L700l?3`0?3`l00`<3000`00
00001P0`<300l?3`0?3`l03`l?00/;2`00000;P0l?3`100000190?ooo`00@03oool2000004d0oooo
1P0000070?3`l003092@T00`<300l?3`0080l?3`00<0D51@030`<03`l?00103`l?000`20P800820P
0?3`l02i0?3`l0@00000A`3oool00400oooo0P00001?0?ooo`L000001@3`l?000`000000h>3P0?3`
l0020?3`l003092@T03`l?00l?3`00<0l?3`00<0<30`0820P03`l?00^P3`l?04000004H0oooo0010
0?ooo`800000DP3oool6000000<0l?3`00<0L71`092@T03`l?001`3`l?000`3Ph>0000000>3Ph02m
0?3`l0@00000A03oool00400oooo0P00001E0?ooo`H0000000<0h>3P0410@03`l?001`3`l?000`20
P800L71`0?3`l02n0?3`l0@00000@`3oool00400oooo0P00001G0?ooo`H00000203`l?000`2`/;00
l?3`0?3`l0300?3`l0@00000@@3oool00400oooo0P00001J0?ooo`H00000b@3`l?0400000400oooo
00100?ooo`800000G03oool700000<P0l?3`1000000n0?ooo`00@03oool2000005l0oooo1P000037
0?3`l0@00000?@3oool00400oooo0P00001R0?ooo`H00000aP3`l?04000003/0oooo00100?ooo`<0
0000H03oool2000000030?ooo`000000000000@00000a@3`l?04000003X0oooo00110?ooo`800000
H03oool2000000@0oooo1P0000340?3`l0@00000>03oool00440oooo0P00001P0?ooo`8000001P3o
ool700000<80l?3`1000000g0?ooo`00@@3oool200000600oooo0P0000090?ooo`H00000`P3`l?04
000003D0oooo00110?ooo`800000G`3oool3000000`0oooo1P0000300?3`l0@00000=03oool00440
oooo0P00001O0?ooo`8000003`3oool600000<00l?3`0`00000c0?ooo`00@@3oool3000005h0oooo
0P00000B0?ooo`H00000_P3`l?0400000340oooo00120?ooo`800000GP3oool2000001@0oooo1`00
002l0?3`l0@00000<03oool00480oooo0P00001g0?ooo`H00000_03`l?04000002h0oooo00120?oo
o`800000NP3oool600000;X0l?3`1000000]0?ooo`00@P3oool2000003l0oooo1P00000g0?ooo`H0
0000^P3`l?04000002/0oooo000N0?ooo`P00000703oool2000003`0oooo3000000g0?ooo`H00000
^03`l?04000002X0oooo000O0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`<00000>P3oool4000000H0oooo1000000h0?ooo`L00000]`3`
l?04000002P0oooo000O0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00`0oooo0P00000i0?ooo`<00000103oool01P1gMgL0A4A4000000000000EEEE09VIV@<00000
>P3oool600000;H0l?3`1000000W0?ooo`007`3oool2000000P0oooo0P0000090?ooo`8000003@3o
ool2000003P0oooo0`0000070?ooo`8000000`3oool3000003`0oooo1P00002e0?3`l0@000009@3o
ool001l0oooo0P0000000`3oool00000000000050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02`3oool2000003L0oooo0`0000080?ooo`800000103oool3000000`0oooo0P00000_
0?ooo`H00000]03`l?04000002@0oooo000G0?ooo`D000000`3oool5000000@0oooo0P0000050?oo
o`800000103oool2000000`0oooo0P00000g0?ooo`8000002@3oool2000000D0oooo0P00000<0?oo
o`800000<P3oool600000;<0l?3`1000000R0?ooo`00603oool3000000@0oooo0P0000000`3oool0
0000000000040?ooo`800000103oool3000000@0oooo0P00000<0?ooo`800000=`3oool2000000T0
oooo0P0000050?ooo`8000002`3oool3000003@0oooo1`00002a0?3`l0@000008@3oool001P0oooo
0`0000040?ooo`8000001`3oool2000000@0oooo0P0000050?ooo`800000303oool3000003D0oooo
0P00000:0?ooo`8000001P3oool2000000X0oooo0P00000h0?ooo`H00000/@3`l?04000001l0oooo
000H0?ooo`<00000103oool2000000<0oooo0P0000020?ooo`800000103oool2000000D0oooo0P00
000=0?ooo`800000=@3oool2000000X0oooo0P0000060?ooo`8000002@3oool3000003/0oooo1P00
002_0?3`l0@000007P3oool001P0oooo0`0000030?ooo`P000000P3oool2000000@0oooo0P000005
0?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3oool2000000T0oooo0P00000n
0?ooo`H00000[`3`l?04000001`0oooo000H0?ooo`<000003@3oool2000000@0oooo0P0000050?oo
o`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3oool2000000P0oooo0`0000110?oo
o`H00000[@3`l?04000001/0oooo000H0?ooo`<000003@3oool2000000@0oooo0P0000050?ooo`80
00003@3oool2000003D0oooo0P0000070?ooo`030<c<c01EEED0^k^k008000001P3oool2000000L0
oooo0`0000140?ooo`L00000[03`l?04000001T0oooo000H0?ooo`<000003@3oool2000000@0oooo
0P0000050?ooo`8000003@3oool2000003D0oooo0P0000080?ooo`040>k^kP1VIVH00000000000H0
oooo0P0000070?ooo`800000B03oool600000:/0l?3`1000000H0?ooo`00603oool3000000d0oooo
0P0000030?ooo`@00000103oool2000000d0oooo0`00000e0?ooo`8000002@3oool00`2k^k/04A4A
0?ooo`040?ooo`8000001`3oool3000004/0oooo1P00002Z0?3`l0@000005P3oool001P0oooo0`00
000>0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`0=0?ooo`800000
=@3oool200000100oooo0P0000070?ooo`800000CP3oool600000:T0l?3`1000000E0?ooo`00603o
ool3000000h0oooo0P0000030?ooo`800000103oool2000000l0oooo0P00000e0?ooo`<000003P3o
ool3000000H0oooo0`00001A0?ooo`H00000Z03`l?03000001@0oooo000G0?ooo`D000003P3oool0
10000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool03P3oool2000003H0oooo0`00
000<0?ooo`<000001`3oool2000005@0oooo1`00002V0?3`l0@000004P3oool002/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`<00000=P3oool3000000X0oooo0`00001Q
0?ooo`H00000Y@3`l?0400000140oooo00160?ooo`800000=`3oool4000000H0oooo1000001U0?oo
o`H00000Y03`l?04000000l0oooo00160?ooo`800000>03oool<000006P0oooo1P00002S0?3`l0@0
00003P3oool004H0oooo0`00000j0?ooo`H00000KP3oool600000:80l?3`1000000<0?ooo`00A`3o
ool200000;00oooo1`00002P0?3`l0@000002`3oool004L0oooo0P00002c0?ooo`H00000X03`l?04
000000T0oooo00170?ooo`<00000]@3oool6000009h0l?3`100000080?ooo`00B03oool2000004L0
oooo0P00001^0?ooojL000001`3oool004P0oooo0P0000170?ooo`800000L@3ooonT000000L0oooo
00180?ooo`<00000A@3oool300000?l0oooo7@3oool004T0oooo0P0000140?ooo`<00000o`3ooolN
0?ooo`00B@3oool2000004@0oooo0P00003o0?oooal0oooo00190?ooo`<00000@P3oool300000?l0
oooo7`3oool004X0oooo0P0000120?ooo`800000o`3ooolP0?ooo`00BP3oool300000400oooo0`00
003H0?ooo`H000000P3oool2000000030?ooo`000000oooo00@0oooo0`0000000`3oool000000?oo
o`020?ooo`800000103oool200000080oooo0`000000103oool000000?ooo`0000060?ooo`<00000
0`3oool4000000d0oooo001;0?ooo`800000?`3oool300000=P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool20000
00030?ooo`000000oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool02P3oool004/0oooo0P00000o0?ooo`800000f@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`00B`3oool3000003d0oooo0`0000090?ooo`8000000`3oool300000<l0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool01`3oool2000000d0oooo001<0?ooo`800000?@3oool2000000`0oooo00H00000
0?ooo`3oool000000?ooo`00003=0?ooo`8000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0000000@0oooo1P0000020?ooo`8000003`3oool004`0oooo0P00001;0?ooo`04
0000003oool0oooo00000</0oooo100000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000004@3oool004`0oooo0`00001:0?ooo`040000003oool0oooo00000<X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0000000000040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00C@3oool2000004X0oooo00@000000?oo
o`3oool00000bP3oool00`000000oooo0?ooo`040?ooo`@0000000@0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000000P3oool3000000030?oo
o`000000oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`800000103oool4000000d0
oooo001=0?ooo`800000B03oool00`000000oooo000000020?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000F0?ooo`030000003oool0oooo02D0oooo
001=0?ooo`<00000B03oool700000<T0oooo1P0000020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool09@3oool004h0oooo0P00003o0?ooof00oooo001>0?ooo`800000o`3ooomP0?oo
o`00CP3oool3000003@0oooo0P00003o0?ooobT0oooo001?0?ooo`800000=03oool200000?l0oooo
:@3oool004l0oooo0`00000b0?ooo`<00000o`3ooolY0?ooo`00D03oool200000380oooo0P00003o
0?ooobX0oooo001@0?ooo`<00000<03oool300000?l0oooo:P3oool00540oooo0`00000_0?ooo`80
0000o`3oool[0?ooo`00DP3oool2000002h0oooo0`00003o0?ooob/0oooo001B0?ooo`<00000;03o
ool300000?l0oooo;03oool005<0oooo0P00000/0?ooo`800000o`3oool]0?ooo`00D`3oool30000
02X0oooo0`00003o0?ooobd0oooo001D0?ooo`800000:P3oool200000?l0oooo;P3oool005@0oooo
0`00000X0?ooo`<00000o`3oool^0?ooo`00E@3oool2000002P0oooo0P00003o0?ooobl0oooo001E
0?ooo`<00000o`3ooomH0?ooo`00EP3oool300000?l0ooooE`3oool005L0oooo0P00003o0?oooeL0
oooo001G0?ooo`<00000o`3ooomF0?ooo`00F03oool200000?l0ooooEP3oool005P0oooo0`00003o
0?oooeD0oooo001I0?ooo`800000o`3ooomE0?ooo`00F@3oool3000001l0oooo0P00003o0?oooc<0
oooo001J0?ooo`8000007`3oool200000?l0oooo<`3oool005X0oooo0`00000M0?ooo`<00000o`3o
oolc0?ooo`00F`3oool3000001/0oooo0`00003o0?oooc@0oooo001L0?ooo`8000005@3oool80000
06H0oooo3P0000300?ooo`00G03oool3000001@0oooo2000001A0?ooob@00000_`3oool005d0oooo
0P00000D0?ooo`T00000>`3oool[000000`0oooo1000002m0?ooo`00G@3oool300000180oooo2`00
000U0?ooob/000008P3oool400000;`0oooo001N0?ooo`8000004P3oool;00000100oooo:`00000i
0?ooo`@00000^P3oool00780oooo<@00001?0?ooo`D00000^03oool00680oooo;000001V0?ooo`@0
0000]`3oool004d0oooo;000001m0?ooo`@00000]@3oool003P0oooo:`00000>0?ooo`L00000O`3o
ool400000;@0oooo000S0?ooob/000008`3oool600000880oooo1000002b0?ooo`00603ooolQ0000
03P0oooo1@0000240?ooo`@00000/@3oool001P0oooo3000001=0?ooo`@00000Q`3oool400000:l0
oooo000J0?ooo`L00000C`3oool4000008T0oooo1@00002]0?ooo`007@3oool6000004d0oooo0`00
002<0?ooo`@00000[03oool00200oooo1P00001:0?ooo`800000S`3oool400000:X0oooo000R0?oo
o`L00000f@3oool400000:T0oooo000U0?ooo`H00000f@3oool400000:L0oooo000X0?ooo`H00000
e`3oool400000:H0oooo000Z0?ooo`L00000eP3oool4000002l0oooo2P00001[0?ooo`00;@3oool6
00000=D0oooo1000000_0?ooo`<000000`3oool3000006/0oooo000`0?ooo`H00000;P3oool<0000
09X0oooo1000000]0?ooo`<00000103oool2000006/0oooo000b0?ooo`L00000:`3oool<000009/0
oooo1@00000[0?ooo`<00000L@3oool003D0oooo1P00000Y0?ooo`800000203oool2000009d0oooo
1000000Z0?ooo`<00000L@3oool003P0oooo1P00000V0?ooo`800000203oool2000000D0oooo1@00
002E0?ooo`@00000:03oool3000000<0oooo0P00001/0?ooo`00>P3oool7000002<0oooo0P000008
0?ooo`8000001P3oool3000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`24
0?ooo`@000009`3oool8000006`0oooo000m0?ooo`H000008@3oool2000000P0oooo0P0000060?oo
o`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08D0oooo1000000U0?oo
o`<000000`3oool2000006`0oooo00100?ooo`H000007P3oool2000000P0oooo0P0000060?ooo`<0
0000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08H0oooo1000000T0?ooo`<0
0000L@3oool00480oooo1`00000K0?ooo`800000203oool2000000H0oooo1P0000040?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo08L0oooo1000000R0?ooo`<00000
103oool2000006/0oooo00150?ooo`L00000603oool<000000H0oooo1`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`280?ooo`@000008@3o
ool3000000<0oooo0`00001[0?ooo`00B03oool6000001H0oooo300000060?ooo`<0000000<0oooo
0000000000000P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2:0?ooo`@000007P3oool:000006/0oooo001;0?ooo`H000009@3oool30000
0080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2;0?ooo`D00000T@3oool004d0oooo1`00000R0?ooo`<000000P3oool300000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08d0
oooo1000002@0?ooo`00D03oool600000200oooo0`0000020?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S`3oool4000008h0oooo
001C0?ooo`H00000703oool5000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0900oooo1000002=0?ooo`00E@3oool7
000001/0oooo1@0000040?ooo`040000003oool0oooo0?ooo`@000000`3oool00`000000oooo0?oo
o`2B0?ooo`@00000R`3oool005P0oooo1P00000S0?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`2D0?ooo`@00000RP3oool005/0oooo1P00000P0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`2F0?ooo`@00000R03oool005d0oooo1`00000N
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool5000008H0oooo001P0?oo
o`H00000`03oool4000008D0oooo001S0?ooo`H00000_`3oool4000008<0oooo001U0?ooo`L00000
_@3oool400000880oooo001X0?ooo`H00000_@3oool400000800oooo001[0?ooo`H00000^`3oool4
000007l0oooo001]0?ooo`L00000^P3oool4000007d0oooo001`0?ooo`H00000^@3oool4000007`0
oooo001c0?ooo`H00000^03oool4000007X0oooo001e0?ooo`L00000]P3oool5000007P0oooo001h
0?ooo`H00000]P3oool4000007L0oooo001k0?ooo`H00000]@3oool4000007D0oooo001m0?ooo`L0
0000/`3oool4000007@0oooo00200?ooo`H00000/`3oool400000780oooo00230?ooo`H00000/@3o
ool400000740oooo00250?ooo`L00000/03oool4000006l0oooo00280?ooo`H00000[`3oool40000
06h0oooo002;0?ooo`H00000[P3oool4000006`0oooo002=0?ooo`L00000[03oool5000006X0oooo
002@0?ooo`H00000[03oool4000006T0oooo002C0?ooo`H00000Z`3oool4000006L0oooo002E0?oo
o`L00000Z@3oool4000006H0oooo002H0?ooo`L00000Z03oool4000006@0oooo002K0?ooo`H00000
Y`3oool4000006<0oooo002N0?ooo`H00000YP3oool400000640oooo002P0?ooo`L00000Y03oool5
000005l0oooo002S0?ooo`H00000Y03oool4000005h0oooo002V0?ooo`H00000X`3oool4000005`0
oooo002X0?ooo`L00000X@3oool4000005/0oooo002[0?ooo`H00000X@3oool4000005T0oooo002^
0?ooo`H00000W`3oool4000005P0oooo002`0?ooo`L00000WP3oool4000005H0oooo002c0?ooo`H0
0000W@3oool4000005D0oooo002f0?ooo`H00000W03oool4000005<0oooo002h0?ooo`L00000VP3o
ool500000540oooo002k0?ooo`H00000VP3oool400000500oooo002n0?ooo`H00000V@3oool40000
04h0oooo00300?ooo`L00000U`3oool4000004d0oooo00330?oooj000000C03oool00<H0ooooW@00
001<0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3o
oon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooolE0?ooo`L0000000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00800000DP3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000005<0
oooo003o0?oooaD0oooo1`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool000000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool2000000<0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00@000000?ooo`3oool00000
D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`030000003oool00000008000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?ooo`<0
00000`3oool00`000000oooo0000000200000080oooo00D000000?ooo`00000000000?ooo`030000
00D0oooo0P0000040?ooo`030000003oool00000008000000P3oool300000580oooo003o0?oooaD0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1A0?ooo`00o`3ooolE0?ooo`L00000
3`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0540oooo003o0?oook00oooo003o
0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o
0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo0000
\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00aP3oool700000>80oooo00340?ooo`/00000h03oool00<80oooo1000
00070?ooo`@00000gP3oool00<40oooo0`00000;0?ooo`<00000g@3oool00<00oooo0`0000040?oo
o`0507MgM`0R8R80MgMg06IVIP2IVIT0103oool300000=`0oooo00300?ooo`8000001@3oool01P0c
<c<0k^k^0?ooo`3oool0MgMg03<c<`@0oooo0P00003L0?ooo`00_`3oool2000000X0oooo00<0gMgM
0000001gMgL0103oool200000=/0oooo002o0?ooo`8000002`3oool00`0000004A4A0?ooo`030?oo
o`800000>03oool300000:00oooo002n0?ooo`8000002`3oool00`3<c<`00000000000050?ooo`80
0000>03oool00`000000oooo0?ooo`2O0?ooo`00_P3oool2000000P0oooo00H0k^k^0?ooo`3^k^h0
A4A40000000c<c<50?ooo`800000>03oool00`000000oooo0?ooo`2O0?ooo`00_P3oool2000000P0
oooo00H0VIVI014A4@000000000003<c<`3<c<`50?ooo`800000>03oool00`000000oooo0?ooo`2O
0?ooo`00_P3oool2000000T0oooo00<0k^k^05EEE@1VIVH01`3oool2000001`0oooo0`0000050?oo
o`<000000`3oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool50000
00@0oooo00<000000?ooo`3oool0103oool3000000L0oooo0`0000060?ooo`<000000P3oool50000
00050?ooo`00000000000000003oool00`00001S0?ooo`00_P3oool2000000/0oooo00<04A4A07Mg
M`3oool01@3oool2000001d0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
00000080oooo0`0000000`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0680oooo002n0?ooo`8000001`3oool0103^k^h0oooo0?ooo`3oool2014A4@H0oooo0P00000N
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1R0?ooo`00_P3oool2
000000L0oooo00H0VIVI07MgM`2k^k/0EEEE0000000A4A460?ooo`8000007P3oool7000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo0`0000030?ooo`050000003oool0oooo0?ooo`000000I03oool00;l0
oooo0P0000070?ooo`050:ZZZP0R8R80000003<c<`3<c<`01@3oool200000200oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`06000000L0oooo1P0000030?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0680oooo002o0?ooo`8000004@3oool200000200oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool000000080oooo0`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool30000
0080oooo00<000000?ooo`3oool0HP3oool00<00oooo0P00000?0?ooo`8000008@3oool01@000000
oooo0?ooo`3oool0000000H0oooo0P0000000`3oool000000?ooo`020?ooo`<00000103oool01000
0000oooo0000000000040?ooo`@0000000@0oooo0000003oool0oooo0`000000103oool000000000
000000030?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0
oooo0`0000040?ooo`040000003oool00000000006D0oooo00300?ooo`<000003@3oool300000280
oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?ooo`00`@3oool3000000/0
oooo0`00000S0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000L`3oool00<80
oooo100000070?ooo`@00000903oool00`000000oooo000000090?ooo`800000;`3oool00`000000
oooo0?ooo`030?ooo`040000003oool00000000007<0oooo00340?ooo`/000009`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0
oooo00<000000?ooo`3oool0L@3oool00<H0oooo1`00003R0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001h0?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003X0oooo001f0?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
=P3oool00780oooo0?l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`00000000@0oooo0000003oool00000>P3oool00700ooooo`000005000000030?oo
o`000000000003P0oooo001`0?ooool00000100000000`3oool000000?ooo`0i0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00002?0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000S`3`l?0i0?ooocL0
clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`800000
00<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i
0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000
S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000008l0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`l0800000>@3`l?0i
0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`8000005P3`l?07000003L0
l?3`0P00000i0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000
403`l?000`000000l?3`0?3`l0040?3`l08000000P3`l?02000000<0l?3`00<000000?3`l03`l?00
2`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00D0l?3`0`00000h0?3`l3T0oooo
=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000403`l?000`000000l?3`0?3`
l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?00103`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00000@0?3`l0030000003`l?00l?3`00@0l?3`0P0000000`3`l?00000000000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l007
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l004
0?3`l0<00000>03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
00h0l?3`100000050?3`l0D000000P3`l?0010000000l?3`0?3`l03`l?02000000<0l?3`0`000002
0?3`l0030000003`l?00l?3`00<0l?3`100000020?3`l0030000003`l?00l?3`0080l?3`0`000004
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l003
0?3`l0@00000=`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool20000
00d0l?3`00H000000?3`l03`l?0000000?3`l00000040?3`l080000000<0l?3`0000000000000P3`
l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`0000003`l?0000000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000103`l?000`000000
l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0030?3`l0@00000=`3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00
L03oool2000000`0l?3`00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`
l08000000P3`l?02000000030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000103`l?00
0`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0@00000=`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000000`0l?3`00D000000?3`l03`l?00l?3`000000020?3`l0030000003`l?00
l?3`00L0000000<0l?3`0000003`l?00103`l?0010000000l?3`0?3`l00000040?3`l0030000003`
l?00l?3`00D0l?3`0P0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`
l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?04000003L0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000<
0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?000`000000l?3`0?3`l0080?3`l0030000003`
l?00l?3`00<0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l0030?3`l0800000
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`1@00000f0?3`l3T0oooo
=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000303`l?001@000000l?3`0?3`
l03`l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`
l00000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00<0l?3`1@00000f0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`8000003@3`l?0300000003
0?3`l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?000`3`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo
0P00000N0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?000`3`l?0400000080l?3`
00@000000?3`l03`l?00l?3`100000040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0030?3`l0H00000=@3`l?0i0?ooocL0clo?0P0000000`3oool0
00000?ooo`0i0?ooo`00L03oool2000001l0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`
0?3`l0090?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?06000003D0l?3`>@3ooolg0<o?c`<0
000000<0oooo000000000000>03oool00700oooo0P00000O0?3`l0030000003`l?00l?3`00/0l?3`
00<000000?3`l03`l?002@3`l?001@000000l?3`0?3`l03`l?00000000D0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1P00000e0?3`l3T0
oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000803`l?000`000000l?3`
0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?001@3`l?07000003@0l?3`
>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0L00000=03`
l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`1`00000?
0?3`l0L000007P3`l?0i0?oooal0clo?00<000000<o?c`3?cll00`3?cll00`000000clo?0<o?c`0?
0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0L000001`3`l?000`00
0000l?3`0?3`l0060?3`l08000000P3`l?02000000@0l?3`00<000000?3`l03`l?00103`l?000`00
0000l?3`0?3`l00@0?3`l1H0oooo1@0000040?ooo`800000603ooolN0<o?c`030000003?cll0clo?
00D0clo?00<000000<o?c`3?cll03P3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`80
0000E03`l?08000000H0l?3`00<000000?3`l03`l?001P3`l?02000000L0l?3`00<000000?3`l03`
l?001P3`l?000`000000l?3`0?3`l00?0?3`l1D0oooo0`0000030?ooo`8000000P3oool3000001L0
oooo7@3?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00d0clo?0`0000000`3oool0
00000000000h0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000003`l?00l?3`00H0l?3`
0P0000000`3`l?000000000000040?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?00
2`3`l?03000000030?3`l03oool0oooo0180oooo0`0000050?ooo`@0000000<0oooo0000003oool0
4`3oool3000001<0clo?0`000000103?cll000000000000000030<o?c`040000003?cll0clo?0<o?
c`<000000`3?cll00`000000clo?0<o?c`0=0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00001D0?3`l0P000001P3`l?0400000080l?3`0P0000000`3`l?00000000000003000000<0
l?3`00<000000?3`l03`l?000P3`l?03000000<0l?3`00<000000?3`l03`l?002P3`l?05000001<0
oooo0P0000060?ooo`<000005`3oool500000100clo?00<000000<o?c`3?cll00P0000030<o?c`03
0000003?cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0
000000<0oooo000000000000>03oool00700oooo0P00001D0?3`l0T000001@3`l?0010000000l?3`
0?3`l03`l?02000000<0l?3`0P0000000`3`l?000000000000030?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0P000003`3oool3000000L0
oooo0P00000G0?ooo`L000003P3?cll01@000000clo?0<o?c`3?cll0000000<0clo?00<000000<o?
c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0040000003`l?00l?3`0?3`
l08000000`3`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0X000003@3oool3000000L0oooo0P00000G0?oo
o`T00000303?cll01@000000clo?0<o?c`3?cll0000000<0clo?00<000000<o?c`000000103?cll0
0`000000clo?0<o?c`040<o?c`030000003?cll0clo?00`0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00l?3`0080l?3`00<000000?3`
l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`00
0000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolF000000/0clo?00D000000<o?
c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0103?cll0
0`000000clo?0<o?c`0<0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`
l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303oool30000
00L0oooo0`00000:0?oooaH000002`3?cll200000080clo?00<000000<o?c`3?cll00P0000000`3?
cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?cll30000
00030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?09000000D0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003`3oool2000000H0oooo00@000000?ooo`00
000000005P3oool8000000h0clo?0P0000030<o?c`8000000`3?cll01@000000clo?0<o?c`3?cll0
000000D0clo?00<000000<o?c`3?cll03@3?cll2000000030?ooo`000000oooo03T0oooo001`0?oo
o`800000E03`l?08000000H0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`
l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`
l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool7000001T0clo?00<00000
0<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?00
0`000000l?3`0?3`l00:0?3`l0D00000503oool3000000<0oooo00<000000?ooo`3oool00`00000E
0?ooo`D00000703?cll010000000clo?0<o?c`0000040<o?c`030000003?cll0clo?00h0clo?0P00
00000`3oool000000?ooo`0i0?ooo`00L03oool2000005@0l?3`2000000H0?3`l0050000003`l?00
l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l0@000005`3oool4000000<0oooo0`00
000E0?ooo`<000007`3?cll00`000000clo?000000030<o?c`030000003?cll0clo?00l0clo?0`00
00000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1`00000I0?3`l0050000003`l?00
l?3`0?3`l0000000103`l?000`000000l?3`0?3`l00;0?3`l08000000P3`l?0f0?ooo`80000000<0
oooo0<o?c`3?cll0=@3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?07
000001X0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00@0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000E03`l?07000003@0l?3`>@3ooolg0<o?
c`80000000<0oooo0000003oool0>@3oool00700oooo0P00001D0?3`l0L00000=03`l?0i0?ooocL0
clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000005@0l?3`1P00000e0?3`l3T0oooo
=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000E03`l?06000003D0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000`0?3`l0030000003`l?00
l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0l?3`>@3ooolg0<o?c`80000000<0oooo
0000003oool0>@3oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<000000?3`
l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000X0?3`l0@00000
0P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l00G0?3`l0D00000
=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002L0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<0
00000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3o
ool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l0000000103`l?00
0`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000:P3`l?0200000080l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000:03`l?02000000@0
l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0
l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000
9`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0000
00040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?03000003P0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000X0?3`l0@000000P3`l?00
10000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?005`3`l?03000003P0l?3`>@3o
oolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0050000003`l?00
l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`l0800000>@3`l?0i0?ooocL0clo?0`00
00000`3oool000000000000h0?ooo`00L03oool2000002l0l?3`00D000000?3`l03`l?00l?3`0000
00050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`800000<03`l?000`000000l?3`0?3`l0050?3`l0030000003`l?00
l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00002?0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000/0?ooo`<00000@@3oool2000008l0
l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool002/0oooo00D000000?ooo`3oool0
oooo000000100?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00
<03oool00`000000oooo0?ooo`0m0?ooo`800000203`l?04000008<0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000@0
oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo000000000000
0`3oool4000002L0oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0i0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`02000000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`<00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo0P0000020?3`l0X00000
P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00803oool00`000000oooo0?oo
o`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`8000001`3oool00`000000oooo0?ooo`0T0?ooo`d00000
Q03`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`009`3oool200000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool2000000D0oooo0P00000V0?ooo`d00000Q@3`l?0i0?ooocL0clo?0`0000000`3oool00000
0?ooo`0h0?ooo`009@3oool2000000050?ooo`000000oooo0?ooo`000000103oool00`000000oooo
000000040?ooo`030000003oool0oooo0080oooo1P0000030?ooo`800000:03oool=000008D0l?3`
>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00240oooo100000030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`060?ooo`800000
0P3oool00`000000oooo0?ooo`0Y0?ooo`/00000QP3`l?0i0?ooocL0clo?0`0000000`3oool00000
0?ooo`0h0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
0P3oool2000000030?ooo`000000000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0ooooo`000004000003`0
oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80000000D0oooo0000003oool0
00000?ooo`03000000D0oooo100000000`3oool000000?ooo`020?ooo`@000009`3ooooo000000@0
0000?03oool00200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02d0oooo2000003o0?ooocL0oooo000Q0?ooo`H0000000<0oooo0000003oool05`3o
ool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000000000000P00003o0?ooocP0oooo001_
0?ooo`<000000`3oool200000?l0oooo>@3oool006h0oooo0`00003o0?ooocl0oooo001]0?ooo`<0
0000=@3oool20?l00?l0oooo2@3oool006`0oooo0`00000f0?ooo`80o`00o`3oool90?ooo`002`3o
ool7000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool3000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo0`000000103oool0
000000000000000=0?ooo`<00000=`3oool20?l00?l0oooo2@3oool000/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00/0oooo0`00
000g0?ooo`@0o`00o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000;0?ooo`<00000>03oool40?l00?l0oooo203oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000002P3oool3000003T0oooo103o003o0?oo
o`P0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool600000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`D0000000<0oooo0000003oool0203oool3000003X0oooo1@3o003o0?ooo`L0
oooo000;0?ooo`L0000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`000000203oool3000003X0oooo1P3o003o0?ooo`L0oooo000;0?ooo`030000003o
ool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000
oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001`3oool3000003/0oooo1P3o003o0?ooo`L0oooo000;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P0000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003oool000000080
00000P3oool01@000000oooo000000000000oooo00<000001@3oool2000000@0oooo00<000000?oo
o`0000000P0000020?ooo`<000000`3oool400000080oooo00<000000?ooo`3oool0103oool30000
03`0oooo1`3o003o0?ooo`H0oooo000;0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`<00000?@3oool70?l00?l0oooo1P3oool000/0oooo
1`00000?0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`<00000?P3oool70?l00?l0oooo1P3oool00640oooo0`00000n0?ooo`T0o`00o`3o
ool50?ooo`00H03oool3000003l0oooo2@3o003o0?ooo`D0oooo001O0?ooo`<00000@03oool90?l0
0?l0oooo1@3oool005h0oooo0`0000150?ooo`80o`00o`3oool80?ooo`00GP3oool2000004H0oooo
0P3o003o0?ooo`P0oooo001M0?ooo`<00000AP3oool20?l00?l0oooo203oool005d0oooo0P000017
0?ooo`80o`00o`3oool80?ooo`00G03oool3000004L0oooo0P3o003o0?ooo`P0oooo001K0?ooo`<0
0000B03oool20?l00?l0oooo203oool005/0oooo0P00003o0?oooe<0oooo001J0?ooo`<00000o`3o
oomC0?ooo`00FP3oool200000?l0ooooE03oool005T0oooo0`00003o0?oooe@0oooo001H0?ooo`<0
0000o`3ooomE0?ooo`00F03oool200000?l0ooooEP3oool005L0oooo0`00003o0?oooeH0oooo001G
0?ooo`800000o`3ooomG0?ooo`00EP3oool300000?l0ooooE`3oool005D0oooo0`00001@0?ooo`80
o`00o`3oool60?ooo`00E@3oool200000540oooo0P3o003o0?ooo`H0oooo001D0?ooo`<00000D@3o
ool20?l00?l0oooo1P3oool005@0oooo0P00001B0?ooo`80o`00o`3oool60?ooo`00D`3oool30000
0580oooo0P3o003o0?ooo`H0oooo001B0?ooo`<00000D`3oool20?l00?l0oooo1P3oool00580oooo
0P00001D0?ooo`80o`00o`3oool60?ooo`00D@3oool3000005@0oooo0P3o003o0?ooo`H0oooo001A
0?ooo`800000E@3oool20?l00?l0oooo1P3oool00500oooo0`00001E0?ooo`80o`00o`3oool60?oo
o`00D03oool2000005H0oooo0P3o003o0?ooo`H0oooo001?0?ooo`<00000EP3oool20?l00?l0oooo
1P3oool004l0oooo0P00003o0?oooel0oooo001>0?ooo`<00000o`3ooomO0?ooo`00CP3oool20000
0?l0ooooH03oool004h0oooo0P00003o0?ooof00oooo001=0?ooo`<00000o`3ooomP0?ooo`00C@3o
ool200000?l0ooooH@3oool004`0oooo0`00003o0?ooof40oooo001<0?ooo`800000o`3ooomR0?oo
o`00B`3oool300000?l0ooooHP3oool004/0oooo0P00001L0?ooo`80o`00o`3oool50?ooo`00BP3o
ool3000005`0oooo0P3o003o0?ooo`D0oooo001:0?ooo`800000G@3oool20?l00?l0oooo1@3oool0
04T0oooo0`00001M0?ooo`<0o`00o`3oool40?ooo`00B@3oool2000005l0oooo0P3o003o0?ooo`@0
oooo00190?ooo`800000G`3oool20?l00?l0oooo103oool004P0oooo0`00001O0?ooo`80o`00o`3o
ool40?ooo`00B03oool200000600oooo0P3o003o0?ooo`@0oooo00170?ooo`<00000H03oool30?l0
0?l0oooo0`3oool004L0oooo0P00001R0?ooo`80o`00o`3oool30?ooo`00AP3oool300000680oooo
0P3o003o0?ooo`<0oooo00160?ooo`800000H`3oool20?l00?l0oooo0`3oool004H0oooo0P00003o
0?ooofP0oooo00160?ooo`800000o`3ooomX0?ooo`00:@3oool6000001H0oooo0`00003o0?ooofP0
oooo000V0?ooo``000004`3oool200000?l0ooooJ@3oool002D0oooo100000060?ooo`@000004P3o
ool200000?l0ooooJ@3oool002@0oooo0`0000020?ooo`L0000000@0A4A400000000000000004@3o
ool200000?l0ooooJ@3oool002<0oooo0`0000030?ooo`030:ZZZP000000000000@0<c<c00<0A4A4
0?ooo`0000000P00000@0?ooo`800000o`3ooomY0?ooo`008P3oool3000000D0oooo00<0c<c<0000
002IVIT00`3oool00`2ZZZX0oooo0?ooo`03000000l0oooo0P00003o0?ooofT0oooo000R0?ooo`80
00001`3oool00`3<c<`0000009VIV@060?ooo`8000003`3oool200000?l0ooooJ@3oool00280oooo
0P0000080?ooo`030<c<c0000000ZZZZ00D0oooo0P00000>0?ooo`<00000I@3oool20?l00?l0oooo
0P3oool00240oooo0P00000:0?ooo`0308R8R0000000k^k^00D0oooo0P00000=0?ooo`800000IP3o
ool20?l00?l0oooo0P3oool00240oooo0P00000;0?ooo`030000001VIVH0oooo00@0oooo0P00000=
0?ooo`800000IP3oool20?l00?l0oooo0P3oool00240oooo0P00000;0?ooo`808R8R1@3oool20000
00d0oooo0P00001V0?ooo`80o`00MP3oool<000007l0oooo000Q0?ooo`8000001P3oool01@2ZZZX0
c<c<0?ooo`3oool0c<c<008000001@3oool2000000d0oooo0P00001V0?ooo`80o`00H`3ooolP0000
07h0oooo000Q0?ooo`8000001`3oool00`0c<c<0IVIV06IVIP020000000305EEE@3oool0oooo00<0
oooo0P00000=0?ooo`800000IP3oool20?l00540oooo9P00000:0?3`l0@00000O03oool00240oooo
0P0000070?ooo`060>k^kP1gMgL04A4A0000001EEED0k^k^1@3oool2000000d0oooo0P00001V0?oo
o`80o`00?P3ooolV000001h0l?3`1000001k0?ooo`008P3oool200000100oooo0P00000=0?ooo`<0
0000IP3oool20?l002/0oooo9`00000b0?3`l0@00000N@3oool00280oooo0P00000@0?ooo`800000
3@3oool2000006L0oooo0P3o000I0?ooobH00000AP3`l?04000007P0oooo000R0?ooo`<000003P3o
ool3000000d0oooo0P00001W0?ooo`80o`001P3ooolV000005/0l?3`1000001f0?ooo`008`3oool3
000000`0oooo0`00000>0?ooo`800000G@3oool:00000080o`006P00001^0?3`l0@00000M@3oool0
02@0oooo0`00000:0?ooo`<000003`3oool2000004X0oooo7@0000020?l000L00000P`3`l?040000
07<0oooo000U0?ooo`@000001P3oool400000100oooo0P00000g0?ooobL00000UP3`l?0400000780
oooo000V0?ooo``000004@3oool2000002D0oooo9P00002[0?3`l0<00000L@3oool002T0oooo1P00
000C0?ooo`<000004P3ooolV00000;l0l?3`1000001_0?ooo`00@P3oool2000000X0oooo7@00003B
0?3`l0@00000KP3oool00480oooo0P00000:0?ooo`X00000i`3`l?04000002X0oooo0P0000000`3o
ool0000000000002000003/0oooo00120?ooo`800000303oool700000>T0l?3`1000000Y0?ooo`@0
00000P3oool2000003X0oooo00120?ooo`8000003`3oool600000>T0l?3`1000000W0?ooo`<00000
0`3oool3000003T0oooo00120?ooo`8000004P3oool600000>L0l?3`1000000V0?ooo`800000103o
ool3000003T0oooo00120?ooo`800000503oool6000003<0l?3`400000080?3`l08000000`3`l?02
0?l009D0l?3`1000000Y0?ooo`@00000>@3oool00480oooo0P00000G0?ooo`H00000<03`l?0C0000
00@0l?3`0`0000030?3`l080o`00UP3`l?04000002H0oooo1@00000j0?ooo`00@P3oool2000001T0
oooo1`00000N0?3`l08000000`3`l?0200000080l?3`0P00000C0?3`l0`000000P3`l?020?l009P0
l?3`1000000R0?ooo`H00000>`3oool00480oooo0P00000L0?ooo`H00000703`l?02000000<0l?3`
0P0000020?3`l08000005P3`l?0900000080l?3`0P3o002I0?3`l0@00000803oool5000003d0oooo
00120?ooo`8000007`3oool6000003d0l?3`1P0000020?3`l080o`00V`3`l?04000001h0oooo0`00
00040?ooo`800000>@3oool00440oooo0`00000Q0?ooo`H00000>P3`l?08000000030?3`l03o0000
o`0009`0l?3`1000000M0?ooo`<000000`3oool3000003T0oooo00110?ooo`8000009@3oool60000
03L0l?3`200000000`3`l?00o`000?l0002N0?3`l0@00000703oool200000080oooo1000000i0?oo
o`00@@3oool2000002L0oooo1`00000d0?3`l0P0000000<0l?3`0?l0003o0000W`3`l?04000001`0
oooo100000000`3oool000000000000i0?ooo`00@@3oool2000002X0oooo1P00000e0?3`l0H00000
X`3`l?04000005X0oooo00110?ooo`800000;@3oool6000003D0l?3`0`00002T0?3`l0@00000F@3o
ool00440oooo0P00000_0?ooo`H00000g03`l?04000005L0oooo00110?ooo`800000<P3oool60000
02<0l?3`00<0P8200?3`l03`l?001P3`l?000`1PH600d=3@0?3`l0050?3`l0D00000X@3`l?040000
05H0oooo00110?ooo`800000=03oool7000001l0l?3`00<0X:2P051@D03`l?001`3`l?000`2`/;00
D51@0?3`l0040?3`l0L00000XP3`l?04000005@0oooo00110?ooo`800000=`3oool6000001d0l?3`
00<0820P0:2PX03`l?00203`l?000`0@4100h>3P0?3`l0030?3`l0L00000X`3`l?04000005<0oooo
00110?ooo`800000>P3oool600000180l?3`00D0<30`051@D01PH600@4100<30`0020?3`l0030<30
`0000000l?3`0080l?3`00@0L71`0000000`<300`<300`3`l?000`1@D500P8200?3`l0030?3`l0L0
0000Y@3`l?0300000580oooo00110?ooo`800000?03oool600000100l?3`00D0D51@0?3`l03`l?00
H61P020P80020?3`l003061PH010@400l?3`0080l?3`0P0000020:2PX0<0l?3`00<0T92@020P803`
l?000`3`l?0700000:H0l?3`1000001@0?ooo`00@@3oool2000003l0oooo1P00000=0?3`l0030=3@
d03`l?00/;2`008000000P3`l?000`0`<300L71`0?3`l0020?3`l0030000000`<300l?3`00@0l?3`
00<0`<300000003`l?00103`l?0500000:P0l?3`1000001?0?ooo`00@@3oool200000440oooo1`00
000:0?3`l0050>3Ph010@40000000000001@D5000P3`l?000`000000/;2`0?3`l0020?3`l0030000
000`<300l?3`00D0l?3`00<000000;2`/03`l?00/P3`l?04000004d0oooo00110?ooo`800000A03o
ool6000000P0l?3`00D0D51@000000000000D51@0>3Ph0020?3`l0030000002`/;00l?3`0080l?3`
00<00000030`<03`l?001@3`l?000`000000/;2`0?3`l02c0?3`l0@00000C03oool00440oooo0P00
00170?ooo`H000001@3`l?02000000030<30`03`l?00l?3`0080l?3`00<000000;2`/03`l?000P3`
l?000`000000<30`0?3`l0050?3`l0030000002`/;00l?3`0;D0l?3`1000001:0?ooo`00@03oool3
000004T0oooo1P0000030?3`l005010@401`L700l?3`0?3`l01@D5000P3`l?000`0P8200X:2P0?3`
l0020?3`l0030000000`<300l?3`00@0l?3`00<0`<300000003`l?00]`3`l?04000004T0oooo0010
0?ooo`800000C@3oool6000000050<30`010@400L71`051@D010@4000P3`l?001@1@D500L71`0?3`
l03`l?00<30`00<0000000H0<30`0?3`l03`l?00l?3`092@T00@412j0?3`l0@00000A`3oool00400
oooo0P00001?0?ooo`L00000103`l?000`2@T900<30`0?3`l0020?3`l003051@D00`<300l?3`00@0
l?3`00<0D51@061PH03`l?00^P3`l?04000004H0oooo00100?ooo`800000DP3oool6000000<0l?3`
00<000000>3Ph03`l?000P3`l?000`2@T900l?3`0?3`l0030?3`l0030000003@d=00l?3`0;`0l?3`
100000140?ooo`00@03oool2000005D0oooo1P0000000`1`L700T92@0?3`l0070?3`l0030:2PX00`
<300l?3`0;h0l?3`100000130?ooo`00@03oool2000005L0oooo1P0000080?3`l003071`L03@d=00
l?3`0<00l?3`100000110?ooo`00@03oool2000005X0oooo1P0000390?3`l0@00000@03oool00400
oooo0P00001L0?ooo`L00000b03`l?04000003h0oooo00100?ooo`800000G`3oool600000<L0l?3`
1000000m0?ooo`00@03oool200000680oooo1P0000360?3`l0@00000>`3oool00400oooo0P00001T
0?ooo`H00000a@3`l?04000003X0oooo00100?ooo`<00000IP3oool600000<@0l?3`1000000h0?oo
o`00@@3oool200000600oooo0P0000060?ooo`L00000`P3`l?04000003L0oooo00110?ooo`800000
H03oool2000000T0oooo1P0000320?3`l0@00000=@3oool00440oooo0P00001P0?ooo`800000303o
ool600000<00l?3`1000000d0?ooo`00@@3oool2000005l0oooo0`00000>0?ooo`H00000`03`l?03
000003<0oooo00110?ooo`800000G`3oool200000180oooo1P00002n0?3`l0@00000<@3oool00440
oooo0`00001N0?ooo`800000503oool700000;`0l?3`1000000`0?ooo`00@P3oool2000007L0oooo
1P00002l0?3`l0@00000;P3oool00480oooo0P00001j0?ooo`H00000^P3`l?04000002d0oooo0012
0?ooo`800000?`3oool6000003L0oooo1P00002j0?3`l0@00000:`3oool001h0oooo2000000L0?oo
o`800000?03oool<000003L0oooo1P00002h0?3`l0@00000:P3oool001l0oooo0P0000030?ooo`80
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00000k0?ooo`@0
00001P3oool4000003P0oooo1`00002g0?3`l0@00000:03oool001l0oooo0P0000090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool3000003T0oooo0`00000:0?ooo`<00000
>P3oool600000;H0l?3`1000000W0?ooo`007`3oool2000000P0oooo0P0000090?ooo`8000003@3o
ool2000003P0oooo0`0000050?ooo`0707MgM`14A4@000000000001EEED0VIVI0?ooo`03000003`0
oooo1P00002e0?3`l0@000009@3oool001l0oooo0P0000000`3oool00000000000050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool2000003L0oooo0`0000080?ooo`800000
103oool3000000`0oooo0P00000_0?ooo`H00000]03`l?04000002@0oooo000G0?ooo`D000000`3o
ool5000000@0oooo0P0000050?ooo`800000103oool2000000`0oooo0P00000g0?ooo`8000002@3o
ool2000000D0oooo0P00000<0?ooo`800000<P3oool600000;<0l?3`1000000R0?ooo`00603oool3
000000@0oooo0P0000000`3oool00000000000040?ooo`800000103oool3000000@0oooo0P00000<
0?ooo`800000=`3oool2000000T0oooo0P0000050?ooo`8000002`3oool3000003@0oooo1`00002a
0?3`l0@000008@3oool001P0oooo0`0000040?ooo`8000001`3oool2000000@0oooo0P0000050?oo
o`800000303oool2000003H0oooo0P00000:0?ooo`8000001P3oool2000000X0oooo0P00000h0?oo
o`H00000/@3`l?04000001l0oooo000H0?ooo`<00000103oool2000000<0oooo0P0000020?ooo`80
0000103oool2000000D0oooo0P00000<0?ooo`<00000=@3oool2000000X0oooo0P0000060?ooo`80
00002@3oool3000003/0oooo1P00002_0?3`l0@000007P3oool001P0oooo0`0000030?ooo`P00000
0P3oool2000000@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`800000
1P3oool2000000T0oooo0P00000n0?ooo`H00000[`3`l?04000001`0oooo000H0?ooo`<000003@3o
ool2000000@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3o
ool2000000P0oooo0`0000110?ooo`H00000[@3`l?04000001/0oooo000H0?ooo`<000003@3oool2
000000@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3oool2
000000L0oooo0`0000140?ooo`L00000[03`l?04000001T0oooo000H0?ooo`<000003@3oool20000
00@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P0000070?ooo`030<c<c01EEED0^k^k
008000001P3oool2000000L0oooo0P0000180?ooo`H00000Z`3`l?04000001P0oooo000H0?ooo`<0
00003@3oool2000000<0oooo100000040?ooo`8000003@3oool2000003H0oooo0P0000070?ooo`04
0>k^kP1VIVH00000000000D0oooo0P0000070?ooo`<00000B`3oool600000:X0l?3`1000000F0?oo
o`00603oool3000000h0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003oool0oooo
00`0oooo0`00000e0?ooo`8000002@3oool00`2k^k/04A4A0?ooo`040?ooo`8000001`3oool20000
04h0oooo1P00002Y0?3`l0@000005@3oool001P0oooo0`00000>0?ooo`8000000`3oool2000000@0
oooo0P00000?0?ooo`800000=@3oool3000000h0oooo0`0000060?ooo`<00000D@3oool600000:P0
l?3`0`00000D0?ooo`005`3oool5000000h0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`03
0000003oool0oooo00h0oooo0P00000f0?ooo`<00000303oool3000000L0oooo0P00001D0?ooo`L0
0000YP3`l?0400000180oooo000[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool2000003L0oooo0`00000:0?ooo`<00000H@3oool600000:D0l?3`1000000A0?ooo`00A@3o
ool3000003L0oooo100000060?ooo`@00000I@3oool600000:@0l?3`1000000?0?ooo`00AP3oool2
000003P0oooo3000001X0?ooo`H00000X`3`l?04000000h0oooo00160?ooo`800000>`3oool60000
06h0oooo1P00002R0?3`l0@00000303oool004H0oooo0`00002`0?ooo`L00000X03`l?04000000/0
oooo00170?ooo`800000/`3oool600000:00l?3`100000090?ooo`00A`3oool200000;H0oooo1P00
002N0?3`l0@00000203oool004L0oooo0`0000170?ooo`800000KP3ooonW000000L0oooo00180?oo
o`800000A`3oool200000740ooooY00000070?ooo`00B03oool2000004H0oooo0`00003o0?oooad0
oooo00180?ooo`<00000A03oool300000?l0oooo7P3oool004T0oooo0P0000140?ooo`800000o`3o
oolO0?ooo`00B@3oool2000004<0oooo0`00003o0?oooal0oooo00190?ooo`<00000@P3oool20000
0?l0oooo803oool004X0oooo0P0000110?ooo`<00000f03oool600000080oooo0P0000000`3oool0
00000?ooo`040?ooo`<0000000<0oooo0000003oool00P3oool2000000@0oooo0P0000020?ooo`<0
000000@0oooo0000003oool000001P3oool3000000<0oooo1000000=0?ooo`00BP3oool200000400
oooo0`00003H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool000000?ooo`040?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo001:0?ooo`<00000
?`3oool200000=T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool004/0oooo0P00000n0?ooo`<00000
2@3oool2000000<0oooo0`00003?0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo000000040?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`00
B`3oool2000003h0oooo0P00000<0?ooo`060000003oool0oooo0000003oool00000c@3oool20000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000040?ooo`H000000P3o
ool2000000l0oooo001;0?ooo`<00000B`3oool010000000oooo0?ooo`00003;0?ooo`@00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool000000140oooo001<0?ooo`800000
B`3oool010000000oooo0?ooo`00003:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000103o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool004`0oooo0P00001;0?ooo`040000003oool0oooo00000<X0oooo00<000000?ooo`3oool0
103oool4000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool300000080oooo0`0000000`3oool000000?ooo`030?ooo`050000003oool00000
0?ooo`000000103oool2000000@0oooo1000000=0?ooo`00C03oool3000004P0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000005P3oool00`000000oooo0?ooo`0U0?ooo`00C@3oool2000004T0oooo1`0000390?ooo`H0
00000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0oooo001=0?ooo`800000
o`3ooomQ0?ooo`00C@3oool300000?l0ooooH03oool004h0oooo0P00000e0?ooo`800000o`3ooolY
0?ooo`00CP3oool2000003D0oooo0P00003o0?ooobT0oooo001>0?ooo`<00000<`3oool300000?l0
oooo:@3oool004l0oooo0P00000c0?ooo`800000o`3ooolZ0?ooo`00C`3oool300000340oooo0`00
003o0?ooobX0oooo001@0?ooo`<00000<03oool200000?l0oooo:`3oool00540oooo0P00000_0?oo
o`<00000o`3oool[0?ooo`00D@3oool3000002d0oooo0`00003o0?ooob`0oooo001B0?ooo`800000
;@3oool200000?l0oooo;@3oool00580oooo0`00000[0?ooo`<00000o`3oool]0?ooo`00D`3oool3
000002X0oooo0P00003o0?ooobh0oooo001D0?ooo`800000:@3oool300000?l0oooo;P3oool005@0
oooo0`00000X0?ooo`800000o`3oool_0?ooo`00E@3oool200000?l0ooooF@3oool005D0oooo0`00
003o0?oooeP0oooo001F0?ooo`<00000o`3ooomG0?ooo`00E`3oool200000?l0ooooE`3oool005L0
oooo0`00003o0?oooeH0oooo001H0?ooo`800000o`3ooomF0?ooo`00F03oool300000?l0ooooE@3o
ool005T0oooo0`00000O0?ooo`800000o`3ooolc0?ooo`00FP3oool2000001l0oooo0P00003o0?oo
oc<0oooo001J0?ooo`<000007@3oool300000?l0oooo<`3oool005/0oooo0P00000L0?ooo`<00000
o`3ooold0?ooo`00F`3oool3000001D0oooo1@0000000`3oool000000000001V0?ooo`h00000`03o
ool005`0oooo0`00000D0?ooo`P00000D@3ooolT00000;l0oooo001M0?ooo`800000503oool90000
03/0oooo:`00000<0?ooo`@00000_@3oool005d0oooo0`00000B0?ooo`/000009@3oool[00000280
oooo1000002l0?ooo`00GP3oool200000180oooo2`00000@0?ooob/00000>@3oool400000;X0oooo
001b0?oooc400000C`3oool400000;T0oooo001R0?ooob`00000IP3oool400000;L0oooo001=0?oo
ob`00000O03oool500000;D0oooo000h0?ooob/000003P3oool7000007l0oooo1000002d0?ooo`00
8`3oool[000002<0oooo1P0000220?ooo`@00000/P3oool001P0oooo8@00000h0?ooo`D00000Q03o
ool400000;40oooo000H0?ooo``00000C@3oool4000008L0oooo1000002_0?ooo`006P3oool70000
04l0oooo100000290?ooo`@00000[P3oool001d0oooo1P00001=0?ooo`<00000S03oool400000:`0
oooo000P0?ooo`H00000BP3oool2000008h0oooo1000002[0?ooo`008P3oool700000=T0oooo1000
002Y0?ooo`009@3oool600000=P0oooo1000002X0?ooo`00:03oool600000=L0oooo1000002V0?oo
o`00:P3oool600000=H0oooo1000000`0?ooo`X00000J`3oool002d0oooo1P00003E0?ooo`@00000
;`3oool3000000<0oooo0`00001[0?ooo`00;`3oool700000=<0oooo1@00000]0?ooo`<00000103o
ool2000006/0oooo000b0?ooo`H00000;03oool<000009/0oooo1000000/0?ooo`<00000L@3oool0
03D0oooo1P00000Y0?ooo``00000W@3oool4000002X0oooo0`00001a0?ooo`00=`3oool7000002H0
oooo0P0000080?ooo`8000001@3oool5000009@0oooo1000000Y0?ooo`<000000`3oool2000006`0
oooo000j0?ooo`H00000903oool2000000P0oooo0P0000060?ooo`<000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08@0oooo1000000W0?ooo`P00000K03oool003d0oooo1P00
000Q0?ooo`800000203oool2000000H0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0Q03oool4000002H0oooo0`0000030?ooo`800000K03oool003l0oooo1`00000N
0?ooo`800000203oool2000000H0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0QP3oool4000002@0oooo0`00001a0?ooo`00@P3oool6000001`0oooo0P0000080?oo
o`8000001P3oool6000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?oo
o`3oool0QP3oool4000002<0oooo0`0000040?ooo`800000J`3oool004D0oooo1P00000I0?ooo``0
00001P3oool7000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08P0oooo1000000Q0?ooo`<000000`3oool3000006/0oooo00170?ooo`H00000
5`3oool<000000H0oooo0`0000000`3oool000000000000200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08T0oooo1000000O0?ooo`X00000
J`3oool004X0oooo1P00000V0?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08/0oooo1000002B0?ooo`00C03oool7
000002<0oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0S03oool400000940oooo001?0?ooo`H000008@3oool30000
0080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2>0?ooo`@00000S`3oool00580oooo1P00000M0?ooo`D0000000<0oooo00000000
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0S`3oool5000008d0oooo001D0?ooo`L00000703oool5000000@0oooo00@000000?ooo`3oool0
oooo100000030?ooo`030000003oool0oooo0940oooo1000002<0?ooo`00E`3oool6000002@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09@0oooo1000002:0?ooo`00
FP3oool600000240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo09D0
oooo100000290?ooo`00G03oool7000001l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2H0?ooo`@00000Q`3oool005l0oooo1P0000300?ooo`@00000QP3oool00680oooo1P00002o
0?ooo`@00000Q03oool006@0oooo1P00002n0?ooo`@00000P`3oool006L0oooo1P00002m0?ooo`@0
0000P@3oool006T0oooo1`00002k0?ooo`@00000P03oool006`0oooo1P00002k0?ooo`@00000OP3o
ool006l0oooo1P00002i0?ooo`D00000O03oool00740oooo1`00002h0?ooo`@00000N`3oool007@0
oooo1P00002h0?ooo`@00000N@3oool007L0oooo1P00002f0?ooo`@00000N03oool007T0oooo1`00
002e0?ooo`@00000MP3oool007`0oooo1P00002d0?ooo`@00000M@3oool007l0oooo1P00002c0?oo
o`@00000L`3oool00840oooo1P00002b0?ooo`@00000LP3oool008@0oooo1P00002a0?ooo`@00000
L03oool008H0oooo1`00002_0?ooo`@00000K`3oool008T0oooo1P00002_0?ooo`@00000K@3oool0
08`0oooo1P00002]0?ooo`@00000K03oool008h0oooo1`00002/0?ooo`@00000JP3oool00940oooo
1P00002[0?ooo`D00000J03oool009@0oooo1P00002Z0?ooo`@00000I`3oool009H0oooo1`00002Y
0?ooo`@00000I@3oool009T0oooo1P00002X0?ooo`@00000I03oool009`0oooo1P00002W0?ooo`@0
0000HP3oool009h0oooo1P00002V0?ooo`@00000H@3oool00:40oooo1P00002U0?ooo`@00000G`3o
ool00:<0oooo1`00002S0?ooo`@00000GP3oool00:H0oooo1P00002S0?ooo`@00000G03oool00:T0
oooo1P00002Q0?ooo`@00000F`3oool00:/0oooo1`00002P0?ooo`@00000F@3oool00:h0oooo1P00
002O0?ooo`@00000F03oool00;40oooo1P00002N0?ooo`@00000EP3oool00;<0oooo1`00002L0?oo
o`D00000E03oool00;H0oooo1P00002L0?ooo`@00000D`3oool00;T0oooo1P00002K0?ooo`@00000
D@3oool00;/0oooo1P00002J0?ooo`@00000D03oool00;h0oooo1P00002I0?ooo`@00000CP3oool0
0<00oooo1`00002G0?ooo`@00000C@3oool00<<0ooooX000001<0?ooo`00aP3ooonM000004`0oooo
003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo
003o0?oook00oooo003o0?oooaD0oooo1`0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo0`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P00001B0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo1P0000020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3oool70000
00030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`03
0000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool0
10000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000030?ooo`8000000`3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P0000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003oool0
0000008000000P3oool01@000000oooo000000000000oooo00<000001@3oool2000000@0oooo00<0
00000?ooo`0000000P0000020?ooo`<00000DP3oool00?l0oooo5@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0540oooo003o0?oooaD0oooo1`00000?0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0D@3oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00aP3oool700000>80oooo00340?ooo`/00000h03oool00<80oooo100000070?ooo`@00000
gP3oool00<40oooo0`00000;0?ooo`<00000g@3oool00<00oooo0`0000040?ooo`0507MgM`0R8R80
MgMg06IVIP2IVIT0103oool300000=`0oooo00300?ooo`8000001@3oool01P0c<c<0k^k^0?ooo`3o
ool0MgMg03<c<`@0oooo0P00003L0?ooo`00_`3oool2000000X0oooo00<0gMgM0000001gMgL0103o
ool200000=/0oooo002o0?ooo`8000002`3oool00`0000004A4A0?ooo`030?ooo`800000f`3oool0
0;h0oooo0P00000;0?ooo`030<c<c0000000000000D0oooo0P00000g0?ooo`<00000X03oool00;h0
oooo0P0000080?ooo`060>k^kP3oool0k^k^04A4A0000000<c<c1@3oool2000003P0oooo00<00000
0?ooo`3oool0W`3oool00;h0oooo0P0000080?ooo`0609VIV@0A4A4000000000000c<c<0c<c<1@3o
ool2000003P0oooo00<000000?ooo`3oool0W`3oool00;h0oooo0P0000090?ooo`030>k^kP1EEED0
IVIV00L0oooo0P00000h0?ooo`030000003oool0oooo09l0oooo002n0?ooo`8000002`3oool00`0A
4A40MgMg0?ooo`050?ooo`800000703oool3000000D0oooo0`0000030?ooo`80000000<0oooo0000
003oool00P3oool500000080oooo100000060?ooo`D00000103oool00`000000oooo0?ooo`040?oo
o`<000001`3oool3000000H0oooo0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`03
000006<0oooo002n0?ooo`8000001`3oool0103^k^h0oooo0?ooo`3oool2014A4@H0oooo0P00000M
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000<0
oooo0000003oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1R0?ooo`00_`3oool2
000000H0oooo00H0VIVI07MgM`2k^k/0EEEE0000000A4A450?ooo`8000007`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0HP3oool00;l0oooo0P0000070?ooo`050:ZZ
ZP0R8R80000003<c<`3<c<`01@3oool2000001l0oooo1`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`<000000`3oool01@000000oooo0?ooo`3oool0000006@0oooo00300?ooo`8000003`3oool20000
0240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`06000000L0
oooo1P0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0680oooo00300?ooo`<000003@3oool300000240oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool0HP3oool00<40oooo0`00000;0?ooo`<0
00008P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000000`3oool000000?ooo`020?oo
o`<00000103oool010000000oooo0000000000040?ooo`@0000000@0oooo0000003oool0oooo0`00
0000103oool000000000000000030?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo0`0000040?ooo`040000003oool00000000006D0oooo00320?ooo`@0
00001`3oool4000002@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00a03oool;000002H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00aP3oool7000002P0oooo00<000000?ooo`0000002@3oool2000002l0oooo00<000000?ooo`3o
ool00`3oool010000000oooo00000000001c0?ooo`00mP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<000000?ooo`3o
ool0L@3oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool007H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0f0?ooo`00N03oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000000j0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001b0?ooo`3o0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000040?oo
o`000000oooo000003X0oooo001`0?ooool000001@0000000`3oool000000000000h0?ooo`00L03o
oooo000000@0000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`
l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`800000E03`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00d0l?3`00<000000?3`
l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00D0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000403`l?000`000000
l?3`0?3`l0030?3`l0L000000P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00@0l?3`0P0000020?3`l0800000
0P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?00
1`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000>0?3`l0@000001@3`l?02000000D0l?3`00@000000?3`l03`l?00l?3`0P0000030?3`l0<00000
0P3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
0`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000=0?3`l0060000003`l?00l?3`0000003`l?000000103`l?02000000030?3`l000000000000080
l?3`00<000000?3`l03`l?000`3`l?001P000000l?3`0?3`l0000000l?3`00000080l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?000`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool0
0700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`
l?0500000080l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000040?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000
003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`l03`l?00
l?3`0P0000000`3`l?000000000000020?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`
l?000000103`l?000`000000l?3`0?3`l0050?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo
03T0oooo001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`
l03`l?00l?3`0P0000020?3`l080000000<0l?3`0000003`l?00103`l?0010000000l?3`0?3`l000
00040?3`l0030000003`l?00l?3`00<0l?3`0P0000040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000`3`l?04000003L0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?000`000000l?3`0?3`
l007000000030?3`l0000000l?3`0080l?3`00<000000?3`l00000000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`8000003@3`l?03000000030?3`l0000000000000/0l?3`00<00000
0?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?05000003H0l?3`>@3ooolg
0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000N0?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?000`3`l?0400000080l?3`00@000000?3`l03`l?00l?3`10000004
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l003
0?3`l0D00000=P3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
01l0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`
0?3`l00000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?00103`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool0
0700oooo0P00000O0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?001@00
0000l?3`0?3`l03`l?00000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00@0l?3`1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo001`0?ooo`800000803`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`
00T0l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?001@3`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo0000
000000003`3oool6000002<0oooo001`0?ooo`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`80
000000<0oooo0000003oool03@3oool<00000200oooo001`0?ooo`800000E03`l?07000003@0l?3`
>@3ooolg0<o?c`<0000000<0oooo0000000000002`3oool4000000H0oooo1000000O0?ooo`00L03o
ool2000005@0l?3`1`00000d0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo00/0oooo0`00
000:0?ooo`<000007P3oool00700oooo0P00001D0?3`l0L000001`3`l?000`000000l?3`0?3`l005
0?3`l0L00000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0100l?3`>@3ooolO
0<o?c`030000003?cll0clo?00<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000
000000T0oooo0`0000070?ooo`0303<c<`000000oooo0080oooo0`00000M0?ooo`00L03oool20000
05@0l?3`1`0000070?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l08000000`3`l?000`00
0000l?3`0?3`l0060?3`l0030000003`l?00l?3`00/0l?3`0`0000000`3`l?00oooo0?ooo`0D0?oo
o`D00000103oool2000001D0oooo0`00000N0<o?c`030000003?cll0clo?00D0clo?00<000000<o?
c`3?cll03P3?cll2000000030?ooo`000000oooo00T0oooo0`0000080?ooo`0303<c<`000000oooo
00<0oooo0`00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000003`l?00l?3`00H0
l?3`0P0000070?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?002`3`l?04000001D0
oooo0`0000030?ooo`8000000P3oool3000001@0oooo1000000L0<o?c`030000003?cll0clo?00L0
clo?00<000000<o?c`3?cll03@3?cll3000000030?ooo`000000000000P0oooo0P0000090?ooo`03
03<c<`000000oooo00@0oooo0P00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0@00000
0P3`l?02000000040?3`l000000000000?3`l08000000`3`l?000`000000l?3`0?3`l0020?3`l0<0
00000`3`l?000`000000l?3`0?3`l00:0?3`l0H000004P3oool3000000D0oooo100000000`3oool0
00000?ooo`0C0?ooo`D000004@3?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?
c`3?cll0clo?0`0000030<o?c`030000003?cll0clo?00d0clo?0P0000000`3oool000000?ooo`09
0?ooo`800000103oool507MgM`04014A4@000000MgMg0=gMg@<0oooo0P00000L0?ooo`00L03oool2
000005@0l?3`200000060?3`l0040000003`l?00l?3`0?3`l08000000`3`l?05000000<0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`1`00
000A0?ooo`8000001P3oool3000001L0oooo1`00000>0<o?c`030000003?cll0clo?008000000`3?
cll00`000000clo?000000040<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?
cll3000000030?ooo`000000000000L0oooo0P0000050?ooo`P0000000<0^k^k0?ooo`3oool00P3o
ool2000001/0oooo001`0?ooo`800000E03`l?09000000D0l?3`00@000000?3`l03`l?00l?3`0P00
00030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002P3`l?09000000h0oooo0`0000070?ooo`8000005`3o
ool8000000d0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`80000000<0oooo0000003oool0
203oool2000000D0oooo00<0c<c<05EEE@3oool00P3oool00`0c<c<000000?ooo`050?ooo`800000
6`3oool00700oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0040000003`
l?00l?3`0?3`l08000000P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`2P00000=0?ooo`<000001`3oool2000001L0oooo
2@00000<0<o?c`050000003?cll0clo?0<o?c`0000000`3?cll00`000000clo?000000040<o?c`03
0000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?cll3000000030?ooo`000000000000L0
oooo0P0000060?ooo`0609VIV@28R8P0oooo0?ooo`0c<c<000001P3oool2000001/0oooo001`0?oo
o`800000E03`l?09000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0070000
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?000000
01D00000303oool3000000L0oooo0`00000:0?oooaH000002`3?cll01@000000clo?0<o?c`3?cll0
000000<0clo?00<000000<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0
clo?00`0clo?0P0000000`3oool000000?ooo`080?ooo`8000001`3oool01@1EEED0^k^k0?ooo`0c
<c<0000000H0oooo0P00000K0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00<0l?3`00<000000?3`l00000005@00000<0?ooo`<000001`3oool3000000X0oooo5P00000;
0<o?c`8000000P3?cll00`000000clo?0<o?c`02000000030<o?c`000000clo?00<0clo?00<00000
0<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo0000000000001`3oool2
000000P0oooo00@0<c<c0<c<c00c<c<000001P3oool2000001/0oooo001`0?ooo`800000E03`l?09
000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003`3oool2
000000H0oooo00@000000?ooo`00000000005P3oool8000000h0clo?0P0000030<o?c`8000000`3?
cll01@000000clo?0<o?c`3?cll0000000D0clo?00<000000<o?c`3?cll03@3?cll2000000030?oo
o`000000oooo00P0oooo0P0000080?ooo`040>k^kP0c<c<08R8R000000H0oooo0P00000K0?ooo`00
L03oool2000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?000`000000
l?3`0?3`l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool70000
01T0clo?00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3o
ool00000000000080?ooo`800000203oool00`3<c<`00000000000050?ooo`800000703oool00700
oooo0P00001D0?3`l0P00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`
l03`l?002`3`l?05000001@0oooo0`0000030?ooo`030000003oool0oooo00<000005@3oool50000
01`0clo?00@000000<o?c`3?cll00000103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo
0000003oool02@3oool2000000T0oooo00<0VIVI0000003oool0103oool2000001`0oooo001`0?oo
o`800000E03`l?08000001P0l?3`00D000000?3`l03`l?00l?3`000000040?3`l0030000003`l?00
l?3`00/0l?3`1000000G0?ooo`@000000`3oool3000001D0oooo0`00000O0<o?c`030000003?cll0
000000<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000000000P0oooo0`00000>
0?ooo`<00000703oool00700oooo0P00001D0?3`l0L000006P3`l?000`000000l?3`0?3`l0040?3`
l0030000003`l?00l?3`00`0l?3`0P0000020?3`l3H0oooo0P0000000`3oool0clo?0<o?c`0e0<o?
c`80000000<0oooo0000003oool02P3oool3000000`0oooo0`00000M0?ooo`00L03oool2000005@0
l?3`1`00000d0?3`l3T0oooo=`3?cll3000000030?ooo`000000000000X0oooo0`00000:0?ooo`<0
00007P3oool00700oooo0P00001D0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0<0?ooo`@000001P3oool4000001l0oooo001`0?ooo`800000E03`l?07000003@0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000303oool<00000200oooo001`0?ooo`800000E03`l?06
000003D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0403oool6000002<0oooo001`0?oo
o`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000`0?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000
003`l?00l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<0
00000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3o
ool00700oooo0P00000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?00
0`000000l?3`0?3`l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?
c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0
l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000
:P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i
0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000X0?3`l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00000_0?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0
l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000
l?3`0?3`l0050?3`l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
000/0?ooo`<00000@@3oool2000000T0l?3`0`0000230?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo000[0?ooo`050000003oool0oooo0?ooo`000000@03oool2000000L0l?3`1@00
00230?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000`0?ooo`030000003oool0
oooo03d0oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`008@3oool6000000030?ooo`000000oooo00<0oooo0P000000103oool000000?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000000`3oool00000000000030?ooo`@000009`3oool2
00000080l?3`2@0000240?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000P0?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo0000
003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0903oool=000008@0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00200oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool2
000000L0oooo00<000000?ooo`3oool0903oool<000008D0l?3`>@3ooolg0<o?c`80000000<0oooo
0000003oool0>@3oool002L0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`8000009P3oool<
000008H0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool002D0oooo0P0000001@3o
ool000000?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`H000000`3oool2000002P0oooo300000260?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo000Q0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool0:@3oool:
000008L0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool00200oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool0000000000003
0?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0T0?ooool000001000000l0?ooo`00803oool00`000000oooo0?ooo`04
0?ooo`800000103oool2000000050?ooo`000000oooo0000003oool00`0000050?ooo`@0000000<0
oooo0000003oool00P3oool4000002L0ooooo`000004000003`0oooo000P0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`P00000o`3ooolh
0?ooo`008@3oool6000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool0:`3oool30000
0080oooo1000003o0?ooocP0oooo001^0?ooo`<00000103oool2000002h0oooo0P3o003o0?ooo`T0
oooo001]0?ooo`<00000=@3oool20?l00?l0oooo2@3oool006`0oooo0`00000f0?ooo`80o`00o`3o
ool90?ooo`00J`3oool3000003H0oooo103o003o0?ooo`P0oooo000;0?ooo`L0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo008000000`3oool3000000040?ooo`0000000000000000`0oooo
0`00000g0?ooo`@0o`00o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3o
ool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000003oool02P3oool3000003P0oooo103o003o0?oo
o`P0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0
oooo1000000i0?ooo`D0o`00o`3oool70?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000080?ooo`@00000>P3oool50?l00?l0oooo1`3oool000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo1@00
00000`3oool000000?ooo`060?ooo`<00000>`3oool60?l00?l0oooo1`3oool000/0oooo1`000000
0`3oool000000?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000203oool00`000000oooo00000006
0?ooo`<00000?03oool60?l00?l0oooo1`3oool000/0oooo00<000000?ooo`3oool01@3oool20000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`8000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000030?ooo`040000003oool0000000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo0P0000030?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000005
0?ooo`<00000?@3oool70?l00?l0oooo1P3oool000/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003o
ool000000000003oool00`0000050?ooo`800000103oool00`000000oooo0000000200000080oooo
0`0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`<00000?P3oool70?l00?l0oooo
1P3oool000/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo0?ooo`<00000?`3oool70?l00?l0oooo1P3oool000/0oooo1`00000?0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03000003l0oooo2@3o
003o0?ooo`D0oooo001O0?ooo`<00000@03oool90?l00?l0oooo1@3oool005h0oooo0`0000110?oo
o`T0o`00o`3oool50?ooo`00GP3oool200000480oooo1`3o003o0?ooo`L0oooo001M0?ooo`<00000
AP3oool20?l00?l0oooo203oool005d0oooo0P0000170?ooo`80o`00o`3oool80?ooo`00G03oool3
000004L0oooo0P3o003o0?ooo`P0oooo001K0?ooo`<00000B03oool20?l00?l0oooo203oool005/0
oooo0P0000190?ooo`80o`00o`3oool80?ooo`00FP3oool3000004T0oooo0P3o003o0?ooo`P0oooo
001J0?ooo`800000o`3ooomD0?ooo`00F@3oool300000?l0ooooE03oool005T0oooo0P00003o0?oo
oeD0oooo001H0?ooo`<00000o`3ooomE0?ooo`00E`3oool300000?l0ooooEP3oool005L0oooo0P00
003o0?oooeL0oooo001F0?ooo`<00000o`3ooomG0?ooo`00EP3oool200000500oooo0P3o003o0?oo
o`H0oooo001E0?ooo`<00000D03oool20?l00?l0oooo1P3oool005D0oooo0P00001A0?ooo`80o`00
o`3oool60?ooo`00E03oool300000540oooo0P3o003o0?ooo`H0oooo001D0?ooo`800000DP3oool2
0?l00?l0oooo1P3oool005<0oooo0`00001B0?ooo`80o`00o`3oool60?ooo`00DP3oool3000005<0
oooo0P3o003o0?ooo`H0oooo001B0?ooo`800000E03oool20?l00?l0oooo1P3oool00540oooo0`00
001D0?ooo`80o`00o`3oool60?ooo`00D@3oool2000005D0oooo0P3o003o0?ooo`H0oooo001@0?oo
o`<00000E@3oool20?l00?l0oooo1P3oool00500oooo0P00001F0?ooo`80o`00o`3oool60?ooo`00
C`3oool3000005H0oooo0P3o003o0?ooo`H0oooo001?0?ooo`800000E`3oool20?l00?l0oooo1P3o
ool004l0oooo0P00003o0?oooel0oooo001>0?ooo`<00000o`3ooomO0?ooo`00CP3oool200000?l0
ooooH03oool004d0oooo0`00003o0?ooof00oooo001=0?ooo`800000o`3ooomQ0?ooo`00C03oool3
00000?l0ooooH@3oool004`0oooo0P00003o0?ooof80oooo001;0?ooo`<00000F`3oool20?l00?l0
oooo1@3oool004/0oooo0P00001L0?ooo`80o`00o`3oool50?ooo`00B`3oool2000005`0oooo0P3o
003o0?ooo`D0oooo001:0?ooo`<00000G03oool20?l00?l0oooo1@3oool004X0oooo0P00001M0?oo
o`<0o`00o`3oool40?ooo`00B@3oool3000005h0oooo0P3o003o0?ooo`@0oooo00190?ooo`800000
G`3oool20?l00?l0oooo103oool004P0oooo0`00001O0?ooo`80o`00o`3oool40?ooo`00B03oool2
00000600oooo0P3o003o0?ooo`@0oooo00180?ooo`800000H03oool20?l00?l0oooo103oool004L0
oooo0`00001P0?ooo`<0o`00o`3oool30?ooo`00A`3oool200000680oooo0P3o003o0?ooo`<0oooo
00160?ooo`<00000HP3oool20?l00?l0oooo0`3oool004H0oooo0P00001S0?ooo`80o`00o`3oool3
0?ooo`00AP3oool200000?l0ooooJ03oool004H0oooo0P00003o0?ooofP0oooo000Y0?ooo`H00000
5P3oool300000?l0ooooJ03oool002H0oooo3000000C0?ooo`800000o`3ooomY0?ooo`009@3oool4
000000H0oooo1000000B0?ooo`800000o`3ooomY0?ooo`00903oool300000080oooo1`0000001014
A4@0000000000000000A0?ooo`800000o`3ooomY0?ooo`008`3oool3000000<0oooo00<0VIVI0000
00000000100c<c<00`14A4@0oooo0000000200000100oooo0P00003o0?ooofT0oooo000R0?ooo`<0
00001@3oool00`3<c<`000000;^k^`030?ooo`0308R8R03oool0oooo00<000003`3oool200000?l0
ooooJ@3oool00280oooo0P0000070?ooo`030<c<c00A4A40c<c<00H0oooo0P00000?0?ooo`800000
o`3ooomY0?ooo`008P3oool2000000P0oooo00<0^k^k0000003^k^h01@3oool2000000h0oooo0`00
001U0?ooo`80o`00o`3oool20?ooo`008@3oool2000000X0oooo00<0IVIV03<c<`3oool01@3oool2
000000d0oooo0P00001V0?ooo`80o`00o`3oool20?ooo`008@3oool2000000X0oooo00<0gMgM0000
002k^k/01@3oool2000000d0oooo0P00001V0?ooo`80o`00o`3oool20?ooo`008@3oool2000000/0
oooo00<08R8R04A4A03oool0103oool2000000d0oooo0P00001V0?ooo`80o`00MP3oool<000007l0
oooo000Q0?ooo`8000002`3oool2014A4@D0oooo0P00000=0?ooo`800000IP3oool20?l006<0oooo
8000001n0?ooo`008@3oool2000000H0oooo00L0ZZZZ0<c<c03oool0oooo0;^k^`0000004A4A00D0
oooo0P00000=0?ooo`800000IP3oool20?l00540oooo9P00000:0?3`l0@00000O03oool00240oooo
0P0000070?ooo`0303<c<`1VIVH0IVIV0080000000<0EEEE0?ooo`3oool00`3oool2000000d0oooo
0P00001V0?ooo`80o`00?P3ooolV000001h0l?3`1000001k0?ooo`008P3oool2000000H0oooo00H0
k^k^07MgM`000000000005EEE@3^k^h40?ooo`8000003@3oool3000006H0oooo0P3o000[0?ooobL0
0000<P3`l?04000007T0oooo000R0?ooo`800000403oool2000000d0oooo0P00001W0?ooo`80o`00
6@3ooolV000004H0l?3`1000001h0?ooo`008P3oool3000000h0oooo0`00000=0?ooo`800000I`3o
ool20?l000H0oooo9P00001K0?3`l0@00000MP3oool002<0oooo0`00000<0?ooo`<000003P3oool2
000005d0oooo2P0000020?l001X00000KP3`l?04000007D0oooo000T0?ooo`<000002P3oool30000
00l0oooo0P00001:0?oooad000000P3o0007000008<0l?3`1000001c0?ooo`009@3oool4000000H0
oooo1000000@0?ooo`800000=`3ooolW000009H0l?3`1000001b0?ooo`009P3oool<00000140oooo
0P00000U0?ooobH00000Z`3`l?0300000740oooo000Y0?ooo`H000004`3oool300000180oooo9P00
002o0?3`l0@00000K`3oool00480oooo0P00000:0?oooad00000dP3`l?04000002`0oooo0P000000
0`3oool0000000000002000003/0oooo00120?ooo`8000002P3oool:00000>L0l?3`1000000Z0?oo
o`@000000P3oool2000003X0oooo00120?ooo`800000303oool700000>T0l?3`1000000Y0?ooo`<0
00000`3oool3000003T0oooo00120?ooo`8000003`3oool600000>T0l?3`1000000W0?ooo`800000
103oool3000003T0oooo00120?ooo`8000004P3oool600000>L0l?3`1000000[0?ooo`@00000>@3o
ool00480oooo0P00000D0?ooo`H00000<`3`l?0@000000P0l?3`0P0000030?3`l080o`00U@3`l?04
000002L0oooo1@00000j0?ooo`00@P3oool2000001L0oooo1P00000Q0?3`l08000000`3`l?020000
0080l?3`0P0000040?3`l1<00000103`l?03000000<0l?3`0P3o002F0?3`l0@00000903oool60000
03/0oooo00120?ooo`8000006@3oool7000001h0l?3`0P0000030?3`l08000000P3`l?02000001<0
l?3`300000020?3`l080o`00V03`l?0400000240oooo1@00000m0?ooo`00@P3oool2000001`0oooo
1P00000m0?3`l0T000000P3`l?020?l009T0l?3`1000000P0?ooo`<00000103oool2000003T0oooo
00110?ooo`<000007`3oool6000003d0l?3`1P0000020?3`l080o`00V`3`l?04000001h0oooo0`00
00030?ooo`<00000>@3oool00440oooo0P00000R0?ooo`H00000>P3`l?08000000030?3`l03o0000
o`0009`0l?3`1000000N0?ooo`8000000P3oool4000003T0oooo00110?ooo`8000009@3oool60000
03L0l?3`200000000`3`l?00o`000?l0002N0?3`l0@000007@3oool4000000030?ooo`0000000000
03T0oooo00110?ooo`8000009`3oool7000003@0l?3`2000002R0?3`l0@00000G03oool00440oooo
0P00000Z0?ooo`H00000=@3`l?0600000:<0l?3`1000001J0?ooo`00@@3oool2000002d0oooo1P00
000e0?3`l0<00000Y03`l?04000005T0oooo00110?ooo`800000;`3oool6000002H0l?3`00<0h>3P
0?3`l03`l?00/`3`l?04000005L0oooo00110?ooo`800000<P3oool600000280l?3`00<0d=3@020P
803`l?001`3`l?000`1`L700d=3@0?3`l0050?3`l0D00000X@3`l?04000005H0oooo00110?ooo`80
0000=03oool7000001l0l?3`00<0D51@092@T03`l?001`3`l?000`2`/;00D51@0?3`l0040?3`l0L0
0000XP3`l?04000005@0oooo00110?ooo`800000=`3oool6000001`0l?3`00<0d=3@0000003Ph>00
2@3`l?000`0@4100d=3@0?3`l0030?3`l0L00000X`3`l?04000005<0oooo00110?ooo`800000>P3o
ool600000180l?3`00D0<30`051@D01PH600<30`0<30`0020?3`l0030820P00`<300l?3`0080l?3`
00@0L71`0000000`<300`<300`3`l?000`1PH600L71`0?3`l0030?3`l0L00000Y@3`l?0300000580
oooo00110?ooo`800000?03oool600000100l?3`00D0D51@0?3`l03`l?00L71`020P80020?3`l003
030`<01`L700l?3`0080l?3`00@00000010@402`/;00X:2P0`3`l?000`2PX:00820P0?3`l0030?3`
l0L00000YP3`l?0400000500oooo00110?ooo`800000?`3oool6000000d0l?3`00<0d=3@0?3`l02@
T9000P0000020?3`l003010@402PX:00l?3`0080l?3`00<00000030`<03`l?00103`l?000`3@d=00
00000?3`l0040?3`l0D00000Z03`l?04000004l0oooo00110?ooo`800000@@3oool7000000X0l?3`
00D0/;2`010@40000000410@0<30`0020?3`l0030000002`/;00l?3`0080l?3`00<00000030`<03`
l?001@3`l?000`000000/;2`0?3`l02b0?3`l0@00000C@3oool00440oooo0P0000140?ooo`H00000
203`l?02000000030;2`/03`l?00l?3`0080l?3`00<000000;2`/03`l?000P3`l?000`000000<30`
0?3`l0050?3`l0030000002`/;00l?3`0;<0l?3`1000001<0?ooo`00@03oool3000004L0oooo1P00
00050?3`l005010@401`L700l?3`0?3`l01@D5000P3`l?000`0@4100X:2P0?3`l0020?3`l0030000
000`<300l?3`00D0l?3`00<000000<30`03`l?00]@3`l?04000004X0oooo00100?ooo`800000BP3o
ool6000000<0l?3`00D0`<300410@01`L700D51@0410@0020?3`l0050410@01`L700l?3`0?3`l00`
<3000`0000001P0`<300l?3`0?3`l03`l?00/;2`00000;P0l?3`100000190?ooo`00@03oool20000
04d0oooo1P0000070?3`l003092@T00`<300l?3`0080l?3`00<0D51@030`<03`l?00103`l?000`20
P800820P0?3`l02i0?3`l0@00000A`3oool00400oooo0P00001?0?ooo`L000001@3`l?000`000000
h>3P0?3`l0020?3`l003092@T03`l?00l?3`00<0l?3`00<0<30`0820P03`l?00^P3`l?04000004H0
oooo00100?ooo`800000DP3oool6000000<0l?3`00<0L71`092@T03`l?001`3`l?000`3Ph>000000
0>3Ph02m0?3`l0@00000A03oool00400oooo0P00001E0?ooo`H0000000<0h>3P0410@03`l?001`3`
l?000`20P800L71`0?3`l02n0?3`l0@00000@`3oool00400oooo0P00001G0?ooo`H00000203`l?00
0`2`/;00l?3`0?3`l0300?3`l0@00000@@3oool00400oooo0P00001J0?ooo`H00000b@3`l?040000
0400oooo00100?ooo`800000G03oool700000<P0l?3`1000000n0?ooo`00@03oool2000005l0oooo
1P0000370?3`l0@00000?@3oool00400oooo0P00001R0?ooo`H00000aP3`l?04000003/0oooo0010
0?ooo`<00000H03oool2000000030?ooo`000000000000@00000a@3`l?04000003X0oooo00110?oo
o`800000H03oool2000000@0oooo1P0000340?3`l0@00000>03oool00440oooo0P00001P0?ooo`80
00001P3oool700000<80l?3`1000000g0?ooo`00@@3oool200000600oooo0P0000090?ooo`H00000
`P3`l?04000003D0oooo00110?ooo`800000G`3oool3000000`0oooo1P0000300?3`l0@00000=03o
ool00440oooo0P00001O0?ooo`8000003`3oool600000<00l?3`0`00000c0?ooo`00@@3oool30000
05h0oooo0P00000B0?ooo`H00000_P3`l?0400000340oooo00120?ooo`800000GP3oool2000001@0
oooo1`00002l0?3`l0@00000<03oool00480oooo0P00001g0?ooo`H00000_03`l?04000002h0oooo
00120?ooo`800000NP3oool600000;X0l?3`1000000]0?ooo`00@P3oool2000003l0oooo1P00000g
0?ooo`H00000^P3`l?04000002/0oooo000N0?ooo`P00000703oool2000003`0oooo3000000g0?oo
o`H00000^03`l?04000002X0oooo000O0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`<00000>P3oool4000000H0oooo1000000h0?ooo`L0
0000]`3`l?04000002P0oooo000O0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo0P00000i0?ooo`<00000103oool01P1gMgL0A4A4000000000000EEEE09VI
V@<00000>P3oool600000;H0l?3`1000000W0?ooo`007`3oool2000000P0oooo0P0000090?ooo`80
00003@3oool2000003P0oooo0`0000070?ooo`8000000`3oool3000003`0oooo1P00002e0?3`l0@0
00009@3oool001l0oooo0P0000000`3oool00000000000050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02`3oool2000003L0oooo0`0000080?ooo`800000103oool3000000`0oooo
0P00000_0?ooo`H00000]03`l?04000002@0oooo000G0?ooo`D000000`3oool5000000@0oooo0P00
00050?ooo`800000103oool2000000`0oooo0P00000g0?ooo`8000002@3oool2000000D0oooo0P00
000<0?ooo`800000<P3oool600000;<0l?3`1000000R0?ooo`00603oool3000000@0oooo0P000000
0`3oool00000000000040?ooo`800000103oool3000000@0oooo0P00000<0?ooo`800000=`3oool2
000000T0oooo0P0000050?ooo`8000002`3oool3000003@0oooo1`00002a0?3`l0@000008@3oool0
01P0oooo0`0000040?ooo`8000001`3oool2000000@0oooo0P0000050?ooo`800000303oool30000
03D0oooo0P00000:0?ooo`8000001P3oool2000000X0oooo0P00000h0?ooo`H00000/@3`l?040000
01l0oooo000H0?ooo`<00000103oool2000000<0oooo0P0000020?ooo`800000103oool2000000D0
oooo0P00000=0?ooo`800000=@3oool2000000X0oooo0P0000060?ooo`8000002@3oool3000003/0
oooo1P00002_0?3`l0@000007P3oool001P0oooo0`0000030?ooo`P000000P3oool2000000@0oooo
0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3oool2000000T0oooo
0P00000n0?ooo`H00000[`3`l?04000001`0oooo000H0?ooo`<000003@3oool2000000@0oooo0P00
00050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3oool2000000P0oooo0`00
00110?ooo`H00000[@3`l?04000001/0oooo000H0?ooo`<000003@3oool2000000@0oooo0P000005
0?ooo`8000003@3oool2000003D0oooo0P0000070?ooo`030<c<c01EEED0^k^k008000001P3oool2
000000L0oooo0`0000140?ooo`L00000[03`l?04000001T0oooo000H0?ooo`<000003@3oool20000
00@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P0000080?ooo`040>k^kP1VIVH00000
000000H0oooo0P0000070?ooo`800000B03oool600000:/0l?3`1000000H0?ooo`00603oool30000
00d0oooo0P0000030?ooo`@00000103oool2000000d0oooo0`00000e0?ooo`8000002@3oool00`2k
^k/04A4A0?ooo`040?ooo`8000001`3oool3000004/0oooo1P00002Z0?3`l0@000005P3oool001P0
oooo0`00000>0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`0=0?oo
o`800000=@3oool200000100oooo0P0000070?ooo`800000CP3oool600000:T0l?3`1000000E0?oo
o`00603oool3000000h0oooo0P0000030?ooo`800000103oool2000000l0oooo0P00000e0?ooo`<0
00003P3oool3000000H0oooo0`00001A0?ooo`H00000Z03`l?03000001@0oooo000G0?ooo`D00000
3P3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool03P3oool2000003H0
oooo0`00000<0?ooo`<000001`3oool2000005@0oooo1`00002V0?3`l0@000004P3oool002/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`<00000=P3oool3000000X0oooo
0`00001Q0?ooo`H00000Y@3`l?0400000140oooo00160?ooo`800000=`3oool4000000H0oooo1000
001U0?ooo`H00000Y03`l?04000000l0oooo00160?ooo`800000>03oool<000006P0oooo1P00002S
0?3`l0@000003P3oool004H0oooo0`00000j0?ooo`H00000KP3oool600000:80l?3`1000000<0?oo
o`00A`3oool200000;00oooo1`00002P0?3`l0@000002`3oool004L0oooo0P00002c0?ooo`H00000
X03`l?04000000T0oooo00170?ooo`<00000]@3oool6000009h0l?3`100000080?ooo`00B03oool2
000004L0oooo0P00001^0?ooojL000001`3oool004P0oooo0P0000170?ooo`800000L@3ooonT0000
00L0oooo00180?ooo`<00000A@3oool300000?l0oooo7@3oool004T0oooo0P0000140?ooo`<00000
o`3ooolN0?ooo`00B@3oool2000004@0oooo0P00003o0?oooal0oooo00190?ooo`<00000@P3oool3
00000?l0oooo7`3oool004X0oooo0P0000120?ooo`800000o`3ooolP0?ooo`00BP3oool300000400
oooo0`00003H0?ooo`H000000P3oool2000000030?ooo`000000oooo00@0oooo0`0000000`3oool0
00000?ooo`020?ooo`800000103oool200000080oooo0`000000103oool000000?ooo`0000060?oo
o`<000000`3oool4000000d0oooo001;0?ooo`800000?`3oool300000=P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3o
ool2000000030?ooo`000000oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00<000000?ooo`3oool02P3oool004/0oooo0P00000o0?ooo`800000f@3oool00`000000oooo
0?ooo`040?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`00B`3oool3000003d0oooo0`0000090?ooo`8000000`3oool300000<l0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool01`3oool2000000d0oooo001<0?ooo`800000?@3oool2000000`0oooo
00H000000?ooo`3oool000000?ooo`00003=0?ooo`8000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0000000@0oooo1P0000020?ooo`8000003`3oool004`0oooo0P00001;
0?ooo`040000003oool0oooo00000</0oooo100000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000004@3oool004`0oooo0`00001:0?ooo`040000003oool0oooo00000<X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0000000000040?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00C@3oool2000004X0oooo00@0
00000?ooo`3oool00000bP3oool00`000000oooo0?ooo`040?ooo`@0000000@0oooo0000003oool0
00000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000000P3oool30000
00030?ooo`000000oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`800000103oool4
000000d0oooo001=0?ooo`800000B03oool00`000000oooo000000020?ooo`030000003oool0oooo
0<P0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000F0?ooo`030000003oool0oooo
02D0oooo001=0?ooo`<00000B03oool700000<T0oooo1P0000020?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool09@3oool004h0oooo0P00003o0?ooof00oooo001>0?ooo`800000o`3o
oomP0?ooo`00CP3oool3000003@0oooo0P00003o0?ooobT0oooo001?0?ooo`800000=03oool20000
0?l0oooo:@3oool004l0oooo0`00000b0?ooo`<00000o`3ooolY0?ooo`00D03oool200000380oooo
0P00003o0?ooobX0oooo001@0?ooo`<00000<03oool300000?l0oooo:P3oool00540oooo0`00000_
0?ooo`800000o`3oool[0?ooo`00DP3oool2000002h0oooo0`00003o0?ooob/0oooo001B0?ooo`<0
0000;03oool300000?l0oooo;03oool005<0oooo0P00000/0?ooo`800000o`3oool]0?ooo`00D`3o
ool3000002X0oooo0`00003o0?ooobd0oooo001D0?ooo`800000:P3oool200000?l0oooo;P3oool0
05@0oooo0`00000X0?ooo`<00000o`3oool^0?ooo`00E@3oool2000002P0oooo0P00003o0?ooobl0
oooo001E0?ooo`<00000o`3ooomH0?ooo`00EP3oool300000?l0ooooE`3oool005L0oooo0P00003o
0?oooeL0oooo001G0?ooo`<00000o`3ooomF0?ooo`00F03oool200000?l0ooooEP3oool005P0oooo
0`00003o0?oooeD0oooo001I0?ooo`800000o`3ooomE0?ooo`00F@3oool3000001l0oooo0P00003o
0?oooc<0oooo001J0?ooo`8000007`3oool200000?l0oooo<`3oool005X0oooo0`00000M0?ooo`<0
0000o`3ooolc0?ooo`00F`3oool3000001/0oooo0`00003o0?oooc@0oooo001L0?ooo`8000005@3o
ool8000006H0oooo3P0000300?ooo`00G03oool3000001@0oooo2000001A0?ooob@00000_`3oool0
05d0oooo0P00000D0?ooo`T00000>`3oool[000000`0oooo1000002m0?ooo`00G@3oool300000180
oooo2`00000U0?ooob/000008P3oool400000;`0oooo001N0?ooo`8000004P3oool;00000100oooo
:`00000i0?ooo`@00000^P3oool00780oooo<@00001?0?ooo`D00000^03oool00680oooo;000001V
0?ooo`@00000]`3oool004d0oooo;000001m0?ooo`@00000]@3oool003P0oooo:`00000>0?ooo`L0
0000O`3oool400000;@0oooo000S0?ooob/000008`3oool600000880oooo1000002b0?ooo`00603o
oolQ000003P0oooo1@0000240?ooo`@00000/@3oool001P0oooo3000001=0?ooo`@00000Q`3oool4
00000:l0oooo000J0?ooo`L00000C`3oool4000008T0oooo1@00002]0?ooo`007@3oool6000004d0
oooo0`00002<0?ooo`@00000[03oool00200oooo1P00001:0?ooo`800000S`3oool400000:X0oooo
000R0?ooo`L00000f@3oool400000:T0oooo000U0?ooo`H00000f@3oool400000:L0oooo000X0?oo
o`H00000e`3oool400000:H0oooo000Z0?ooo`L00000eP3oool4000002l0oooo2P00001[0?ooo`00
;@3oool600000=D0oooo1000000_0?ooo`<000000`3oool3000006/0oooo000`0?ooo`H00000;P3o
ool<000009X0oooo1000000]0?ooo`<00000103oool2000006/0oooo000b0?ooo`L00000:`3oool<
000009/0oooo1@00000[0?ooo`<00000L@3oool003D0oooo1P00000Y0?ooo`800000203oool20000
09d0oooo1000000Z0?ooo`<00000L@3oool003P0oooo1P00000V0?ooo`800000203oool2000000D0
oooo1@00002E0?ooo`@00000:03oool3000000<0oooo0P00001/0?ooo`00>P3oool7000002<0oooo
0P0000080?ooo`8000001P3oool3000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`240?ooo`@000009`3oool8000006`0oooo000m0?ooo`H000008@3oool2000000P0oooo0P00
00060?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08D0oooo1000
000U0?ooo`<000000`3oool2000006`0oooo00100?ooo`H000007P3oool2000000P0oooo0P000006
0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08H0oooo1000000T
0?ooo`<00000L@3oool00480oooo1`00000K0?ooo`800000203oool2000000H0oooo1P0000040?oo
o`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo08L0oooo1000000R0?oo
o`<00000103oool2000006/0oooo00150?ooo`L00000603oool<000000H0oooo1`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`280?ooo`@0
00008@3oool3000000<0oooo0`00001[0?ooo`00B03oool6000001H0oooo300000060?ooo`<00000
00<0oooo0000000000000P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2:0?ooo`@000007P3oool:000006/0oooo001;0?ooo`H000009@3o
ool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2;0?ooo`D00000T@3oool004d0oooo1`00000R0?ooo`<000000P3oool3
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo08d0oooo1000002@0?ooo`00D03oool600000200oooo0`0000020?ooo`<000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S`3oool40000
08h0oooo001C0?ooo`H00000703oool5000000030?ooo`000000000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0900oooo1000002=0?ooo`00
E@3oool7000001/0oooo1@0000040?ooo`040000003oool0oooo0?ooo`@000000`3oool00`000000
oooo0?ooo`2B0?ooo`@00000R`3oool005P0oooo1P00000S0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`2D0?ooo`@00000RP3oool005/0oooo1P00000P0?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2F0?ooo`@00000R03oool005d0oooo
1`00000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool5000008H0oooo
001P0?ooo`H00000`03oool4000008D0oooo001S0?ooo`H00000_`3oool4000008<0oooo001U0?oo
o`L00000_@3oool400000880oooo001X0?ooo`H00000_@3oool400000800oooo001[0?ooo`H00000
^`3oool4000007l0oooo001]0?ooo`L00000^P3oool4000007d0oooo001`0?ooo`H00000^@3oool4
000007`0oooo001c0?ooo`H00000^03oool4000007X0oooo001e0?ooo`L00000]P3oool5000007P0
oooo001h0?ooo`H00000]P3oool4000007L0oooo001k0?ooo`H00000]@3oool4000007D0oooo001m
0?ooo`L00000/`3oool4000007@0oooo00200?ooo`H00000/`3oool400000780oooo00230?ooo`H0
0000/@3oool400000740oooo00250?ooo`L00000/03oool4000006l0oooo00280?ooo`H00000[`3o
ool4000006h0oooo002;0?ooo`H00000[P3oool4000006`0oooo002=0?ooo`L00000[03oool50000
06X0oooo002@0?ooo`H00000[03oool4000006T0oooo002C0?ooo`H00000Z`3oool4000006L0oooo
002E0?ooo`L00000Z@3oool4000006H0oooo002H0?ooo`L00000Z03oool4000006@0oooo002K0?oo
o`H00000Y`3oool4000006<0oooo002N0?ooo`H00000YP3oool400000640oooo002P0?ooo`L00000
Y03oool5000005l0oooo002S0?ooo`H00000Y03oool4000005h0oooo002V0?ooo`H00000X`3oool4
000005`0oooo002X0?ooo`L00000X@3oool4000005/0oooo002[0?ooo`H00000X@3oool4000005T0
oooo002^0?ooo`H00000W`3oool4000005P0oooo002`0?ooo`L00000WP3oool4000005H0oooo002c
0?ooo`H00000W@3oool4000005D0oooo002f0?ooo`H00000W03oool4000005<0oooo002h0?ooo`L0
0000VP3oool500000540oooo002k0?ooo`H00000VP3oool400000500oooo002n0?ooo`H00000V@3o
ool4000004h0oooo00300?ooo`L00000U`3oool4000004d0oooo00330?oooj000000C03oool00<H0
ooooW@00001<0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?oo
o`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooolE0?ooo`L0000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00800000DP3oool00?l0oooo5@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000005<0oooo003o
0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000005<0oooo003o0?oooaD0oooo1`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool000000080oooo0P0000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool2000000<0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00@000000?ooo`3o
ool00000D`3oool00?l0oooo5@3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080
00000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo00000003
0?ooo`<000000`3oool00`000000oooo0000000200000080oooo00D000000?ooo`00000000000?oo
o`03000000D0oooo0P0000040?ooo`030000003oool00000008000000P3oool300000580oooo003o
0?oooaD0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1A0?ooo`00o`3ooolE0?oo
o`L000003`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0540oooo003o0?oook00
oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00
oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00
oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001YB000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00aP3oool700000>80oooo00340?ooo`/00000h03oool00<80oooo100000070?ooo`@00000
gP3oool00<40oooo0`00000;0?ooo`<00000g@3oool00<00oooo0`0000040?ooo`0507MgM`0R8R80
MgMg06IVIP2IVIT0103oool300000=`0oooo00300?ooo`8000001@3oool01P0c<c<0k^k^0?ooo`3o
ool0MgMg03<c<`@0oooo0P00003L0?ooo`00_`3oool2000000X0oooo00<0gMgM0000001gMgL0103o
ool200000=/0oooo002o0?ooo`8000002`3oool00`0000004A4A0?ooo`030?ooo`800000f`3oool0
0;h0oooo0P00000;0?ooo`030<c<c0000000000000D0oooo0P00000g0?ooo`<00000X03oool00;h0
oooo0P0000080?ooo`060>k^kP3oool0k^k^04A4A0000000<c<c1@3oool2000003P0oooo00<00000
0?ooo`3oool0W`3oool00;h0oooo0P0000080?ooo`0609VIV@0A4A4000000000000c<c<0c<c<1@3o
ool2000003P0oooo00<000000?ooo`3oool0W`3oool00;h0oooo0P0000090?ooo`030>k^kP1EEED0
IVIV00L0oooo0P00000h0?ooo`030000003oool0oooo09l0oooo002n0?ooo`8000002`3oool00`0A
4A40MgMg0?ooo`050?ooo`800000703oool3000000D0oooo0`0000030?ooo`80000000<0oooo0000
003oool00P3oool500000080oooo100000060?ooo`D00000103oool00`000000oooo0?ooo`040?oo
o`<000001`3oool3000000H0oooo0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`03
000006<0oooo002n0?ooo`8000001`3oool0103^k^h0oooo0?ooo`3oool2014A4@H0oooo0P00000M
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000<0
oooo0000003oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1R0?ooo`00_`3oool2
000000H0oooo00H0VIVI07MgM`2k^k/0EEEE0000000A4A450?ooo`8000007`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0HP3oool00;l0oooo0P0000070?ooo`050:ZZ
ZP0R8R80000003<c<`3<c<`01@3oool2000001l0oooo1`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`<000000`3oool01@000000oooo0?ooo`3oool0000006@0oooo00300?ooo`8000003`3oool20000
0240oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`06000000L0
oooo1P0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0680oooo00300?ooo`<000003@3oool300000240oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool0HP3oool00<40oooo0`00000;0?ooo`<0
00008P3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000000`3oool000000?ooo`020?oo
o`<00000103oool010000000oooo0000000000040?ooo`@0000000@0oooo0000003oool0oooo0`00
0000103oool000000000000000030?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo0`0000040?ooo`040000003oool00000000006D0oooo00320?ooo`@0
00001`3oool4000002@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00a03oool;000002H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001c0?oo
o`00aP3oool7000002P0oooo00<000000?ooo`0000002@3oool2000002l0oooo00<000000?ooo`3o
ool00`3oool010000000oooo00000000001c0?ooo`00mP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<000000?ooo`3o
ool0L@3oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool007H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0f0?ooo`00N03oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000000j0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03H0oooo001b0?ooo`3o0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000040?oo
o`000000oooo000003X0oooo001`0?ooool000001@0000000`3oool000000000000h0?ooo`00L03o
oooo000000@0000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`l3T0oooo=`3?cll3
000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0clo?0P0000000`3o
ool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000S`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2
000008l0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00002?0?3`
l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000S`3`l?0i0?ooocL0
clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000008l0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`800000E03`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00d0l?3`00<000000?3`
l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00D0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000403`l?000`000000
l?3`0?3`l0030?3`l0L000000P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?00103`l?02000003T0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00000@0?3`l0030000003`l?00l?3`00@0l?3`0P0000020?3`l0800000
0P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?00
1`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00
000>0?3`l0@000001@3`l?02000000D0l?3`00@000000?3`l03`l?00l?3`0P0000030?3`l0<00000
0P3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
0`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00
000=0?3`l0060000003`l?00l?3`0000003`l?000000103`l?02000000030?3`l000000000000080
l?3`00<000000?3`l03`l?000`3`l?001P000000l?3`0?3`l0000000l?3`00000080l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?000`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool0
0700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?0010000000l?3`0?3`l03`
l?0500000080l?3`00<000000?3`l03`l?000`3`l?0010000000l?3`0?3`l00000040?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`l0030000
003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000
003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo
001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`l03`l?00
l?3`0P0000000`3`l?000000000000020?3`l0030000003`l?00l?3`00<0l?3`00@000000?3`l03`
l?000000103`l?000`000000l?3`0?3`l0050?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`
l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo
03T0oooo001`0?ooo`800000303`l?001@000000l?3`0?3`l03`l?0000000080l?3`00@000000?3`
l03`l?00l?3`0P0000020?3`l080000000<0l?3`0000003`l?00103`l?0010000000l?3`0?3`l000
00040?3`l0030000003`l?00l?3`00<0l?3`0P0000040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000`3`l?04000003L0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03o
ool00700oooo0P00000<0?3`l0050000003`l?00l?3`0?3`l00000000P3`l?000`000000l?3`0?3`
l007000000030?3`l0000000l?3`0080l?3`00<000000?3`l00000000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0020?3`l0030000003`l?00l?3`00<0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`00
0000oooo03T0oooo001`0?ooo`8000003@3`l?03000000030?3`l0000000000000/0l?3`00<00000
0?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`l?05000003H0l?3`>@3ooolg
0<o?c`<0000000<0oooo000000000000>03oool00700oooo0P00000N0?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?000`3`l?0400000080l?3`00@000000?3`l03`l?00l?3`10000004
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l003
0?3`l0D00000=P3`l?0i0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool20000
01l0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0050000003`l?00l?3`
0?3`l00000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<00000
0?3`l03`l?00103`l?05000003H0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool0
0700oooo0P00000O0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?001@00
0000l?3`0?3`l03`l?00000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00@0l?3`1P00000e0?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo001`0?ooo`800000803`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`
00T0l?3`00<000000?3`l03`l?001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?001@3`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo0000
000000003`3oool6000002<0oooo001`0?ooo`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`80
000000<0oooo0000003oool03@3oool<00000200oooo001`0?ooo`800000E03`l?07000003@0l?3`
>@3ooolg0<o?c`<0000000<0oooo0000000000002`3oool4000000H0oooo1000000O0?ooo`00L03o
ool2000005@0l?3`1`00000d0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo00/0oooo0`00
000:0?ooo`<000007P3oool00700oooo0P00001D0?3`l0L000001`3`l?000`000000l?3`0?3`l005
0?3`l0L00000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0100l?3`>@3ooolO
0<o?c`030000003?cll0clo?00<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000
000000T0oooo0`0000070?ooo`0303<c<`000000oooo0080oooo0`00000M0?ooo`00L03oool20000
05@0l?3`1`0000070?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l08000000`3`l?000`00
0000l?3`0?3`l0060?3`l0030000003`l?00l?3`00/0l?3`0`0000000`3`l?00oooo0?ooo`0D0?oo
o`D00000103oool2000001D0oooo0`00000N0<o?c`030000003?cll0clo?00D0clo?00<000000<o?
c`3?cll03P3?cll2000000030?ooo`000000oooo00T0oooo0`0000080?ooo`0303<c<`000000oooo
00<0oooo0`00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0030000003`l?00l?3`00H0
l?3`0P0000070?3`l0030000003`l?00l?3`00H0l?3`00<000000?3`l03`l?002`3`l?04000001D0
oooo0`0000030?ooo`8000000P3oool3000001@0oooo1000000L0<o?c`030000003?cll0clo?00L0
clo?00<000000<o?c`3?cll03@3?cll3000000030?ooo`000000000000P0oooo0P0000090?ooo`03
03<c<`000000oooo00@0oooo0P00000L0?ooo`00L03oool2000005@0l?3`200000060?3`l0@00000
0P3`l?02000000040?3`l000000000000?3`l08000000`3`l?000`000000l?3`0?3`l0020?3`l0<0
00000`3`l?000`000000l?3`0?3`l00:0?3`l0H000004P3oool3000000D0oooo100000000`3oool0
00000?ooo`0C0?ooo`D000004@3?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?
c`3?cll0clo?0`0000030<o?c`030000003?cll0clo?00d0clo?0P0000000`3oool000000?ooo`09
0?ooo`800000103oool507MgM`04014A4@000000MgMg0=gMg@<0oooo0P00000L0?ooo`00L03oool2
000005@0l?3`200000060?3`l0040000003`l?00l?3`0?3`l08000000`3`l?05000000<0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`1`00
000A0?ooo`8000001P3oool3000001L0oooo1`00000>0<o?c`030000003?cll0clo?008000000`3?
cll00`000000clo?000000040<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?
cll3000000030?ooo`000000000000L0oooo0P0000050?ooo`P0000000<0^k^k0?ooo`3oool00P3o
ool2000001/0oooo001`0?ooo`800000E03`l?09000000D0l?3`00@000000?3`l03`l?00l?3`0P00
00030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002P3`l?09000000h0oooo0`0000070?ooo`8000005`3o
ool8000000d0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`80000000<0oooo0000003oool0
203oool2000000D0oooo00<0c<c<05EEE@3oool00P3oool00`0c<c<000000?ooo`050?ooo`800000
6`3oool00700oooo0P00001D0?3`l0T000001@3`l?000`000000l?3`0?3`l0020?3`l0040000003`
l?00l?3`0?3`l08000000P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0030?3`l0030000003`l?00l?3`00X0l?3`2P00000=0?ooo`<000001`3oool2000001L0oooo
2@00000<0<o?c`050000003?cll0clo?0<o?c`0000000`3?cll00`000000clo?000000040<o?c`03
0000003?cll0clo?00@0clo?00<000000<o?c`3?cll0303?cll3000000030?ooo`000000000000L0
oooo0P0000060?ooo`0609VIV@28R8P0oooo0?ooo`0c<c<000001P3oool2000001/0oooo001`0?oo
o`800000E03`l?09000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0070000
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?000000
01D00000303oool3000000L0oooo0`00000:0?oooaH000002`3?cll01@000000clo?0<o?c`3?cll0
000000<0clo?00<000000<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0
clo?00`0clo?0P0000000`3oool000000?ooo`080?ooo`8000001`3oool01@1EEED0^k^k0?ooo`0c
<c<0000000H0oooo0P00000K0?ooo`00L03oool2000005@0l?3`2@0000050?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00
l?3`00<0l?3`00<000000?3`l00000005@00000<0?ooo`<000001`3oool3000000X0oooo5P00000;
0<o?c`8000000P3?cll00`000000clo?0<o?c`02000000030<o?c`000000clo?00<0clo?00<00000
0<o?c`3?cll0103?cll00`000000clo?0<o?c`0<0<o?c`<0000000<0oooo0000000000001`3oool2
000000P0oooo00@0<c<c0<c<c00c<c<000001P3oool2000001/0oooo001`0?ooo`800000E03`l?09
000000D0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?000`3`l?000`000000l?3`0?3`l00:0?3`l0T000003`3oool2
000000H0oooo00@000000?ooo`00000000005P3oool8000000h0clo?0P0000030<o?c`8000000`3?
cll01@000000clo?0<o?c`3?cll0000000D0clo?00<000000<o?c`3?cll03@3?cll2000000030?oo
o`000000oooo00P0oooo0P0000080?ooo`040>k^kP0c<c<08R8R000000H0oooo0P00000K0?ooo`00
L03oool2000005@0l?3`2000000G0?3`l0040000003`l?00l?3`0?3`l0@000000`3`l?000`000000
l?3`0?3`l00:0?3`l0L000004@3oool3000000D0oooo00@000000?ooo`00000000005P3oool70000
01T0clo?00<000000<o?c`3?cll0100000030<o?c`030000003?cll0clo?00d0clo?0`0000000`3o
ool00000000000080?ooo`800000203oool00`3<c<`00000000000050?ooo`800000703oool00700
oooo0P00001D0?3`l0P00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`
l03`l?002`3`l?05000001@0oooo0`0000030?ooo`030000003oool0oooo00<000005@3oool50000
01`0clo?00@000000<o?c`3?cll00000103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo
0000003oool02@3oool2000000T0oooo00<0VIVI0000003oool0103oool2000001`0oooo001`0?oo
o`800000E03`l?08000001P0l?3`00D000000?3`l03`l?00l?3`000000040?3`l0030000003`l?00
l?3`00/0l?3`1000000G0?ooo`@000000`3oool3000001D0oooo0`00000O0<o?c`030000003?cll0
000000<0clo?00<000000<o?c`3?cll03`3?cll3000000030?ooo`000000000000P0oooo0`00000>
0?ooo`<00000703oool00700oooo0P00001D0?3`l0L000006P3`l?000`000000l?3`0?3`l0040?3`
l0030000003`l?00l?3`00`0l?3`0P0000020?3`l3H0oooo0P0000000`3oool0clo?0<o?c`0e0<o?
c`80000000<0oooo0000003oool02P3oool3000000`0oooo0`00000M0?ooo`00L03oool2000005@0
l?3`1`00000d0?3`l3T0oooo=`3?cll3000000030?ooo`000000000000X0oooo0`00000:0?ooo`<0
00007P3oool00700oooo0P00001D0?3`l0L00000=03`l?0i0?ooocL0clo?0P0000000`3oool00000
0?ooo`0<0?ooo`@000001P3oool4000001l0oooo001`0?ooo`800000E03`l?07000003@0l?3`>@3o
oolg0<o?c`<0000000<0oooo000000000000303oool<00000200oooo001`0?ooo`800000E03`l?06
000003D0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0403oool6000002<0oooo001`0?oo
o`800000E03`l?06000003D0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000`0?3`l0030000003`l?00l?3`00D0l?3`00<000000?3`l03`l?006@3`l?06000003D0
l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000_0?3`l0030000
003`l?00l?3`00L0l?3`00<000000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`<00000
00<0oooo000000000000>03oool00700oooo0P00000_0?3`l0030000003`l?00l?3`00L0l?3`00<0
00000?3`l03`l?00603`l?05000003H0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3o
ool00700oooo0P00000X0?3`l0@000000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?00
0`000000l?3`0?3`l00G0?3`l0D00000=P3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`00L03oool2000002L0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`000000040?3`
l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`l?005`3`l?04000003L0l?3`>@3ooolg0<o?
c`80000000<0oooo0000003oool0>@3oool00700oooo0P00000W0?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`01L0
l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`000000000003P0oooo001`0?ooo`800000
:P3`l?0200000080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
001`0?ooo`800000:03`l?02000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`
l0040?3`l0030000003`l?00l?3`01L0l?3`1000000g0?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo001`0?ooo`8000009`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`0080l?3`00<000000?3`l03`l?00103`l?000`000000l?3`0?3`l00G0?3`l0<00000>03`l?0i
0?ooocL0clo?0P0000000`3oool000000?ooo`0i0?ooo`00L03oool2000002L0l?3`00<000000?3`
l03`l?000P3`l?000`000000l?3`000000040?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`<0000000<0oooo000000000000>03oool00700
oooo0P00000X0?3`l0@000000P3`l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`
l03`l?005`3`l?03000003P0l?3`>@3ooolg0<o?c`80000000<0oooo0000003oool0>@3oool00700
oooo0P00000_0?3`l0050000003`l?00l?3`0?3`l00000001@3`l?000`000000l?3`0?3`l00H0?3`
l0800000>@3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h0?ooo`00L03oool2000002l0
l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`01P0l?3`0P00000i0?3`
l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo001`0?ooo`800000<03`l?000`000000
l?3`0?3`l0050?3`l0030000003`l?00l?3`05@0l?3`>@3ooolg0<o?c`<0000000<0oooo00000000
0000>03oool00700oooo0P00002?0?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo
000/0?ooo`<00000@@3oool2000000T0l?3`0`0000230?3`l3T0oooo=`3?cll3000000030?ooo`00
0000000003P0oooo000[0?ooo`050000003oool0oooo0?ooo`000000@03oool2000000L0l?3`1@00
00230?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000`0?ooo`030000003oool0
oooo03d0oooo0P0000050?3`l0L00000P`3`l?0i0?ooocL0clo?0`0000000`3oool000000000000h
0?ooo`008@3oool6000000030?ooo`000000oooo00<0oooo0P000000103oool000000?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000000`3oool00000000000030?ooo`@000009`3oool2
00000080l?3`2@0000240?3`l3T0oooo=`3?cll2000000030?ooo`000000oooo03T0oooo000P0?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo0000
003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0903oool=000008@0l?3`>@3ooolg0<o?c`<0000000<0oooo
000000000000>03oool00200oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool2
000000L0oooo00<000000?ooo`3oool0903oool<000008D0l?3`>@3ooolg0<o?c`80000000<0oooo
0000003oool0>@3oool002L0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`8000009P3oool<
000008H0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool002D0oooo0P0000001@3o
ool000000?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`H000000`3oool2000002P0oooo300000260?3`l3T0oooo=`3?cll2000000030?ooo`000000
oooo03T0oooo000Q0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool0:@3oool:
000008L0l?3`>@3ooolg0<o?c`<0000000<0oooo0000003oool0>03oool00200oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool0000000000003
0?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0T0?ooool000001000000l0?ooo`00803oool00`000000oooo0?ooo`04
0?ooo`800000103oool2000000050?ooo`000000oooo0000003oool00`0000050?ooo`@0000000<0
oooo0000003oool00P3oool4000002L0ooooo`000004000003`0oooo000P0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`P00000o`3ooolh
0?ooo`008@3oool6000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool0:`3oool30000
0080oooo1000003o0?ooocP0oooo001^0?ooo`<00000103oool2000002h0oooo0P00o`3o0?ooo`T0
oooo001]0?ooo`<00000=@3oool2003o0?l0oooo2@3oool006`0oooo0`00000f0?ooo`800?l0o`3o
ool90?ooo`00J`3oool3000003H0oooo1000o`3o0?ooo`P0oooo000;0?ooo`L0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo008000000`3oool3000000040?ooo`0000000000000000`0oooo
0`00000g0?ooo`@00?l0o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3o
ool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000003oool02P3oool3000003P0oooo1000o`3o0?oo
o`P0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0
oooo1000000i0?ooo`D00?l0o`3oool70?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000080?ooo`@00000>P3oool5003o0?l0oooo1`3oool000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo1@00
00000`3oool000000?ooo`060?ooo`<00000>`3oool6003o0:L0oooo0`3o001L0?ooo`002`3oool7
000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000080?ooo`030000003oool0
000000H0oooo0`00000l0?ooo`H00?l0YP3oool40?l005`0oooo000;0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`8000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool3000003d0oooo1`00o`2T0?ooo`<0o`00GP3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P00
00020?ooo`050000003oool000000000003oool00`0000050?ooo`800000103oool00`000000oooo
0000000200000080oooo0`0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`<00000
?P3oool7003o0:<0oooo0`3o001O0?ooo`002`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00000o0?ooo`L00?l0XP3oool30?l00600oooo
000;0?ooo`L000003`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`00000o0?ooo`T00?l0X@3oool20?l00640oooo001O0?ooo`<00000@03oool9
003o0?l0oooo1@3oool005h0oooo0`0000110?ooo`T00?l0o`3oool50?ooo`00GP3oool200000480
oooo1`00o`3o0?ooo`L0oooo001M0?ooo`<00000AP3oool2003o0?l0oooo203oool005d0oooo0P00
00170?ooo`800?l0o`3oool80?ooo`00G03oool3000004L0oooo0P00o`3o0?ooo`P0oooo001K0?oo
o`<00000B03oool2003o09h0oooo0P3o001W0?ooo`00F`3oool2000004T0oooo0P00o`2M0?ooo`<0
o`00I`3oool005X0oooo0`0000190?ooo`800?l0W03oool30?l006P0oooo001J0?ooo`800000i`3o
ool30?l006T0oooo001I0?ooo`<00000iP3oool30?l006X0oooo001I0?ooo`800000iP3oool30?l0
06/0oooo001H0?ooo`<00000i@3oool30?l006`0oooo001G0?ooo`<00000i@3oool30?l006d0oooo
001G0?ooo`800000iP3oool20?l006h0oooo001F0?ooo`<00000o`3ooomG0?ooo`00EP3oool20000
0500oooo0P00o`3o0?ooo`H0oooo001E0?ooo`<00000D03oool2003o0?l0oooo1P3oool005D0oooo
0P00001A0?ooo`800?l0o`3oool60?ooo`00E03oool300000540oooo0P00o`3o0?ooo`H0oooo001D
0?ooo`800000DP3oool2003o06/0oooo1`00002C0?ooo`00D`3oool300000580oooo0P00o`1Y0?oo
o`/000006`3oool20?l007@0oooo001B0?ooo`<00000D`3oool2003o06L0oooo100000070?ooo`@0
00006@3oool20?l007@0oooo001B0?ooo`800000E03oool2003o06H0oooo0`00000;0?ooo`<00000
5`3oool30?l007@0oooo001A0?ooo`<00000E03oool2003o06D0oooo0`0000030?ooo`060=gMg@0R
8R80EEEE08R8R01gMgL0gMgM103oool3000001D0oooo0`3o001e0?ooo`00D@3oool2000005D0oooo
0P00o`1U0?ooo`800000103oool01`3<c<`0VIVI0?ooo`3oool0k^k^028R8P3<c<`0103oool20000
01@0oooo0`3o001f0?ooo`00D03oool3000005D0oooo0P00o`1T0?ooo`8000002P3oool00`1gMgL0
A4A40?ooo`040?ooo`8000004P3oool30?l007L0oooo001@0?ooo`800000EP3oool2003o06@0oooo
0P00000:0?ooo`0305EEE@000000oooo00@0oooo0P00000A0?ooo`<0o`00N03oool004l0oooo0`00
001F0?ooo`800?l0H`3oool2000000X0oooo00<0c<c<0000000R8R801P3oool2000000l0oooo0`3o
001i0?ooo`00C`3oool2000005L0oooo0P00o`1S0?ooo`800000203oool01@3^k^h0MgMg00000000
0000VIVI00H0oooo0P00000>0?ooo`<0o`00NP3oool004l0oooo0P00002l0?ooo`8000001`3oool0
1@2ZZZX00000000000000000MgMg00L0oooo0P00000=0?ooo`<0o`00N`3oool004h0oooo0`00002l
0?ooo`8000001`3oool0103^k^h0000008R8R03MgMd80?ooo`8000003@3oool20?l007`0oooo001>
0?ooo`800000_@3oool2000000P0oooo00<0IVIV0?ooo`3oool0203oool2000008/0oooo001=0?oo
o`<00000_@3oool2000000P0oooo00<0VIVI03<c<`0c<c<00P0c<c<00`3^k^h0oooo0?ooo`030?oo
o`800000R`3oool004d0oooo0P00002o0?ooo`8000001`3oool00`3^k^h000000000000200000003
09VIV@3oool0oooo0080oooo0P00002<0?ooo`00C03oool300000;l0oooo0P00000A0?ooo`800000
S03oool004`0oooo0P0000310?ooo`8000003`3oool2000008d0oooo001;0?ooo`<00000F`3oool2
003o06@0oooo0`00000=0?ooo`<000002@3oool20?l00880oooo001;0?ooo`800000G03oool2003o
06D0oooo0`00000;0?ooo`<000002P3oool20?l00880oooo001;0?ooo`800000G03oool2003o06H0
oooo100000070?ooo`@000002P3oool30?l00880oooo001:0?ooo`<00000G03oool2003o06P0oooo
2`00000;0?ooo`<0o`00P`3oool004X0oooo0P00001M0?ooo`<00?l0J@3oool7000000`0oooo0`3o
00240?ooo`00B@3oool3000005h0oooo0P00o`1k0?ooo`<0o`00Q@3oool004T0oooo0P00001O0?oo
o`800?l0N`3oool20?l008H0oooo00180?ooo`<00000G`3oool2003o07X0oooo0`3o00260?ooo`00
B03oool200000600oooo0P00o`1i0?ooo`<0o`00Q`3oool004P0oooo0P00001P0?ooo`800?l0N03o
ool30?l008P0oooo00170?ooo`<00000H03oool3003o07L0oooo0P3o00290?ooo`00A`3oool20000
0680oooo0P00o`3o0?ooo`<0oooo00160?ooo`<00000HP3oool2003o0?l0oooo0`3oool004H0oooo
0P00001S0?ooo`800?l0o`3oool30?ooo`00AP3oool200000?l0ooooJ03oool004H0oooo0P00003o
0?ooofP0oooo000Y0?ooo`H000005P3oool300000?l0ooooJ03oool002H0oooo3000000C0?ooo`80
0000e`3oool20?l008l0oooo000U0?ooo`@000001P3oool400000180oooo0P00003G0?ooo`80o`00
S`3oool002@0oooo0`0000020?ooo`L0000000@0A4A400000000000000004@3oool200000=H0oooo
0`3o002?0?ooo`008`3oool3000000<0oooo00<0VIVI000000000000100c<c<00`14A4@0oooo0000
000200000100oooo0P00003E0?ooo`<0o`00T03oool00280oooo0`0000050?ooo`030<c<c0000000
^k^k00<0oooo00<0R8R80?ooo`3oool00`00000?0?ooo`800000e03oool30?l00940oooo000R0?oo
o`8000001`3oool00`3<c<`04A4A0<c<c0060?ooo`8000003`3oool200000=<0oooo0`3o002B0?oo
o`008P3oool2000000P0oooo00<0^k^k0000003^k^h01@3oool2000000h0oooo0`00001U0?ooo`80
0?l0J`3oool30?l009<0oooo000Q0?ooo`8000002P3oool00`1VIVH0<c<c0?ooo`050?ooo`800000
3@3oool2000006H0oooo0P00o`1Z0?ooo`<0o`00U03oool00240oooo0P00000:0?ooo`030=gMg@00
0000^k^k00D0oooo0P00000=0?ooo`800000IP3oool2003o06T0oooo0`3o002E0?ooo`008@3oool2
000000/0oooo00<08R8R04A4A03oool0103oool2000000d0oooo0P00001V0?ooo`800?l0J03oool3
0?l000/0oooo3000001o0?ooo`008@3oool2000000/0oooo0P0A4A450?ooo`8000003@3oool20000
06H0oooo0P00o`1S0?ooo`D000000P3o000I000007h0oooo000Q0?ooo`8000001P3oool01`2ZZZX0
c<c<0?ooo`3oool0^k^k0000000A4A401@3oool2000000d0oooo0P00001V0?ooo`800?l0D@3ooolV
000000X0l?3`1000001l0?ooo`008@3oool2000000L0oooo00<0<c<c06IVIP1VIVH00P0000000`1E
EED0oooo0?ooo`030?ooo`8000003@3oool2000006H0oooo0P00o`0n0?ooobH000007P3`l?040000
07/0oooo000R0?ooo`8000001P3oool01P3^k^h0MgMg000000000000EEEE0>k^kP@0oooo0P00000=
0?ooo`<00000IP3oool2003o02/0oooo9`00000b0?3`l0@00000N@3oool00280oooo0P00000@0?oo
o`8000003@3oool2000006L0oooo0P00o`0I0?ooobH00000AP3`l?04000007P0oooo000R0?ooo`<0
00003P3oool3000000d0oooo0P00001W0?ooo`800?l01P3ooolV000005/0l?3`1000001f0?ooo`00
8`3oool3000000`0oooo0`00000>0?ooo`800000G@3oool:000000800?l06P0000170?3`l080o`00
9@3`l?04000007D0oooo000T0?ooo`<000002P3oool3000000l0oooo0P00001:0?oooad000000P00
o`07000005T0l?3`0`3o000W0?3`l0@00000L`3oool002D0oooo100000060?ooo`@00000403oool2
000003L0oooo9`00001Z0?3`l0<0o`00:@3`l?0400000780oooo000V0?ooo``000004@3oool20000
02D0oooo9P00001l0?3`l0<0o`00;03`l?0300000740oooo000Y0?ooo`H000004`3oool300000180
oooo9P00002>0?3`l0<0o`00;P3`l?04000006l0oooo00120?ooo`8000002P3ooolM000009l0l?3`
0`3o000`0?3`l0@00000;03oool2000000030?ooo`000000000000800000>`3oool00480oooo0P00
000:0?ooo`X00000/@3`l?030?l003<0l?3`1000000Z0?ooo`@000000P3oool2000003X0oooo0012
0?ooo`800000303oool700000;40l?3`0`3o000e0?3`l0@00000:@3oool3000000<0oooo0`00000i
0?ooo`00@P3oool2000000l0oooo1P00002^0?3`l0<0o`00>03`l?04000002L0oooo0P0000040?oo
o`<00000>@3oool00480oooo0P00000B0?ooo`H00000Z`3`l?020?l003X0l?3`1000000[0?ooo`@0
0000>@3oool00480oooo0P00000D0?ooo`H00000<`3`l?0@000000P0l?3`0P0000030?3`l0800?l0
U@3`l?04000002L0oooo1@00000j0?ooo`00@P3oool2000001L0oooo1P00000Q0?3`l08000000`3`
l?0200000080l?3`0P0000040?3`l1<00000103`l?03000000<0l?3`0P00o`2F0?3`l0@00000903o
ool6000003/0oooo00120?ooo`8000006@3oool7000001h0l?3`0P0000030?3`l08000000P3`l?02
000001<0l?3`300000020?3`l0800?l0V03`l?0400000240oooo1@00000m0?ooo`00@P3oool20000
01`0oooo1P00000m0?3`l0T000000P3`l?02003o09T0l?3`1000000P0?ooo`<00000103oool20000
03T0oooo00110?ooo`<000007`3oool6000003d0l?3`1P0000020?3`l0800?l0V`3`l?04000001h0
oooo0`0000030?ooo`<00000>@3oool00440oooo0P00000R0?ooo`H00000>P3`l?08000000030?3`
l000o`000?l00540l?3`0P3o00190?3`l0@000007P3oool200000080oooo1000000i0?ooo`00@@3o
ool2000002D0oooo1P00000g0?3`l0P0000000<0l?3`003o0000o`00D@3`l?020?l004/0l?3`1000
000M0?ooo`@0000000<0oooo000000000000>@3oool00440oooo0P00000W0?ooo`L00000=03`l?08
000005<0l?3`0`3o001<0?3`l0@00000G03oool00440oooo0P00000Z0?ooo`H00000=@3`l?060000
02L0l?3`00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00J0?3`l080o`000`3`l?030?l0
04l0l?3`1000001J0?ooo`00@@3oool2000002d0oooo1P00000e0?3`l0<000009P3`l?000`2`/;00
H61P0?3`l0060?3`l0030=3@d01@D500l?3`01X0l?3`0`3o0000103`l?00o`000?l0003o001A0?3`
l0@00000F@3oool00440oooo0P00000_0?ooo`H000009P3`l?000`3Ph>00l?3`0?3`l00c0?3`l003
010@4030`<00l?3`00L0l?3`00<0820P0=3@d03`l?00603`l?070?l005@0l?3`1000001G0?ooo`00
@@3oool200000380oooo1P00000R0?3`l0030=3@d00P8200l?3`00L0l?3`00<0L71`0=3@d03`l?00
1@3`l?05000001H0l?3`0`000000103`l?0000000000000000020?3`l0030;2`/00@4100l?3`0080
l?3`00@0L71`0000000`<300h>3P0P3`l?000`1`L700H61P0?3`l00H0?3`l0P0o`00E03`l?040000
05H0oooo00110?ooo`800000=03oool7000001l0l?3`00<0D51@092@T03`l?001`3`l?000`2`/;00
D51@0?3`l0040?3`l0L00000503`l?000`000000l?3`0?3`l002000000<0l?3`00@000000?3`l01P
H600H61P0`3`l?0010000000410@0;2`/02`/;020?3`l0030;2`/00P8200l?3`01L0l?3`2P3o001E
0?3`l0@00000E03oool00440oooo0P00000g0?ooo`H00000703`l?000`3@d=0000000>3Ph0090?3`
l003010@403@d=00l?3`00<0l?3`1`00000D0?3`l0050000003`l?00l?3`0?3`l00000000`3`l?00
10000000l?3`020P802@T9030?3`l0030000000`<300l?3`00<0l?3`00<0h>3P0000003`l?005`3`
l?0:0?l005H0l?3`1000001C0?ooo`00@@3oool2000003X0oooo1P00000B0?3`l005030`<01@D500
H61P030`<030`<000P3`l?000`20P800<30`0?3`l0020?3`l004071`L0000000<30`0<30`0<0l?3`
00<0H61P071`L03`l?000`3`l?07000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l004
0000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000`<300?3`l00E0?3`
l0T0o`00FP3`l?0300000580oooo00110?ooo`800000?03oool600000100l?3`00D0D51@0?3`l03`
l?00L71`020P80020?3`l003030`<01`L700l?3`0080l?3`00@00000010@402`/;00X:2P0`3`l?00
0`2PX:00820P0?3`l0030?3`l0L000000`3`l?03000000h0l?3`00D000000?3`l03`l?00l?3`0000
00030?3`l0040000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000d=3@
0?3`l00E0?3`l0P0o`00G03`l?0400000500oooo00110?ooo`800000?`3oool6000000d0l?3`00<0
d=3@0?3`l02@T9000P0000020?3`l003010@402PX:00l?3`0080l?3`00<00000030`<03`l?00103`
l?000`3@d=0000000?3`l0040?3`l0D00000103`l?05000000`0l?3`0P0000020?3`l0030000003`
l?00l?3`0080000000<0l?3`0000002`/;000`3`l?000`000000<30`0?3`l0030?3`l0030;2`/000
0000l?3`01H0l?3`1`3o001N0?3`l0@00000C`3oool00440oooo0P0000110?ooo`L000002P3`l?00
1@2`/;00410@0000000@4100`<300080l?3`00<000000;2`/03`l?000P3`l?000`000000<30`0?3`
l0050?3`l0030000002`/;00l?3`00h0l?3`1@00000;0?3`l08000000`3`l?0200000080l?3`00D0
<30`092@T03`l?00l?3`061PH00200000006030`<02@T900l?3`0?3`l02@T900<30`5P3`l?060?l0
0680l?3`1000001=0?ooo`00@@3oool2000004@0oooo1P0000080?3`l080000000<0/;2`0?3`l03`
l?000P3`l?000`000000/;2`0?3`l0020?3`l0030000000`<300l?3`00D0l?3`00<000000;2`/03`
l?00403`l?0500000180l?3`00<0L71`061PH03`l?000P3`l?000`1@D500<30`0?3`l0030?3`l003
051@D020P800l?3`01D0l?3`1@3o001T0?3`l0@00000C03oool00400oooo0`0000170?ooo`H00000
1@3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0410@0:2PX03`l?000P3`l?000`000000
<30`0?3`l0050?3`l00300000030`<00l?3`0180l?3`1@00000@0?3`l0030=3@d00@4100l?3`00<0
l?3`00<0T92@0?3`l03`l?000P3`l?000`000000h>3P0?3`l00D0?3`l0D0o`00I`3`l?04000004X0
oooo00100?ooo`800000BP3oool6000000<0l?3`00D0`<300410@01`L700D51@0410@0020?3`l005
0410@01`L700l?3`0?3`l00`<3000`0000001P0`<300l?3`0?3`l03`l?00/;2`000001H0l?3`1@00
000?0?3`l0030410@03@d=00l?3`00H0l?3`00<0X:2P061PH03`l?005@3`l?030?l006X0l?3`1000
00190?ooo`00@03oool2000004d0oooo1P0000070?3`l003092@T00`<300l?3`0080l?3`00<0D51@
030`<03`l?00103`l?000`20P800820P0?3`l00G0?3`l0D000003@3`l?000`3@d=00H61P0?3`l006
0?3`l0030<30`03Ph>00l?3`01@0l?3`0`3o001]0?3`l0@00000A`3oool00400oooo0P00001?0?oo
o`L000001@3`l?000`000000h>3P0?3`l0020?3`l003092@T03`l?00l?3`00<0l?3`00<0<30`0820
P03`l?006@3`l?05000000`0l?3`00<0h>3P0?3`l03`l?00703`l?020?l006l0l?3`100000160?oo
o`00@03oool200000580oooo1P0000030?3`l003071`L02@T900l?3`00L0l?3`00<0h>3P0000003P
h>00703`l?05000009`0l?3`100000140?ooo`00@03oool2000005D0oooo1P0000000`3Ph>00@410
0?3`l0070?3`l0030820P01`L700l?3`01h0l?3`1P00002J0?3`l0@00000@`3oool00400oooo0P00
001G0?ooo`H00000203`l?000`2`/;00l?3`0?3`l00P0?3`l0L00000V@3`l?0400000440oooo0010
0?ooo`800000FP3oool6000002/0l?3`2000000G0?3`l0D00000NP3`l?0400000400oooo00100?oo
o`800000G03oool7000002/0l?3`200000080?3`l0<00000203`l?07000007/0l?3`1000000n0?oo
o`00@03oool2000005l0oooo1P00000]0?3`l0P00000103`l?05000000H0l?3`1`00001l0?3`l0@0
0000?@3oool00400oooo0P00001R0?ooo`H00000;@3`l?08000000030?3`l0000000000000@00000
1@3`l?07000007h0l?3`1000000k0?ooo`00@03oool300000600oooo0P0000000`3oool000000000
0004000002l0l?3`300000040?3`l0L00000O`3`l?04000003X0oooo00110?ooo`800000H03oool2
000000@0oooo1P00000_0?3`l0T000001@3`l?0500000880l?3`1000000h0?ooo`00@@3oool20000
0600oooo0P0000060?ooo`L00000;@3`l?06000008l0l?3`1000000g0?ooo`00@@3oool200000600
oooo0P0000090?ooo`H00000:`3`l?04000009<0l?3`1000000e0?ooo`00@@3oool2000005l0oooo
0`00000<0?ooo`H00000:03`l?02000009H0l?3`1000000d0?ooo`00@@3oool2000005l0oooo0P00
000?0?ooo`H00000`03`l?03000003<0oooo00110?ooo`<00000GP3oool200000180oooo1P00002n
0?3`l0@00000<@3oool00480oooo0P00001N0?ooo`800000503oool700000;`0l?3`1000000`0?oo
o`00@P3oool2000007L0oooo1P00000^0?3`l0030820P03`l?00l?3`01T0l?3`00<0H61P0=3@d03`
l?00K`3`l?04000002h0oooo00120?ooo`800000NP3oool6000002X0l?3`00<0X:2P051@D03`l?00
6P3`l?000`2`/;00D51@0?3`l01`0?3`l0@00000;@3oool00480oooo0P00000o0?ooo`H00000=`3o
ool6000002P0l?3`00<0820P0:2PX03`l?006`3`l?000`0@4100h>3P0?3`l01a0?3`l0@00000:`3o
ool001h0oooo2000000L0?ooo`800000?03oool<000003L0oooo1P00000N0?3`l008030`<01@D500
H61P0410@030`<00l?3`0<30`00000040?3`l004071`L0000000<30`0<30`0<0l?3`00<0L71`0000
003`l?001@3`l?001P2@T900@410000000000000D51@092@T0@0l?3`00<0D51@0820P03`l?00LP3`
l?04000002X0oooo000O0?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0<0?ooo`<00000>P3oool4000000H0oooo1000000h0?ooo`L000006`3`l?00
201@D500l?3`0?3`l01PH600820P0?3`l01PH600@410103`l?0200000080X:2P0`3`l?000`1`L700
00000?3`l0070?3`l08000001P3`l?000`2@T900820P0?3`l01d0?3`l0@00000:03oool001l0oooo
0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool2000003T0oooo
0`0000040?ooo`0607MgM`14A4@000000000001EEED0VIVI0`00000j0?ooo`H000006@3`l?000`3@
d=00l?3`0;2`/002000000030?3`l00`<300L71`00@0l?3`00<00000030`<03`l?00103`l?000`1`
L70000000?3`l0070?3`l08000001P3`l?000`3@d=0000000?3`l01e0?3`l0@000009`3oool001l0
oooo0P0000080?ooo`8000002@3oool2000000d0oooo0P00000h0?ooo`<000001`3oool2000000<0
oooo0`00000l0?ooo`H000005P3`l?00203Ph>00@410000000000000D51@0?3`l0000000/;2`103`
l?001@000000<30`0?3`l03`l?00T92@0080L71`00<0<30`0000001`L7000P1`L7000`2`/;00l?3`
0?3`l0020?3`l08000001`3`l?000`000000/;2`0?3`l01f0?3`l0@000009@3oool001l0oooo0P00
00000`3oool00000000000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3o
ool2000003L0oooo0`0000080?ooo`800000103oool3000000`0oooo0P00000_0?ooo`H00000503`
l?00201@D50000000000001@D500h>3P0?3`l0000000/;2`103`l?001@000000<30`0?3`l03`l?00
<30`00L0000000<0L71`0?3`l03`l?000P3`l?02000000L0l?3`00<000000;2`/03`l?00M`3`l?04
000002@0oooo000G0?ooo`D000000`3oool5000000@0oooo0P0000050?ooo`800000103oool20000
00`0oooo0P00000g0?ooo`8000002@3oool2000000D0oooo0P00000<0?ooo`800000<P3oool60000
0140l?3`0P0000001P30`<00l?3`0?3`l03`l?0000000;2`/0@0l?3`00<00000030`<03`l?00103`
l?000`1`L70000000?3`l0070?3`l08000001`3`l?000`000000/;2`0?3`l01i0?3`l0@000008P3o
ool001P0oooo0`0000040?ooo`80000000<0oooo000000000000103oool2000000@0oooo0`000004
0?ooo`800000303oool2000003L0oooo0P0000090?ooo`8000001@3oool2000000/0oooo0`00000d
0?ooo`L000003P3`l?00100@4100L71`0?3`l01PH6020?3`l003020P802PX:00l?3`00<0l?3`00<0
0000030`<03`l?00103`l?000`1`L70000000?3`l0070?3`l08000001P3`l?000`30`<0000000?3`
l01k0?3`l0@000008@3oool001P0oooo0`0000040?ooo`8000001`3oool2000000@0oooo0P000005
0?ooo`800000303oool3000003D0oooo0P00000:0?ooo`8000001P3oool2000000X0oooo0P00000h
0?ooo`H00000303`l?001030`<00<30`071`L010@4020?3`l003051@D01`L700l?3`0080l?3`00D0
<30`0000000000000000030`<0030?3`l003071`L0000000l?3`00L0l?3`0P0000060?3`l003092@
T00@4100l?3`07d0l?3`1000000O0?ooo`00603oool3000000@0oooo0P0000030?ooo`8000000P3o
ool2000000@0oooo0P0000050?ooo`8000003@3oool2000003D0oooo0P00000:0?ooo`8000001P3o
ool2000000T0oooo0`00000k0?ooo`H000003`3`l?000`2@T900820P0?3`l0030?3`l003051@D00`
<300l?3`00@0l?3`00<0/;2`071`L03`l?001`3`l?02000000H0l?3`00<0D51@061PH03`l?00OP3`
l?04000001h0oooo000H0?ooo`<000000`3oool800000080oooo0P0000040?ooo`8000001@3oool2
000000d0oooo0P00000e0?ooo`8000002P3oool2000000H0oooo0P0000090?ooo`800000?P3oool6
000000h0l?3`00<000000>3Ph03`l?000`3`l?000`2@T900l?3`0?3`l00:0?3`l0030<30`01@D500
/;2`008000001P3`l?000`000000d=3@0?3`l0200?3`l0@00000703oool001P0oooo0`00000=0?oo
o`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000X0oooo0P0000060?oo
o`800000203oool300000440oooo1P00000;0?3`l003071`L02@T900l?3`0140l?3`00@0h>3P061P
H000000000001@3`l?000`2PX:00<30`0?3`l0220?3`l0@000006`3oool001P0oooo0`00000=0?oo
o`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000L0oooo00<0c<c<05EE
E@2k^k/00P0000060?ooo`8000001`3oool3000004@0oooo1`0000080?3`l0030>3Ph010@400l?3`
01<0l?3`00<0/;2`010@403`l?00103`l?000`1`L700d=3@0?3`l0240?3`l0@000006@3oool001P0
oooo0`00000=0?ooo`800000103oool2000000D0oooo0P00000=0?ooo`800000=@3oool2000000P0
oooo00@0k^k^06IVIP00000000001P3oool2000000L0oooo0P0000180?ooo`H000001`3`l?000`3@
d=00l?3`0?3`l02Q0?3`l0@00000603oool001P0oooo0`00000=0?ooo`8000000`3oool4000000@0
oooo0P00000=0?ooo`<00000=@3oool2000000T0oooo00<0^k^k014A4@3oool0103oool2000000L0
oooo0`00001;0?ooo`H00000ZP3`l?04000001H0oooo000H0?ooo`<000003P3oool010000000oooo
0?ooo`3oool4000000@0oooo00<000000?ooo`3oool03@3oool2000003D0oooo0P00000@0?ooo`80
00001`3oool2000004h0oooo1P00002Y0?3`l0@000005@3oool001P0oooo0`00000>0?ooo`800000
0`3oool2000000@0oooo0P00000?0?ooo`800000=@3oool3000000h0oooo0`0000060?ooo`<00000
D@3oool600000:P0l?3`0`00000D0?ooo`005`3oool5000000h0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`030000003oool0oooo00h0oooo0P00000f0?ooo`<00000303oool3000000L0oooo
0P00001D0?ooo`L00000YP3`l?0400000180oooo000[0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03`3oool3000003H0oooo0`00000:0?ooo`<00000H@3oool600000:D0l?3`1000
000A0?ooo`00AP3oool2000003L0oooo100000060?ooo`@00000I@3oool600000:@0l?3`1000000?
0?ooo`00AP3oool2000003P0oooo3000001X0?ooo`H00000X`3`l?04000000h0oooo00160?ooo`<0
0000>P3oool6000006h0oooo1P00002R0?3`l0@00000303oool004L0oooo0P00002`0?ooo`L00000
X03`l?04000000/0oooo00170?ooo`800000/`3oool600000:00l?3`100000090?ooo`00A`3oool3
00000;D0oooo1P00002N0?3`l0@00000203oool004P0oooo0P0000170?ooo`800000KP3ooonW0000
00L0oooo00180?ooo`800000A`3oool200000740ooooY00000070?ooo`00B03oool3000004D0oooo
0`00003o0?oooad0oooo00190?ooo`800000A03oool300000?l0oooo7P3oool004T0oooo0P000014
0?ooo`800000o`3ooolO0?ooo`00B@3oool300000480oooo0`00003o0?oooal0oooo001:0?ooo`80
0000@P3oool200000?l0oooo803oool004X0oooo0`0000100?ooo`<00000f03oool600000080oooo
0P0000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000003oool00P3oool2000000@0oooo
0P0000020?ooo`<0000000@0oooo0000003oool000001P3oool3000000<0oooo1000000=0?ooo`00
B`3oool2000003l0oooo0`00003H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool000000?ooo`04
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo
001;0?ooo`800000?`3oool200000=T0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool004/0oooo0`00
000m0?ooo`<000002@3oool2000000<0oooo0`00003?0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo000000040?ooo`030000003oool0oooo00L0oooo
0P00000=0?ooo`00C03oool2000003d0oooo0P00000<0?ooo`060000003oool0oooo0000003oool0
0000c@3oool200000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo00000004
0?ooo`H000000P3oool2000000l0oooo001<0?ooo`800000B`3oool010000000oooo0?ooo`00003;
0?ooo`@00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool000000140oooo
001<0?ooo`<00000BP3oool010000000oooo0?ooo`00003:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`0000000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool004d0oooo0P00001:0?ooo`040000003oool0oooo00000<X0oooo00<0
00000?ooo`3oool0103oool4000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool300000080oooo0`0000000`3oool000000?ooo`030?ooo`05
0000003oool000000?ooo`000000103oool2000000@0oooo1000000=0?ooo`00C@3oool2000004P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0U0?ooo`00C@3oool3000004P0oooo
1`0000390?ooo`H000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0oooo
001>0?ooo`800000o`3ooomP0?ooo`00CP3oool200000?l0ooooH03oool004h0oooo0`00000d0?oo
o`800000o`3ooolY0?ooo`00C`3oool2000003@0oooo0P00003o0?ooobT0oooo001?0?ooo`<00000
<P3oool300000?l0oooo:@3oool00500oooo0P00000b0?ooo`800000o`3ooolZ0?ooo`00D03oool3
00000300oooo0`00003o0?ooobX0oooo001A0?ooo`<00000;`3oool200000?l0oooo:`3oool00580
oooo0P00000^0?ooo`<00000o`3oool[0?ooo`00DP3oool3000002`0oooo0`00003o0?ooob`0oooo
001C0?ooo`800000;03oool200000?l0oooo;@3oool005<0oooo0`00000Z0?ooo`<00000o`3oool]
0?ooo`00E03oool2000002X0oooo0P00003o0?ooobh0oooo001D0?ooo`<00000:03oool300000?l0
oooo;P3oool005D0oooo0P00000X0?ooo`800000o`3oool_0?ooo`00E@3oool300000?l0ooooF03o
ool005H0oooo0`00003o0?oooeL0oooo001G0?ooo`800000o`3ooomG0?ooo`00E`3oool300000?l0
ooooEP3oool005P0oooo0P00003o0?oooeH0oooo001H0?ooo`<00000o`3ooomE0?ooo`00F@3oool2
00000?l0ooooE@3oool005T0oooo0`00000O0?ooo`800000o`3ooolc0?ooo`00FP3oool2000001l0
oooo0P00003o0?oooc<0oooo001J0?ooo`<000007@3oool300000?l0oooo<`3oool005/0oooo0`00
000K0?ooo`<00000o`3ooold0?ooo`00G03oool2000001D0oooo2000001V0?ooo`h00000`03oool0
05`0oooo0`00000D0?ooo`P00000D@3ooolT00000;l0oooo001M0?ooo`800000503oool9000003/0
oooo:`00000<0?ooo`@00000_@3oool005d0oooo0`00000B0?ooo`/000009@3oool[00000280oooo
1000002l0?ooo`00GP3oool200000180oooo2`00000@0?ooob/00000>@3oool400000;X0oooo001b
0?oooc400000C`3oool500000;P0oooo001R0?ooob`00000IP3oool400000;L0oooo001=0?ooob`0
0000O@3oool400000;D0oooo000h0?ooob/000003P3oool7000007l0oooo1000002d0?ooo`008`3o
ool[000002<0oooo1P0000220?ooo`@00000/P3oool001P0oooo8@00000h0?ooo`D00000Q03oool4
00000;40oooo000H0?ooo``00000C@3oool4000008L0oooo1000002_0?ooo`006P3oool7000004l0
oooo100000290?ooo`D00000[@3oool001d0oooo1P00001=0?ooo`<00000S03oool400000:`0oooo
000P0?ooo`H00000BP3oool2000008l0oooo1000002Z0?ooo`008P3oool700000=T0oooo1000002Y
0?ooo`009@3oool600000=T0oooo1000002W0?ooo`00:03oool600000=L0oooo1000002V0?ooo`00
:P3oool700000=H0oooo1000000_0?ooo`X00000J`3oool002d0oooo1P00003E0?ooo`@00000;`3o
ool3000000<0oooo0`00001[0?ooo`00<03oool6000002h0oooo3000002J0?ooo`@00000;@3oool3
000000@0oooo0P00001[0?ooo`00<P3oool7000002/0oooo3000002K0?ooo`D00000:`3oool30000
0740oooo000e0?ooo`H00000:@3oool2000000P0oooo0P00002M0?ooo`@00000:P3oool300000740
oooo000h0?ooo`H000009P3oool2000000P0oooo0P0000050?ooo`D00000U@3oool4000002P0oooo
0`0000030?ooo`800000K03oool003X0oooo1`00000S0?ooo`800000203oool2000000H0oooo0`00
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Q03oool4000002L0oooo2000
001/0?ooo`00?@3oool600000240oooo0P0000080?ooo`8000001P3oool3000000P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`250?ooo`@000009@3oool3000000<0oooo0P00001/
0?ooo`00@03oool6000001h0oooo0P0000080?ooo`8000001P3oool3000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`260?ooo`@00000903oool300000740oooo00120?ooo`L0
00006`3oool2000000P0oooo0P0000060?ooo`H00000103oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool00`000000oooo0?ooo`270?ooo`@000008P3oool3000000@0oooo0P00001[0?ooo`00
A@3oool7000001P0oooo300000060?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0R03oool400000240oooo0`0000030?ooo`<00000
J`3oool004P0oooo1P00000F0?ooo``000001P3oool3000000030?ooo`0000000000008000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0RP3o
ool4000001h0oooo2P00001[0?ooo`00B`3oool6000002D0oooo0`0000020?ooo`<000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0R`3oool5
00000940oooo001=0?ooo`L000008P3oool300000080oooo0`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2=0?ooo`@00000T03oool00500
oooo1P00000P0?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo08l0oooo1000002>0?ooo`00D`3oool6000001`0oooo
1@0000000`3oool00000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2@0?ooo`@00000S@3oool005D0oooo1`00000K0?ooo`D00000103o
ool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool0TP3oool4000008/0oooo
001H0?ooo`H000008`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
U03oool4000008X0oooo001K0?ooo`H00000803oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0UP3oool4000008P0oooo001M0?ooo`L000007P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo09P0oooo1@0000260?ooo`00H03oool600000<00oooo10000025
0?ooo`00H`3oool600000;l0oooo100000230?ooo`00I@3oool700000;d0oooo100000220?ooo`00
J03oool600000;d0oooo100000200?ooo`00J`3oool600000;/0oooo1000001o0?ooo`00K@3oool7
00000;X0oooo1000001m0?ooo`00L03oool600000;T0oooo1000001l0?ooo`00L`3oool600000;P0
oooo1000001j0?ooo`00M@3oool700000;H0oooo1@00001h0?ooo`00N03oool600000;H0oooo1000
001g0?ooo`00N`3oool600000;D0oooo1000001e0?ooo`00O@3oool700000;<0oooo1000001d0?oo
o`00P03oool600000;<0oooo1000001b0?ooo`00P`3oool600000;40oooo1000001a0?ooo`00Q@3o
ool700000;00oooo1000001_0?ooo`00R03oool600000:l0oooo1000001^0?ooo`00R`3oool60000
0:h0oooo1000001/0?ooo`00S@3oool700000:`0oooo1@00001Z0?ooo`00T03oool600000:`0oooo
1000001Y0?ooo`00T`3oool600000:/0oooo1000001W0?ooo`00U@3oool700000:T0oooo1000001V
0?ooo`00V03oool700000:P0oooo1000001T0?ooo`00V`3oool600000:L0oooo1000001S0?ooo`00
WP3oool600000:H0oooo1000001Q0?ooo`00X03oool700000:@0oooo1@00001O0?ooo`00X`3oool6
00000:@0oooo1000001N0?ooo`00YP3oool600000:<0oooo1000001L0?ooo`00Z03oool700000:40
oooo1000001K0?ooo`00Z`3oool600000:40oooo1000001I0?ooo`00[P3oool6000009l0oooo1000
001H0?ooo`00/03oool7000009h0oooo1000001F0?ooo`00/`3oool6000009d0oooo1000001E0?oo
o`00]P3oool6000009`0oooo1000001C0?ooo`00^03oool7000009X0oooo1@00001A0?ooo`00^`3o
ool6000009X0oooo1000001@0?ooo`00_P3oool6000009T0oooo1000001>0?ooo`00`03oool70000
09L0oooo1000001=0?ooo`00``3ooonP000004`0oooo00360?oooid00000C03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03oool00?l0oooo/03o
ool00?l0oooo/03oool00?l0oooo5@3oool7000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`000000103oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0200000580oooo003o0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000D`3oool00?l0oooo5@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000005<0oooo003o0?oooaD0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool600000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00001C0?ooo`00o`3ooolE0?ooo`L0
000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo
00<000000?ooo`3oool01@3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo0P0000030?oo
o`040000003oool0000000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000<0oooo0P0000030?ooo`040000003oool0oooo000005<0oooo003o0?oooaD0oooo
00<000000?ooo`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000P0000020?ooo`050000003oool000000000003oool00`0000050?ooo`800000103oool0
0`000000oooo0000000200000080oooo0`00001B0?ooo`00o`3ooolE0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0D@3oool00?l0oooo5@3oool7000000l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1A0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{431, 421.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->-6,
  AnimationCycleRepetitions->Infinity]
}, Closed]],

Cell[TextData[{
  "Modelling of Adaptive Systems: One adaptation step\n\n",
  StyleBox["Double-click on the graphics to start the animation.",
    FontWeight->"Bold"]
}], "NumberedFigure",
  CellTags->"AdaptationStep"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "An Adaptation Sequence (",
  ButtonBox["Animation",
    ButtonData:>"Adaptation sequence animation",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Subsubsection"],

Cell[TextData[{
  "If the system performs several steps of adaptation, we get pathways of \
evolution as depicted in Figure ",
  CounterBox["NumberedFigure", "Adaptation sequence (Figure)"],
  "."
}], "Text"],

Cell[" ", "Text",
  CellTags->"Adaptation sequence animation"],

Cell[CellGroupData[{

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`3o0?ooo`X0
oooo001_0?ooo`<00000=03oool2003o0?l0oooo2P3oool006h0oooo0`00000e0?ooo`<00?l0o`3o
ool90?ooo`002`3oool7000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
1@3oool300000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080
oooo0`000000103oool0000000000000000?0?ooo`<00000=@3oool4003o0?l0oooo2@3oool000/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
oooo00d0oooo0`00000f0?ooo`@00?l0o`3oool90?ooo`002`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000d0oooo0`00000g0?ooo`D00?l0o`3oool80?oo
o`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0
oooo0`00000h0?ooo`D00?l0o`3oool80?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo1P0000000`3oool000000?oo
o`030?ooo`050000003oool0oooo0?ooo`0000000`3oool5000000030?ooo`000000oooo00X0oooo
0`00000i0?ooo`D00?l0o`3oool80?ooo`002`3oool7000000030?ooo`000000oooo00<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000002P3oool3000003T0oooo1`00o`3o
0?ooo`L0oooo000;0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`8000000`3oool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`00
0000103oool010000000oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000090?ooo`<00000>P3oool7
003o0?l0oooo1`3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003oool000000000003oool0
0`0000060?ooo`8000000`3oool00`000000oooo00000002000000<0oooo0`0000020?ooo`@00000
0P3oool00`000000oooo0?ooo`060?ooo`<00000>`3oool7003o0?l0oooo1`3oool000/0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0`00
000l0?ooo`P00?l0o`3oool60?ooo`002`3oool7000000l0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0`00000m0?ooo`P00?l0o`3oool6
0?ooo`00H`3oool3000003d0oooo2@00o`3o0?ooo`H0oooo001R0?ooo`<00000?P3oool:003o0?l0
oooo1@3oool00640oooo0`00000o0?ooo`X00?l0o`3oool50?ooo`00H@3oool200000400oooo2000
o`3o0?ooo`L0oooo001P0?ooo`<00000A@3oool2003o0?l0oooo203oool005l0oooo0`0000160?oo
o`800?l0o`3oool80?ooo`00G`3oool2000004L0oooo0P00o`3o0?ooo`P0oooo001N0?ooo`<00000
A`3oool2003o0?l0oooo203oool005d0oooo0`0000180?ooo`800?l0o`3oool80?ooo`00G@3oool2
000004T0oooo0P00o`3o0?ooo`P0oooo001L0?ooo`<00000o`3ooomC0?ooo`00F`3oool300000?l0
ooooE03oool005/0oooo0P00003o0?oooeD0oooo001J0?ooo`<00000o`3ooomE0?ooo`00F@3oool3
00000?l0ooooEP3oool005P0oooo0`00003o0?oooeL0oooo001H0?ooo`800000o`3ooomH0?ooo`00
E`3oool3000004l0oooo0P00o`3o0?ooo`L0oooo001F0?ooo`<00000D03oool2003o0?l0oooo1`3o
ool005H0oooo0P00001A0?ooo`800?l0o`3oool70?ooo`00E@3oool300000540oooo0P00o`3o0?oo
o`L0oooo001D0?ooo`<00000DP3oool3003o0?l0oooo1P3oool005@0oooo0P00001D0?ooo`800?l0
o`3oool60?ooo`00D`3oool3000005@0oooo0P00o`3o0?ooo`H0oooo001B0?ooo`<00000E@3oool2
003o0?l0oooo1P3oool00580oooo0P00001F0?ooo`800?l0o`3oool60?ooo`00D@3oool3000005H0
oooo0P00o`3o0?ooo`H0oooo001A0?ooo`800000E`3oool3003o0?l0oooo1@3oool00540oooo0P00
001H0?ooo`800?l0o`3oool50?ooo`00D03oool3000005P0oooo0P00o`3o0?ooo`D0oooo001@0?oo
o`800000F@3oool2003o0?l0oooo1@3oool00500oooo0P00003o0?ooof00oooo001?0?ooo`<00000
o`3ooomP0?ooo`00C`3oool200000?l0ooooH@3oool004l0oooo0P00003o0?ooof40oooo001>0?oo
o`<00000o`3ooomQ0?ooo`00CP3oool200000?l0ooooHP3oool004h0oooo0P00003o0?ooof80oooo
001=0?ooo`<00000F`3oool2003o0?l0oooo1@3oool004d0oooo0P00001L0?ooo`800?l0o`3oool5
0?ooo`00C@3oool2000005`0oooo0P00o`3o0?ooo`D0oooo001<0?ooo`<00000G03oool2003o0?l0
oooo1@3oool004`0oooo0P00001M0?ooo`800?l0o`3oool50?ooo`00C03oool2000005d0oooo0P00
o`3o0?ooo`D0oooo001;0?ooo`<00000G@3oool2003o0?l0oooo1@3oool004/0oooo0P00001N0?oo
o`<00?l0o`3oool40?ooo`00B`3oool2000005l0oooo0P00o`3o0?ooo`@0oooo001:0?ooo`<00000
G`3oool2003o0?l0oooo103oool004X0oooo0P00001P0?ooo`800?l0o`3oool40?ooo`00BP3oool2
00000600oooo0P00o`3o0?ooo`@0oooo00190?ooo`<00000H03oool2003o0?l0oooo103oool004T0
oooo0P00001Q0?ooo`800?l0o`3oool40?ooo`00B@3oool200000?l0ooooI`3oool004P0oooo0`00
003o0?ooofL0oooo00180?ooo`800000o`3ooomX0?ooo`00B03oool200000?l0ooooJ03oool004P0
oooo0P00003o0?ooofP0oooo00180?ooo`800000o`3ooomX0?ooo`00A`3oool300000?l0ooooJ03o
ool004L0oooo0P00003o0?ooofT0oooo00170?ooo`800000I@3oool2003o0?l0oooo0P3oool004L0
oooo0P00001U0?ooo`800?l0o`3oool20?ooo`00AP3oool3000006D0oooo0P00o`3o0?ooo`80oooo
00160?ooo`800000IP3oool2003o0?l0oooo0P3oool004H0oooo0P00001V0?ooo`800?l0o`3oool2
0?ooo`00AP3oool2000006H0oooo0P00o`3o0?ooo`80oooo00160?ooo`800000IP3oool3003o07D0
oooo3000001o0?ooo`00A@3oool3000006L0oooo0P00o`1R0?ooob000000OP3oool004D0oooo0P00
001X0?ooo`800?l0C`3ooolW00000080oooo203`l?04000007`0oooo00150?ooo`800000J03oool2
003o03d0oooo9P0000020?oooa`0l?3`1000001k0?ooo`00A@3oool2000006P0oooo0P00o`0Z0?oo
obH000000`3oool`0?3`l0@00000N@3oool004@0oooo0`00001X0?ooo`800?l05`3ooolW00000080
ooooA03`l?04000007P0oooo00140?ooo`800000J@3oool2003o00D0oooo9P0000030?oooeP0l?3`
0`0000000`3`l?00oooo0?ooo`1d0?ooo`00A03oool2000005d0oooo9P0000030?ooof`0l?3`1000
001e0?ooo`00A03oool2000004X0oooo9`0000030?ooogl0l?3`100000000`3`l?00oooo0?ooo`1a
0?ooo`00A03oool2000003P0oooo9P0000030?oooi@0l?3`1000001b0?ooo`00@`3oool3000002D0
oooo9P0000040?ooojL0l?3`100000000`3`l?00oooo0?ooo`0/0?ooo`80000000<0oooo00000000
00000P00000k0?ooo`00@`3oool2000001<0oooo9`0000030?oook`0l?3`1000000]0?ooo`@00000
0P3oool2000003X0oooo00130?ooo`8000002P3ooolM000000@0ooooc`3`l?04000002`0oooo0`00
00030?ooo`<00000>@3oool004<0oooo0P00000:0?ooo`X00000103ooooT0?3`l0@00000:P3oool2
000000@0oooo0`00000i0?ooo`00@`3oool2000000`0oooo1P00003[0?3`l0@00000;P3oool40000
03T0oooo00130?ooo`8000003`3oool6000003X0l?3`3`0000080?3`l08000000P3`l?02003o09<0
l?3`1000000Z0?ooo`D00000>P3oool004<0oooo0P00000A0?ooo`L000009`3`l?02000000<0l?3`
0P0000020?3`l08000001@3`l?0B000000D0l?3`0P0000020?3`l0800?l0U03`l?04000002L0oooo
1P00000k0?ooo`00@`3oool2000001@0oooo1P00000U0?3`l08000000`3`l?0200000080l?3`0P00
000C0?3`l0L0000000<0l?3`0000000000000P000000103`l?000?l0003o0000o`2E0?3`l0@00000
903oool5000003d0oooo00130?ooo`8000005P3oool00`3`l?00000000000004000004<0l?3`2@00
00020?3`l0800?l0UP3`l?04000002<0oooo0`0000040?ooo`800000>@3oool004<0oooo0P00000I
0?ooo`H00000A03`l?0600000080l?3`0P00o`2H0?3`l0<0000000<0l?3`0?ooo`3oool07`3oool3
000000<0oooo0`00000i0?ooo`00@`3oool2000001`0oooo1P0000100?3`l0P0000000@0l?3`003o
0000o`000?l0V03`l?0400000240oooo0P0000020?ooo`@00000>@3oool004<0oooo0P00000N0?oo
o`H00000?@3`l?0900000080l?3`0P00o`2I0?3`l0@0000000<0l?3`0?ooo`3oool07P3oool40000
00030?ooo`000000000003T0oooo00130?ooo`8000008@3oool6000003X0l?3`2@00002O0?3`l0@0
0000G`3oool004<0oooo0P00000S0?ooo`L00000>P3`l?07000009l0l?3`100000000`3`l?00oooo
0?ooo`1K0?ooo`00@`3oool2000002H0oooo1P00000l0?3`l0<00000X@3`l?04000005`0oooo0013
0?ooo`800000:@3oool600000=h0l?3`100000000`3`l?00oooo0?ooo`1H0?ooo`00@`3oool20000
02/0oooo1P00000Z0?3`l0030820P03`l?00l?3`00H0l?3`00<0L71`0=3@d03`l?001@3`l?040000
09l0l?3`1000001I0?ooo`00@P3oool3000002h0oooo1P00000V0?3`l0030;2`/010@400l?3`00L0
l?3`00<0/;2`051@D03`l?000`3`l?08000009h0l?3`100000000`3`l?00oooo0?ooo`1E0?ooo`00
@P3oool200000340oooo1`00000S0?3`l003020P802PX:00l?3`00P0l?3`00<0410@0>3Ph03`l?00
0P3`l?0800000:00l?3`1000001F0?ooo`00@P3oool2000003@0oooo1P00000I0?3`l005030`<01@
D500H61P0410@030`<000P3`l?000`30`<0000000?3`l0030?3`l004071`L0000000820P0<30`080
l?3`00<0D51@071`L03`l?000P3`l?0800000:40l?3`100000000`3`l?00oooo0?ooo`1B0?ooo`00
@P3oool2000003H0oooo00<0l?3`0000000000001000000F0?3`l005051@D03`l?00l?3`061PH00P
82000P3`l?000`1PH600<30`0?3`l0030?3`l08000000P2PX:020?3`l003092@T00P8200l?3`0080
l?3`2000002S0?3`l0<0000000<0l?3`0?ooo`3oool0D@3oool00480oooo0P00000i0?ooo`H00000
503`l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000`3`l?000`000000<30`
0?3`l0030?3`l0030=3@d0000000l?3`00@0l?3`1000002V0?3`l0@0000000<0l?3`0?ooo`3oool0
C`3oool00480oooo0P00000l0?ooo`H000004@3`l?001@3Ph>00@410000000000000D51@0080l?3`
00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`l0030000002`/;00l?3`0:h0l?3`
100000000`3`l?00oooo0?ooo`1>0?ooo`00@P3oool2000003h0oooo1P00000?0?3`l005051@D000
00000000051@D03Ph>000P3`l?000`000000/;2`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`
00<000000;2`/03`l?00/03`l?04000004l0oooo00120?ooo`800000@@3oool6000000`0l?3`0P00
00000`30`<00l?3`0?3`l0020?3`l0030000002`/;00l?3`00<0l?3`00<00000030`<03`l?00103`
l?000`000000/;2`0?3`l02a0?3`l0@0000000<0l?3`0?ooo`3oool0B`3oool00480oooo0P000013
0?ooo`L000002@3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0820P092@T03`l?000`3`
l?000`000000<30`0?3`l0030?3`l0030<30`0000000l?3`0;@0l?3`1000001<0?ooo`00@P3oool2
000004H0oooo1P0000070?3`l0050<30`01@D500L71`051@D010@4000P3`l?000`1@D500H61P0?3`
l0020?3`l005030`<000000000000000000`<3000P3`l?000`2@T900410@0?3`l02e0?3`l0@00000
00<0l?3`0?ooo`3oool0B03oool00480oooo0P0000190?ooo`H000002`3`l?000`2PX:00820P0?3`
l0030?3`l003051@D00`<300l?3`00<0l?3`0P1@D52h0?3`l0@00000B@3oool00480oooo0P00001;
0?ooo`H000002P3`l?000`0@4100d=3@0?3`l0030?3`l003092@T03`l?00l?3`0080l?3`00<00000
0=3@d03`l?00^03`l?04000000030?3`l03oool0oooo04D0oooo00120?ooo`800000CP3oool60000
00L0l?3`00<0L71`092@T03`l?001`3`l?000`2PX:00<30`0?3`l02k0?3`l0@00000AP3oool00480
oooo0P00001@0?ooo`H000001@3`l?000`3Ph>00<30`0?3`l0070?3`l003071`L03@d=00l?3`0;`0
l?3`100000000`3`l?00oooo0?ooo`120?ooo`00@P3oool2000005<0oooo1P0000030?3`l0030=3@
d03`l?00l?3`0<L0l?3`100000130?ooo`00@P3oool2000005D0oooo1`00003;0?3`l0@0000000<0
l?3`0?ooo`3oool0?`3oool00480oooo0P00001H0?ooo`H00000b`3`l?03000000030?3`l03oool0
oooo03h0oooo00120?ooo`800000F`3oool600000<T0l?3`100000000`3`l?00oooo0?ooo`0l0?oo
o`00@P3oool2000005d0oooo1`0000370?3`l0@0000000<0l?3`0?ooo`3oool0>`3oool00480oooo
0`00001O0?ooo`H00000a`3`l?04000000030?3`l03oool0oooo03T0oooo00130?ooo`800000H03o
ool800000<D0l?3`100000000`3`l?00oooo0?ooo`0h0?ooo`00@`3oool200000600oooo0P000002
0?ooo`H00000a@3`l?04000000030?3`l03oool0oooo03H0oooo00130?ooo`800000G`3oool30000
00D0oooo1P0000330?3`l0@0000000<0l?3`0?ooo`3oool0=@3oool004<0oooo0P00001O0?ooo`80
0000203oool600000<<0l?3`100000000`3`l?00oooo0?ooo`0c0?ooo`00@`3oool2000005h0oooo
0`00000;0?ooo`H00000`@3`l?04000000030?3`l03oool0oooo0380oooo00130?ooo`800000GP3o
ool2000000h0oooo1P0000310?3`l0@0000000<0l?3`0?ooo`3oool0<03oool004<0oooo0`00001`
0?ooo`H00000_`3`l?04000000030?3`l03oool0oooo02l0oooo00140?ooo`800000LP3oool70000
0;h0l?3`0`0000000`3`l?00oooo0?ooo`0^0?ooo`00A03oool2000007D0oooo1P00002m0?3`l0@0
000000<0l?3`0?ooo`3oool0;03oool00200oooo200000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0303oool2000007P0oooo1P00002k0?3`l0@0000000<0l?3`0?ooo`3oool0
:`3oool00240oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo0P00001j0?ooo`H00000^`3`l?04000000030?3`l03oool0oooo02T0oooo000Q
0?ooo`800000203oool2000000T0oooo0P00000<0?ooo`800000O@3oool600000;T0l?3`10000000
0`3`l?00oooo0?ooo`0X0?ooo`008@3oool2000000P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`800000O`3oool600000;T0l?3`100000000`3`l?00oooo0?ooo`0V0?oo
o`006@3oool5000000<0oooo0P0000000`3oool00000000000040?ooo`8000001@3oool2000000@0
oooo0P00000;0?ooo`800000E`3oool2000002T0oooo1P00002g0?3`l0@0000000<0l?3`0?ooo`3o
ool09@3oool001X0oooo0`0000040?ooo`D00000103oool2000000@0oooo0`0000040?ooo`800000
2`3oool3000005H0oooo0P00000[0?ooo`L00000]P3`l?04000000030?3`l03oool0oooo02<0oooo
000J0?ooo`<00000103oool2000000030?ooo`000000000000@0oooo0P0000040?ooo`8000001@3o
ool2000000`0oooo0P00001E0?ooo`<00000;P3oool600000;D0l?3`100000000`3`l?00oooo0?oo
o`0R0?ooo`006P3oool3000000@0oooo0P0000070?ooo`800000103oool2000000D0oooo0P00000<
0?ooo`800000E@3oool200000380oooo1P00002d0?3`l0@0000000<0l?3`0?ooo`3oool0803oool0
01X0oooo0`0000040?ooo`8000000`3oool200000080oooo0P0000040?ooo`8000001@3oool20000
00`0oooo0P00001D0?ooo`<00000=03oool600000;<0l?3`100000000`3`l?00oooo0?ooo`0O0?oo
o`006P3oool3000000<0oooo200000020?ooo`800000103oool2000000D0oooo0P00000<0?ooo`80
0000E03oool2000003P0oooo1P00002b0?3`l0<000000P3`l?0O0?ooo`006P3oool3000000d0oooo
0P0000040?ooo`8000001@3oool2000000`0oooo0P00001C0?ooo`<00000>P3oool600000;40l?3`
100000000`3`l?00oooo0?ooo`0L0?ooo`006P3oool3000000d0oooo0P0000040?ooo`8000001@3o
ool2000000`0oooo0P00001B0?ooo`<00000?P3oool600000:l0l?3`100000020?3`l1`0oooo000J
0?ooo`<000003@3oool2000000<0oooo100000040?ooo`800000303oool300000540oooo0P000011
0?ooo`L00000[P3`l?04000000030?3`l03oool0oooo01T0oooo000J0?ooo`<000003P3oool01000
0000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0303oool200000500oooo0`000014
0?ooo`H00000[@3`l?0400000080l?3`6@3oool001X0oooo0`00000>0?ooo`8000000`3oool20000
00@0oooo0P00000>0?ooo`800000D03oool2000004P0oooo1P00002/0?3`l0@0000000<0l?3`0?oo
o`3oool05P3oool001T0oooo1@00000>0?ooo`040000003oool0oooo0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`800000C`3oool3000004X0oooo1P00002[0?3`l0@000000P3`l?0F0?oo
o`00;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo0P00001?0?ooo`80
0000CP3oool600000:X0l?3`100000000`3`l?00oooo0?ooo`0C0?ooo`00AP3oool300000:00oooo
1`00002X0?3`l0@000000P3`l?0C0?ooo`00A`3oool200000:<0oooo1P00002X0?3`l0@0000000<0
l?3`0?ooo`3oool0403oool004L0oooo0P00002V0?ooo`H00000YP3`l?04000000030?3`l03oool0
oooo00l0oooo00170?ooo`<00000Y`3oool600000:H0l?3`100000000`3`l?00oooo0?ooo`0=0?oo
o`00B03oool200000:X0oooo1P00002T0?3`l0@0000000<0l?3`0?ooo`3oool0303oool004P0oooo
0P00002/0?ooo`H00000Y03`l?0300000080l?3`303oool004P0oooo0`00002^0?ooo`H00000XP3`
l?04000000030?3`l03oool0oooo00T0oooo00190?ooo`800000B03oool2000006H0oooo1`00002P
0?3`l0@000000P3`l?090?ooo`00B@3oool3000004L0oooo0P00001Y0?ooo`H00000X03`l?040000
00030?3`l03oool0oooo00H0oooo001:0?ooo`800000AP3oool3000006`0oooo1P00002N0?3`l0@0
00000P3`l?060?ooo`00BP3oool2000004D0oooo0`00001_0?ooojL000000P3`l?050?ooo`00BP3o
ool3000004@0oooo0P00001c0?oooj@000000`3`l?040?ooo`00B`3oool2000004<0oooo0`00001f
0?oooj@0l?3`103oool004/0oooo0`0000120?ooo`800000o`3ooolP0?ooo`00C03oool200000440
oooo0`00003o0?ooob00oooo001<0?ooo`800000@03oool300000?l0oooo8@3oool004`0oooo0`00
000o0?ooo`800000f`3oool600000080oooo0P0000000`3oool000000?ooo`030?ooo`<0000000<0
oooo0000003oool00`3oool2000000<0oooo0P0000020?ooo`<0000000D0oooo0000003oool0oooo
000000050?ooo`<00000103oool4000000`0oooo001=0?ooo`800000?P3oool3000000T0oooo0P00
00030?ooo`<00000b@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool004d0
oooo0P00000n0?ooo`800000303oool01P000000oooo0?ooo`000000oooo00000<T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool004d0oooo0`00001;0?ooo`040000003oool0oooo00000=80oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000001P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
203oool2000000`0oooo001>0?ooo`800000B`3oool010000000oooo0?ooo`00003@0?ooo`800000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000001P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo1P00
00030?ooo`8000003P3oool004h0oooo0`00001:0?ooo`040000003oool0oooo00000<`0oooo1000
00040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000403oool0
04l0oooo0P0000180?ooo`030000003oool000000080oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00C`3oool2000004T0oooo1`000039
0?ooo`030000003oool0oooo00@0oooo100000001P3oool000000?ooo`000000oooo000000@0oooo
00<000000?ooo`3oool00P3oool3000000060?ooo`00000000000000003oool00000103oool01P00
0000oooo0?ooo`000000oooo000000<0oooo0P0000050?ooo`@00000303oool004l0oooo0`00003o
0?oooaT0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000E0?ooo`030000003oool0
oooo02D0oooo001@0?ooo`800000o`3ooolJ0?ooo`H000000P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02D0oooo001@0?ooo`800000=@3oool200000?l0oooo:@3oool00500oooo
0`00000d0?ooo`800000o`3ooolY0?ooo`00D@3oool2000003<0oooo0`00003o0?ooobT0oooo001A
0?ooo`<00000<@3oool300000?l0oooo:P3oool00580oooo0P00000a0?ooo`800000o`3oool[0?oo
o`00DP3oool3000002l0oooo0`00003o0?ooob/0oooo001C0?ooo`<00000;P3oool200000?l0oooo
;03oool005@0oooo0P00000]0?ooo`<00000o`3oool/0?ooo`00E03oool3000002/0oooo0`00003o
0?ooobd0oooo001E0?ooo`800000:`3oool200000?l0oooo;P3oool005D0oooo0`00000Y0?ooo`<0
0000o`3oool^0?ooo`00EP3oool2000002T0oooo0P00003o0?ooobl0oooo001F0?ooo`<00000o`3o
oomI0?ooo`00E`3oool300000?l0ooooF03oool005P0oooo0P00003o0?oooeP0oooo001H0?ooo`<0
0000o`3ooomG0?ooo`00F@3oool200000?l0ooooE`3oool005T0oooo0`00003o0?oooeH0oooo001J
0?ooo`<00000o`3ooomE0?ooo`00F`3oool2000001l0oooo0P00003o0?oooc@0oooo001K0?ooo`<0
00007P3oool200000?l0oooo=03oool005`0oooo0P00000M0?ooo`<00000o`3ooold0?ooo`00G03o
ool3000001/0oooo0`00003o0?ooocD0oooo001M0?ooo`8000006`3oool200000?l0oooo=P3oool0
05d0oooo0`00000F0?ooo`H00000I`3oool>00000<00oooo001N0?ooo`<000005@3oool600000580
oooo9000002o0?ooo`00G`3oool2000001D0oooo1`00000l0?ooob/00000303oool400000;d0oooo
001O0?ooo`<000004`3oool9000002D0oooo;000000R0?ooo`@00000_03oool00600oooo0P00000C
0?ooo`T00000403oool/000003T0oooo1000002j0?ooo`00M@3oool_00000500oooo1@00002h0?oo
o`00I03oool[000006L0oooo1000002g0?ooo`00CP3oool]000007d0oooo1000002e0?ooo`00>@3o
ool/000000l0oooo1P00001o0?ooo`@00000]03oool002@0oooo:`00000T0?ooo`H00000PP3oool4
00000;80oooo000I0?ooob400000>@3oool5000008@0oooo1000002a0?ooo`006@3oool<000004h0
oooo100000270?ooo`@00000[`3oool001/0oooo1`00001@0?ooo`@00000R@3oool500000:d0oooo
000N0?ooo`H00000CP3oool3000008`0oooo1000002/0?ooo`008@3oool6000004/0oooo0P00002?
0?ooo`@00000ZP3oool002<0oooo1`00003J0?ooo`@00000Z@3oool002H0oooo1P00000P0?ooo`D0
0000]@3oool400000:L0oooo000Y0?ooo`H000007P3oool3000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2T0?ooo`@00000YP3oool002/0oooo1`00000K0?ooo`<00000203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:D0oooo1000000_0?ooo`X00000J`3o
ool002h0oooo1P00000I0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0:H0oooo1000000_0?ooo`<000000`3oool3000006/0oooo000a0?ooo`H000005P3oool60000
00@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3oool0oooo3000002J
0?ooo`@00000;@3oool3000000@0oooo0P00001[0?ooo`00<`3oool7000001<0oooo1`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool<
000009/0oooo1@00000[0?ooo`<00000L@3oool003H0oooo1P00000A0?ooo`<0000000<0oooo0000
000000000P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`3oool2000000P0oooo0P00002M0?ooo`@00000:P3oool300000740oooo000i0?oo
o`H000003P3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00002O0?ooo`@00000:03oool3
000000<0oooo0P00001/0?ooo`00>`3oool7000000/0oooo0`0000020?ooo`<000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P000008
0?ooo`800000X03oool4000002L0oooo2000001/0?ooo`00?P3oool6000000T0oooo0`0000020?oo
o`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0oooo0P0000080?ooo`800000XP3oool4000002D0oooo0`0000030?ooo`800000K03oool0
0440oooo1P0000050?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000X`3oool4
000002@0oooo0`00001a0?ooo`00@`3oool7000000@0oooo1@0000040?ooo`040000003oool0oooo
0?ooo`@000000`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00002U0?ooo`@000008P3o
ool3000000@0oooo0P00001[0?ooo`00AP3oool7000000/0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080oooo3000002V0?ooo`@000008@3oool3000000<0oooo0`00
001[0?ooo`00B@3oool6000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo3000002X0?ooo`@000007P3oool:000006/0oooo001<0?ooo`H000001`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0;P0oooo1@00002A0?ooo`00CP3oool70000
0<P0oooo1000002@0?ooo`00D@3oool600000<P0oooo1000002>0?ooo`00E03oool600000<H0oooo
1000002=0?ooo`00EP3oool700000<D0oooo1000002;0?ooo`00F@3oool600000<@0oooo1000002:
0?ooo`00G03oool600000<<0oooo100000280?ooo`00GP3oool700000<40oooo1@0000260?ooo`00
H@3oool600000<40oooo100000250?ooo`00I03oool600000<00oooo100000230?ooo`00IP3oool7
00000;h0oooo100000220?ooo`00J@3oool600000;h0oooo100000200?ooo`00K03oool600000;`0
oooo1000001o0?ooo`00KP3oool700000;/0oooo1000001m0?ooo`00L@3oool600000;X0oooo1000
001l0?ooo`00M03oool600000;T0oooo1000001j0?ooo`00MP3oool700000;L0oooo1@00001h0?oo
o`00N@3oool600000;L0oooo1000001g0?ooo`00O03oool600000;H0oooo1000001e0?ooo`00OP3o
ool700000;@0oooo1000001d0?ooo`00P@3oool600000;@0oooo1000001b0?ooo`00Q03oool60000
0;80oooo1000001a0?ooo`00QP3oool700000;40oooo1000001_0?ooo`00R@3oool600000;00oooo
1000001^0?ooo`00S03oool600000:l0oooo1000001/0?ooo`00SP3oool700000:d0oooo1@00001Z
0?ooo`00T@3oool600000:d0oooo1000001Y0?ooo`00U03oool600000:`0oooo1000001W0?ooo`00
UP3oool700000:X0oooo1000001V0?ooo`00V@3oool700000:T0oooo1000001T0?ooo`00W03oool6
00000:P0oooo1000001S0?ooo`00W`3oool600000:L0oooo1000001Q0?ooo`00X@3oool700000:D0
oooo1@00001O0?ooo`00Y03oool600000:D0oooo1000001N0?ooo`00Y`3oool600000:@0oooo1000
001L0?ooo`00Z@3oool700000:80oooo1000001K0?ooo`00[03oool600000:80oooo1000001I0?oo
o`00[`3oool600000:00oooo1000001H0?ooo`00/@3oool7000009l0oooo1000001F0?ooo`00]03o
ool6000009h0oooo1000001E0?ooo`00]`3oool6000009d0oooo1000001C0?ooo`00^@3oool70000
09/0oooo1@00001A0?ooo`00_03oool6000009/0oooo1000001@0?ooo`00_`3oool6000009X0oooo
1000001>0?ooo`00`@3oool7000009P0oooo1000001=0?ooo`00a03ooonQ000004`0oooo00370?oo
oih00000C03oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool0
0?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo4@3oool7000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool300000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool2000005L0oooo003o0?oooa40oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?oo
o`000000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000F03oool00?l0oooo4@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo1P0000000`3oool000000?ooo`030?ooo`050000003oool0
oooo0?ooo`000000F03oool00?l0oooo4@3oool7000000030?ooo`000000oooo00<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool2000000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`8000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo0P0000030?ooo`040000003oool0000000000080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`000000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool00000008000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
0`000000oooo000000030?ooo`<000000`3oool00`000000oooo0000000200000080oooo00D00000
0?ooo`00000000000?ooo`03000000H0oooo0P0000030?ooo`030000003oool00000008000000`3o
ool3000005L0oooo003o0?oooa40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1F
0?ooo`00o`3ooolA0?ooo`L000003`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
05H0oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo003o0?oook80oooo0000\
\>"], "Graphics",
  CellMargins->{{Inherited, 243}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`3o0?ooo`X0
oooo001_0?ooo`<00000=03oool2003o0?l0oooo2P3oool006h0oooo0`00000e0?ooo`<00?l0ZP3o
ool20?l005`0oooo000;0?ooo`L0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
00000P3oool3000000040?ooo`0000000000000000l0oooo0`00000e0?ooo`@00?l0ZP3oool20?l0
05`0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P000000
0`3oool000000?ooo`0=0?ooo`<00000=P3oool4003o0:T0oooo0`3o001L0?ooo`002`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo0`00000g0?oo
o`D00?l0Y`3oool30?l005d0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool3000003P0oooo1@00o`2V0?ooo`<0o`00GP3oool000/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`H0000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
1@0000000`3oool000000?ooo`0:0?ooo`<00000>@3oool5003o0:H0oooo0P3o001O0?ooo`002`3o
ool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`0000002P3oool3000003T0oooo1`00o`3o0?ooo`L0oooo000;0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000
000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000090?ooo`<00000>P3oool7003o0?l0oooo1`3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P00
00020?ooo`050000003oool000000000003oool00`0000060?ooo`8000000`3oool00`000000oooo
00000002000000<0oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`<00000
>`3oool7003o0?l0oooo1`3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo0`00000l0?ooo`P00?l0o`3oool60?ooo`002`3oool7
000000l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo0`00000m0?ooo`P00?l0o`3oool60?ooo`00H`3oool3000003d0oooo2@00o`3o0?oo
o`H0oooo001R0?ooo`<00000?P3oool:003o09/0oooo0P3o001W0?ooo`00H@3oool3000003l0oooo
2P00o`2K0?ooo`80o`00I`3oool00640oooo0P0000100?ooo`P00?l0W03oool30?l006L0oooo001P
0?ooo`<00000A@3oool2003o09`0oooo0`3o001X0?ooo`00G`3oool3000004H0oooo0P00o`2K0?oo
o`<0o`00J@3oool005l0oooo0P0000170?ooo`800?l0VP3oool30?l006X0oooo001N0?ooo`<00000
A`3oool2003o09X0oooo0P3o001[0?ooo`00G@3oool3000004P0oooo0P00o`2I0?ooo`<0o`00J`3o
ool005d0oooo0P0000190?ooo`800?l0V03oool30?l006`0oooo001L0?ooo`<00000hP3oool30?l0
06d0oooo001K0?ooo`<00000h`3oool20?l006h0oooo001K0?ooo`800000o`3ooomE0?ooo`00FP3o
ool300000?l0ooooE@3oool005T0oooo0`00003o0?oooeH0oooo001H0?ooo`<00000o`3ooomG0?oo
o`00F03oool200000?l0ooooF03oool005L0oooo0`00001?0?ooo`800?l0T03oool20?l007@0oooo
001F0?ooo`<00000D03oool2003o0900oooo0P3o001d0?ooo`00EP3oool200000540oooo0P00o`2?
0?ooo`<0o`00M03oool005D0oooo0`00001A0?ooo`800?l0SP3oool30?l007D0oooo001D0?ooo`<0
0000DP3oool3003o08`0oooo0`3o001f0?ooo`00E03oool2000005@0oooo0P00o`2;0?ooo`<0o`00
M`3oool005<0oooo0`00001D0?ooo`800?l0RP3oool30?l007P0oooo001B0?ooo`<00000E@3oool2
003o08T0oooo0`3o001i0?ooo`00DP3oool2000005H0oooo0P00o`280?ooo`<0o`00NP3oool00540
oooo0`00001F0?ooo`800?l0Q`3oool30?l007/0oooo001A0?ooo`800000E`3oool3003o08H0oooo
0P3o001l0?ooo`00D@3oool2000005P0oooo0P00o`3o0?ooo`D0oooo001@0?ooo`<00000F03oool2
003o0?l0oooo1@3oool00500oooo0P00001I0?ooo`800?l0o`3oool50?ooo`00D03oool200000?l0
ooooH03oool004l0oooo0`00003o0?ooof00oooo001?0?ooo`800000g03oool20?l00880oooo001?
0?ooo`800000g03oool20?l00880oooo001>0?ooo`<00000f`3oool30?l00880oooo001>0?ooo`80
0000f`3oool30?l008<0oooo001>0?ooo`800000fP3oool30?l008@0oooo001=0?ooo`<00000F`3o
ool2003o07`0oooo0`3o00250?ooo`00C@3oool2000005`0oooo0P00o`1l0?ooo`80o`00QP3oool0
04d0oooo0P00001L0?ooo`800?l0N`3oool30?l008H0oooo001<0?ooo`<00000G03oool2003o07X0
oooo0`3o00270?ooo`00C03oool2000005d0oooo0P00o`1i0?ooo`<0o`00R03oool004`0oooo0P00
001M0?ooo`800?l0N@3oool20?l008T0oooo001;0?ooo`<00000G@3oool2003o0?l0oooo1@3oool0
04/0oooo0P00001N0?ooo`<00?l0o`3oool40?ooo`00B`3oool2000005l0oooo0P00o`3o0?ooo`@0
oooo001:0?ooo`<00000G`3oool2003o0?l0oooo103oool004X0oooo0P00001P0?ooo`800?l0o`3o
ool40?ooo`00BP3oool200000600oooo0P00o`3o0?ooo`@0oooo00190?ooo`<00000H03oool2003o
0?l0oooo103oool004T0oooo0P00001Q0?ooo`800?l0L03oool20?l00940oooo00190?ooo`800000
d`3oool20?l00940oooo00180?ooo`<00000dP3oool30?l00940oooo00180?ooo`800000dP3oool3
0?l00980oooo00180?ooo`800000d@3oool30?l009<0oooo00180?ooo`800000d03oool30?l009@0
oooo00180?ooo`800000d03oool20?l009D0oooo00170?ooo`<00000c`3oool30?l009D0oooo0017
0?ooo`800000c`3oool30?l009H0oooo00170?ooo`800000I@3oool2003o06L0oooo0`3o002G0?oo
o`00A`3oool2000006D0oooo0P00o`1W0?ooo`80o`00V03oool004H0oooo0`00001U0?ooo`800?l0
o`3oool20?ooo`00AP3oool2000006H0oooo0P00o`3o0?ooo`80oooo00160?ooo`800000IP3oool2
003o0?l0oooo0P3oool004H0oooo0P00001V0?ooo`800?l0o`3oool20?ooo`00AP3oool2000006H0
oooo0`00o`1e0?ooo``00000O`3oool004D0oooo0`00001W0?ooo`800?l0HP3ooolP000007h0oooo
00150?ooo`800000J03oool2003o04l0oooo4@0000020?l001@000000P3oool80?3`l0@00000O03o
ool004D0oooo0P00001X0?ooo`800?l0?@3ooolS00000080o`0000<000000?ooo`3oool0703`l?04
000007/0oooo00150?ooo`800000J03oool2003o02X0oooo9P0000030?ooo``0l?3`0`3o000Q0?3`
l0@00000N@3oool004@0oooo0`00001X0?ooo`800?l05`3ooolW00000080oooo7P3`l?030?l002<0
l?3`1000001h0?ooo`00A03oool2000006T0oooo0P00o`050?ooobH000000`3oool_0?3`l0<0o`00
9P3`l?03000000030?3`l03oool0oooo07@0oooo00140?ooo`800000G@3ooolV000000<0oooo@@3`
l?030?l002P0l?3`1000001e0?ooo`00A03oool2000004X0oooo9`0000030?oooe80l?3`0`3o000Z
0?3`l0@0000000<0l?3`0?ooo`3oool0L@3oool004@0oooo0P00000h0?ooobH000000`3ooomT0?3`
l0<0o`00;@3`l?0400000780oooo00130?ooo`<000009@3ooolV000000@0ooooM@3`l?030?l002l0
l?3`100000000`3`l?00oooo0?ooo`0/0?ooo`80000000<0oooo0000000000000P00000k0?ooo`00
@`3oool2000001<0oooo9`0000030?ooohL0l?3`0`3o000b0?3`l0@00000;@3oool400000080oooo
0P00000j0?ooo`00@`3oool2000000X0oooo7@0000040?oooiT0l?3`0P3o000d0?3`l0@00000;03o
ool3000000<0oooo0`00000i0?ooo`00@`3oool2000000X0oooo2P0000040?ooon@0l?3`1000000Z
0?ooo`800000103oool3000003T0oooo00130?ooo`800000303oool600000>/0l?3`1000000^0?oo
o`@00000>@3oool004<0oooo0P00000?0?ooo`H00000>P3`l?0?000000P0l?3`0P0000020?3`l080
0?l0T`3`l?04000002X0oooo1@00000j0?ooo`00@`3oool200000140oooo1`00000W0?3`l0800000
0`3`l?0200000080l?3`0P0000050?3`l18000001@3`l?0200000080l?3`0P00o`2D0?3`l0@00000
9`3oool6000003/0oooo00130?ooo`800000503oool6000002D0l?3`0P0000030?3`l08000000P3`
l?02000001<0l?3`1`0000000`3`l?00000000000002000000040?3`l000o`000?l0003o09D0l?3`
1000000T0?ooo`D00000?@3oool004<0oooo0P00000F0?ooo`030?3`l0000000000000@00000@`3`
l?0900000080l?3`0P00o`1A0?3`l080o`00@`3`l?04000002<0oooo0`0000040?ooo`800000>@3o
ool004<0oooo0P00000I0?ooo`H00000A03`l?0600000080l?3`0P00o`1A0?3`l080o`00A@3`l?03
000000030?3`l03oool0oooo01l0oooo0`0000030?ooo`<00000>@3oool004<0oooo0P00000L0?oo
o`H00000@03`l?08000000040?3`l000o`000?l0003o04T0l?3`0P3o00040?3`l0<0o`00AP3`l?04
00000240oooo0P0000020?ooo`@00000>@3oool004<0oooo0P00000N0?ooo`H00000?@3`l?090000
0080l?3`0P00o`190?3`l0<0o`000P3`l?030?l004P0l?3`100000000`3`l?00oooo0?ooo`0N0?oo
o`@0000000<0oooo000000000000>@3oool004<0oooo0P00000Q0?ooo`H00000>P3`l?09000004`0
l?3`203o001;0?3`l0@00000G`3oool004<0oooo0P00000S0?ooo`L00000>P3`l?07000002L0l?3`
00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00I0?3`l0L0o`00C@3`l?04000000030?3`
l03oool0oooo05/0oooo00130?ooo`8000009P3oool6000003`0l?3`0`00000V0?3`l0030;2`/01P
H600l?3`00H0l?3`00<0d=3@051@D03`l?00603`l?080?l004l0l?3`1000001L0?ooo`00@`3oool2
000002T0oooo1P00001R0?3`l003010@4030`<00l?3`00L0l?3`00<0820P0=3@d03`l?005`3`l?09
0?l004l0l?3`100000000`3`l?00oooo0?ooo`1H0?ooo`00@`3oool2000002/0oooo1P00000Z0?3`
l0030820P03`l?00l?3`00H0l?3`00<0L71`0=3@d03`l?001@3`l?04000001L0l?3`0`000000103`
l?0000000000000000020?3`l0030;2`/00@4100l?3`0080l?3`00@0L71`0000000`<300h>3P0P3`
l?000`1`L700H61P0?3`l00F0?3`l0/0o`00D03`l?04000005T0oooo00120?ooo`<00000;P3oool6
000002H0l?3`00<0/;2`0410@03`l?001`3`l?000`2`/;00D51@0?3`l0030?3`l0P00000503`l?00
0`000000l?3`0?3`l002000000<0l?3`00@000000?3`l01PH600H61P0`3`l?0010000000410@0;2`
/02`/;020?3`l0030;2`/00P8200l?3`01H0l?3`2`3o001A0?3`l0@0000000<0l?3`0?ooo`3oool0
E@3oool00480oooo0P00000a0?ooo`L000008`3`l?000`0P8200X:2P0?3`l0080?3`l003010@403P
h>00l?3`0080l?3`2000000D0?3`l0050000003`l?00l?3`0?3`l00000000`3`l?0010000000l?3`
020P802@T9030?3`l0030000000`<300l?3`00<0l?3`00<0h>3P0000003`l?005P3`l?090?l005D0
l?3`1000001F0?ooo`00@P3oool2000003@0oooo1P00000I0?3`l005030`<01@D500H61P0410@030
`<000P3`l?000`30`<0000000?3`l0030?3`l004071`L0000000820P0<30`080l?3`00<0D51@071`
L03`l?000P3`l?08000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0040000003`l?00
00000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000`<300?3`l00D0?3`l0P0o`00F03`
l?04000000030?3`l03oool0oooo0580oooo00120?ooo`800000=P3oool00`3`l?00000000000004
000001H0l?3`00D0D51@0?3`l03`l?00H61P020P80020?3`l003061PH00`<300l?3`00<0l?3`0P00
00020:2PX080l?3`00<0T92@020P803`l?000P3`l?08000000<0l?3`0`00000>0?3`l0050000003`
l?00l?3`0?3`l00000000`3`l?0010000000l?3`0000002`/;030?3`l0030000000`<300l?3`00@0
l?3`00<000000=3@d03`l?00503`l?070?l005/0l?3`0`0000000`3`l?00oooo0?ooo`1A0?ooo`00
@P3oool2000003T0oooo1P00000D0?3`l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300L71`
0?3`l0030?3`l0030000000`<300l?3`00<0l?3`00<0d=3@0000003`l?00103`l?04000000D0l?3`
1@00000<0?3`l08000000P3`l?000`000000l?3`0?3`l002000000030?3`l0000000/;2`00<0l?3`
00<00000030`<03`l?000`3`l?000`2`/;0000000?3`l00D0?3`l0H0o`00GP3`l?04000000030?3`
l03oool0oooo04l0oooo00120?ooo`800000?03oool600000140l?3`00D0h>3P0410@00000000000
051@D0020?3`l0030000002`/;00l?3`00<0l?3`00<00000030`<03`l?00103`l?000`000000/;2`
0?3`l00>0?3`l0D000002`3`l?02000000<0l?3`0P0000020?3`l005030`<02@T900l?3`0?3`l01P
H6000P0000001P0`<300T92@0?3`l03`l?00T92@030`<1D0l?3`103o001Q0?3`l0@0000000<0l?3`
0?ooo`3oool0CP3oool00480oooo0P00000n0?ooo`H000003`3`l?001@1@D50000000000001@D500
h>3P0080l?3`00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`l0030000002`/;00
l?3`0100l?3`1@00000B0?3`l003071`L01PH600l?3`0080l?3`00<0D51@030`<03`l?000`3`l?00
0`1@D500P8200?3`l00C0?3`l0@0o`00I03`l?04000004l0oooo00120?ooo`800000@@3oool60000
00`0l?3`0P0000000`30`<00l?3`0?3`l0020?3`l0030000002`/;00l?3`00<0l?3`00<00000030`
<03`l?00103`l?000`000000/;2`0?3`l00B0?3`l0D00000403`l?000`3@d=00410@0?3`l0030?3`
l003092@T03`l?00l?3`0080l?3`00<000000>3Ph03`l?004`3`l?020?l006L0l?3`100000000`3`
l?00oooo0?ooo`1;0?ooo`00@P3oool2000004<0oooo1`0000090?3`l005010@401`L700l?3`0?3`
l01@D5000P3`l?000`0P8200T92@0?3`l0030?3`l0030000000`<300l?3`00<0l?3`00<0`<300000
003`l?005@3`l?05000000l0l?3`00<0@4100=3@d03`l?001P3`l?000`2PX:00H61P0?3`l01o0?3`
l0@00000C03oool00480oooo0P0000160?ooo`H000001`3`l?001@30`<00D51@071`L01@D500@410
0080l?3`00<0D51@061PH03`l?000P3`l?001@0`<3000000000000000000<30`0080l?3`00<0T92@
010@403`l?005`3`l?05000000d0l?3`00<0d=3@061PH03`l?001P3`l?000`30`<00h>3P0?3`l020
0?3`l0@0000000<0l?3`0?ooo`3oool0B03oool00480oooo0P0000190?ooo`H000002`3`l?000`2P
X:00820P0?3`l0030?3`l003051@D00`<300l?3`00<0l?3`0P1@D50J0?3`l0D00000303`l?000`3P
h>00l?3`0?3`l02:0?3`l0@00000B@3oool00480oooo0P00001;0?ooo`H000002P3`l?000`0@4100
d=3@0?3`l0030?3`l003092@T03`l?00l?3`0080l?3`00<000000=3@d03`l?006`3`l?05000009P0
l?3`100000000`3`l?00oooo0?ooo`150?ooo`00@P3oool2000004h0oooo1P0000070?3`l003071`
L02@T900l?3`00L0l?3`00<0X:2P030`<03`l?007P3`l?06000009L0l?3`100000160?ooo`00@P3o
ool200000500oooo1P0000050?3`l0030>3Ph00`<300l?3`00L0l?3`00<0L71`0=3@d03`l?00803`
l?07000009D0l?3`100000000`3`l?00oooo0?ooo`120?ooo`00@P3oool2000005<0oooo1P000003
0?3`l0030=3@d03`l?00l?3`02`0l?3`2000000G0?3`l0D00000M`3`l?04000004<0oooo00120?oo
o`800000E@3oool700000380l?3`200000080?3`l0<00000203`l?07000007L0l?3`100000000`3`
l?00oooo0?ooo`0o0?ooo`00@P3oool2000005P0oooo1P00000d0?3`l0P00000103`l?05000000H0
l?3`1`00001i0?3`l0<0000000<0l?3`0?ooo`3oool0?P3oool00480oooo0P00001K0?ooo`H00000
=03`l?08000000030?3`l0000000000000D00000103`l?07000007X0l?3`100000000`3`l?00oooo
0?ooo`0l0?ooo`00@P3oool2000005d0oooo1`00000e0?3`l0d000000`3`l?07000007/0l?3`1000
00000`3`l?00oooo0?ooo`0k0?ooo`00@P3oool3000005l0oooo1P00000f0?3`l0X00000103`l?05
000007h0l?3`100000000`3`l?00oooo0?ooo`0i0?ooo`00@`3oool200000600oooo2000000e0?3`
l0H00000RP3`l?04000000030?3`l03oool0oooo03P0oooo00130?ooo`800000H03oool200000080
oooo1P00000c0?3`l0@00000SP3`l?04000000030?3`l03oool0oooo03H0oooo00130?ooo`800000
G`3oool3000000D0oooo1P00000`0?3`l0800000T@3`l?04000000030?3`l03oool0oooo03D0oooo
00130?ooo`800000G`3oool2000000P0oooo1P0000330?3`l0@0000000<0l?3`0?ooo`3oool0<`3o
ool004<0oooo0P00001N0?ooo`<000002`3oool600000<40l?3`100000000`3`l?00oooo0?ooo`0b
0?ooo`00@`3oool2000005h0oooo0P00000>0?ooo`H00000`@3`l?04000000030?3`l03oool0oooo
0300oooo00130?ooo`<00000L03oool6000003D0l?3`00<0P8200?3`l03`l?00603`l?000`1PH600
d=3@0?3`l01/0?3`l0@0000000<0l?3`0?ooo`3oool0;`3oool004@0oooo0P00001b0?ooo`L00000
<@3`l?000`2PX:00D51@0?3`l00I0?3`l0030;2`/01@D500l?3`06h0l?3`0`0000000`3`l?00oooo
0?ooo`0^0?ooo`00A03oool2000007D0oooo1P00000_0?3`l003020P802PX:00l?3`01X0l?3`00<0
410@0>3Ph03`l?00KP3`l?04000000030?3`l03oool0oooo02`0oooo000P0?ooo`P000001@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00001h0?ooo`H00000903`l?00
1@0`<300D51@061PH010@400`<300080l?3`00<0`<300000003`l?000`3`l?00101`L7000000030`
<030`<030?3`l003071`L0000000l?3`00D0l?3`00H0L71`0410@00000000000051@D02@T9030?3`
l003051@D020P800l?3`06l0l?3`100000000`3`l?00oooo0?ooo`0[0?ooo`008@3oool2000000<0
oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool2000007X0
oooo1P00000R0?3`l005051@D03`l?00l?3`061PH00P82000P3`l?000`1PH600@4100?3`l0030?3`
l08000000P2PX:030?3`l003071`L0000000l?3`00L0l?3`0P0000050?3`l003092@T00P8200l?3`
0740l?3`100000000`3`l?00oooo0?ooo`0Y0?ooo`008@3oool2000000P0oooo0P0000090?ooo`80
0000303oool2000007d0oooo1P00000O0?3`l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300
L71`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0
l?3`00<0d=3@0000003`l?00LP3`l?04000000030?3`l03oool0oooo02P0oooo000Q0?ooo`800000
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00001o0?ooo`H00000
7@3`l?001@3Ph>00@410000000000000D51@0080l?3`00<000000;2`/03`l?000`3`l?0010000000
<30`0?3`l03`l?03071`L003030`<0000000L71`0080L71`00<0/;2`0?3`l03`l?000P3`l?020000
00H0l?3`00<000000;2`/03`l?00L`3`l?04000000030?3`l03oool0oooo02H0oooo000I0?ooo`D0
00000`3oool2000000030?ooo`000000000000@0oooo0P0000050?ooo`800000103oool2000000/0
oooo0P00001G0?ooo`800000:@3oool6000001X0l?3`00D0D51@000000000000D51@0>3Ph0020?3`
l0030000002`/;00l?3`00<0l?3`00@00000030`<03`l?00l?3`200000000`1`L700l?3`0?3`l002
0?3`l08000001P3`l?000`000000/;2`0?3`l01d0?3`l0@0000000<0l?3`0?ooo`3oool09@3oool0
01X0oooo0`0000040?ooo`D00000103oool2000000@0oooo0`0000040?ooo`8000002`3oool30000
05H0oooo0P00000[0?ooo`L000005`3`l?02000000030<30`03`l?00l?3`0080l?3`00<000000;2`
/03`l?000`3`l?000`000000<30`0?3`l0040?3`l003071`L0000000l?3`00L0l?3`0P0000060?3`
l0030000002`/;00l?3`07H0l?3`100000000`3`l?00oooo0?ooo`0S0?ooo`006P3oool3000000@0
oooo0P0000000`3oool00000000000040?ooo`800000103oool2000000D0oooo0P00000<0?ooo`80
0000E@3oool3000002h0oooo1P00000E0?3`l004010@401`L700l?3`051@D0<0l?3`00<0820P0:2P
X03`l?000`3`l?000`000000<30`0?3`l0040?3`l003071`L0000000l?3`00L0l?3`0P0000050?3`
l0030<30`0000000l?3`07P0l?3`100000000`3`l?00oooo0?ooo`0R0?ooo`006P3oool3000000@0
oooo0P0000070?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000E@3oool200000380
oooo1P00000B0?3`l0040<30`00`<300L71`0410@0<0l?3`00<0D51@061PH03`l?000P3`l?001@0`
<3000000000000000000<30`00<0l?3`00<0L71`0000003`l?001`3`l?02000000D0l?3`00<0T92@
010@403`l?00NP3`l?04000000030?3`l03oool0oooo0200oooo000J0?ooo`<00000103oool20000
00<0oooo0P0000020?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000E03oool30000
03@0oooo1P00000G0?3`l003092@T00P8200l?3`00<0l?3`00<0D51@030`<03`l?00103`l?000`2`
/;00L71`0?3`l0070?3`l08000001@3`l?000`1@D500H61P0?3`l01k0?3`l0@0000000<0l?3`0?oo
o`3oool07`3oool001X0oooo0`0000030?ooo`P000000P3oool2000000@0oooo0P0000050?ooo`80
0000303oool2000005@0oooo0P00000h0?ooo`H000005@3`l?000`000000h>3P0?3`l0030?3`l003
092@T03`l?00l?3`00X0l?3`00<0`<30051@D02`/;000P0000050?3`l0030000003@d=00l?3`07d0
l?3`0`0000020?3`l1l0oooo000J0?ooo`<000003@3oool2000000@0oooo0P0000050?ooo`800000
303oool2000005<0oooo0`00000j0?ooo`H000004`3`l?000`1`L700T92@0?3`l00A0?3`l0040>3P
h01PH6000000000000@0l?3`00<0X:2P030`<03`l?00O`3`l?04000000030?3`l03oool0oooo01`0
oooo000J0?ooo`<000003@3oool2000000@0oooo0P0000050?ooo`800000303oool200000580oooo
0`00000n0?ooo`H00000403`l?000`3Ph>00<30`0?3`l00C0?3`l0030;2`/00@4100l?3`00<0l?3`
00<0L71`0=3@d03`l?00P03`l?0400000080l?3`703oool001X0oooo0`00000=0?ooo`8000000`3o
ool4000000@0oooo0P00000<0?ooo`<00000D@3oool200000440oooo1`00000>0?3`l0030=3@d03`
l?00l?3`09d0l?3`100000000`3`l?00oooo0?ooo`0I0?ooo`006P3oool3000000h0oooo00@00000
0?ooo`3oool0oooo100000040?ooo`030000003oool0oooo00`0oooo0P00001@0?ooo`<00000A03o
ool600000:d0l?3`100000020?3`l1T0oooo000J0?ooo`<000003P3oool2000000<0oooo0P000004
0?ooo`8000003P3oool200000500oooo0P0000180?ooo`H00000[03`l?04000000030?3`l03oool0
oooo01H0oooo000I0?ooo`D000003P3oool010000000oooo0?ooo`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool2000004l0oooo0`00001:0?ooo`H00000Z`3`l?0400000080l?3`5P3oool0
02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`800000C`3oool20000
04h0oooo1P00002Z0?3`l0@0000000<0l?3`0?ooo`3oool04`3oool004H0oooo0`00002P0?ooo`L0
0000Z03`l?0400000080l?3`4`3oool004L0oooo0P00002S0?ooo`H00000Z03`l?04000000030?3`
l03oool0oooo0100oooo00170?ooo`800000YP3oool600000:H0l?3`100000000`3`l?00oooo0?oo
o`0?0?ooo`00A`3oool300000:L0oooo1P00002V0?3`l0@0000000<0l?3`0?ooo`3oool03@3oool0
04P0oooo0P00002Z0?ooo`H00000Y03`l?04000000030?3`l03oool0oooo00`0oooo00180?ooo`80
0000[03oool600000:@0l?3`0`0000020?3`l0`0oooo00180?ooo`<00000[P3oool600000:80l?3`
100000000`3`l?00oooo0?ooo`090?ooo`00B@3oool2000004P0oooo0P00001V0?ooo`L00000X03`
l?0400000080l?3`2@3oool004T0oooo0`0000170?ooo`800000J@3oool600000:00l?3`10000000
0`3`l?00oooo0?ooo`060?ooo`00BP3oool2000004H0oooo0`00001/0?ooo`H00000WP3`l?040000
0080l?3`1P3oool004X0oooo0P0000150?ooo`<00000K`3ooonW00000080l?3`1@3oool004X0oooo
0`0000140?ooo`800000L`3ooonT000000<0l?3`103oool004/0oooo0P0000130?ooo`<00000MP3o
oonT0?3`l0@0oooo001;0?ooo`<00000@P3oool200000?l0oooo803oool004`0oooo0P0000110?oo
o`<00000o`3ooolP0?ooo`00C03oool200000400oooo0`00003o0?ooob40oooo001<0?ooo`<00000
?`3oool200000=/0oooo1P0000020?ooo`80000000<0oooo0000003oool00`3oool3000000030?oo
o`000000oooo00<0oooo0P0000030?ooo`8000000P3oool3000000050?ooo`000000oooo0?ooo`00
00001@3oool3000000@0oooo1000000<0?ooo`00C@3oool2000003h0oooo0`0000090?ooo`800000
0`3oool300000<T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool2000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo008000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo001=0?oo
o`800000?P3oool2000000`0oooo00H000000?ooo`3oool000000?ooo`0000390?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo000000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo001=0?ooo`<00000B`3oool010000000oooo0?ooo`00003B0?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000H0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0
oooo0P00000<0?ooo`00CP3oool2000004/0oooo00@000000?ooo`3oool00000d03oool200000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000H0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`H00000
0`3oool2000000h0oooo001>0?ooo`<00000BP3oool010000000oooo0?ooo`00003<0?ooo`@00000
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo001?
0?ooo`800000B03oool00`000000oooo000000020?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo008000000`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02@3oool004l0oooo0P0000190?ooo`L00000b@3o
ool00`000000oooo0?ooo`040?ooo`@0000000H0oooo0000003oool000000?ooo`0000040?ooo`03
0000003oool0oooo0080oooo0`0000001P3oool00000000000000000oooo000000@0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`8000001@3oool4000000`0oooo001?0?ooo`<00000o`3o
oolI0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000005@3oool00`000000oooo0?oo
o`0U0?ooo`00D03oool200000?l0oooo6P3oool600000080oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0U0?ooo`00D03oool2000003D0oooo0P00003o0?ooobT0oooo001@0?ooo`<0
0000=03oool200000?l0oooo:@3oool00540oooo0P00000c0?ooo`<00000o`3ooolY0?ooo`00D@3o
ool300000340oooo0`00003o0?ooobX0oooo001B0?ooo`800000<@3oool200000?l0oooo:`3oool0
0580oooo0`00000_0?ooo`<00000o`3oool[0?ooo`00D`3oool3000002h0oooo0P00003o0?ooob`0
oooo001D0?ooo`800000;@3oool300000?l0oooo;03oool005@0oooo0`00000[0?ooo`<00000o`3o
ool]0?ooo`00E@3oool2000002/0oooo0P00003o0?ooobh0oooo001E0?ooo`<00000:@3oool30000
0?l0oooo;P3oool005H0oooo0P00000Y0?ooo`800000o`3oool_0?ooo`00EP3oool300000?l0oooo
F@3oool005L0oooo0`00003o0?oooeP0oooo001H0?ooo`800000o`3ooomH0?ooo`00F03oool30000
0?l0ooooE`3oool005T0oooo0P00003o0?oooeL0oooo001I0?ooo`<00000o`3ooomF0?ooo`00FP3o
ool300000?l0ooooE@3oool005/0oooo0P00000O0?ooo`800000o`3ooold0?ooo`00F`3oool30000
01h0oooo0P00003o0?oooc@0oooo001L0?ooo`8000007@3oool300000?l0oooo=03oool005`0oooo
0`00000K0?ooo`<00000o`3ooole0?ooo`00G@3oool2000001/0oooo0P00003o0?ooocH0oooo001M
0?ooo`<000005P3oool6000006L0oooo3P0000300?ooo`00GP3oool3000001D0oooo1P00001B0?oo
ob@00000_`3oool005l0oooo0P00000E0?ooo`L00000?03oool[000000`0oooo1000002m0?ooo`00
G`3oool3000001<0oooo2@00000U0?ooob`000008P3oool400000;`0oooo001P0?ooo`8000004`3o
ool900000100oooo;000000i0?ooo`@00000^P3oool007D0oooo;`00001@0?ooo`D00000^03oool0
06@0oooo:`00001W0?ooo`@00000]`3oool004h0oooo;@00001m0?ooo`@00000]@3oool003T0oooo
;000000?0?ooo`H00000O`3oool400000;@0oooo000T0?ooob/00000903oool600000880oooo1000
002b0?ooo`006@3ooolQ000003T0oooo1@0000240?ooo`@00000/@3oool001T0oooo3000001>0?oo
o`@00000Q`3oool400000:l0oooo000K0?ooo`L00000D03oool4000008T0oooo1@00002]0?ooo`00
7P3oool6000004h0oooo0`00002<0?ooo`@00000[03oool00240oooo1P00001;0?ooo`800000S`3o
ool400000:X0oooo000S0?ooo`L00000fP3oool400000:T0oooo000V0?ooo`H00000803oool50000
0;D0oooo1000002W0?ooo`00:@3oool6000001h0oooo0`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0Y03oool400000:H0oooo000[0?ooo`L000006`3oool3000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2U0?ooo`@00000;`3oool:000006/0oooo
000^0?ooo`H000006@3oool3000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2V0?ooo`@00000;`3oool3000000<0oooo0`00001[0?ooo`00<@3oool6000001H0oooo1P000004
0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`040000003oool0oooo0?ooo``00000VP3o
ool4000002d0oooo0`0000040?ooo`800000J`3oool003<0oooo1`00000C0?ooo`L000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo3000
002K0?ooo`D00000:`3oool300000740oooo000f0?ooo`H000004@3oool3000000030?ooo`000000
0000008000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo0P0000080?ooo`800000W@3oool4000002X0oooo0`00001a0?ooo`00>@3oool6
000000h0oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000W`3oool4000002P0oooo0`00
00030?ooo`800000K03oool003/0oooo1`00000;0?ooo`<000000P3oool300000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000203o
ool200000:00oooo1000000W0?ooo`P00000K03oool003h0oooo1P0000090?ooo`<000000P3oool3
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`800000203oool200000:80oooo1000000U0?ooo`<000000`3oool2000006`0oooo0011
0?ooo`H000001@3oool5000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000203oool200000:<0oooo1000
000T0?ooo`<00000L@3oool004<0oooo1`0000040?ooo`D00000103oool010000000oooo0?ooo`3o
ool4000000<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000Y@3oool400000280oooo
0`0000040?ooo`800000J`3oool004H0oooo1`00000;0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo``00000YP3oool400000240oooo0`0000030?ooo`<00000
J`3oool004T0oooo1P0000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo``00000Z03oool4000001h0oooo2P00001[0?ooo`00C03oool6000000L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2h0?ooo`D00000T@3oool004h0oooo1`000038
0?ooo`@00000T03oool00540oooo1P0000380?ooo`@00000SP3oool005@0oooo1P0000360?ooo`@0
0000S@3oool005H0oooo1`0000350?ooo`@00000R`3oool005T0oooo1P0000340?ooo`@00000RP3o
ool005`0oooo1P0000330?ooo`@00000R03oool005h0oooo1`0000310?ooo`D00000QP3oool00640
oooo1P0000310?ooo`@00000Q@3oool006@0oooo1P0000300?ooo`@00000P`3oool006H0oooo1`00
002n0?ooo`@00000PP3oool006T0oooo1P00002n0?ooo`@00000P03oool006`0oooo1P00002l0?oo
o`@00000O`3oool006h0oooo1`00002k0?ooo`@00000O@3oool00740oooo1P00002j0?ooo`@00000
O03oool007@0oooo1P00002i0?ooo`@00000NP3oool007H0oooo1`00002g0?ooo`D00000N03oool0
07T0oooo1P00002g0?ooo`@00000M`3oool007`0oooo1P00002f0?ooo`@00000M@3oool007h0oooo
1`00002d0?ooo`@00000M03oool00840oooo1P00002d0?ooo`@00000LP3oool008@0oooo1P00002b
0?ooo`@00000L@3oool008H0oooo1`00002a0?ooo`@00000K`3oool008T0oooo1P00002`0?ooo`@0
0000KP3oool008`0oooo1P00002_0?ooo`@00000K03oool008h0oooo1`00002]0?ooo`D00000JP3o
ool00940oooo1P00002]0?ooo`@00000J@3oool009@0oooo1P00002/0?ooo`@00000I`3oool009H0
oooo1`00002Z0?ooo`@00000IP3oool009T0oooo1`00002Y0?ooo`@00000I03oool009`0oooo1P00
002X0?ooo`@00000H`3oool009l0oooo1P00002W0?ooo`@00000H@3oool00:40oooo1`00002U0?oo
o`D00000G`3oool00:@0oooo1P00002U0?ooo`@00000GP3oool00:L0oooo1P00002T0?ooo`@00000
G03oool00:T0oooo1`00002R0?ooo`@00000F`3oool00:`0oooo1P00002R0?ooo`@00000F@3oool0
0:l0oooo1P00002P0?ooo`@00000F03oool00;40oooo1`00002O0?ooo`@00000EP3oool00;@0oooo
1P00002N0?ooo`@00000E@3oool00;L0oooo1P00002M0?ooo`@00000D`3oool00;T0oooo1`00002K
0?ooo`D00000D@3oool00;`0oooo1P00002K0?ooo`@00000D03oool00;l0oooo1P00002J0?ooo`@0
0000CP3oool00<40oooo1`00002H0?ooo`@00000C@3oool00<@0ooooX@00001<0?ooo`00a`3ooonN
000004`0oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o
0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oooa40oooo1`0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P00001G0?ooo`00o`3ooolA0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0
000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000005P0
oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`H0000000<0oooo0000003oool00`3oool01@000000oooo0?oo
o`3oool0000005P0oooo003o0?oooa40oooo1`0000000`3oool000000?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo0000001H0?ooo`00o`3ooolA0?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000000000020?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`8000000`3oool01@00
0000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003o
ool000000000003oool00`0000060?ooo`8000000`3oool00`000000oooo00000002000000<0oooo
0`00001G0?ooo`00o`3ooolA0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0EP3o
ool00?l0oooo4@3oool7000000l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1F
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`3o0?ooo`X0
oooo001_0?ooo`<00000=03oool2003o0?l0oooo2P3oool006h0oooo0`00000e0?ooo`<00?l0ZP3o
ool20?l005`0oooo000;0?ooo`L0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
00000P3oool3000000040?ooo`0000000000000000l0oooo0`00000e0?ooo`@00?l0ZP3oool20?l0
05`0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P000000
0`3oool000000?ooo`0=0?ooo`<00000=P3oool4003o0:T0oooo0`3o001L0?ooo`002`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo0`00000g0?oo
o`D00?l0Y`3oool30?l005d0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool3000003P0oooo1@00o`2V0?ooo`<0o`00GP3oool000/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`H0000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
1@0000000`3oool000000?ooo`0:0?ooo`<00000>@3oool5003o0:H0oooo0P3o001O0?ooo`002`3o
ool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`0000002P3oool3000003T0oooo1`00o`3o0?ooo`L0oooo000;0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000
000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000090?ooo`<00000>P3oool7003o0?l0oooo1`3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P00
00020?ooo`050000003oool000000000003oool00`0000060?ooo`8000000`3oool00`000000oooo
00000002000000<0oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`<00000
>`3oool7003o0?l0oooo1`3oool000/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo0`00000l0?ooo`P00?l0o`3oool60?ooo`002`3oool7
000000l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo0`00000m0?ooo`P00?l0o`3oool60?ooo`00H`3oool3000003d0oooo2@00o`3o0?oo
o`H0oooo001R0?ooo`<00000?P3oool:003o09/0oooo0P3o001W0?ooo`00H@3oool3000003l0oooo
2P00o`2K0?ooo`80o`00I`3oool00640oooo0P0000100?ooo`P00?l0W03oool30?l006L0oooo001P
0?ooo`<00000A@3oool2003o09`0oooo0`3o001X0?ooo`00G`3oool3000004H0oooo0P00o`2K0?oo
o`<0o`00J@3oool005l0oooo0P0000170?ooo`800?l0VP3oool30?l006X0oooo001N0?ooo`<00000
A`3oool2003o09X0oooo0P3o001[0?ooo`00G@3oool3000004P0oooo0P00o`2I0?ooo`<0o`00J`3o
ool005d0oooo0P0000190?ooo`800?l0V03oool30?l006`0oooo001L0?ooo`<00000hP3oool30?l0
06d0oooo001K0?ooo`<00000h`3oool20?l006h0oooo001K0?ooo`800000o`3ooomE0?ooo`00FP3o
ool300000?l0ooooE@3oool005T0oooo0`00003o0?oooeH0oooo001H0?ooo`<00000o`3ooomG0?oo
o`00F03oool200000?l0ooooF03oool005L0oooo0`00001?0?ooo`800?l0T03oool20?l007@0oooo
001F0?ooo`<00000D03oool2003o0900oooo0P3o001d0?ooo`00EP3oool200000540oooo0P00o`2?
0?ooo`<0o`00M03oool005D0oooo0`00001A0?ooo`800?l0SP3oool30?l007D0oooo001D0?ooo`<0
0000DP3oool3003o08`0oooo0`3o001f0?ooo`00E03oool2000005@0oooo0P00o`2;0?ooo`<0o`00
M`3oool005<0oooo0`00001D0?ooo`800?l0RP3oool30?l007P0oooo001B0?ooo`<00000E@3oool2
003o08T0oooo0`3o001i0?ooo`00DP3oool2000005H0oooo0P00o`280?ooo`<0o`00NP3oool00540
oooo0`00001F0?ooo`800?l0Q`3oool30?l007/0oooo001A0?ooo`800000E`3oool3003o08H0oooo
0P3o001l0?ooo`00D@3oool2000005P0oooo0P00o`3o0?ooo`D0oooo001@0?ooo`<00000F03oool2
003o0?l0oooo1@3oool00500oooo0P00001I0?ooo`800?l0o`3oool50?ooo`00D03oool200000?l0
ooooH03oool004l0oooo0`00003o0?ooof00oooo001?0?ooo`800000g03oool20?l00880oooo001?
0?ooo`800000g03oool20?l00880oooo001>0?ooo`<00000f`3oool30?l00880oooo001>0?ooo`80
0000f`3oool30?l008<0oooo001>0?ooo`800000fP3oool30?l008@0oooo001=0?ooo`<00000F`3o
ool2003o07`0oooo0`3o00250?ooo`00C@3oool2000005`0oooo0P00o`1l0?ooo`80o`00QP3oool0
04d0oooo0P00001L0?ooo`800?l0N`3oool30?l008H0oooo001<0?ooo`<00000G03oool2003o07X0
oooo0`3o00270?ooo`00C03oool2000005d0oooo0P00o`1i0?ooo`<0o`00R03oool004`0oooo0P00
001M0?ooo`800?l0N@3oool20?l008T0oooo001;0?ooo`<00000G@3oool2003o0?l0oooo1@3oool0
04/0oooo0P00001N0?ooo`<00?l0o`3oool40?ooo`00B`3oool2000005l0oooo0P00o`3o0?ooo`@0
oooo001:0?ooo`<00000G`3oool2003o0?l0oooo103oool004X0oooo0P00001P0?ooo`800?l0o`3o
ool40?ooo`00BP3oool200000600oooo0P00o`3o0?ooo`@0oooo00190?ooo`<00000H03oool2003o
0?l0oooo103oool004T0oooo0P00001Q0?ooo`800?l0L03oool20?l00940oooo00190?ooo`800000
d`3oool20?l00940oooo00180?ooo`<00000dP3oool30?l00940oooo00180?ooo`800000dP3oool3
0?l00980oooo00180?ooo`800000d@3oool30?l009<0oooo00180?ooo`800000d03oool30?l009@0
oooo00180?ooo`800000d03oool20?l009D0oooo00170?ooo`<00000c`3oool30?l009D0oooo0017
0?ooo`800000c`3oool30?l009H0oooo00170?ooo`800000I@3oool2003o06L0oooo0`3o002G0?oo
o`00A`3oool2000006D0oooo0P00o`1W0?ooo`80o`00V03oool004H0oooo0`00001U0?ooo`800?l0
o`3oool20?ooo`00AP3oool2000006H0oooo0P00o`3o0?ooo`80oooo00160?ooo`800000IP3oool2
003o0?l0oooo0P3oool004H0oooo0P00001V0?ooo`800?l0o`3oool20?ooo`00AP3oool2000006H0
oooo0`00o`1e0?ooo``00000O`3oool004D0oooo0`00001W0?ooo`800?l0HP3ooolP000007h0oooo
00150?ooo`800000J03oool2003o04l0oooo4@0000020?l001@000000P3oool80?3`l0@00000O03o
ool004D0oooo0P00001X0?ooo`800?l0?@3ooolS00000080o`0000<000000?ooo`3oool0703`l?04
000007/0oooo00150?ooo`800000J03oool2003o02X0oooo9P0000030?ooo``0l?3`0`3o000Q0?3`
l0@00000N@3oool004@0oooo0`00001X0?ooo`800?l05`3ooolW00000080oooo7P3`l?030?l002<0
l?3`1000001h0?ooo`00A03oool2000006T0oooo0P00o`050?ooobH000000`3oool_0?3`l0<0o`00
9P3`l?03000000030?3`l03oool0oooo07@0oooo00140?ooo`800000G@3ooolV000000<0oooo@@3`
l?030?l002P0l?3`1000001e0?ooo`00A03oool2000004X0oooo9`0000030?oooe80l?3`0`3o000Z
0?3`l0@0000000<0l?3`0?ooo`3oool0L@3oool004@0oooo0P00000h0?ooobH000000`3ooomT0?3`
l0<0o`00;@3`l?0400000780oooo00130?ooo`<000009@3ooolV000000@0ooooM@3`l?030?l002l0
l?3`100000000`3`l?00oooo0?ooo`0/0?ooo`80000000<0oooo0000000000000P00000k0?ooo`00
@`3oool2000001<0oooo9`0000030?ooohL0l?3`0`3o000b0?3`l0@00000;@3oool400000080oooo
0P00000j0?ooo`00@`3oool2000000X0oooo7@0000040?oooiT0l?3`0P3o000d0?3`l0@00000;03o
ool3000000<0oooo0`00000i0?ooo`00@`3oool2000000X0oooo2P0000040?ooon@0l?3`1000000Z
0?ooo`800000103oool3000003T0oooo00130?ooo`800000303oool600000>/0l?3`1000000^0?oo
o`@00000>@3oool004<0oooo0P00000?0?ooo`H00000>P3`l?0?000000P0l?3`0P0000020?3`l080
0?l0T`3`l?04000002X0oooo1@00000j0?ooo`00@`3oool200000140oooo1`00000W0?3`l0800000
0`3`l?0200000080l?3`0P0000050?3`l18000001@3`l?0200000080l?3`0P00o`2D0?3`l0@00000
9`3oool6000003/0oooo00130?ooo`800000503oool6000002D0l?3`0P0000030?3`l08000000P3`
l?02000001<0l?3`1`0000000`3`l?00000000000002000000040?3`l000o`000?l0003o09D0l?3`
1000000T0?ooo`D00000?@3oool004<0oooo0P00000F0?ooo`030?3`l0000000000000@00000@`3`
l?0900000080l?3`0P00o`1A0?3`l080o`00@`3`l?04000002<0oooo0`0000040?ooo`800000>@3o
ool004<0oooo0P00000I0?ooo`H00000A03`l?0600000080l?3`0P00o`1A0?3`l080o`00A@3`l?03
000000030?3`l03oool0oooo01l0oooo0`0000030?ooo`<00000>@3oool004<0oooo0P00000L0?oo
o`H00000@03`l?08000000040?3`l000o`000?l0003o04T0l?3`0P3o00040?3`l0<0o`00AP3`l?04
00000240oooo0P0000020?ooo`@00000>@3oool004<0oooo0P00000N0?ooo`H00000?@3`l?090000
0080l?3`0P00o`190?3`l0<0o`000P3`l?030?l004P0l?3`100000000`3`l?00oooo0?ooo`0N0?oo
o`@0000000<0oooo000000000000>@3oool004<0oooo0P00000Q0?ooo`H00000>P3`l?09000004`0
l?3`203o001;0?3`l0@00000G`3oool004<0oooo0P00000S0?ooo`L00000>P3`l?07000002L0l?3`
00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00I0?3`l0L0o`00C@3`l?04000000030?3`
l03oool0oooo05/0oooo00130?ooo`8000009P3oool6000003`0l?3`0`00000V0?3`l0030;2`/01P
H600l?3`00H0l?3`00<0d=3@051@D03`l?00603`l?080?l004l0l?3`1000001L0?ooo`00@`3oool2
000002T0oooo1P00001R0?3`l003010@4030`<00l?3`00L0l?3`00<0820P0=3@d03`l?005`3`l?09
0?l004l0l?3`100000000`3`l?00oooo0?ooo`1H0?ooo`00@`3oool2000002/0oooo1P00000Z0?3`
l0030820P03`l?00l?3`00H0l?3`00<0L71`0=3@d03`l?001@3`l?04000001L0l?3`0`000000103`
l?0000000000000000020?3`l0030;2`/00@4100l?3`0080l?3`00@0L71`0000000`<300h>3P0P3`
l?000`1`L700H61P0?3`l00F0?3`l0/0o`00D03`l?04000005T0oooo00120?ooo`<00000;P3oool6
000002H0l?3`00<0/;2`0410@03`l?001`3`l?000`2`/;00D51@0?3`l0030?3`l0P00000503`l?00
0`000000l?3`0?3`l002000000<0l?3`00@000000?3`l01PH600H61P0`3`l?0010000000410@0;2`
/02`/;020?3`l0030;2`/00P8200l?3`01H0l?3`2`3o001A0?3`l0@0000000<0l?3`0?ooo`3oool0
E@3oool00480oooo0P00000a0?ooo`L000008`3`l?000`0P8200X:2P0?3`l0080?3`l003010@403P
h>00l?3`0080l?3`2000000D0?3`l0050000003`l?00l?3`0?3`l00000000`3`l?0010000000l?3`
020P802@T9030?3`l0030000000`<300l?3`00<0l?3`00<0h>3P0000003`l?005P3`l?090?l005D0
l?3`1000001F0?ooo`00@P3oool2000003@0oooo1P00000I0?3`l005030`<01@D500H61P0410@030
`<000P3`l?000`30`<0000000?3`l0030?3`l004071`L0000000820P0<30`080l?3`00<0D51@071`
L03`l?000P3`l?08000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0040000003`l?00
00000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000`<300?3`l00D0?3`l0P0o`00F03`
l?04000000030?3`l03oool0oooo0580oooo00120?ooo`800000=P3oool00`3`l?00000000000004
000001H0l?3`00D0D51@0?3`l03`l?00H61P020P80020?3`l003061PH00`<300l?3`00<0l?3`0P00
00020:2PX080l?3`00<0T92@020P803`l?000P3`l?08000000<0l?3`0`00000>0?3`l0050000003`
l?00l?3`0?3`l00000000`3`l?0010000000l?3`0000002`/;030?3`l0030000000`<300l?3`00@0
l?3`00<000000=3@d03`l?00503`l?070?l005/0l?3`0`0000000`3`l?00oooo0?ooo`1A0?ooo`00
@P3oool2000003T0oooo1P00000D0?3`l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300L71`
0?3`l0030?3`l0030000000`<300l?3`00<0l?3`00<0d=3@0000003`l?00103`l?04000000D0l?3`
1@00000<0?3`l08000000P3`l?000`000000l?3`0?3`l002000000030?3`l0000000/;2`00<0l?3`
00<00000030`<03`l?000`3`l?000`2`/;0000000?3`l00D0?3`l0H0o`00GP3`l?04000000030?3`
l03oool0oooo04l0oooo00120?ooo`800000?03oool600000140l?3`00D0h>3P0410@00000000000
051@D0020?3`l0030000002`/;00l?3`00<0l?3`00<00000030`<03`l?00103`l?000`000000/;2`
0?3`l00>0?3`l0D000002`3`l?02000000<0l?3`0P0000020?3`l005030`<02@T900l?3`0?3`l01P
H6000P0000001P0`<300T92@0?3`l03`l?00T92@030`<1D0l?3`103o001Q0?3`l0@0000000<0l?3`
0?ooo`3oool0CP3oool00480oooo0P00000n0?ooo`H000003`3`l?001@1@D50000000000001@D500
h>3P0080l?3`00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`l0030000002`/;00
l?3`0100l?3`1@00000B0?3`l003071`L01PH600l?3`0080l?3`00<0D51@030`<03`l?000`3`l?00
0`1@D500P8200?3`l00C0?3`l0@0o`00I03`l?04000004l0oooo00120?ooo`800000@@3oool60000
00`0l?3`0P0000000`30`<00l?3`0?3`l0020?3`l0030000002`/;00l?3`00<0l?3`00<00000030`
<03`l?00103`l?000`000000/;2`0?3`l00B0?3`l0D00000403`l?000`3@d=00410@0?3`l0030?3`
l003092@T03`l?00l?3`0080l?3`00<000000>3Ph03`l?004`3`l?020?l006L0l?3`100000000`3`
l?00oooo0?ooo`1;0?ooo`00@P3oool2000004<0oooo1`0000090?3`l005010@401`L700l?3`0?3`
l01@D5000P3`l?000`0P8200T92@0?3`l0030?3`l0030000000`<300l?3`00<0l?3`00<0`<300000
003`l?005@3`l?05000000l0l?3`00<0@4100=3@d03`l?001P3`l?000`2PX:00H61P0?3`l01o0?3`
l0@00000C03oool00480oooo0P0000160?ooo`H000001`3`l?001@30`<00D51@071`L01@D500@410
0080l?3`00<0D51@061PH03`l?000P3`l?001@0`<3000000000000000000<30`0080l?3`00<0T92@
010@403`l?005`3`l?05000000d0l?3`00<0d=3@061PH03`l?001P3`l?000`30`<00h>3P0?3`l020
0?3`l0@0000000<0l?3`0?ooo`3oool0B03oool00480oooo0P0000190?ooo`H000002`3`l?000`2P
X:00820P0?3`l0030?3`l003051@D00`<300l?3`00<0l?3`0P1@D50J0?3`l0D00000303`l?000`3P
h>00l?3`0?3`l02:0?3`l0@00000B@3oool00480oooo0P00001;0?ooo`H000002P3`l?000`0@4100
d=3@0?3`l0030?3`l003092@T03`l?00l?3`0080l?3`00<000000=3@d03`l?006`3`l?05000009P0
l?3`100000000`3`l?00oooo0?ooo`150?ooo`00@P3oool2000004h0oooo1P0000070?3`l003071`
L02@T900l?3`00L0l?3`00<0X:2P030`<03`l?007P3`l?06000009L0l?3`100000160?ooo`00@P3o
ool200000500oooo1P0000050?3`l0030>3Ph00`<300l?3`00L0l?3`00<0L71`0=3@d03`l?00803`
l?07000009D0l?3`100000000`3`l?00oooo0?ooo`120?ooo`00@P3oool2000005<0oooo1P000003
0?3`l0030=3@d03`l?00l?3`02`0l?3`2000000G0?3`l0D00000M`3`l?04000004<0oooo00120?oo
o`800000E@3oool700000380l?3`200000080?3`l0<00000203`l?07000007L0l?3`100000000`3`
l?00oooo0?ooo`0o0?ooo`00@P3oool2000005P0oooo1P00000d0?3`l0P00000103`l?05000000H0
l?3`1`00001i0?3`l0<0000000<0l?3`0?ooo`3oool0?P3oool00480oooo0P00001K0?ooo`H00000
=03`l?08000000030?3`l0000000000000D00000103`l?07000007X0l?3`100000000`3`l?00oooo
0?ooo`0l0?ooo`00@P3oool2000005d0oooo1`00000e0?3`l0d000000`3`l?07000007/0l?3`1000
00000`3`l?00oooo0?ooo`0k0?ooo`00@P3oool3000005l0oooo1P00000f0?3`l0X00000103`l?05
000007h0l?3`100000000`3`l?00oooo0?ooo`0i0?ooo`00@`3oool200000600oooo2000000e0?3`
l0H00000RP3`l?04000000030?3`l03oool0oooo03P0oooo00130?ooo`800000H03oool200000080
oooo1P00000c0?3`l0@00000SP3`l?04000000030?3`l03oool0oooo03H0oooo00130?ooo`800000
G`3oool3000000D0oooo1P00000`0?3`l0800000T@3`l?04000000030?3`l03oool0oooo03D0oooo
00130?ooo`800000G`3oool2000000P0oooo1P0000330?3`l0@0000000<0l?3`0?ooo`3oool0<`3o
ool004<0oooo0P00001N0?ooo`<000002`3oool600000<40l?3`100000000`3`l?00oooo0?ooo`0b
0?ooo`00@`3oool2000005h0oooo0P00000>0?ooo`H00000`@3`l?04000000030?3`l03oool0oooo
0300oooo00130?ooo`<00000L03oool6000003D0l?3`00<0P8200?3`l03`l?00603`l?000`1PH600
d=3@0?3`l01/0?3`l0@0000000<0l?3`0?ooo`3oool0;`3oool004@0oooo0P00001b0?ooo`L00000
<@3`l?000`2PX:00D51@0?3`l00I0?3`l0030;2`/01@D500l?3`06h0l?3`0`0000000`3`l?00oooo
0?ooo`0^0?ooo`00A03oool2000007D0oooo1P00000_0?3`l003020P802PX:00l?3`01X0l?3`00<0
410@0>3Ph03`l?00KP3`l?04000000030?3`l03oool0oooo02`0oooo000P0?ooo`P000001@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0P00001h0?ooo`H00000903`l?00
1@0`<300D51@061PH010@400`<300080l?3`00<0`<300000003`l?000`3`l?00101`L7000000030`
<030`<030?3`l003071`L0000000l?3`00D0l?3`00H0L71`0410@00000000000051@D02@T9030?3`
l003051@D020P800l?3`06l0l?3`100000000`3`l?00oooo0?ooo`0[0?ooo`008@3oool2000000<0
oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool2000007X0
oooo1P00000R0?3`l005051@D03`l?00l?3`061PH00P82000P3`l?000`1PH600@4100?3`l0030?3`
l08000000P2PX:030?3`l003071`L0000000l?3`00L0l?3`0P0000050?3`l003092@T00P8200l?3`
0740l?3`100000000`3`l?00oooo0?ooo`0Y0?ooo`008@3oool2000000P0oooo0P0000090?ooo`80
0000303oool2000007d0oooo1P00000O0?3`l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300
L71`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0
l?3`00<0d=3@0000003`l?00LP3`l?04000000030?3`l03oool0oooo02P0oooo000Q0?ooo`800000
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P00001o0?ooo`H00000
7@3`l?001@3Ph>00@410000000000000D51@0080l?3`00<000000;2`/03`l?000`3`l?0010000000
<30`0?3`l03`l?03071`L003030`<0000000L71`0080L71`00<0/;2`0?3`l03`l?000P3`l?020000
00H0l?3`00<000000;2`/03`l?00L`3`l?04000000030?3`l03oool0oooo02H0oooo000I0?ooo`D0
00000`3oool2000000030?ooo`000000000000@0oooo0P0000050?ooo`800000103oool2000000/0
oooo0P00001G0?ooo`800000:@3oool6000001X0l?3`00<0D51@0000000000000P0000020?3`l003
0000002`/;00l?3`00<0l?3`00@00000030`<03`l?00l?3`200000000`1`L700l?3`0?3`l0020?3`
l08000001P3`l?000`000000/;2`0?3`l01d0?3`l0@0000000<0l?3`0?ooo`3oool09@3oool001X0
oooo0`0000040?ooo`D00000103oool2000000@0oooo0`0000040?ooo`8000002`3oool3000005H0
oooo0P00000[0?ooo`L000005`3`l?02000000030<30`000000000000080l?3`00<000000;2`/03`
l?000`3`l?000`000000<30`0?3`l0040?3`l003071`L0000000l?3`00L0l?3`0P0000060?3`l003
0000002`/;00l?3`07H0l?3`100000000`3`l?00oooo0?ooo`0S0?ooo`006P3oool3000000@0oooo
0P0000000`3oool00000000000040?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000
E@3oool3000002h0oooo1P00000E0?3`l003010@401`L700l?3`008000000P3`l?000`0P8200X:2P
0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0l?3`
00<0`<300000003`l?00N03`l?04000000030?3`l03oool0oooo0280oooo000J0?ooo`<00000103o
ool2000000L0oooo0P0000040?ooo`8000001@3oool2000000`0oooo0P00001E0?ooo`800000<P3o
ool600000180l?3`00<0`<30030`<01`L7000P0000020?3`l003051@D01PH600l?3`0080l?3`00D0
<30`0000000000000000030`<0030?3`l003071`L0000000l?3`00L0l?3`0P0000050?3`l003092@
T00@4100l?3`07X0l?3`100000000`3`l?00oooo0?ooo`0P0?ooo`006P3oool3000000@0oooo0P00
00030?ooo`8000000P3oool2000000@0oooo0P0000050?ooo`800000303oool2000005@0oooo0`00
000d0?ooo`H000004P3`l?0300000080l?3`00<0T92@020P803`l?000`3`l?000`1@D500<30`0?3`
l0040?3`l0030;2`/01`L700l?3`00L0l?3`0P0000050?3`l003051@D01PH600l?3`07/0l?3`1000
00000`3`l?00oooo0?ooo`0O0?ooo`006P3oool3000000<0oooo200000020?ooo`800000103oool2
000000D0oooo0P00000<0?ooo`800000E03oool2000003P0oooo1P00000?0?3`l0800000103`l?00
0`000000h>3P0?3`l0030?3`l003092@T03`l?00l?3`00X0l?3`00<0`<30051@D02`/;000P000005
0?3`l0030000003@d=00l?3`07d0l?3`0`0000020?3`l1l0oooo000J0?ooo`<000003@3oool20000
00@0oooo0P0000050?ooo`800000303oool2000005<0oooo0`00000j0?ooo`H000003@3`l?020000
00@0l?3`00<0L71`092@T03`l?004@3`l?00103Ph>00H61P0000000000040?3`l0030:2PX00`<300
l?3`07l0l?3`100000000`3`l?00oooo0?ooo`0L0?ooo`006P3oool3000000d0oooo0P0000040?oo
o`8000001@3oool2000000`0oooo0P00001B0?ooo`<00000?P3oool6000000X0l?3`0P0000040?3`
l0030>3Ph00`<300l?3`01<0l?3`00<0/;2`010@403`l?000`3`l?000`1`L700d=3@0?3`l0200?3`
l0@000000P3`l?0L0?ooo`006P3oool3000000d0oooo0P0000030?ooo`@00000103oool2000000`0
oooo0`00001A0?ooo`800000@@3oool7000000h0l?3`00<0d=3@0?3`l03`l?00W@3`l?0400000003
0?3`l03oool0oooo01T0oooo000J0?ooo`<000003P3oool010000000oooo0?ooo`3oool4000000@0
oooo00<000000?ooo`3oool0303oool200000500oooo0`0000140?ooo`H00000[@3`l?0400000080
l?3`6@3oool001X0oooo0`00000>0?ooo`8000000`3oool2000000@0oooo0P00000>0?ooo`800000
D03oool2000004P0oooo1P00002/0?3`l0@0000000<0l?3`0?ooo`3oool05P3oool001T0oooo1@00
000>0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`800000
C`3oool3000004X0oooo1P00002[0?3`l0@000000P3`l?0F0?ooo`00;@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo0P00001?0?ooo`800000CP3oool600000:X0l?3`1000
00000`3`l?00oooo0?ooo`0C0?ooo`00AP3oool300000:00oooo1`00002X0?3`l0@000000P3`l?0C
0?ooo`00A`3oool200000:<0oooo1P00002X0?3`l0@0000000<0l?3`0?ooo`3oool0403oool004L0
oooo0P00002V0?ooo`H00000YP3`l?04000000030?3`l03oool0oooo00l0oooo00170?ooo`<00000
Y`3oool600000:H0l?3`100000000`3`l?00oooo0?ooo`0=0?ooo`00B03oool2000009d0oooo0P00
000;0?ooo`H00000Y03`l?04000000030?3`l03oool0oooo00`0oooo00180?ooo`800000W@3oool2
000000d0oooo1P00002T0?3`l0<000000P3`l?0<0?ooo`00B03oool3000009`0oooo0P00000@0?oo
o`H00000XP3`l?04000000030?3`l03oool0oooo00T0oooo00190?ooo`800000B03oool200000540
oooo0`00000B0?ooo`L00000X03`l?0400000080l?3`2@3oool004T0oooo0`0000170?ooo`800000
D@3oool2000001H0oooo1P00002P0?3`l0@0000000<0l?3`0?ooo`3oool01P3oool004X0oooo0P00
00160?ooo`<00000D@3oool2000001T0oooo1P00002N0?3`l0@000000P3`l?060?ooo`00BP3oool2
000004D0oooo0`00001A0?ooo`<000006`3ooonW00000080l?3`1@3oool004X0oooo0`0000140?oo
o`800000DP3oool2000001l0ooooY00000030?3`l0@0oooo001;0?ooo`800000@`3oool300000580
oooo0P00000R0?oooj@0l?3`103oool004/0oooo0`0000120?ooo`800000D`3oool200000<X0oooo
001<0?ooo`800000@@3oool300000580oooo0`00003:0?ooo`00C03oool200000400oooo0`00001C
0?ooo`800000b`3oool004`0oooo0`00000o0?ooo`800000E03oool2000008D0oooo1P0000020?oo
o`80000000<0oooo0000003oool00`3oool3000000030?ooo`000000oooo00<0oooo0P0000030?oo
o`8000000P3oool3000000050?ooo`000000oooo0?ooo`0000001@3oool3000000@0oooo1000000<
0?ooo`00C@3oool2000003h0oooo0`0000090?ooo`8000000`3oool300000<T0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool2
000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo001=0?ooo`800000?P3oool2000000`0oooo00H0
00000?ooo`3oool000000?ooo`0000390?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo001=0?ooo`<00000B`3oool0
10000000oooo0?ooo`00003B0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo0P00000<0?ooo`00CP3oool20000
04/0oooo00@000000?ooo`3oool00000d03oool200000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000030?ooo`H000000`3oool2000000h0oooo001>0?ooo`<0
0000BP3oool010000000oooo0?ooo`00003<0?ooo`@00000103oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000100oooo001?0?ooo`800000B03oool00`000000oooo
000000020?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
00000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool004l0oooo0P0000190?ooo`L00000b@3oool00`000000oooo0?ooo`040?ooo`@0
000000H0oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo0080oooo0`000000
1P3oool00000000000000000oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`8000001@3oool4000000`0oooo001?0?ooo`<00000o`3ooolI0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0U0?ooo`00D03oool200000?l0oooo
6P3oool600000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0U0?ooo`00D03o
ool2000003D0oooo0P00001H0?ooo`800000cP3oool00500oooo0`00000d0?ooo`800000F03oool2
00000<h0oooo001A0?ooo`800000<`3oool3000005P0oooo0P00003>0?ooo`00D@3oool300000340
oooo0`00001H0?ooo`<00000cP3oool00580oooo0P00000a0?ooo`800000F@3oool200000<l0oooo
001B0?ooo`<00000;`3oool3000005T0oooo0P00003?0?ooo`00D`3oool3000002h0oooo0P00001J
0?ooo`800000c`3oool005@0oooo0P00000]0?ooo`<00000F@3oool300000<l0oooo001D0?ooo`<0
0000:`3oool3000005X0oooo0P00003@0?ooo`00E@3oool2000002/0oooo0P00001K0?ooo`800000
d03oool005D0oooo0`00000Y0?ooo`<00000F`3oool200000=00oooo001F0?ooo`800000:@3oool2
000005/0oooo0`00003@0?ooo`00EP3oool3000008D0oooo0P00003A0?ooo`00E`3oool3000008@0
oooo0P00003A0?ooo`00F03oool200000?l0ooooF03oool005P0oooo0`00003o0?oooeL0oooo001I
0?ooo`800000o`3ooomG0?ooo`00F@3oool300000?l0ooooEP3oool005X0oooo0`00003o0?oooeD0
oooo001K0?ooo`8000007`3oool200000?l0oooo=03oool005/0oooo0`00000N0?ooo`800000o`3o
oold0?ooo`00G03oool2000001d0oooo0`00003o0?oooc@0oooo001L0?ooo`<000006`3oool30000
05h0oooo0P00003D0?ooo`00G@3oool2000001/0oooo0P00001O0?ooo`800000e03oool005d0oooo
0`00000F0?ooo`H00000GP3oool3000000H0oooo3P0000300?ooo`00GP3oool3000001D0oooo1P00
001B0?ooob@00000_`3oool005l0oooo0P00000E0?ooo`L00000?03oool[000000`0oooo1000002m
0?ooo`00G`3oool3000001<0oooo2@00000U0?ooob`000001P3oool7000001D0oooo1000002l0?oo
o`00H03oool2000001<0oooo2@00000@0?ooob`000006`3oool7000001L0oooo1000002j0?ooo`00
M@3oool_00000340oooo2000000G0?ooo`D00000^03oool006@0oooo:`0000160?ooo`T00000603o
ool400000;L0oooo001>0?ooobd00000FP3oool9000001X0oooo1000002e0?ooo`00>@3oool/0000
00l0oooo1P00001K0?ooo`T000006`3oool400000;@0oooo000T0?ooob/00000903oool6000005`0
oooo2000000N0?ooo`@00000/P3oool001T0oooo8@00000i0?ooo`D00000G@3oool8000001l0oooo
1000002a0?ooo`006@3oool<000004h0oooo1000001N0?ooo`L000008P3oool400000:l0oooo000K
0?ooo`L00000D03oool4000005l0oooo1P00000T0?ooo`D00000[@3oool001h0oooo1P00001>0?oo
o`<00000H03oool6000002H0oooo1000002/0?ooo`008@3oool6000004/0oooo0P00001Q0?ooo`D0
0000:@3oool400000:X0oooo000S0?ooo`L00000Z`3oool5000002X0oooo1000002Y0?ooo`009P3o
ool600000200oooo1@0000240?ooo`@00000;@3oool400000:L0oooo000Y0?ooo`H000007P3oool3
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1b0?ooo`<00000;`3oool4
00000:H0oooo000[0?ooo`L000006`3oool3000000P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1a0?ooo`<00000<@3oool4000002l0oooo2P00001[0?ooo`00;P3oool6000001T0
oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool2000003<0
oooo1000000_0?ooo`<000000`3oool3000006/0oooo000a0?ooo`H000005P3oool6000000@0oooo
00<000000?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3oool0oooo3000002J0?ooo`@0
0000;@3oool3000000@0oooo0P00001[0?ooo`00<`3oool7000001<0oooo1`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool<000009/0
oooo1@00000[0?ooo`<00000L@3oool003H0oooo1P00000A0?ooo`<0000000<0oooo000000000000
0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool2000000P0oooo0P00002M0?ooo`@00000:P3oool300000740oooo000i0?ooo`H00000
3P3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo``00000=P3oool4000002P0
oooo0`0000030?ooo`800000K03oool003/0oooo1`00000;0?ooo`<000000P3oool300000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`80
0000203oool2000005d0oooo3000000g0?ooo`@000009`3oool8000006`0oooo000n0?ooo`H00000
2@3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo`800000203oool2000003T0
oooo1000000U0?ooo`<000000`3oool2000006`0oooo00110?ooo`H000001@3oool5000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo0?ooo`800000203oool2000005d0oooo0P0000080?ooo`800000>P3oool4000002@0
oooo0`00001a0?ooo`00@`3oool7000000@0oooo1@0000040?ooo`040000003oool0oooo0?ooo`@0
00000`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo`800000203oool20000
03`0oooo1000000R0?ooo`<00000103oool2000006/0oooo00160?ooo`L000002`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool<000000<0oooo103?clm:0?oo
o`@0clo?203oool2000000P0oooo0P00000m0?ooo`@000008@3oool3000000<0oooo0`00001[0?oo
o`00B@3oool6000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo300000030?ooo`P0clo?AP3oool70<o?c`D0oooo0P0000080?ooo`800000?`3oool40000
01h0oooo2P00001[0?ooo`00C03oool6000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0E0?ooo`T0clo?@P3oool80<o?c`@0oooo0P0000080?ooo`800000@03oool500000940
oooo001>0?ooo`L000009`3oool80<o?cc`0oooo2`3?cll40?ooo``00000@P3oool400000900oooo
001A0?ooo`H00000:@3oool80<o?cc80oooo3`3?cll60?ooo``00000A03oool4000008h0oooo001D
0?ooo`H00000:@3ooolC0<o?cal0oooo303?cll30?ooo`@0clo?F03oool4000008d0oooo001F0?oo
o`L00000:P3ooold0<o?c`T0oooo0`3?clmK0?ooo`@00000R`3oool005T0oooo1P00000f0?ooob40
clo?3P3oool20<o?ced0oooo1000002:0?ooo`00G03oool6000005T0oooo1@00001U0?ooo`@00000
R03oool005h0oooo1`00001G0?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04<0oooo1@0000260?ooo`00H@3oool6000005D0oooo0`0000080?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0A03oool4000008D0oooo001T0?ooo`H00000DP3oool30000
00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`160?ooo`@00000P`3oool006H0
oooo1`00001?0?ooo`H00000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool400000880
oooo001Y0?ooo`H00000C@3oool7000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`180?ooo`@00000P03oool006`0oooo1P00001:0?ooo`<0000000<0oooo0000000000000P00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B@3oool4000007l0oooo001^
0?ooo`L00000A`3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B`3oool4
000007d0oooo001a0?ooo`H00000A@3oool300000080oooo0`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0C03oool4000007`0oooo001d0?ooo`H00000@P3oool300000080
oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0CP3oool4000007X0
oooo001f0?ooo`L00000?P3oool5000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1?0?ooo`D00000N03oool007T0oooo1P00000n0?ooo`D00000103o
ool010000000oooo0?ooo`3oool4000000d0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1A0?ooo`@00000M`3oool007`0oooo1P0000150?ooo`050000003oool0oooo0?ooo`000000
303oool4000000D0oooo00<000000?ooo`3oool0E03oool4000007D0oooo001n0?ooo`L00000@P3o
ool01@000000oooo0?ooo`3oool0000000h0oooo0P0000050?ooo`030000003oool0oooo05D0oooo
1000001d0?ooo`00P@3oool600000440oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05P0oooo1000001b0?ooo`00Q03oool600000;80oooo1000001a
0?ooo`00QP3oool700000;40oooo1000001_0?ooo`00R@3oool600000;00oooo1000001^0?ooo`00
S03oool600000:l0oooo1000001/0?ooo`00SP3oool700000:d0oooo1@00001Z0?ooo`00T@3oool6
00000:d0oooo1000001Y0?ooo`00U03oool600000:`0oooo1000001W0?ooo`00UP3oool700000:X0
oooo1000001V0?ooo`00V@3oool700000:T0oooo1000001T0?ooo`00W03oool600000:P0oooo1000
001S0?ooo`00W`3oool600000:L0oooo1000001Q0?ooo`00X@3oool700000:D0oooo1@00001O0?oo
o`00Y03oool600000:D0oooo1000001N0?ooo`00Y`3oool600000:@0oooo1000001L0?ooo`00Z@3o
ool700000:80oooo1000001K0?ooo`00[03oool600000:80oooo1000001I0?ooo`00[`3oool60000
0:00oooo1000001H0?ooo`00/@3oool7000009l0oooo1000001F0?ooo`00]03oool6000009h0oooo
1000001E0?ooo`00]`3oool6000009d0oooo1000001C0?ooo`00^@3oool7000009/0oooo1@00001A
0?ooo`00_03oool6000009/0oooo1000001@0?ooo`00_`3oool6000009X0oooo1000001>0?ooo`00
`@3oool7000009P0oooo1000001=0?ooo`00a03ooonQ000004`0oooo00370?oooih00000C03oool0
0?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool0
0?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo4@3oool7000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool300000080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000005L0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003o
ool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000F03oool0
0?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000F03oool00?l0oooo
4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo1P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000
F03oool00?l0oooo4@3oool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool2000000<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo0P0000030?ooo`040000003oool0000000000080oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`050000003oool0oooo
0?ooo`000000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
008000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`<000000`3oool00`000000oooo0000000200000080oooo00D000000?ooo`0000000000
0?ooo`03000000H0oooo0P0000030?ooo`030000003oool00000008000000`3oool3000005L0oooo
003o0?oooa40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1F0?ooo`00o`3ooolA
0?ooo`L000003`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05H0oooo003o0?oo
ok80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`0<0?ooo`80
0?l0n`3oool006l0oooo0`00000d0?ooo`800?l0303oool2003o0?/0oooo001^0?ooo`<00000=@3o
ool3003o00/0oooo0`00o`2L0?ooo`80o`00G03oool000/0oooo1`0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`0000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`<0000000@0oooo00000000000000003`3oool30000
03D0oooo1000o`0;0?ooo`@00?l0V`3oool20?l000X0oooo0P3o001@0?ooo`002`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03@3oool3
000003H0oooo1000o`0<0?ooo`@00?l0V@3oool30?l000X0oooo0P3o001@0?ooo`002`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo0`00000g0?oo
o`D00?l02`3oool5003o09L0oooo0`3o000:0?ooo`<0o`00D03oool000/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`<00000>03oool5003o00/0
oooo1P00o`2E0?ooo`<0o`002`3oool20?l00540oooo000;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool6000000030?ooo`00
0000oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`D0000000<0oooo0000003oool0
2P3oool3000003T0oooo1@00o`0;0?ooo`L00?l0U03oool20?l000`0oooo0P3o001A0?ooo`002`3o
ool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`0000002P3oool3000003T0oooo1`00o`0:0?ooo`P00?l0X03oool30?l00540oooo000;0?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3o
ool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000090?ooo`<00000>P3oool7003o00/0oooo2000o`2O
0?ooo`80o`00DP3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003oool000000000003oool0
0`0000060?ooo`8000000`3oool00`000000oooo00000002000000<0oooo0`0000020?ooo`@00000
0P3oool00`000000oooo0?ooo`060?ooo`<00000>`3oool7003o00/0oooo2@00o`3b0?ooo`002`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool3000003`0oooo2000o`0:0?ooo`X00?l0l@3oool000/0oooo1`00000?0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<00000?@3oool8
003o00X0oooo2P00o`3a0?ooo`00H`3oool3000003d0oooo2@00o`0:0?ooo`P00?l0l`3oool00680
oooo0`00000n0?ooo`X00?l02P3oool6003o08/0oooo0P3o001W0?ooo`00H@3oool3000003l0oooo
2P00o`0:0?ooo`<00?l000<0oooo003o0000o`00R`3oool20?l006L0oooo001Q0?ooo`800000@03o
ool8003o00`0oooo0P00o`020?ooo`<00?l0R@3oool30?l006L0oooo001P0?ooo`<00000A@3oool2
003o0180oooo0`00o`270?ooo`<0o`004@3oool20?l005D0oooo001O0?ooo`<00000AP3oool2003o
01<0oooo0`00o`250?ooo`<0o`004P3oool20?l005D0oooo001O0?ooo`800000A`3oool2003o01@0
oooo0P00o`240?ooo`<0o`004P3oool30?l005D0oooo001N0?ooo`<00000A`3oool2003o09X0oooo
0P3o000C0?ooo`80o`00EP3oool005d0oooo0`0000180?ooo`800?l0V@3oool30?l00180oooo0`3o
001F0?ooo`00G@3oool2000004T0oooo0P00o`2H0?ooo`<0o`004`3oool20?l005L0oooo001L0?oo
o`<00000hP3oool30?l001@0oooo0P3o001G0?ooo`00F`3oool300000><0oooo0P3o000D0?ooo`<0
o`00E`3oool005/0oooo0P00003j0?ooo`80o`00F03oool005X0oooo0`00003i0?ooo`<0o`00F03o
ool005T0oooo0`00003j0?ooo`80o`00F@3oool005P0oooo0`00001X0?ooo`800?l0k03oool005P0
oooo0P00001Y0?ooo`800?l0k03oool005L0oooo0`00001?0?ooo`800?l0603oool3003o07D0oooo
0P3o001d0?ooo`00EP3oool300000500oooo0P00o`0I0?ooo`800?l0M@3oool20?l007@0oooo001F
0?ooo`800000D@3oool2003o01T0oooo0`00o`1c0?ooo`<0o`00M03oool005D0oooo0`00001A0?oo
o`800?l06P3oool2003o0780oooo0`3o000G0?ooo`80o`00G03oool005@0oooo0`00001B0?ooo`<0
0?l06@3oool3003o0700oooo0`3o000H0?ooo`80o`00G03oool005@0oooo0P00001D0?ooo`800?l0
6P3oool3003o06h0oooo0`3o000H0?ooo`<0o`00G03oool005<0oooo0`00001D0?ooo`800?l06`3o
ool2003o06d0oooo0`3o000I0?ooo`80o`00G@3oool00580oooo0`00001E0?ooo`800?l06`3oool3
003o06/0oooo0`3o000I0?ooo`<0o`00G@3oool00580oooo0P00001F0?ooo`800?l0703oool2003o
06X0oooo0`3o000J0?ooo`80o`00GP3oool00540oooo0`00001F0?ooo`800?l0703oool3003o06P0
oooo0`3o000J0?ooo`<0o`00GP3oool00540oooo0P00001G0?ooo`<00?l0703oool2003o06P0oooo
0P3o000K0?ooo`80o`00G`3oool00540oooo0P00001H0?ooo`800?l0XP3oool30?l005l0oooo001@
0?ooo`<00000F03oool2003o0:80oooo0P3o001P0?ooo`00D03oool2000005T0oooo0P00o`2Q0?oo
o`<0o`00H03oool00500oooo0P00003l0?ooo`80o`00H@3oool004l0oooo0`00003o0?ooof00oooo
001?0?ooo`800000g03oool20?l00880oooo001?0?ooo`800000g03oool20?l00880oooo001>0?oo
o`<00000O03oool2003o05d0oooo0`3o00220?ooo`00CP3oool2000007d0oooo0P00o`1L0?ooo`<0
o`00P`3oool004h0oooo0P00001m0?ooo`<00?l0FP3oool30?l008@0oooo001=0?ooo`<00000F`3o
ool2003o0240oooo0P00o`1I0?ooo`<0o`007`3oool20?l006@0oooo001=0?ooo`800000G03oool2
003o0240oooo0P00o`1I0?ooo`80o`00803oool20?l006@0oooo001=0?ooo`800000G03oool2003o
0240oooo0`00o`1G0?ooo`<0o`00803oool20?l006@0oooo001<0?ooo`<00000G03oool2003o0280
oooo0P00o`1F0?ooo`<0o`00803oool30?l006@0oooo001<0?ooo`800000G@3oool2003o0280oooo
0`00o`1D0?ooo`<0o`008@3oool20?l006D0oooo001<0?ooo`800000G@3oool2003o02<0oooo0P00
o`1D0?ooo`80o`008P3oool20?l006D0oooo001;0?ooo`<00000G@3oool2003o02<0oooo0`00o`1f
0?ooo`<0o`00I@3oool004/0oooo0P00001N0?ooo`<00?l08`3oool2003o07H0oooo0P3o001V0?oo
o`00B`3oool2000005l0oooo0P00o`0S0?ooo`800?l0MP3oool20?l006H0oooo001:0?ooo`<00000
G`3oool2003o02<0oooo0`00o`1d0?ooo`<0o`00IP3oool004X0oooo0P00001P0?ooo`800?l0903o
ool2003o07@0oooo0P3o001W0?ooo`00BP3oool200000600oooo0P00o`2J0?ooo`80o`00I`3oool0
04T0oooo0`00001P0?ooo`800?l0o`3oool40?ooo`00B@3oool200000640oooo0P00o`1`0?ooo`80
o`00T@3oool004T0oooo0P00003C0?ooo`80o`00T@3oool004P0oooo0`00003B0?ooo`<0o`00T@3o
ool004P0oooo0P00003B0?ooo`<0o`00TP3oool004P0oooo0P00003A0?ooo`<0o`00T`3oool004P0
oooo0P00002>0?ooo`800?l0@03oool30?l002P0oooo0P3o001Z0?ooo`00B03oool2000008h0oooo
0P00o`100?ooo`80o`00:@3oool20?l006X0oooo00170?ooo`<00000SP3oool3003o03h0oooo0`3o
000X0?ooo`<0o`00JP3oool004L0oooo0P00002@0?ooo`800?l0?@3oool30?l002T0oooo0P3o001[
0?ooo`00A`3oool2000006D0oooo0P00o`0Y0?ooo`800?l0?03oool30?l002T0oooo0`3o001[0?oo
o`00A`3oool2000006D0oooo0P00o`0Y0?ooo`<00?l0>`3oool20?l002X0oooo0P3o001/0?ooo`00
AP3oool3000006D0oooo0P00o`0Z0?ooo`800?l0I`3oool20?l006`0oooo00160?ooo`800000IP3o
ool2003o02X0oooo0`00o`1U0?ooo`<0o`00K03oool004H0oooo0P00001V0?ooo`800?l0:`3oool2
003o06D0oooo0P3o001]0?ooo`00AP3oool2000006H0oooo0P00o`0[0?ooo`800?l0I03oool30?l0
06d0oooo00160?ooo`800000IP3oool3003o02X0oooo0`00o`180?ooo``000003`3oool20?l006h0
oooo00150?ooo`<00000I`3oool2003o02/0oooo0P00o`0e0?ooob000000OP3oool004D0oooo0P00
001X0?ooo`800?l0C`3ooolA00000080o`00500000020?ooo`P0l?3`1000001l0?ooo`00A@3oool2
000006P0oooo0P00o`0m0?ooob<000000P3o00000`000000oooo0?ooo`0L0?3`l0@00000N`3oool0
04D0oooo0P00001X0?ooo`800?l0:P3ooolV000000<0oooo303`l?030?l00240l?3`1000001i0?oo
o`00A03oool3000006P0oooo0P00o`0G0?ooobL000000P3ooolN0?3`l0<0o`008`3`l?04000007P0
oooo00140?ooo`800000J@3oool2003o00D0oooo9P0000030?ooobl0l?3`0`3o000V0?3`l0<00000
00<0l?3`0?ooo`3oool0M03oool004@0oooo0P00001M0?ooobH000000`3ooom10?3`l0<0o`00:03`
l?04000007D0oooo00140?ooo`800000BP3ooolW000000<0ooooDP3`l?030?l002X0l?3`10000000
0`3`l?00o`000?l0001a0?ooo`00A03oool2000003P0oooo9P0000030?ooof@0l?3`0`3o000]0?3`
l0<000000P3o001a0?ooo`00@`3oool3000002D0oooo9P0000040?ooogD0l?3`0`3o000_0?3`l005
0000003o0000o`000?l0003`l?00;P3oool2000000030?ooo`000000000000800000>`3oool004<0
oooo0P00000C0?ooobL000000`3ooomP0?3`l0800?l09@3`l?030?l00340l?3`0P3o0003000002d0
oooo100000020?ooo`800000>P3oool004<0oooo0P00000:0?oooad00000103ooomb0?3`l0800?l0
9@3`l?020?l002d0l?3`0`3o0000103`l?00o`000?l0003o0004000002`0oooo0`0000030?ooo`<0
0000>@3oool004<0oooo0P00000:0?ooo`X00000103ooon50?3`l0<00?l0D`3`l?060?l000<0l?3`
1000000Z0?ooo`800000103oool3000003T0oooo00130?ooo`800000303oool6000008`0l?3`0P00
o`1C0?3`l0L0o`000`3`l?04000002h0oooo1000000i0?ooo`00@`3oool2000000l0oooo1P00000j
0?3`l0l00000203`l?0200000080l?3`0P00o`0b0?3`l0<00?l0DP3`l?090?l000<0l?3`1000000Z
0?ooo`D00000>P3oool004<0oooo0P00000A0?ooo`L000009`3`l?02000000<0l?3`0P0000020?3`
l08000001@3`l?0B000000D0l?3`0P0000020?3`l0800?l0<`3`l?02003o0540l?3`2P3o00040?3`
l0@000009`3oool6000003/0oooo00130?ooo`800000503oool6000002D0l?3`0P0000030?3`l080
00000P3`l?02000001<0l?3`1`0000000`3`l?00000000000002000000040?3`l000o`000?l0003o
0380l?3`0`00o`1@0?3`l0X0o`001P3`l?04000002@0oooo1@00000m0?ooo`00@`3oool2000001H0
oooo00<0l?3`000000000000100000130?3`l0T000000P3`l?02003o03<0l?3`0P00o`0L0?3`l080
o`00<P3`l?090?l000P0l?3`1000000S0?ooo`<00000103oool2000003T0oooo00130?ooo`800000
6@3oool6000004@0l?3`1P0000020?3`l0800?l0<`3`l?03003o01/0l?3`0P3o000b0?3`l0P0o`00
2`3`l?03000000030?3`l03oool0oooo01l0oooo0`0000030?ooo`<00000>@3oool004<0oooo0P00
000L0?ooo`H00000@03`l?08000000040?3`l000o`000?l0003o03<0l?3`0P00o`0D0?3`l080o`00
103`l?030?l00380l?3`1`3o000=0?3`l0@000008@3oool200000080oooo1000000i0?ooo`00@`3o
ool2000001h0oooo1P00000m0?3`l0T000000P3`l?02003o03<0l?3`0`00o`0C0?3`l0<0o`000P3`
l?030?l003<0l?3`1P3o000?0?3`l0@0000000<0l?3`0?ooo`3oool07P3oool4000000030?ooo`00
0000000003T0oooo00130?ooo`8000008@3oool6000003X0l?3`2@00000h0?3`l0800?l04P3`l?08
0?l003@0l?3`1@3o000B0?3`l0@00000G`3oool004<0oooo0P00000S0?ooo`L00000>P3`l?070000
02L0l?3`00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00I0?3`l0L0o`00=03`l?060?l0
01<0l?3`100000000`3`l?00oooo0?ooo`1K0?ooo`00@`3oool2000002H0oooo1P00000l0?3`l0<0
00009P3`l?000`2`/;00H61P0?3`l0060?3`l0030=3@d01@D500l?3`01P0l?3`203o000d0?3`l0D0
o`005P3`l?04000005`0oooo00130?ooo`800000:@3oool600000680l?3`00<0410@0<30`03`l?00
1`3`l?000`0P8200d=3@0?3`l00G0?3`l0T0o`00<`3`l?040?l001P0l?3`100000000`3`l?00oooo
0?ooo`1H0?ooo`00@`3oool2000002/0oooo1P00000Z0?3`l0030820P03`l?00l?3`00H0l?3`00<0
L71`0=3@d03`l?001@3`l?04000001L0l?3`0`000000103`l?0000000000000000020?3`l0030;2`
/00@4100l?3`0080l?3`00@0L71`0000000`<300h>3P0P3`l?000`1`L700H61P0?3`l00F0?3`l0/0
o`00<P3`l?030?l001/0l?3`1000001I0?ooo`00@P3oool3000002h0oooo1P00000V0?3`l0030;2`
/010@400l?3`00L0l?3`00<0/;2`051@D03`l?000`3`l?08000001@0l?3`00<000000?3`l03`l?00
0P0000030?3`l0040000003`l?00H61P061PH0<0l?3`00@00000010@402`/;00/;2`0P3`l?000`2`
/;00820P0?3`l00F0?3`l0/0o`00<P3`l?020?l001d0l?3`100000000`3`l?00oooo0?ooo`1E0?oo
o`00@P3oool200000340oooo1`00000S0?3`l003020P802PX:00l?3`00P0l?3`00<0410@0>3Ph03`
l?000P3`l?08000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0040000003`l?00820P
092@T0<0l?3`00<00000030`<03`l?000`3`l?000`3Ph>0000000?3`l00F0?3`l0T0o`00E@3`l?04
000005H0oooo00120?ooo`800000=03oool6000001T0l?3`00D0<30`051@D01PH600@4100<30`002
0?3`l0030<30`0000000l?3`00<0l?3`00@0L71`0000000P8200`<300P3`l?000`1@D500L71`0?3`
l0020?3`l0P00000503`l?001@000000l?3`0?3`l03`l?00000000<0l?3`00@000000?3`l0000000
/;2`0`3`l?000`000000<30`0?3`l0040?3`l00300000030`<00l?3`01@0l?3`203o001H0?3`l0@0
000000<0l?3`0?ooo`3oool0DP3oool00480oooo0P00000f0?ooo`030?3`l0000000000000@00000
5P3`l?001@1@D500l?3`0?3`l01PH600820P0080l?3`00<0H61P030`<03`l?000`3`l?0200000080
X:2P0P3`l?000`2@T900820P0?3`l0020?3`l0P000000`3`l?03000000h0l?3`00D000000?3`l03`
l?00l?3`000000030?3`l0040000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?00
0`000000d=3@0?3`l0090?3`l0800?l02@3`l?070?l000X0l?3`00<0d=3@0?3`l03`l?005@3`l?00
0`1`L700h>3P0?3`l00f0?3`l0<0000000<0l?3`0?ooo`3oool0D@3oool00480oooo0P00000i0?oo
o`H00000503`l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000`3`l?000`00
0000<30`0?3`l0030?3`l0030=3@d0000000l?3`00@0l?3`100000050?3`l0D00000303`l?020000
0080l?3`00<000000?3`l03`l?000P0000000`3`l?0000000;2`/0030?3`l0030000000`<300l?3`
00<0l?3`00<0/;2`0000003`l?002P3`l?02003o00P0l?3`1P3o000;0?3`l0030;2`/01PH600l?3`
01H0l?3`00<0X:2P071`L03`l?00=`3`l?04000000030?3`l03oool0oooo04l0oooo00120?ooo`80
0000?03oool600000140l?3`00D0h>3P0410@00000000000051@D0020?3`l0030000002`/;00l?3`
00<0l?3`00<00000030`<03`l?00103`l?000`000000/;2`0?3`l00>0?3`l0D000002`3`l?020000
00<0l?3`0P0000020?3`l005030`<02@T900l?3`0?3`l01PH6000P0000001P0`<300T92@0?3`l03`
l?00T92@030`<0/0l?3`0P00o`080?3`l0@0o`003@3`l?000`0@4100`<300?3`l00G0?3`l003010@
403Ph>00l?3`03L0l?3`100000000`3`l?00oooo0?ooo`1>0?ooo`00@P3oool2000003h0oooo1P00
000?0?3`l005051@D00000000000051@D03Ph>000P3`l?000`000000/;2`0?3`l0030?3`l0030000
000`<300l?3`00@0l?3`00<000000;2`/03`l?00403`l?0500000180l?3`00<0L71`061PH03`l?00
0P3`l?000`1@D500<30`0?3`l0030?3`l003051@D020P800l?3`00X0l?3`0P00o`070?3`l0@0o`00
0`3`l?03000000040?3`l00000000000000000<0l?3`00<0/;2`010@403`l?000P3`l?00101`L700
0000030`<03Ph>030?3`l0030000002`/;00l?3`00<0l?3`00H0/;2`061PH00000000000061PH02@
T9030?3`l003051@D020P800l?3`03T0l?3`1000001?0?ooo`00@P3oool200000440oooo1P00000<
0?3`l080000000<0`<300?3`l03`l?000P3`l?000`000000/;2`0?3`l0030?3`l0030000000`<300
l?3`00@0l?3`00<000000;2`/03`l?004P3`l?0500000100l?3`00<0d=3@010@403`l?000`3`l?00
0`2@T900l?3`0?3`l0020?3`l0030000003Ph>00l?3`00X0l?3`0`00o`060?3`l080o`00103`l?00
0`000000l?3`0?3`l002000000<0l?3`00<000000?3`l03`l?000P1PH6030?3`l0040000000@4100
/;2`0;2`/0<0l?3`00<000000;2`/03`l?001@3`l?000`0`<30000000?3`l0040?3`l0030820P010
@400l?3`00/0l?3`1@00000Z0?3`l0@0000000<0l?3`0?ooo`3oool0B`3oool00480oooo0P000013
0?ooo`L000002@3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0820P092@T03`l?000`3`
l?000`000000<30`0?3`l0030?3`l0030<30`0000000l?3`01D0l?3`1@00000?0?3`l0030410@03@
d=00l?3`00H0l?3`00<0X:2P061PH03`l?00303`l?02003o00`0l?3`00D000000?3`l03`l?00l?3`
000000030?3`l0050000003`l?00l?3`020P802@T9000`3`l?0010000000<30`0?3`l03`l?030;2`
/00500000020P800/;2`0;2`/03@d=000`3`l?000`0`<30000000?3`l0040?3`l0030;2`/0000000
l?3`00X0l?3`1`00000[0?3`l0@00000C03oool00480oooo0P0000160?ooo`H000001`3`l?001@30
`<00D51@071`L01@D500@4100080l?3`00<0D51@061PH03`l?000P3`l?001@0`<300000000000000
0000<30`0080l?3`00<0T92@010@403`l?005`3`l?05000000d0l?3`00<0d=3@061PH03`l?001P3`
l?000`30`<00h>3P0?3`l00<0?3`l0800?l0303`l?001@000000l?3`0?3`l03`l?00000000<0l?3`
00D000000?3`l03`l?0000000;2`/0030?3`l0040000000`<300l?3`0?3`l0L0000000H0L71`0?3`
l03`l?00l?3`030`<00000050?3`l0030;2`/0000000l?3`00X0l?3`1`00000/0?3`l0@0000000<0
l?3`0?ooo`3oool0B03oool00480oooo0P0000190?ooo`H000002`3`l?000`2PX:00820P0?3`l003
0?3`l003051@D00`<300l?3`00<0l?3`0P1@D50J0?3`l0D00000303`l?000`3Ph>00l?3`0?3`l00D
0?3`l0800?l0303`l?001@000000l?3`0?3`l03`l?00000000<0l?3`00D000000?3`l03`l?000000
0;2`/0030?3`l0030000000`<300l?3`00@0l?3`00<000000;2`/03`l?001@3`l?000`0`<3000000
0?3`l0040?3`l0030;2`/0000000l?3`00X0l?3`1`00000^0?3`l0@00000B@3oool00480oooo0P00
001;0?ooo`H000002P3`l?000`0@4100d=3@0?3`l0030?3`l003092@T03`l?00l?3`0080l?3`00<0
00000=3@d03`l?006`3`l?05000002l0l?3`0P0000020?3`l0030000003`l?00l?3`008000000P3`
l?000`000000/;2`0?3`l0020?3`l0030000000`<300l?3`00@0l?3`00<000000;2`/03`l?001@3`
l?000`0`<30000000?3`l0040?3`l0030:2PX00@4100l?3`00X0l?3`1`00000_0?3`l0@0000000<0
l?3`0?ooo`3oool0A@3oool00480oooo0P00001>0?ooo`H000001`3`l?000`1`L700T92@0?3`l007
0?3`l0030:2PX00`<300l?3`01h0l?3`1P00000]0?3`l08000000`3`l?02000000<0l?3`00D0<30`
092@T03`l?00l?3`061PH00200000003030`<02@T900l?3`0080l?3`00<000000;2`/03`l?001@3`
l?000`0`<30000000?3`l0040?3`l004071`L01@D500l?3`0?3`l0P000000P3`l?0500000380l?3`
100000160?ooo`00@P3oool200000500oooo1P0000050?3`l0030>3Ph00`<300l?3`00L0l?3`00<0
L71`0=3@d03`l?00803`l?07000003@0l?3`00<0L71`061PH03`l?000P3`l?000`1@D500<30`0?3`
l00<0?3`l003030`<0000000l?3`00@0l?3`00@0820P092@T03`l?00l?3`2000000j0?3`l0@00000
00<0l?3`0?ooo`3oool0@P3oool00480oooo0P00001C0?ooo`H000000`3`l?000`3@d=00l?3`0?3`
l00/0?3`l0P000005`3`l?05000001@0l?3`00<0d=3@010@403`l?000`3`l?000`2@T900l?3`0?3`
l0090?3`l004061PH02`/;00<30`000000@0l?3`00<0d=3@010@403`l?000P3`l?08000003`0l?3`
100000130?ooo`00@P3oool2000005D0oooo1`00000b0?3`l0P00000203`l?03000000P0l?3`1`00
000D0?3`l0030410@03@d=00l?3`00h0l?3`00@0h>3P071`L00000000000103`l?020820P0030?3`
l0000000000000L00000?P3`l?04000000030?3`l03oool0oooo03l0oooo00120?ooo`800000F03o
ool6000003@0l?3`200000040?3`l0D000001P3`l?07000001@0l?3`00<0d=3@061PH03`l?00403`
l?001030`<00410@0?3`l03`l?0>00000400l?3`0`0000000`3`l?00oooo0?ooo`0n0?ooo`00@P3o
ool2000005/0oooo1P00000d0?3`l0P0000000<0l?3`0000000000001@0000040?3`l0L000001@3`
l?06000000X0l?3`00<0h>3P0?3`l03`l?003P3`l?0;00000080l?3`1@0000120?3`l0@0000000<0
l?3`0?ooo`3oool0?03oool00480oooo0P00001M0?ooo`L00000=@3`l?0=000000<0l?3`1`000005
0?3`l0d00000403`l?0:000000P0l?3`100000130?3`l0@0000000<0l?3`0?ooo`3oool0>`3oool0
0480oooo0`00001O0?ooo`H00000=P3`l?0:000000@0l?3`1@00000;0?3`l0l00000103`l?0:0000
00h0l?3`0P0000160?3`l0@0000000<0l?3`0?ooo`3oool0>@3oool004<0oooo0P00001P0?ooo`P0
0000=@3`l?06000001d0l?3`4P00001K0?3`l0@0000000<0l?3`0?ooo`3oool0>03oool004<0oooo
0P00001P0?ooo`8000000P3oool6000003<0l?3`1000000V0?3`l0H00000HP3`l?04000000030?3`
l03oool0oooo03H0oooo00130?ooo`800000G`3oool3000000D0oooo1P00000`0?3`l0800000T@3`
l?04000000030?3`l03oool0oooo03D0oooo00130?ooo`800000G`3oool2000000P0oooo1P000021
0?3`l0030820P03`l?00l?3`01P0l?3`00<0H61P0=3@d03`l?00903`l?04000000030?3`l03oool0
oooo03<0oooo00130?ooo`800000GP3oool3000000/0oooo1P00001m0?3`l0030:2PX01@D500l?3`
01T0l?3`00<0/;2`051@D03`l?009@3`l?04000000030?3`l03oool0oooo0380oooo00130?ooo`80
0000GP3oool2000000h0oooo1P00001k0?3`l003020P802PX:00l?3`01X0l?3`00<0410@0>3Ph03`
l?009P3`l?04000000030?3`l03oool0oooo0300oooo00130?ooo`<00000L03oool6000003D0l?3`
00<0P8200?3`l03`l?00603`l?000`1PH600d=3@0?3`l00M0?3`l005030`<01@D500H61P0410@030
`<000P3`l?000`30`<0000000?3`l0030?3`l004071`L0000000<30`0<30`0<0l?3`00<0L71`0000
003`l?000`3`l?07000000060410@03`l?00l?3`0?3`l01@D500P820:03`l?04000000030?3`l03o
ool0oooo02l0oooo00140?ooo`800000LP3oool700000340l?3`00<0X:2P051@D03`l?006@3`l?00
0`2`/;00D51@0?3`l00M0?3`l005051@D03`l?00l?3`061PH00P82000P3`l?000`1PH600@4100?3`
l0030?3`l08000000P2PX:030?3`l003071`L0000000l?3`00<0l?3`00<0T92@000000000000100`
<3001P10@400l?3`0?3`l03`l?00T92@020P82X0l?3`0`0000000`3`l?00oooo0?ooo`0^0?ooo`00
A03oool2000007D0oooo1P00000_0?3`l003020P802PX:00l?3`01X0l?3`00<0410@0>3Ph03`l?00
703`l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000`3`l?000`000000<30`
0?3`l0040?3`l003071`L0000000l?3`00@0l?3`00<0`<300000002`/;000`3`l?001P20P800l?3`
0?3`l03`l?00d=3@000002/0l?3`100000000`3`l?00oooo0?ooo`0/0?ooo`00803oool8000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`800000N03oool6000002@0
l?3`00D0<30`051@D01PH600@4100<30`0020?3`l0030<30`0000000l?3`00<0l?3`00@0L71`0000
000`<300`<300`3`l?000`1`L70000000?3`l0050?3`l006071`L010@40000000000001@D500T92@
0`3`l?000`1@D500P8200?3`l00L0?3`l0050>3Ph010@40000000000001@D5000P3`l?000`000000
/;2`0?3`l0030?3`l0040000000`<300l?3`0?3`l0<0L71`00<0<30`0000001`L7000P1`L7001P2`
/;00l?3`0?3`l030`<00410@0<30`0L0l?3`00<000000;2`/03`l?00:P3`l?04000000030?3`l03o
ool0oooo02/0oooo000Q0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0;0?ooo`800000NP3oool600000280l?3`00D0D51@0?3`l03`l?00H61P020P
80020?3`l003061PH010@400l?3`00<0l?3`0P0000020:2PX0<0l?3`00<0L71`0000003`l?001`3`
l?02000000D0l?3`00<0T92@020P803`l?00703`l?001@1@D50000000000001@D500h>3P0080l?3`
00<000000;2`/03`l?000`3`l?0010000000<30`0?3`l03`l?0800000007071`L03`l?00l?3`0?3`
l02`/;0000000>3Ph0060?3`l0030000002`/;00l?3`02`0l?3`100000000`3`l?00oooo0?ooo`0Y
0?ooo`008@3oool2000000P0oooo0P0000090?ooo`800000303oool2000007d0oooo1P00000O0?3`
l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300L71`0?3`l0030?3`l0030000000`<300l?3`
00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0l?3`00<0d=3@0000003`l?00703`l?020000
00030<30`03`l?00l?3`0080l?3`00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`
l003071`L0000000l?3`00L0l?3`00<0H61P030`<03`l?001@3`l?000`000000/;2`0?3`l00]0?3`
l0@0000000<0l?3`0?ooo`3oool0:03oool00240oooo0P0000080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool2000007l0oooo1P00000M0?3`l0050>3Ph010@40000000000
001@D5000P3`l?000`000000/;2`0?3`l0030?3`l0040000000`<300l?3`0?3`l0<0L71`00<0<30`
0000001`L7000P1`L7000`2`/;00l?3`0?3`l0020?3`l08000001P3`l?000`000000/;2`0?3`l00K
0?3`l004010@401`L700l?3`051@D0<0l?3`00<0820P0:2PX03`l?000`3`l?000`000000<30`0?3`
l0040?3`l003071`L0000000l?3`00L0l?3`00<0d=3@0000002`/;00103`l?000`30`<0000000?3`
l00`0?3`l0@0000000<0l?3`0?ooo`3oool09P3oool001T0oooo1@0000030?ooo`80000000<0oooo
000000000000103oool2000000D0oooo0P0000040?ooo`8000002`3oool2000005L0oooo0P00000Y
0?ooo`H000006P3`l?000`1@D50000000000000200000080l?3`00<000000;2`/03`l?000`3`l?00
10000000<30`0?3`l03`l?0800000003071`L03`l?00l?3`0080l?3`0P0000060?3`l0030000002`
/;00l?3`01/0l?3`00@0`<30030`<01`L700@4100`3`l?000`1@D500H61P0?3`l0020?3`l005030`
<000000000000000000`<3000`3`l?000`1`L70000000?3`l0080?3`l003020P8010@400l?3`00<0
l?3`00<0T92@010@403`l?00<@3`l?04000000030?3`l03oool0oooo02D0oooo000J0?ooo`<00000
103oool5000000@0oooo0P0000040?ooo`<00000103oool2000000/0oooo0`00001F0?ooo`800000
:`3oool7000001L0l?3`0P0000000`30`<000000000000020?3`l0030000002`/;00l?3`00<0l?3`
00<00000030`<03`l?00103`l?000`1`L70000000?3`l0070?3`l08000001P3`l?000`000000/;2`
0?3`l00R0?3`l003092@T00P8200l?3`00<0l?3`00<0D51@030`<03`l?00103`l?000`2`/;00L71`
0?3`l0080?3`l080410@103`l?000`1@D500H61P0?3`l00c0?3`l0@0000000<0l?3`0?ooo`3oool0
8`3oool001X0oooo0`0000040?ooo`80000000<0oooo000000000000103oool2000000@0oooo0P00
00050?ooo`800000303oool2000005D0oooo0`00000^0?ooo`H000005@3`l?000`0@4100L71`0?3`
l00200000080l?3`00<0820P0:2PX03`l?000`3`l?000`000000<30`0?3`l0040?3`l003071`L000
0000l?3`00L0l?3`0P0000050?3`l0030<30`0000000l?3`02@0l?3`00<000000>3Ph03`l?000`3`
l?000`2@T900l?3`0?3`l0090?3`l0070:2PX030`<00l?3`0?3`l02`/;000000010@40040?3`l003
0000003@d=00l?3`03@0l?3`100000000`3`l?00oooo0?ooo`0R0?ooo`006P3oool3000000@0oooo
0P0000070?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000E@3oool200000380oooo
1P00000B0?3`l0030<30`00`<300L71`008000000P3`l?000`1@D500H61P0?3`l0020?3`l005030`
<000000000000000000`<3000`3`l?000`1`L70000000?3`l0070?3`l08000001@3`l?000`2@T900
410@0?3`l00T0?3`l003071`L02@T900l?3`0100l?3`00<0<30`061PH01PH6000P0000001P1@D500
l?3`0?3`l03`l?00X:2P030`<3P0l?3`100000000`3`l?00oooo0?ooo`0P0?ooo`006P3oool30000
00@0oooo0P0000030?ooo`8000000P3oool2000000@0oooo0P0000050?ooo`800000303oool20000
05@0oooo0`00000d0?ooo`H000004P3`l?0300000080l?3`00<0T92@020P803`l?000`3`l?000`1@
D500<30`0?3`l0040?3`l0030;2`/01`L700l?3`00L0l?3`0P0000050?3`l003051@D01PH600l?3`
02@0l?3`00<0h>3P030`<03`l?00403`l?001P3Ph>00L71`000000000000D51@0>3Ph0<0l?3`00<0
L71`0=3@d03`l?00>03`l?04000000030?3`l03oool0oooo01l0oooo000J0?ooo`<000000`3oool8
00000080oooo0P0000040?ooo`8000001@3oool2000000`0oooo0P00001D0?ooo`800000>03oool6
000000l0l?3`0P0000040?3`l0030000003Ph>00l?3`00<0l?3`00<0T92@0?3`l03`l?002P3`l?00
0`30`<00D51@0;2`/002000000D0l?3`00<000000=3@d03`l?009@3`l?000`3@d=00l?3`0?3`l01E
0?3`l0<000000P3`l?0O0?ooo`006P3oool3000000d0oooo0P0000040?ooo`8000001@3oool20000
00`0oooo0P00001C0?ooo`<00000>P3oool6000000d0l?3`0P0000040?3`l003071`L02@T900l?3`
0140l?3`00@0h>3P061PH00000000000103`l?000`2PX:00<30`0?3`l01o0?3`l0@0000000<0l?3`
0?ooo`3oool0703oool001X0oooo0`00000=0?ooo`800000103oool2000000D0oooo0P00000<0?oo
o`800000DP3oool3000003h0oooo1P00000:0?3`l0800000103`l?000`3Ph>00<30`0?3`l00C0?3`
l0030;2`/00@4100l?3`00<0l?3`00<0L71`0=3@d03`l?00P03`l?0400000080l?3`703oool001X0
oooo0`00000=0?ooo`8000000`3oool4000000@0oooo0P00000<0?ooo`<00000D@3oool200000440
oooo1`00000>0?3`l0030=3@d03`l?00l?3`09d0l?3`100000000`3`l?00oooo0?ooo`0I0?ooo`00
6P3oool3000000h0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003oool0oooo00`0
oooo0P00001@0?ooo`<00000A03oool600000:d0l?3`100000020?3`l1T0oooo000J0?ooo`<00000
3P3oool2000000<0oooo0P0000040?ooo`8000003P3oool200000500oooo0P0000180?ooo`H00000
[03`l?04000000030?3`l03oool0oooo01H0oooo000I0?ooo`D000003P3oool010000000oooo0?oo
o`3oool2000000@0oooo00<000000?ooo`3oool03@3oool2000004l0oooo0`00001:0?ooo`H00000
Z`3`l?0400000080l?3`5P3oool002d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`800000C`3oool2000004h0oooo1P00002Z0?3`l0@0000000<0l?3`0?ooo`3oool04`3o
ool004H0oooo0`00002P0?ooo`L00000Z03`l?0400000080l?3`4`3oool004L0oooo0P00002S0?oo
o`H00000Z03`l?04000000030?3`l03oool0oooo0100oooo00170?ooo`800000YP3oool600000:H0
l?3`100000000`3`l?00oooo0?ooo`0?0?ooo`00A`3oool300000:L0oooo1P00002V0?3`l0@00000
00<0l?3`0?ooo`3oool03@3oool004P0oooo0P00002M0?ooo`8000002`3oool600000:@0l?3`1000
00000`3`l?00oooo0?ooo`0<0?ooo`00B03oool2000009d0oooo0P00000=0?ooo`H00000Y03`l?03
00000080l?3`303oool004P0oooo0`00002L0?ooo`800000403oool600000:80l?3`100000000`3`
l?00oooo0?ooo`090?ooo`00B@3oool2000004P0oooo0P00001A0?ooo`<000004P3oool700000:00
l?3`100000020?3`l0T0oooo00190?ooo`<00000A`3oool200000540oooo0P00000F0?ooo`H00000
X03`l?04000000030?3`l03oool0oooo00H0oooo001:0?ooo`800000AP3oool300000540oooo0P00
000I0?ooo`H00000WP3`l?0400000080l?3`1P3oool004X0oooo0P0000150?ooo`<00000D@3oool3
000001/0ooooY`0000020?3`l0D0oooo001:0?ooo`<00000A03oool200000580oooo0P00000O0?oo
oj@000000`3`l?040?ooo`00B`3oool2000004<0oooo0`00001B0?ooo`8000008P3ooonT0?3`l0@0
oooo001;0?ooo`<00000@P3oool2000005<0oooo0P00003:0?ooo`00C03oool200000440oooo0`00
001B0?ooo`<00000bP3oool004`0oooo0P0000100?ooo`<00000D`3oool200000</0oooo001<0?oo
o`<00000?`3oool2000005@0oooo0P0000250?ooo`H000000P3oool2000000030?ooo`000000oooo
00<0oooo0`0000000`3oool000000?ooo`030?ooo`8000000`3oool200000080oooo0`0000001@3o
ool000000?ooo`3oool0000000D0oooo0`0000040?ooo`@00000303oool004d0oooo0P00000n0?oo
o`<000002@3oool2000000<0oooo0`0000390?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`00C@3oool2000003h0oooo0P00000<0?ooo`060000003oool0oooo0000003oool0
0000b@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`00C@3oool3000004/0oooo00@000000?ooo`3oool00000dP3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`080?ooo`800000303oool004h0oooo0P00001;0?ooo`040000003oool0oooo
00000=00oooo0P0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool000000`3oool6000000<0oooo0P00000>0?ooo`00CP3oool3000004X0oooo00@000000?ooo`3o
ool00000c03oool4000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000@0?ooo`00C`3oool2000004P0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000020?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo001?0?ooo`80
0000B@3oool700000<T0oooo00<000000?ooo`3oool0103oool4000000060?ooo`000000oooo0000
003oool00000103oool00`000000oooo0?ooo`020?ooo`<0000000H0oooo00000000000000000?oo
o`0000040?ooo`060000003oool0oooo0000003oool000000`3oool2000000D0oooo1000000<0?oo
o`00C`3oool300000?l0oooo6@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000001D0
oooo00<000000?ooo`3oool09@3oool00500oooo0P00003o0?oooaX0oooo1P0000020?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool09@3oool00500oooo0P00000e0?ooo`800000F03o
ool200000<h0oooo001@0?ooo`<00000=03oool2000005P0oooo0P00003>0?ooo`00D@3oool20000
03<0oooo0`00001H0?ooo`800000cP3oool00540oooo0`00000a0?ooo`<00000F03oool300000<h0
oooo001B0?ooo`800000<@3oool2000005T0oooo0P00003?0?ooo`00DP3oool3000002l0oooo0`00
001I0?ooo`800000c`3oool005<0oooo0`00000^0?ooo`800000FP3oool200000<l0oooo001D0?oo
o`800000;@3oool3000005T0oooo0`00003?0?ooo`00E03oool3000002/0oooo0`00001J0?ooo`80
0000d03oool005D0oooo0P00000[0?ooo`800000F`3oool200000=00oooo001E0?ooo`<00000:@3o
ool3000005/0oooo0P00003@0?ooo`00EP3oool2000002T0oooo0P00001K0?ooo`<00000d03oool0
05H0oooo0`0000250?ooo`800000d@3oool005L0oooo0`0000240?ooo`800000d@3oool005P0oooo
0P00003o0?oooeP0oooo001H0?ooo`<00000o`3ooomG0?ooo`00F@3oool200000?l0ooooE`3oool0
05T0oooo0`00003o0?oooeH0oooo001J0?ooo`<00000o`3ooomE0?ooo`00F`3oool2000001l0oooo
0P00003o0?oooc@0oooo001K0?ooo`<000007P3oool200000?l0oooo=03oool005`0oooo0P00000M
0?ooo`<00000o`3ooold0?ooo`00G03oool3000001/0oooo0`00001N0?ooo`800000e03oool005d0
oooo0P00000K0?ooo`800000G`3oool200000=@0oooo001M0?ooo`<000005P3oool6000005h0oooo
0`0000060?ooo`h00000`03oool005h0oooo0`00000E0?ooo`H00000DP3ooolT00000;l0oooo001O
0?ooo`8000005@3oool7000003`0oooo:`00000<0?ooo`@00000_@3oool005l0oooo0`00000C0?oo
o`T000009@3oool/000000H0oooo1`00000E0?ooo`@00000_03oool00600oooo0P00000C0?ooo`T0
0000403oool/000001/0oooo1`00000G0?ooo`@00000^P3oool007D0oooo;`00000a0?ooo`P00000
5`3oool500000;P0oooo001T0?ooob/00000AP3oool9000001P0oooo1000002g0?ooo`00CP3oool]
000005X0oooo2@00000J0?ooo`@00000]@3oool003T0oooo;000000?0?ooo`H00000F`3oool90000
01/0oooo1000002d0?ooo`00903oool[000002@0oooo1P00001L0?ooo`P000007P3oool400000;80
oooo000I0?ooob400000>@3oool5000005d0oooo2000000O0?ooo`@00000/@3oool001T0oooo3000
001>0?ooo`@00000GP3oool700000280oooo1000002_0?ooo`006`3oool700000500oooo1000001O
0?ooo`H00000903oool500000:d0oooo000N0?ooo`H00000CP3oool300000600oooo1P00000V0?oo
o`@00000[03oool00240oooo1P00001;0?ooo`800000H@3oool5000002T0oooo1000002Z0?ooo`00
8`3oool700000:/0oooo1@00000Z0?ooo`@00000Z@3oool002H0oooo1P00000P0?ooo`D00000Q03o
ool4000002d0oooo1000002W0?ooo`00:@3oool6000001h0oooo0`0000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0LP3oool3000002l0oooo1000002V0?ooo`00:`3oool70000
01/0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool30000
0340oooo1000000_0?ooo`X00000J`3oool002h0oooo1P00000I0?ooo`<00000203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0740oooo0P00000c0?ooo`@00000;`3oool3000000<0
oooo0`00001[0?ooo`00<@3oool6000001H0oooo1P0000040?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`040000003oool0oooo0?ooo``00000VP3oool4000002d0oooo0`0000040?ooo`80
0000J`3oool003<0oooo1`00000C0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo3000002K0?ooo`D00000:`3oool300000740
oooo000f0?ooo`H000004@3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`80
0000W@3oool4000002X0oooo0`00001a0?ooo`00>@3oool6000000h0oooo0`0000020?ooo`<00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo0P0000080?ooo`800000G@3oool<000003H0oooo1000000X0?ooo`<000000`3oool2000006`0
oooo000k0?ooo`L000002`3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo``0
0000=`3oool4000002L0oooo2000001/0?ooo`00?P3oool6000000T0oooo0`0000020?ooo`<00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo0P0000080?ooo`800000G@3oool2000000P0oooo0P00000i0?ooo`@000009@3oool3000000<0
oooo0P00001/0?ooo`00@@3oool6000000D0oooo1@0000000`3oool00000000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000P0
oooo0P00001M0?ooo`800000203oool2000003X0oooo1000000T0?ooo`<00000L@3oool004<0oooo
1`0000040?ooo`D00000103oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3o
ool0oooo0P0000080?ooo`800000G@3oool2000000P0oooo0P00000l0?ooo`@000008P3oool30000
00@0oooo0P00001[0?ooo`00AP3oool7000000/0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo300000030?ooo`@0clo?BP3oool40<o?c`P0oooo0P0000080?oo
o`800000?@3oool400000240oooo0`0000030?ooo`<00000J`3oool004T0oooo1P0000090?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo``000000`3oool80<o?
cdH0oooo1`3?cll50?ooo`800000203oool2000003l0oooo1000000N0?ooo`X00000J`3oool004`0
oooo1P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool90<o?cd80
oooo203?cll40?ooo`800000203oool200000400oooo1@00002A0?ooo`00CP3oool7000002L0oooo
203?clll0?ooo`/0clo?103oool<00000480oooo1000002@0?ooo`00D@3oool6000002T0oooo203?
cllb0?ooo`l0clo?1P3oool<000004@0oooo1000002>0?ooo`00E03oool6000002T0oooo4`3?cllO
0?ooo``0clo?0`3oool40<o?ceP0oooo1000002=0?ooo`00EP3oool7000002X0oooo=03?cll90?oo
o`<0clo?F`3oool4000008/0oooo001I0?ooo`H00000=P3ooolQ0<o?c`h0oooo0P3?clmM0?ooo`@0
0000RP3oool005`0oooo1P00001I0?ooo`D00000I@3oool4000008P0oooo001N0?ooo`L00000E`3o
ool3000000T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`130?ooo`D00000QP3o
ool00640oooo1P00001E0?ooo`<00000203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo04@0oooo100000250?ooo`00I03oool600000580oooo0`0000080?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0AP3oool4000008<0oooo001V0?ooo`L00000C`3oool6000000@0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo100000220?ooo`00J@3oool6000004d0oooo
1`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool400000800oooo
001/0?ooo`H00000BP3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04T0oooo1000001o0?ooo`00KP3oool7000004L0oooo0`000002
0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L000001P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo1000001m0?ooo`00L@3oool60000
04D0oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
04`0oooo1000001l0?ooo`00M03oool600000480oooo0`0000020?ooo`<000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04h0oooo1000001j0?ooo`00MP3oool7000003h0oooo
1@0000000`3oool00000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
C`3oool5000007P0oooo001i0?ooo`H00000?P3oool5000000@0oooo00@000000?ooo`3oool0oooo
1000000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0D@3oool4000007L0oooo
001l0?ooo`H00000A@3oool01@000000oooo0?ooo`3oool0000000`0oooo100000050?ooo`030000
003oool0oooo05@0oooo1000001e0?ooo`00OP3oool700000480oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`8000001@3oool00`000000oooo0?ooo`1E0?ooo`@00000M03oool00840oooo1P00
00110?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1H0?ooo`@00000LP3oool008@0oooo1P00002b0?ooo`@00000L@3oool008H0oooo1`00002a0?oo
o`@00000K`3oool008T0oooo1P00002`0?ooo`@00000KP3oool008`0oooo1P00002_0?ooo`@00000
K03oool008h0oooo1`00002]0?ooo`D00000JP3oool00940oooo1P00002]0?ooo`@00000J@3oool0
09@0oooo1P00002/0?ooo`@00000I`3oool009H0oooo1`00002Z0?ooo`@00000IP3oool009T0oooo
1`00002Y0?ooo`@00000I03oool009`0oooo1P00002X0?ooo`@00000H`3oool009l0oooo1P00002W
0?ooo`@00000H@3oool00:40oooo1`00002U0?ooo`D00000G`3oool00:@0oooo1P00002U0?ooo`@0
0000GP3oool00:L0oooo1P00002T0?ooo`@00000G03oool00:T0oooo1`00002R0?ooo`@00000F`3o
ool00:`0oooo1P00002R0?ooo`@00000F@3oool00:l0oooo1P00002P0?ooo`@00000F03oool00;40
oooo1`00002O0?ooo`@00000EP3oool00;@0oooo1P00002N0?ooo`@00000E@3oool00;L0oooo1P00
002M0?ooo`@00000D`3oool00;T0oooo1`00002K0?ooo`D00000D@3oool00;`0oooo1P00002K0?oo
o`@00000D03oool00;l0oooo1P00002J0?ooo`@00000CP3oool00<40oooo1`00002H0?ooo`@00000
C@3oool00<@0ooooX@00001<0?ooo`00a`3ooonN000004`0oooo003o0?oook80oooo003o0?oook80
oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80
oooo003o0?oooa40oooo1`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo0`0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P00001G
0?ooo`00o`3ooolA0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080000000<0oooo0000
003oool00`3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
05P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000004
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`H0000000<0
oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo1`00
00000`3oool000000?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000103oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000001H0?ooo`00o`3ooolA0?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3o
ool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oo
oa40oooo00<000000?ooo`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?oo
o`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<0
00000?ooo`0000000P0000020?ooo`050000003oool000000000003oool00`0000060?ooo`800000
0`3oool00`000000oooo00000002000000<0oooo0`00001G0?ooo`00o`3ooolA0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0EP3oool00?l0oooo4@3oool7000000l0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1F0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00
o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00
o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`0<0?ooo`80
0?l0n`3oool006l0oooo0`00000d0?ooo`800?l0303oool2003o0?/0oooo001^0?ooo`<00000=@3o
ool3003o00/0oooo0`00o`2L0?ooo`80o`00G03oool000/0oooo1`0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0`0000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`<0000000@0oooo00000000000000003`3oool30000
03D0oooo1000o`0;0?ooo`@00?l0V`3oool20?l000X0oooo0P3o001@0?ooo`002`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03@3oool3
000003H0oooo1000o`0<0?ooo`@00?l0V@3oool30?l000X0oooo0P3o001@0?ooo`002`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo0`00000g0?oo
o`D00?l02`3oool5003o09L0oooo0`3o000:0?ooo`<0o`00D03oool000/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`<00000>03oool5003o00/0
oooo1P00o`2E0?ooo`<0o`002`3oool20?l00540oooo000;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool6000000030?ooo`00
0000oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`D0000000<0oooo0000003oool0
2P3oool3000003T0oooo1@00o`0;0?ooo`L00?l0U03oool20?l000`0oooo0P3o001A0?ooo`002`3o
ool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo000000040?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`0000002P3oool3000003T0oooo1`00o`0:0?ooo`P00?l0X03oool30?l00540oooo000;0?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3o
ool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000090?ooo`<00000>P3oool7003o00/0oooo2000o`2O
0?ooo`80o`00DP3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020000
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000000`3o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003oool000000000003oool0
0`0000060?ooo`8000000`3oool00`000000oooo00000002000000<0oooo0`0000020?ooo`@00000
0P3oool00`000000oooo0?ooo`060?ooo`<00000>`3oool7003o00/0oooo2@00o`3b0?ooo`002`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool3000003`0oooo2000o`0:0?ooo`X00?l0l@3oool000/0oooo1`00000?0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<00000?@3oool8
003o00X0oooo2P00o`3a0?ooo`00H`3oool3000003d0oooo2@00o`0:0?ooo`P00?l0l`3oool00680
oooo0`00000n0?ooo`X00?l02P3oool6003o08/0oooo0P3o001W0?ooo`00H@3oool3000003l0oooo
2P00o`0:0?ooo`<00?l000<0oooo003o0000o`00R`3oool20?l006L0oooo001Q0?ooo`800000@03o
ool8003o00`0oooo0P00o`020?ooo`<00?l0R@3oool30?l006L0oooo001P0?ooo`<00000A@3oool2
003o0180oooo0`00o`270?ooo`<0o`004@3oool20?l005D0oooo001O0?ooo`<00000AP3oool2003o
01<0oooo0`00o`250?ooo`<0o`004P3oool20?l005D0oooo001O0?ooo`800000A`3oool2003o01@0
oooo0P00o`240?ooo`<0o`004P3oool30?l005D0oooo001N0?ooo`<00000A`3oool2003o09X0oooo
0P3o000C0?ooo`80o`00EP3oool005d0oooo0`0000180?ooo`800?l0V@3oool30?l00180oooo0`3o
001F0?ooo`00G@3oool2000004T0oooo0P00o`2H0?ooo`<0o`004`3oool20?l005L0oooo001L0?oo
o`<00000hP3oool30?l001@0oooo0P3o001G0?ooo`00F`3oool300000><0oooo0P3o000D0?ooo`<0
o`00E`3oool005/0oooo0P00003j0?ooo`80o`00F03oool005X0oooo0`00003i0?ooo`<0o`00F03o
ool005T0oooo0`00003j0?ooo`80o`00F@3oool005P0oooo0`00001X0?ooo`800?l0k03oool005P0
oooo0P00001Y0?ooo`800?l0k03oool005L0oooo0`00001?0?ooo`800?l0603oool3003o07D0oooo
0P3o001d0?ooo`00EP3oool300000500oooo0P00o`0I0?ooo`800?l0M@3oool20?l007@0oooo001F
0?ooo`800000D@3oool2003o01T0oooo0`00o`1c0?ooo`<0o`00M03oool005D0oooo0`00001A0?oo
o`800?l06P3oool2003o0780oooo0`3o000G0?ooo`80o`00G03oool005@0oooo0`00001B0?ooo`<0
0?l06@3oool3003o0700oooo0`3o000H0?ooo`80o`00G03oool005@0oooo0P00001D0?ooo`800?l0
6P3oool3003o06h0oooo0`3o000H0?ooo`<0o`00G03oool005<0oooo0`00001D0?ooo`800?l06`3o
ool2003o06d0oooo0`3o000I0?ooo`80o`00G@3oool00580oooo0`00001E0?ooo`800?l06`3oool3
003o06/0oooo0`3o000I0?ooo`<0o`00G@3oool00580oooo0P00001F0?ooo`800?l0703oool2003o
06X0oooo0`3o000J0?ooo`80o`00GP3oool00540oooo0`00001F0?ooo`800?l0703oool3003o06P0
oooo0`3o000J0?ooo`<0o`00GP3oool00540oooo0P00001G0?ooo`<00?l0703oool2003o06P0oooo
0P3o000K0?ooo`80o`00G`3oool00540oooo0P00001H0?ooo`800?l0XP3oool30?l005l0oooo001@
0?ooo`<00000F03oool2003o0:80oooo0P3o001P0?ooo`00D03oool2000005T0oooo0P00o`2Q0?oo
o`<0o`00H03oool00500oooo0P00003l0?ooo`80o`00H@3oool004l0oooo0`00003o0?ooof00oooo
001?0?ooo`800000g03oool20?l00880oooo001?0?ooo`800000g03oool20?l00880oooo001>0?oo
o`<00000O03oool2003o05d0oooo0`3o00220?ooo`00CP3oool2000007d0oooo0P00o`1L0?ooo`<0
o`00P`3oool004h0oooo0P00001m0?ooo`<00?l0FP3oool30?l008@0oooo001=0?ooo`<00000F`3o
ool2003o0240oooo0P00o`1I0?ooo`<0o`007`3oool20?l006@0oooo001=0?ooo`800000G03oool2
003o0240oooo0P00o`1I0?ooo`80o`00803oool20?l006@0oooo001=0?ooo`800000G03oool2003o
0240oooo0`00o`1G0?ooo`<0o`00803oool20?l006@0oooo001<0?ooo`<00000G03oool2003o0280
oooo0P00o`1F0?ooo`<0o`00803oool30?l006@0oooo001<0?ooo`800000G@3oool2003o0280oooo
0`00o`1D0?ooo`<0o`008@3oool20?l006D0oooo001<0?ooo`800000G@3oool2003o02<0oooo0P00
o`1D0?ooo`80o`008P3oool20?l006D0oooo001;0?ooo`<00000G@3oool2003o02<0oooo0`00o`1f
0?ooo`<0o`00I@3oool004/0oooo0P00001N0?ooo`<00?l08`3oool2003o07H0oooo0P3o001V0?oo
o`00B`3oool2000005l0oooo0P00o`0S0?ooo`800?l0MP3oool20?l006H0oooo001:0?ooo`<00000
G`3oool2003o02<0oooo0`00o`1d0?ooo`<0o`00IP3oool004X0oooo0P00001P0?ooo`800?l0903o
ool2003o07@0oooo0P3o001W0?ooo`00BP3oool200000600oooo0P00o`2J0?ooo`80o`00I`3oool0
04T0oooo0`00001P0?ooo`800?l0o`3oool40?ooo`00B@3oool200000640oooo0P00o`1`0?ooo`80
o`00T@3oool004T0oooo0P00003C0?ooo`80o`00T@3oool004P0oooo0`00003B0?ooo`<0o`00T@3o
ool004P0oooo0P00003B0?ooo`<0o`00TP3oool004P0oooo0P00003A0?ooo`<0o`00T`3oool004P0
oooo0P00002>0?ooo`800?l0@03oool30?l002P0oooo0P3o001Z0?ooo`00B03oool2000008h0oooo
0P00o`100?ooo`80o`00:@3oool20?l006X0oooo00170?ooo`<00000SP3oool3003o03h0oooo0`3o
000X0?ooo`<0o`00JP3oool004L0oooo0P00002@0?ooo`800?l0?@3oool30?l002T0oooo0P3o001[
0?ooo`00A`3oool2000006D0oooo0P00o`0Y0?ooo`800?l0?03oool30?l002T0oooo0`3o001[0?oo
o`00A`3oool2000006D0oooo0P00o`0Y0?ooo`<00?l0>`3oool20?l002X0oooo0P3o001/0?ooo`00
AP3oool3000006D0oooo0P00o`0Z0?ooo`800?l0I`3oool20?l006`0oooo00160?ooo`800000IP3o
ool2003o02X0oooo0`00o`1U0?ooo`<0o`00K03oool004H0oooo0P00001V0?ooo`800?l0:`3oool2
003o06D0oooo0P3o001]0?ooo`00AP3oool2000006H0oooo0P00o`0[0?ooo`800?l0I03oool30?l0
06d0oooo00160?ooo`800000IP3oool3003o02X0oooo0`00o`180?ooo``000003`3oool20?l006h0
oooo00150?ooo`<00000I`3oool2003o02/0oooo0P00o`0e0?ooob000000OP3oool004D0oooo0P00
001X0?ooo`800?l0C`3ooolA00000080o`00500000020?ooo`P0l?3`1000001l0?ooo`00A@3oool2
000006P0oooo0P00o`0m0?ooob<000000P3o00000`000000oooo0?ooo`0L0?3`l0@00000N`3oool0
04D0oooo0P00001X0?ooo`800?l0:P3ooolV000000<0oooo303`l?030?l00240l?3`1000001i0?oo
o`00A03oool3000006P0oooo0P00o`0G0?ooobL000000P3ooolN0?3`l0<0o`008`3`l?04000007P0
oooo00140?ooo`800000J@3oool2003o00D0oooo9P0000030?ooobl0l?3`0`3o000V0?3`l0<00000
00<0l?3`0?ooo`3oool0M03oool004@0oooo0P00001M0?ooobH000000`3ooom10?3`l0<0o`00:03`
l?04000007D0oooo00140?ooo`800000BP3ooolW000000<0ooooDP3`l?030?l002X0l?3`10000000
0`3`l?00o`000?l0001a0?ooo`00A03oool2000003P0oooo9P0000030?ooof@0l?3`0`3o000]0?3`
l0<000000P3o001a0?ooo`00@`3oool3000002D0oooo9P0000040?ooogD0l?3`0`3o000_0?3`l005
0000003o0000o`000?l0003`l?00;P3oool2000000030?ooo`000000000000800000>`3oool004<0
oooo0P00000C0?ooobL000000`3ooomP0?3`l0800?l09@3`l?030?l00340l?3`0P3o0003000002d0
oooo100000020?ooo`800000>P3oool004<0oooo0P00000:0?oooad00000103ooomb0?3`l0800?l0
9@3`l?020?l002d0l?3`0`3o0000103`l?00o`000?l0003o0004000002`0oooo0`0000030?ooo`<0
0000>@3oool004<0oooo0P00000:0?ooo`X00000103ooon50?3`l0<00?l0D`3`l?060?l000<0l?3`
1000000Z0?ooo`800000103oool3000003T0oooo00130?ooo`800000303oool6000008`0l?3`0P00
o`1C0?3`l0L0o`000`3`l?04000002h0oooo1000000i0?ooo`00@`3oool2000000l0oooo1P00000j
0?3`l0l00000203`l?0200000080l?3`0P00o`0b0?3`l0<00?l0DP3`l?090?l000<0l?3`1000000Z
0?ooo`D00000>P3oool004<0oooo0P00000A0?ooo`L000009`3`l?02000000<0l?3`0P0000020?3`
l08000001@3`l?0B000000D0l?3`0P0000020?3`l0800?l0<`3`l?02003o0540l?3`2P3o00040?3`
l0@000009`3oool6000003/0oooo00130?ooo`800000503oool6000002D0l?3`0P0000030?3`l080
00000P3`l?02000001<0l?3`1`0000000`3`l?00000000000002000000040?3`l000o`000?l0003o
0380l?3`0`00o`1@0?3`l0X0o`001P3`l?04000002@0oooo1@00000m0?ooo`00@`3oool2000001H0
oooo00<0l?3`000000000000100000130?3`l0T000000P3`l?02003o03<0l?3`0P00o`0L0?3`l080
o`00<P3`l?090?l000P0l?3`1000000S0?ooo`<00000103oool2000003T0oooo00130?ooo`800000
6@3oool6000004@0l?3`1P0000020?3`l0800?l0<`3`l?03003o01/0l?3`0P3o000b0?3`l0P0o`00
2`3`l?03000000030?3`l03oool0oooo01l0oooo0`0000030?ooo`<00000>@3oool004<0oooo0P00
000L0?ooo`H00000@03`l?08000000040?3`l000o`000?l0003o03<0l?3`0P00o`0D0?3`l080o`00
103`l?030?l00380l?3`1`3o000=0?3`l0@000008@3oool200000080oooo1000000i0?ooo`00@`3o
ool2000001h0oooo1P00000m0?3`l0T000000P3`l?02003o03<0l?3`0`00o`0C0?3`l0<0o`000P3`
l?030?l003<0l?3`1P3o000?0?3`l0@0000000<0l?3`0?ooo`3oool07P3oool4000000030?ooo`00
0000000003T0oooo00130?ooo`8000008@3oool6000003X0l?3`2@00000h0?3`l0800?l04P3`l?08
0?l003@0l?3`1@3o000B0?3`l0@00000G`3oool004<0oooo0P00000S0?ooo`L00000>P3`l?070000
02L0l?3`00<0d=3@0?3`l03`l?001@3`l?000`2@T900d=3@0?3`l00I0?3`l0L0o`00=03`l?060?l0
01<0l?3`100000000`3`l?00oooo0?ooo`1K0?ooo`00@`3oool2000002H0oooo1P00000l0?3`l0<0
00009P3`l?000`2`/;00H61P0?3`l0060?3`l0030=3@d01@D500l?3`01P0l?3`203o000d0?3`l0D0
o`005P3`l?04000005`0oooo00130?ooo`800000:@3oool600000680l?3`00<0410@0<30`03`l?00
1`3`l?000`0P8200d=3@0?3`l00G0?3`l0T0o`00<`3`l?040?l001P0l?3`100000000`3`l?00oooo
0?ooo`1H0?ooo`00@`3oool2000002/0oooo1P00000Z0?3`l0030820P03`l?00l?3`00H0l?3`00<0
L71`0=3@d03`l?001@3`l?04000001L0l?3`0`000000103`l?0000000000000000020?3`l0030;2`
/00@4100l?3`0080l?3`00@0L71`0000000`<300h>3P0P3`l?000`1`L700H61P0?3`l00F0?3`l0/0
o`00<P3`l?030?l001/0l?3`1000001I0?ooo`00@P3oool3000002h0oooo1P00000V0?3`l0030;2`
/010@400l?3`00L0l?3`00<0/;2`051@D03`l?000`3`l?08000001@0l?3`00<000000?3`l03`l?00
0P0000030?3`l0040000003`l?00H61P061PH0<0l?3`00@00000010@402`/;00/;2`0P3`l?000`2`
/;00820P0?3`l00F0?3`l0/0o`00<P3`l?020?l001d0l?3`100000000`3`l?00oooo0?ooo`1E0?oo
o`00@P3oool200000340oooo1`00000S0?3`l003020P802PX:00l?3`00P0l?3`00<0410@0>3Ph03`
l?000P3`l?08000001@0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0040000003`l?00820P
092@T0<0l?3`00<00000030`<03`l?000`3`l?000`3Ph>0000000?3`l00F0?3`l0T0o`00E@3`l?04
000005H0oooo00120?ooo`800000=03oool6000001T0l?3`00D0<30`051@D01PH600@4100<30`002
0?3`l0030<30`0000000l?3`00<0l?3`00@0L71`0000000P8200`<300P3`l?000`1@D500L71`0?3`
l0020?3`l0P00000503`l?001@000000l?3`0?3`l03`l?00000000<0l?3`00@000000?3`l0000000
/;2`0`3`l?000`000000<30`0?3`l0040?3`l00300000030`<00l?3`01@0l?3`203o001H0?3`l0@0
000000<0l?3`0?ooo`3oool0DP3oool00480oooo0P00000f0?ooo`030?3`l0000000000000@00000
5P3`l?001@1@D500l?3`0?3`l01PH600820P0080l?3`00<0H61P030`<03`l?000`3`l?0200000080
X:2P0P3`l?000`2@T900820P0?3`l0020?3`l0P000000`3`l?03000000h0l?3`00D000000?3`l03`
l?00l?3`000000030?3`l0040000003`l?0000000;2`/0<0l?3`00<00000030`<03`l?00103`l?00
0`000000d=3@0?3`l0090?3`l0800?l02@3`l?070?l000X0l?3`00<0d=3@0?3`l03`l?005@3`l?00
0`1`L700h>3P0?3`l00f0?3`l0<0000000<0l?3`0?ooo`3oool0D@3oool00480oooo0P00000i0?oo
o`H00000503`l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000`3`l?000`00
0000<30`0?3`l0030?3`l0030=3@d0000000l?3`00@0l?3`100000050?3`l0D00000303`l?020000
0080l?3`00<000000?3`l03`l?000P0000000`3`l?0000000;2`/0030?3`l0030000000`<300l?3`
00<0l?3`00<0/;2`0000003`l?002P3`l?02003o00P0l?3`1P3o000;0?3`l0030;2`/01PH600l?3`
01H0l?3`00<0X:2P071`L03`l?00=`3`l?04000000030?3`l03oool0oooo04l0oooo00120?ooo`80
0000?03oool600000140l?3`00D0h>3P0410@00000000000051@D0020?3`l0030000002`/;00l?3`
00<0l?3`00<00000030`<03`l?00103`l?000`000000/;2`0?3`l00>0?3`l0D000002`3`l?020000
00<0l?3`0P0000020?3`l005030`<02@T900l?3`0?3`l01PH6000P0000001P0`<300T92@0?3`l03`
l?00T92@030`<0/0l?3`0P00o`080?3`l0@0o`003@3`l?000`0@4100`<300?3`l00G0?3`l003010@
403Ph>00l?3`03L0l?3`100000000`3`l?00oooo0?ooo`1>0?ooo`00@P3oool2000003h0oooo1P00
000?0?3`l005051@D00000000000051@D03Ph>000P3`l?000`000000/;2`0?3`l0030?3`l0030000
000`<300l?3`00@0l?3`00<000000;2`/03`l?00403`l?0500000180l?3`00<0L71`061PH03`l?00
0P3`l?000`1@D500<30`0?3`l0030?3`l003051@D020P800l?3`00X0l?3`0P00o`070?3`l0@0o`00
0`3`l?03000000040?3`l00000000000000000<0l?3`00<0/;2`010@403`l?000P3`l?00101`L700
0000030`<03Ph>030?3`l0030000002`/;00l?3`00<0l?3`00H0/;2`061PH00000000000061PH02@
T9030?3`l003051@D020P800l?3`03T0l?3`1000001?0?ooo`00@P3oool200000440oooo1P00000<
0?3`l080000000<0`<300?3`l03`l?000P3`l?000`000000/;2`0?3`l0030?3`l0030000000`<300
l?3`00@0l?3`00<000000;2`/03`l?004P3`l?0500000100l?3`00<0d=3@010@403`l?000`3`l?00
0`2@T900l?3`0?3`l0020?3`l0030000003Ph>00l?3`00X0l?3`0`00o`060?3`l080o`00103`l?00
0`000000l?3`0?3`l002000000<0l?3`00<000000?3`l03`l?000P1PH6030?3`l0040000000@4100
/;2`0;2`/0<0l?3`00<000000;2`/03`l?001@3`l?000`0`<30000000?3`l0040?3`l0030820P010
@400l?3`00/0l?3`1@00000Z0?3`l0@0000000<0l?3`0?ooo`3oool0B`3oool00480oooo0P000013
0?ooo`L000002@3`l?001@0@4100L71`0?3`l03`l?00D51@0080l?3`00<0820P092@T03`l?000`3`
l?000`000000<30`0?3`l0030?3`l0030<30`0000000l?3`01D0l?3`1@00000?0?3`l0030410@03@
d=00l?3`00H0l?3`00<0X:2P061PH03`l?00303`l?02003o00`0l?3`00D000000?3`l03`l?00l?3`
000000030?3`l0050000003`l?00l?3`020P802@T9000`3`l?0010000000<30`0?3`l03`l?030;2`
/00500000020P800/;2`0;2`/03@d=000`3`l?000`0`<30000000?3`l0040?3`l0030;2`/0000000
l?3`00X0l?3`1`00000[0?3`l0@00000C03oool00480oooo0P0000160?ooo`H000001`3`l?001@30
`<00D51@071`L01@D500@4100080l?3`00<0D51@061PH03`l?000P3`l?001@0`<300000000000000
0000<30`0080l?3`00<0T92@010@403`l?005`3`l?05000000d0l?3`00<0d=3@061PH03`l?001P3`
l?000`30`<00h>3P0?3`l00<0?3`l0800?l0303`l?001@000000l?3`0?3`l03`l?00000000<0l?3`
00D000000?3`l03`l?0000000;2`/0030?3`l0040000000`<300l?3`0?3`l0L0000000H0L71`0?3`
l03`l?00l?3`030`<00000050?3`l0030;2`/0000000l?3`00X0l?3`1`00000/0?3`l0@0000000<0
l?3`0?ooo`3oool0B03oool00480oooo0P0000190?ooo`H000002`3`l?000`2PX:00820P0?3`l003
0?3`l003051@D00`<300l?3`00<0l?3`0P1@D50J0?3`l0D00000303`l?000`3Ph>00l?3`0?3`l00D
0?3`l0800?l0303`l?001@000000l?3`0?3`l03`l?00000000<0l?3`00D000000?3`l03`l?000000
0;2`/0030?3`l0030000000`<300l?3`00@0l?3`00<000000;2`/03`l?001@3`l?000`0`<3000000
0?3`l0040?3`l0030;2`/0000000l?3`00X0l?3`1`00000^0?3`l0@00000B@3oool00480oooo0P00
001;0?ooo`H000002P3`l?000`0@4100d=3@0?3`l0030?3`l003092@T03`l?00l?3`0080l?3`00<0
00000=3@d03`l?006`3`l?05000002l0l?3`0P0000020?3`l0030000003`l?00l?3`008000000P3`
l?000`000000/;2`0?3`l0020?3`l0030000000`<300l?3`00@0l?3`00<000000;2`/03`l?001@3`
l?000`0`<30000000?3`l0040?3`l0030:2PX00@4100l?3`00X0l?3`1`00000_0?3`l0@0000000<0
l?3`0?ooo`3oool0A@3oool00480oooo0P00001>0?ooo`H000001`3`l?000`1`L700T92@0?3`l007
0?3`l0030:2PX00`<300l?3`01h0l?3`1P00000]0?3`l08000000`3`l?02000000<0l?3`00D0<30`
092@T03`l?00l?3`061PH00200000003030`<02@T900l?3`0080l?3`00<000000;2`/03`l?001@3`
l?000`0`<30000000?3`l0040?3`l004071`L01@D500l?3`0?3`l0P000000P3`l?0500000380l?3`
100000160?ooo`00@P3oool200000500oooo1P0000050?3`l0030>3Ph00`<300l?3`00L0l?3`00<0
L71`0=3@d03`l?00803`l?07000003@0l?3`00<0L71`061PH03`l?000P3`l?000`1@D500<30`0?3`
l00<0?3`l003030`<0000000l?3`00@0l?3`00@0820P092@T03`l?00l?3`2000000j0?3`l0@00000
00<0l?3`0?ooo`3oool0@P3oool00480oooo0P00001C0?ooo`H000000`3`l?000`3@d=00l?3`0?3`
l00/0?3`l0P000005`3`l?05000001@0l?3`00<0d=3@010@403`l?000`3`l?000`2@T900l?3`0?3`
l0090?3`l004061PH02`/;00<30`000000@0l?3`00<0d=3@010@403`l?000P3`l?08000003`0l?3`
100000130?ooo`00@P3oool2000005D0oooo1`00000b0?3`l0P00000203`l?03000000P0l?3`1`00
000D0?3`l0030410@03@d=00l?3`00h0l?3`00@0h>3P071`L00000000000103`l?020820P0030?3`
l0000000000000L00000?P3`l?04000000030?3`l03oool0oooo03l0oooo00120?ooo`800000F03o
ool6000003@0l?3`200000040?3`l0D000001P3`l?07000001@0l?3`00<0d=3@061PH03`l?00403`
l?001030`<00410@0?3`l03`l?0>00000400l?3`0`0000000`3`l?00oooo0?ooo`0n0?ooo`00@P3o
ool2000005/0oooo1P00000d0?3`l0P0000000<0l?3`0000000000001@0000040?3`l0L000001@3`
l?06000000X0l?3`00<0h>3P0?3`l03`l?003P3`l?0;00000080l?3`1@0000120?3`l0@0000000<0
l?3`0?ooo`3oool0?03oool00480oooo0P00001M0?ooo`L00000=@3`l?0=000000<0l?3`1`000005
0?3`l0d00000403`l?0:000000P0l?3`100000130?3`l0@0000000<0l?3`0?ooo`3oool0>`3oool0
0480oooo0`00001O0?ooo`H00000=P3`l?0:000000@0l?3`1@00000;0?3`l0l00000103`l?0:0000
00h0l?3`0P0000160?3`l0@0000000<0l?3`0?ooo`3oool0>@3oool004<0oooo0P00001P0?ooo`P0
0000=@3`l?06000001d0l?3`4P00001K0?3`l0@0000000<0l?3`0?ooo`3oool0>03oool004<0oooo
0P00001P0?ooo`8000000P3oool6000003<0l?3`1000000V0?3`l0H00000HP3`l?04000000030?3`
l03oool0oooo03H0oooo00130?ooo`800000G`3oool3000000D0oooo1P00000`0?3`l0800000T@3`
l?04000000030?3`l03oool0oooo03D0oooo00130?ooo`800000G`3oool2000000P0oooo1P000021
0?3`l0030820P03`l?00l?3`01P0l?3`00<0H61P0=3@d03`l?00903`l?04000000030?3`l03oool0
oooo03<0oooo00130?ooo`800000GP3oool3000000/0oooo1P00001m0?3`l0030:2PX01@D500l?3`
01T0l?3`00<0/;2`051@D03`l?009@3`l?04000000030?3`l03oool0oooo0380oooo00130?ooo`80
0000GP3oool2000000h0oooo1P00001k0?3`l003020P802PX:00l?3`01X0l?3`00<0410@0>3Ph03`
l?009P3`l?04000000030?3`l03oool0oooo0300oooo00130?ooo`<00000L03oool6000003D0l?3`
00<0P8200?3`l03`l?00603`l?000`1PH600d=3@0?3`l00M0?3`l005030`<01@D500H61P0410@030
`<000P3`l?000`30`<0000000?3`l0030?3`l004071`L0000000<30`0<30`0<0l?3`00<0L71`0000
003`l?000`3`l?07000000060410@03`l?00l?3`0?3`l01@D500P820:03`l?04000000030?3`l03o
ool0oooo02l0oooo00140?ooo`800000LP3oool700000340l?3`00<0X:2P051@D03`l?006@3`l?00
0`2`/;00D51@0?3`l00M0?3`l005051@D03`l?00l?3`061PH00P82000P3`l?000`1PH600@4100?3`
l0030?3`l08000000P2PX:030?3`l003071`L0000000l?3`00<0l?3`00<0T92@000000000000100`
<3001P10@400l?3`0?3`l03`l?00T92@020P82X0l?3`0`0000000`3`l?00oooo0?ooo`0^0?ooo`00
A03oool2000007D0oooo1P00000_0?3`l003020P802PX:00l?3`01X0l?3`00<0410@0>3Ph03`l?00
703`l?000`3@d=00l?3`0;2`/00200000080l?3`00<0<30`071`L03`l?000`3`l?000`000000<30`
0?3`l0040?3`l003071`L0000000l?3`00@0l?3`00<0`<300000002`/;000`3`l?001P20P800l?3`
0?3`l03`l?00d=3@000002/0l?3`100000000`3`l?00oooo0?ooo`0/0?ooo`00803oool8000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`800000N03oool6000002@0
l?3`00D0<30`051@D01PH600@4100<30`0020?3`l0030<30`0000000l?3`00<0l?3`00@0L71`0000
000`<300`<300`3`l?000`1`L70000000?3`l0050?3`l006071`L010@40000000000001@D500T92@
0`3`l?000`1@D500P8200?3`l00L0?3`l0050>3Ph010@40000000000001@D5000P3`l?000`000000
/;2`0?3`l0030?3`l0040000000`<300l?3`0?3`l0<0L71`00<0<30`0000001`L7000P1`L7001P2`
/;00l?3`0?3`l030`<00410@0<30`0L0l?3`00<000000;2`/03`l?00:P3`l?04000000030?3`l03o
ool0oooo02/0oooo000Q0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0;0?ooo`800000NP3oool600000280l?3`00D0D51@0?3`l03`l?00H61P020P
80020?3`l003061PH010@400l?3`00<0l?3`0P0000020:2PX0<0l?3`00<0L71`0000003`l?001`3`
l?02000000D0l?3`00<0T92@020P803`l?00703`l?001@1@D50000000000001@D500h>3P0080l?3`
00<000000;2`/03`l?000`3`l?0010000000<30`0?3`l03`l?0800000007071`L03`l?00l?3`0?3`
l02`/;0000000>3Ph0060?3`l0030000002`/;00l?3`02`0l?3`100000000`3`l?00oooo0?ooo`0Y
0?ooo`008@3oool2000000P0oooo0P0000090?ooo`800000303oool2000007d0oooo1P00000O0?3`
l0030=3@d03`l?00/;2`008000000P3`l?000`0`<300L71`0?3`l0030?3`l0030000000`<300l?3`
00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0l?3`00<0d=3@0000003`l?00703`l?020000
00030<30`03`l?00l?3`0080l?3`00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`
l003071`L0000000l?3`00L0l?3`00<0H61P030`<03`l?001@3`l?000`000000/;2`0?3`l00]0?3`
l0@0000000<0l?3`0?ooo`3oool0:03oool00240oooo0P0000080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool2000007l0oooo1P00000M0?3`l0050>3Ph010@40000000000
001@D5000P3`l?000`000000/;2`0?3`l0030?3`l0040000000`<300l?3`0?3`l0<0L71`00<0<30`
0000001`L7000P1`L7000`2`/;00l?3`0?3`l0020?3`l08000001P3`l?000`000000/;2`0?3`l00K
0?3`l004010@401`L700l?3`051@D0<0l?3`00<0820P0:2PX03`l?000`3`l?000`000000<30`0?3`
l0040?3`l003071`L0000000l?3`00L0l?3`00<0d=3@0000002`/;00103`l?000`30`<0000000?3`
l00`0?3`l0@0000000<0l?3`0?ooo`3oool09P3oool001T0oooo1@0000030?ooo`80000000<0oooo
000000000000103oool2000000D0oooo0P0000040?ooo`8000002`3oool2000005L0oooo0P00000Y
0?ooo`H000006P3`l?000`1@D50000000000000200000080l?3`00<000000;2`/03`l?000`3`l?00
10000000<30`0?3`l03`l?0800000003071`L03`l?00l?3`0080l?3`0P0000060?3`l0030000002`
/;00l?3`01/0l?3`00@0`<30030`<01`L700@4100`3`l?000`1@D500H61P0?3`l00200000005030`
<000000000000000000`<3000`3`l?000`1`L70000000?3`l0080?3`l003020P8010@400l?3`00<0
l?3`00<0T92@010@403`l?00<@3`l?04000000030?3`l03oool0oooo02D0oooo000J0?ooo`<00000
103oool5000000@0oooo0P0000040?ooo`<00000103oool2000000/0oooo0`00001F0?ooo`800000
:`3oool7000001L0l?3`0P0000000`30`<000000000000020?3`l0030000002`/;00l?3`00<0l?3`
00<00000030`<03`l?00103`l?000`1`L70000000?3`l0070?3`l08000001P3`l?000`000000/;2`
0?3`l00R0?3`l003092@T00P8200l?3`0080000000<0l?3`051@D00`<3001@3`l?000`2`/;00L71`
0?3`l0080?3`l080410@103`l?000`1@D500H61P0?3`l00c0?3`l0@0000000<0l?3`0?ooo`3oool0
8`3oool001X0oooo0`0000040?ooo`80000000<0oooo000000000000103oool2000000@0oooo0P00
00050?ooo`800000303oool2000005D0oooo0`00000^0?ooo`H000005@3`l?000`0@4100L71`0?3`
l00200000080l?3`00<0820P0:2PX03`l?000`3`l?000`000000<30`0?3`l0040?3`l003071`L000
0000l?3`00L0l?3`0P0000050?3`l0030<30`0000000l?3`02@0l?3`00@000000>3Ph00000000000
0P3`l?000`2@T900l?3`0?3`l0090?3`l0070:2PX030`<00l?3`0?3`l02`/;000000010@40040?3`
l0030000003@d=00l?3`03@0l?3`100000000`3`l?00oooo0?ooo`0R0?ooo`006P3oool3000000@0
oooo0P0000070?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000E@3oool200000380
oooo1P00000B0?3`l0030<30`00`<300L71`008000000P3`l?000`1@D500H61P0?3`l0020?3`l005
030`<000000000000000000`<3000`3`l?000`1`L70000000?3`l0070?3`l08000001@3`l?000`2@
T900410@0?3`l00T0?3`l004071`L00000000000000000l0l?3`00<0<30`061PH01PH6000P000000
1P1@D500l?3`0?3`l03`l?00X:2P030`<3P0l?3`100000000`3`l?00oooo0?ooo`0P0?ooo`006P3o
ool3000000@0oooo0P0000030?ooo`8000000P3oool2000000@0oooo0P0000050?ooo`800000303o
ool2000005@0oooo0`00000d0?ooo`H000004P3`l?0300000080l?3`00<0T92@020P803`l?000`3`
l?000`1@D500<30`0?3`l0040?3`l0030;2`/01`L700l?3`00L0l?3`0P0000050?3`l003051@D01P
H600l?3`02@0l?3`00<0h>3P000000000000403`l?001P3Ph>00L71`000000000000D51@0>3Ph0<0
l?3`00<0L71`0=3@d03`l?00>03`l?04000000030?3`l03oool0oooo01l0oooo000J0?ooo`<00000
0`3oool800000080oooo0P0000040?ooo`8000001@3oool2000000`0oooo0P00001D0?ooo`800000
>03oool6000000l0l?3`0P0000040?3`l0030000003Ph>00l?3`00<0l?3`00<0T92@0?3`l03`l?00
2P3`l?000`30`<00D51@0;2`/002000000D0l?3`00<000000=3@d03`l?009@3`l?02000005H0l?3`
0`0000020?3`l1l0oooo000J0?ooo`<000003@3oool2000000@0oooo0P0000050?ooo`800000303o
ool2000005<0oooo0`00000j0?ooo`H000003@3`l?02000000@0l?3`00<0L71`092@T03`l?004@3`
l?00103Ph>00H61P0000000000040?3`l0030:2PX00`<300l?3`02H0l?3`0P00001G0?3`l0@00000
00<0l?3`0?ooo`3oool0703oool001X0oooo0`00000=0?ooo`800000103oool2000000D0oooo0P00
000<0?ooo`800000DP3oool3000003h0oooo1P00000:0?3`l0800000103`l?000`3Ph>00<30`0?3`
l00C0?3`l0030;2`/00@4100l?3`00<0l?3`00<0L71`0=3@d03`l?00P03`l?0400000080l?3`703o
ool001X0oooo0`00000=0?ooo`8000000`3oool4000000@0oooo0P00000<0?ooo`<00000D@3oool2
00000440oooo1`00000>0?3`l0030=3@d03`l?00l?3`09d0l?3`100000000`3`l?00oooo0?ooo`0I
0?ooo`006P3oool3000000h0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003oool0
oooo00`0oooo0P00001@0?ooo`<00000A03oool600000:d0l?3`100000020?3`l1T0oooo000J0?oo
o`<000003P3oool2000000<0oooo0P0000040?ooo`8000003P3oool200000500oooo0P0000180?oo
o`H00000[03`l?04000000030?3`l03oool0oooo01H0oooo000I0?ooo`D000003P3oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool03@3oool2000004l0oooo0`00001:0?oo
o`H00000Z`3`l?0400000080l?3`5P3oool002d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`800000C`3oool2000004h0oooo1P00002Z0?3`l0@0000000<0l?3`0?ooo`3o
ool04`3oool004H0oooo0`00002P0?ooo`L00000Z03`l?0400000080l?3`4`3oool004L0oooo0P00
002S0?ooo`H00000?P3`l?02000006P0l?3`100000000`3`l?00oooo0?ooo`0@0?ooo`00A`3oool2
00000:H0oooo1P00000k0?3`l0800000J@3`l?04000000030?3`l03oool0oooo00l0oooo00170?oo
o`<00000Y`3oool6000003P0l?3`0`00001[0?3`l0@0000000<0l?3`0?ooo`3oool03@3oool004P0
oooo0P00002M0?ooo`8000002`3oool6000003D0l?3`0P00001]0?3`l0@0000000<0l?3`0?ooo`3o
ool0303oool004P0oooo0P00002M0?ooo`8000003@3oool600000380l?3`0`00001_0?3`l0<00000
0P3`l?0<0?ooo`00B03oool3000009`0oooo0P00000@0?ooo`H00000;`3`l?0200000740l?3`1000
00000`3`l?00oooo0?ooo`090?ooo`00B@3oool2000004P0oooo0P00001A0?ooo`<000004P3oool7
000002/0l?3`0`00001b0?3`l0@000000P3`l?090?ooo`00B@3oool3000004L0oooo0P00001A0?oo
o`8000005P3oool6000002T0l?3`0P00001e0?3`l0@0000000<0l?3`0?ooo`3oool01P3oool004X0
oooo0P0000160?ooo`<00000D@3oool2000001T0oooo1P00000U0?3`l0<00000MP3`l?0400000080
l?3`1P3oool004X0oooo0P0000150?ooo`<00000D@3oool3000001/0ooooY`0000020?3`l0D0oooo
001:0?ooo`<00000A03oool200000580oooo0P00000O0?oooj@000000`3`l?040?ooo`00B`3oool2
000004<0oooo0`00001B0?ooo`8000008P3ooolR0?3`l0800000P03`l?040?ooo`00B`3oool30000
0480oooo0P00001C0?ooo`800000@`3oool3000008@0oooo001<0?ooo`800000@@3oool300000580
oooo0`0000130?ooo`800000Q@3oool004`0oooo0P0000100?ooo`<00000D`3oool200000</0oooo
001<0?ooo`<00000?`3oool2000005@0oooo0P0000250?ooo`H000000P3oool2000000030?ooo`00
0000oooo00<0oooo0`0000000`3oool000000?ooo`030?ooo`8000000`3oool200000080oooo0`00
00001@3oool000000?ooo`3oool0000000D0oooo0`0000040?ooo`@00000303oool004d0oooo0P00
000n0?ooo`<000002@3oool2000000<0oooo0`0000390?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`00C@3oool2000003h0oooo0P00000<0?ooo`060000003oool0oooo0000
003oool00000b@3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`00C@3oool3000004/0oooo00@000000?ooo`3oool0
0000dP3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`080?ooo`800000303oool004h0oooo0P00001;0?ooo`040000003o
ool0oooo00000=00oooo0P0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool000000`3oool6000000<0oooo0P00000>0?ooo`00CP3oool3000004X0oooo00@00000
0?ooo`3oool00000Q`3oool2000004<0oooo100000040?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000403oool004l0oooo0P0000180?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0Q@3oool200000480oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo008000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool004l0oooo0P0000190?ooo`L00000Q03oool300000480oooo00<00000
0?ooo`3oool0103oool4000000060?ooo`000000oooo0000003oool00000103oool00`000000oooo
0?ooo`020?ooo`<0000000H0oooo00000000000000000?ooo`0000040?ooo`060000003oool0oooo
0000003oool000000`3oool2000000D0oooo1000000<0?ooo`00C`3oool300000=<0oooo0P000013
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0U
0?ooo`00D03oool200000=80oooo0`0000140?ooo`H000000P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo02D0oooo001@0?ooo`800000=@3oool2000005P0oooo0P0000110?ooo`80
0000R`3oool00500oooo0`00000d0?ooo`800000F03oool200000400oooo0`00002;0?ooo`00D@3o
ool2000003<0oooo0`00001H0?ooo`800000@03oool2000008`0oooo001A0?ooo`<00000<@3oool3
000005P0oooo0`0000100?ooo`800000S03oool00580oooo0P00000a0?ooo`800000F@3oool20000
0400oooo0`00002<0?ooo`00DP3oool3000002l0oooo0`00001I0?ooo`800000@03oool2000008d0
oooo001C0?ooo`<00000;P3oool2000005X0oooo0P00000o0?ooo`<00000S@3oool005@0oooo0P00
000]0?ooo`<00000F@3oool3000003l0oooo0P00002>0?ooo`00E03oool3000002/0oooo0`00001J
0?ooo`800000d03oool005D0oooo0P00000[0?ooo`800000F`3oool200000=00oooo001E0?ooo`<0
0000:@3oool3000005/0oooo0P00003@0?ooo`00EP3oool2000002T0oooo0P00001K0?ooo`<00000
d03oool005H0oooo0`0000250?ooo`800000d@3oool005L0oooo0`0000240?ooo`800000d@3oool0
05P0oooo0P00003o0?oooeP0oooo001H0?ooo`<00000`P3oool200000980oooo001I0?ooo`800000
`P3oool200000980oooo001I0?ooo`<00000`03oool300000980oooo001J0?ooo`<00000_`3oool2
000009<0oooo001K0?ooo`8000007`3oool2000009d0oooo0`00002C0?ooo`00F`3oool3000001h0
oooo0P00002M0?ooo`800000U03oool005`0oooo0P00000M0?ooo`<00000W03oool3000009@0oooo
001L0?ooo`<000006`3oool3000005h0oooo0P00000m0?ooo`800000U@3oool005d0oooo0P00000K
0?ooo`800000G`3oool2000003`0oooo0`00002E0?ooo`00G@3oool3000001H0oooo1P00001N0?oo
o`<000001P3oool>000002P0oooo0P00002F0?ooo`00GP3oool3000001D0oooo1P00001B0?ooob@0
00009P3oool3000009H0oooo001O0?ooo`8000005@3oool7000003`0oooo:`00000<0?ooo`@00000
903oool2000009L0oooo001O0?ooo`<000004`3oool9000002D0oooo;00000060?ooo`L000005@3o
ool400000;`0oooo001P0?ooo`8000004`3oool900000100oooo;000000K0?ooo`L000005`3oool4
00000;X0oooo001e0?ooobl00000<@3oool8000001L0oooo1@00002h0?ooo`00I03oool[000004H0
oooo2@00000H0?ooo`@00000]`3oool004h0oooo;@00001J0?ooo`T000006P3oool400000;D0oooo
000i0?ooob`000003`3oool6000005/0oooo2@00000K0?ooo`@00000]03oool002@0oooo:`00000T
0?ooo`H00000G03oool8000001h0oooo1000002b0?ooo`006@3ooolQ000003T0oooo1@00001M0?oo
o`P000007`3oool400000;40oooo000I0?ooo``00000CP3oool4000005h0oooo1`00000R0?ooo`@0
0000[`3oool001/0oooo1`00001@0?ooo`@00000G`3oool6000002@0oooo1@00000@0?ooo`800000
V`3oool001h0oooo1P00001>0?ooo`<00000H03oool6000002H0oooo1000000?0?ooo`800000V`3o
ool00240oooo1P00001;0?ooo`800000H@3oool5000002T0oooo1000000<0?ooo`<00000V`3oool0
02<0oooo1`00002[0?ooo`D00000:P3oool4000000X0oooo0`00002L0?ooo`009P3oool600000200
oooo1@0000240?ooo`@00000;@3oool4000000P0oooo0P00002M0?ooo`00:@3oool6000001h0oooo
0`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0LP3oool3000002l0oooo
100000060?ooo`<00000W@3oool002/0oooo1`00000K0?ooo`<00000203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0740oooo0`00000a0?ooo`@00000103oool2000002T0oooo2P00
001[0?ooo`00;P3oool6000001T0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0L@3oool2000003<0oooo100000020?ooo`<00000:P3oool3000000<0oooo0`00001[
0?ooo`00<@3oool6000001H0oooo1P0000040?ooo`030000003oool0oooo0080oooo0`0000030?oo
o`040000003oool0oooo0?ooo``00000VP3oool6000002/0oooo0`0000040?ooo`800000J`3oool0
03<0oooo1`00000C0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo3000002K0?ooo`D00000:`3oool300000740oooo000f0?oo
o`H000004@3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000W03oool5
000002X0oooo0`00001a0?ooo`00>@3oool6000000h0oooo0`0000020?ooo`<000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P000008
0?ooo`800000G@3oool<000003<0oooo0P0000000`3oool0000000000002000002P0oooo0`000003
0?ooo`800000K03oool003/0oooo1`00000;0?ooo`<000000P3oool300000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000203oool2
000005d0oooo3000000g0?ooo`@000009`3oool8000006`0oooo000n0?ooo`H000002@3oool30000
0080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo`800000203oool2000003T0oooo1000000U
0?ooo`<000000`3oool2000006`0oooo00110?ooo`H000001@3oool5000000030?ooo`0000000000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0?ooo`800000203oool2000005d0oooo0P0000080?ooo`800000>P3oool4000002@0oooo0`00001a
0?ooo`00@`3oool7000000@0oooo1@0000040?ooo`040000003oool0oooo0?ooo`@000000`3oool0
10000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo`800000203oool2000003`0oooo1000
000R0?ooo`<00000103oool2000006/0oooo00160?ooo`L000002`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool<000000<0oooo103?clm:0?ooo`@0clo?203o
ool2000000P0oooo0P0000030?ooo`@0clo?=P3oool400000240oooo0`0000030?ooo`<00000J`3o
ool004T0oooo1P0000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo``000000`3oool80<o?cdH0oooo1`3?cll50?ooo`800000203oool2000000<0oooo1`3?
clle0?ooo`@000007P3oool:000006/0oooo001<0?ooo`H000001`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo2@3?clm20?ooo`P0clo?103oool2000000P0oooo0P000006
0?ooo`L0clo?<`3oool500000940oooo001>0?ooo`L000009`3oool80<o?cc`0oooo2`3?cll40?oo
o``000002@3oool70<o?cah0oooo0P00000B0?ooo`@00000T03oool00540oooo1P00000Y0?ooo`P0
clo?<P3oool?0<o?c`H0oooo3000000<0?ooo`L0clo?6`3oool2000001@0oooo1000002>0?ooo`00
E03oool6000002T0oooo4`3?cllO0?ooo``0clo?0`3oool40<o?cb80oooo1P3?cllI0?ooo`800000
5@3oool4000008d0oooo001F0?ooo`L00000:P3ooold0<o?c`T0oooo0`3?cllV0?ooo`@0clo?5`3o
ool3000001L0oooo1000002;0?ooo`00F@3oool6000003H0oooo8@3?cll>0?ooo`80clo?:@3oool4
0<o?caD0oooo0P00000I0?ooo`@00000RP3oool005`0oooo1P00001I0?ooo`D00000<03oool40<o?
c`l0oooo100000000`3oool000000000000K0?ooo`@00000R03oool005h0oooo1`00001G0?ooo`<0
00002@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo0`3?cll>0?ooo`L0
0000703oool5000008H0oooo001Q0?ooo`H00000E@3oool3000000P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0?0?ooo`80clo?3P3oool9000001`0oooo100000250?ooo`00I03o
ool600000580oooo0`0000080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3o
ool30<o?c`d0oooo2P00000M0?ooo`@00000P`3oool006H0oooo1`00001?0?ooo`H00000103oool0
0`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03`3oool20<o?c`d0oooo2P00000N0?ooo`@00000PP3oool0
06T0oooo1P00001=0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00l0oooo0`3?cll<0?ooo`X00000803oool400000800oooo001/0?ooo`H00000BP3oool300000003
0?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100
oooo0P3?cll<0?ooo`T000008P3oool4000007l0oooo001^0?ooo`L00000A`3oool300000080oooo
0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`0000060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0403oool30<o?c`X0oooo2@00000U0?ooo`@00000
O@3oool00740oooo1P0000150?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0A0?ooo`80clo?2P3oool8000002L0oooo1000001l0?ooo`00M03oool6
00000480oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0140oooo1P3?cll60?ooo`L00000:P3oool4000007X0oooo001f0?ooo`L00000?P3oool50000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`P0clo?1P3oool6000002`0oooo1@00001h0?ooo`00N@3oool6000003h0oooo1@0000040?ooo`04
0000003oool0oooo0?ooo`@000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00l0oooo203?cll60?ooo`D00000;`3oool4000007L0oooo001l0?ooo`H00000A@3oool01@000000
oooo0?ooo`3oool0000000`0oooo100000050?ooo`030000003oool0oooo0140oooo1`3?cll60?oo
o`@00000<P3oool4000007D0oooo001n0?ooo`L00000@P3oool01@000000oooo0?ooo`3oool00000
00h0oooo0P0000050?ooo`030000003oool0oooo0180oooo1P3?cll60?ooo`<00000=03oool40000
07@0oooo00210?ooo`H00000@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0503oool40<o?c`L0oooo0P00000g0?ooo`@00000LP3oool008@0oooo
1P00001^0?ooo`<0clo?@@3oool400000740oooo00260?ooo`L00000K03oool20<o?cd<0oooo1000
001_0?ooo`00R@3oool600000;00oooo1000001^0?ooo`00S03oool600000640oooo300000050?oo
o`D00000>03oool4000006`0oooo002>0?ooo`L00000GP3oool<000000H0oooo0`0000090?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool5000006X0oooo002A0?ooo`H00000
G03oool2000000P0oooo0P0000060?ooo`<00000203oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01L0oooo1000001Y0?ooo`00U03oool6000005T0oooo0P0000080?ooo`8000001P3o
ool3000000P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`@00000I`3o
ool009H0oooo1`00001F0?ooo`800000203oool2000000H0oooo1P0000040?ooo`030000003oool0
oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo1`0000040?ooo`030000003oool0
oooo01T0oooo1000001V0?ooo`00V@3oool7000005<0oooo0P0000080?ooo`8000001P3oool70000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`@00000I03oool009`0
oooo1P00001A0?ooo`800000203oool2000000H0oooo0`0000000`3oool000000000000200000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`@00000H`3oool009l0oooo
1P00001>0?ooo`800000203oool2000000H0oooo0`0000020?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L000000`3oool2000000P0oooo00<000000?ooo`3oool0
7P3oool400000640oooo002Q0?ooo`L00000B`3oool2000000P0oooo0P0000060?ooo`<000000P3o
ool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo01l0oooo1@00001O0?ooo`00Y03oool6
000004T0oooo300000060?ooo`<000000P3oool300000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Q0?ooo`@00000GP3oool00:L0oooo1P0000160?ooo``000001@3oool50000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?oo
o`@00000G03oool00:T0oooo1`00001F0?ooo`D00000103oool010000000oooo0?ooo`3oool40000
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02@0oooo1000001K0?ooo`00[03oool6000005h0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`@00000F@3oool0
0:l0oooo1P00001K0?ooo`050000003oool0oooo0?ooo`000000303oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0:03oool4000005P0oooo002a0?ooo`L00000F@3oool0
0`000000oooo0?ooo`0>0?ooo`<00000103oool00`000000oooo0?ooo`0[0?ooo`@00000EP3oool0
0;@0oooo1P00002N0?ooo`@00000E@3oool00;L0oooo1P00002M0?ooo`@00000D`3oool00;T0oooo
1`00002K0?ooo`D00000D@3oool00;`0oooo1P00002K0?ooo`@00000D03oool00;l0oooo1P00002J
0?ooo`@00000CP3oool00<40oooo1`00002H0?ooo`@00000C@3oool00<@0ooooX@00001<0?ooo`00
a`3ooonN000004`0oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80
oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oooa40oooo1`0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P00001G0?ooo`00o`3ooolA0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080000000<0oooo0000003oool00`3oool01@000000oooo0?oo
o`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`H0000000<0oooo0000003oool00`3oool01@000000
oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo1`0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo0000001H0?ooo`00o`3ooolA0?ooo`030000003oool0oooo00D0oooo0P00
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000P3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool010000000oooo0000000000020?oo
o`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000005P0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`05
0000003oool000000000003oool00`0000060?ooo`8000000`3oool00`000000oooo000000020000
00<0oooo0`00001G0?ooo`00o`3ooolA0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0EP3oool00?l0oooo4@3oool7000000l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`1F0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00
o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00
o`3ooonb0?ooo`00o`3ooonb0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001XB000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3oool?0?ooo`<00000X03o
ool00?l0oooo403oool00`000000oooo0?ooo`2O0?ooo`00o`3oool@0?ooo`030000003oool0oooo
09l0oooo003o0?oooa00oooo00<000000?ooo`3oool0W`3oool00?@0oooo0`0000030?ooo`<00000
103oool2000000030?ooo`000000oooo0080oooo1@0000020?ooo`@000001P3oool5000000@0oooo
00<000000?ooo`3oool0103oool2000000P0oooo0`0000060?ooo`<000000P3oool500000080oooo
0`000000103oool0000000000000001R0?ooo`00m03oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
H`3oool00?D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000006<0oooo
003e0?ooo`L000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool6000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`<00000103oool01@000000oooo0?ooo`3oool0000006<0
oooo003f0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001S0?ooo`00mP3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`00mP3o
ool010000000oooo0?ooo`0000070?ooo`80000000<0oooo0000003oool00P3oool3000000@0oooo
00@000000?ooo`0000000000103oool4000000040?ooo`000000oooo0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`<000001@3oool010000000oooo00000000001T0?ooo`00m`3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000007<0oooo003g0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000L`3oool00?P0oooo00<000000?ooo`3oool0203oool2000002l0oooo00<0
00000?ooo`3oool00`3oool010000000oooo00000000001c0?ooo`00n03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool7000000<0oooo00<0
00000?ooo`3oool0L@3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool007P0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0f0?ooo`00MP3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000=P3oool007P0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0f0?ooo`00M@3oool0o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo00000000103oool000000?ooo`0000020?ooo`030000003oool0oooo03@0
oooo001f0?ooo`3o0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000000040?ooo`000000oooo000003P0oooo001b0?ooool000001`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooool000001P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000940l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2
00000940l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00002A0?3`
l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00002A0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000T@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`<000000P3oool0
0`000000oooo0?ooo`0d0?ooo`00LP3oool200000940l?3`=`3oooli0<o?c`80000000<0oooo0000
003oool0=`3oool00780oooo0P00002A0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00001E0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00LP3oool2000005D0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool00780oooo0P00000@0?3`l0030000003`l?00l?3`00<0l?3`1`000003
0?3`l0030000003`l?00l?3`00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l005
0?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l006
0?3`l0800000>P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
0100l?3`00<000000?3`l03`l?00103`l?0200000080l?3`0P0000020?3`l0030000003`l?00l?3`
00/0l?3`00<000000?3`l03`l?002@3`l?000`000000l?3`0?3`l0070?3`l0030000003`l?00l?3`
0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0<00000>@3`l?0g0?oo
ocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000403`l?000`000000
l?3`0?3`l0040?3`l08000001P3`l?000`000000l?3`0?3`l00;0?3`l0030000003`l?00l?3`00T0
l?3`00<000000?3`l03`l?001`3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080
l?3`00<000000?3`l03`l?001@3`l?03000003T0l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00000>0?3`l0@000001@3`l?02000000030?3`l000000000000080l?3`
00@000000?3`l03`l?00l?3`0P0000030?3`l0<000000P3`l?000`000000l?3`0?3`l0030?3`l0@0
00000P3`l?000`000000l?3`0?3`l0020?3`l0<00000103`l?000`000000l?3`0?3`l0020?3`l003
0000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?03000003T0l?3`=`3oooli0<o?c`<0
00000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000d0l?3`00H000000?3`l03`l?00
00000?3`l00000040?3`l0D000000P3`l?000`000000l?3`0?3`l0030?3`l0060000003`l?00l?3`
0000003`l?0000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l0000000103`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0<00000>@3`l?0g0?ooocT0clo?0P00
00000`3oool000000?ooo`0g0?ooo`00LP3oool2000000`0l?3`00D000000?3`l03`l?00l?3`0000
00020?3`l0040000003`l?00l?3`0?3`l080000000<0l?3`0000000000000P3`l?000`000000l?3`
0?3`l0030?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00103`l?000`000000
l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00103`l?04000003P0
l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3oool2000000`0l?3`
00D000000?3`l03`l?00l?3`000000020?3`l0040000003`l?00l?3`0?3`l08000000P3`l?020000
00030?3`l0000000l?3`00@0l?3`00@000000?3`l03`l?000000103`l?000`000000l?3`0?3`l005
0?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<00000
0?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`800000303`l?001@00
0000l?3`0?3`l03`l?0000000080l?3`00<000000?3`l03`l?001`0000000`3`l?0000000?3`l004
0?3`l0040000003`l?00l?3`000000@0l?3`00<000000?3`l03`l?000`3`l?02000000@0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0040?3`l0@00000>03`l?0g0?ooocT0clo?0`00
00020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000303`l?001@000000l?3`0?3`l03`
l?0000000080l?3`00<000000?3`l03`l?00203`l?001`000000l?3`0?3`l03`l?0000000?3`l000
00000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`00<000000?3`l03`
l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1000000h0?3`l3L0
oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000003@3`l?03000000030?3`
l0000000000000/0l?3`00<000000?3`l03`l?000P3`l?0700000080l?3`00<000000?3`l03`l?00
0P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00000000@0l?3`00<000000?3`l03`l?00
103`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?00
103`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000001h0l?3`00<000000?3`l03`l?002`3`l?000`000000l?3`0?3`l0030?3`l0@000000P3`
l?0010000000l?3`0?3`l03`l?04000000@0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`
0?3`l0020?3`l0030000003`l?00l?3`00@0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?oo
o`000000oooo03L0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`l00;0?3`l0030000003`
l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000003`l?00l?3`0080l?3`
00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000=`3`l?0g0?ooocT0clo?
0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`8000007`3`l?000`000000l?3`0?3`
l00;0?3`l0030000003`l?00l?3`00T0l?3`00D000000?3`l03`l?00l?3`000000050?3`l0030000
003`l?00l?3`0080l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0050?3`l0D00000
=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000200l?3`00<0
00000?3`l03`l?002`3`l?000`000000l?3`0?3`l0090?3`l0030000003`l?00l?3`00D0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00H0l?3`1P00
000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E
0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool20000
05D0l?3`1P00000f0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00001E0?3`l0H00000=P3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00
LP3oool2000005D0l?3`1`00000>0?3`l0L00000803`l?0g0?oooal0clo?00<000000<o?c`3?cll0
0`3?cll00`000000clo?0<o?c`0A0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1`0000060?3`l0030000003`l?00l?3`00H0l?3`0P0000020?3`l0800000103`
l?000`000000l?3`0?3`l0040?3`l0030000003`l?00l?3`00d0l?3`0`0000020?3`l1@0oooo1@00
00040?ooo`8000005@3oool3000001h0clo?00<000000<o?c`3?cll01@3?cll00`000000clo?0<o?
c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0060?3`l08000001`3`l?000`000000l?3`0?3`l0060?3`l0030000003`l?00
l?3`00`0l?3`100000000`3`l?00oooo0?ooo`0A0?ooo`<000000`3oool200000080oooo0`00000D
0?ooo`@00000703?cll00`000000clo?0<o?c`070<o?c`030000003?cll0clo?00l0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?07000000H0l?3`00<000000?3`
l03`l?001P3`l?02000000030?3`l0000000000000@0l?3`00<000000?3`l03`l?001P3`l?000`00
0000l?3`0?3`l00<0?3`l0D000004P3oool3000000D0oooo100000000`3oool000000?ooo`0C0?oo
o`H00000403?cll3000000040<o?c`0000000000000000<0clo?00@000000<o?c`3?cll0clo?0`00
00030<o?c`030000003?cll0clo?00l0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool2
000005D0l?3`200000050?3`l0@000000P3`l?02000000030?3`l0000000000000<000000`3`l?00
0`000000l?3`0?3`l0020?3`l0<000000`3`l?000`000000l?3`0?3`l00;0?3`l0L00000403oool2
000000H0oooo0`00000G0?ooo`L000003P3?cll00`000000clo?0<o?c`02000000<0clo?00<00000
0<o?c`000000103?cll00`000000clo?0<o?c`040<o?c`030000003?cll0clo?00h0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?08000000D0l?3`00@000000?3`
l03`l?00l?3`0P0000030?3`l080000000<0l?3`0000000000000`3`l?000`000000l?3`0?3`l002
0?3`l0030000003`l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?08000000h0oooo0`000007
0?ooo`8000005`3oool9000000`0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?
cll0000000@0clo?00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0
oooo0000003oool0=`3oool00780oooo0P00001E0?3`l0P000001@3`l?0010000000l?3`0?3`l03`
l?02000000<0l?3`0P0000020?3`l08000000P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00<0l?3`00<000000?3`l03`l?002`3`l?09000000d0oooo0`0000070?ooo`8000005`3o
ool:000000/0clo?00D000000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?
00<000000<o?c`3?cll0103?cll00`000000clo?0<o?c`0>0<o?c`<000000P3oool00`000000oooo
0?ooo`0d0?ooo`00LP3oool2000005D0l?3`200000050?3`l0030000003`l?00l?3`0080l?3`00<0
00000?3`l03`l?001`0000020?3`l0030000003`l?00l?3`0080l?3`00<000000?3`l03`l?000`3`
l?000`000000l?3`0000000E000000`0oooo0`0000070?ooo`<000002P3ooolG000000X0clo?00D0
00000<o?c`3?cll0clo?000000030<o?c`030000003?cll0000000@0clo?00<000000<o?c`3?cll0
103?cll00`000000clo?0<o?c`0>0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo0P00
001E0?3`l0P000001@3`l?000`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<0
00000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`l?00000001D00000303o
ool3000000L0oooo0`00000:0?oooaL000002P3?cll200000080clo?00<000000<o?c`3?cll00P00
00000`3?cll000000<o?c`030<o?c`030000003?cll0clo?00@0clo?00<000000<o?c`3?cll03P3?
cll300000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000001P3`l?00
0`000000l?3`0?3`l0020?3`l0030000003`l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?00
0`000000l?3`0?3`l0030?3`l0030000003`l?00l?3`00/0l?3`2000000?0?ooo`8000001P3oool0
10000000oooo00000000000F0?ooo`T000003@3?cll2000000<0clo?0P0000030<o?c`050000003?
cll0clo?0<o?c`0000001@3?cll00`000000clo?0<o?c`0?0<o?c`80000000<0oooo0000003oool0
=`3oool00780oooo0P00001E0?3`l0L000001P3`l?000`000000l?3`0?3`l0020?3`l0030000003`
l?00l?3`00T0l?3`00<000000?3`l03`l?000P3`l?000`000000l?3`0?3`l0030?3`l0030000003`
l?00l?3`00/0l?3`1P00000A0?ooo`<000001@3oool010000000oooo00000000000F0?ooo`L00000
6@3?cll00`000000clo?0<o?c`04000000<0clo?00<000000<o?c`3?cll03`3?cll300000080oooo
00<000000?ooo`3oool0=03oool00780oooo0P00001E0?3`l0L000005`3`l?0010000000l?3`0?3`
l03`l?04000000<0l?3`00<000000?3`l03`l?002`3`l?04000000030?3`l03oool0oooo0140oooo
0`0000030?ooo`030000003oool0oooo00<000005@3oool4000001d0clo?00@000000<o?c`3?cll0
0000103?cll00`000000clo?0<o?c`0@0<o?c`80000000<0oooo0000003oool0=`3oool00780oooo
0P00001E0?3`l0L00000603`l?001@000000l?3`0?3`l03`l?00000000@0l?3`00<000000?3`l03`
l?00303`l?02000000<0l?3`5@3oool4000000<0oooo0`00000E0?ooo`80000000<0oooo0<o?c`3?
cll07@3?cll00`000000clo?000000030<o?c`030000003?cll0clo?0140clo?0`0000020?ooo`03
0000003oool0oooo03@0oooo001b0?ooo`800000E@3`l?06000001T0l?3`00D000000?3`l03`l?00
l?3`000000040?3`l0030000003`l?00l?3`0140l?3`=`3oooli0<o?c`80000000<0oooo0000003o
ool0=`3oool00780oooo0P00001E0?3`l0H000006P3`l?000`000000l?3`0?3`l0040?3`l0030000
003`l?00l?3`0180l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00LP3o
ool2000005D0l?3`1P00000f0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b
0?ooo`800000E@3`l?06000003H0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d
0?ooo`00LP3oool2000005D0l?3`1@00000g0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000E@3`l?05000003L0l?3`=`3oooli0<o?c`<000000P3oool00`000000
oooo0?ooo`0d0?ooo`00LP3oool200000340l?3`00<000000?3`l03`l?00103`l?000`000000l?3`
0?3`l00J0?3`l0D00000=`3`l?0g0?ooocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3o
ool200000300l?3`00<000000?3`l03`l?001P3`l?000`000000l?3`0?3`l00I0?3`l0D00000=`3`
l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000<03`l?00
0`000000l?3`0?3`l0060?3`l0030000003`l?00l?3`01T0l?3`1000000h0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?04000000<0l?3`00@000000?3`
l03`l?00l?3`0`0000040?3`l0030000003`l?00l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
0080l?3`00@000000?3`l03`l?0000000`3`l?000`000000l?3`0?3`l0040?3`l0030000003`l?00
l?3`01P0l?3`1000000h0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?oo
o`8000009`3`l?000`000000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<00000
0?3`l03`l?00103`l?000`000000l?3`0?3`l00H0?3`l0@00000>03`l?0g0?ooocT0clo?0`000002
0?ooo`030000003oool0oooo03@0oooo001b0?ooo`800000:P3`l?02000000<0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll2
000000030?ooo`000000oooo03L0oooo001b0?ooo`800000:03`l?02000000D0l?3`00D000000?3`
l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i0?3`l3L0oooo>@3?cll3
00000080oooo00<000000?ooo`3oool0=03oool00780oooo0P00000W0?3`l0030000003`l?00l?3`
00D0l?3`00D000000?3`l03`l?00l?3`000000060?3`l0030000003`l?00l?3`01P0l?3`0`00000i
0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo001b0?ooo`8000009`3`l?000`00
0000l?3`0?3`l0020?3`l0040000003`l?00l?3`000000<0l?3`00<000000?3`l03`l?00103`l?00
0`000000l?3`0?3`l00H0?3`l0<00000>@3`l?0g0?ooocT0clo?0`0000020?ooo`030000003oool0
oooo03@0oooo001b0?ooo`800000:03`l?04000000<0l?3`00<000000?3`l03`l?00100000040?3`
l0030000003`l?00l?3`01P0l?3`0P00000j0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo001b0?ooo`800000<03`l?0010000000l?3`0?3`l00000050?3`l0030000003`l?00l?3`
01T0l?3`0P00000j0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3oool0=03oool00780
oooo0P00000`0?3`l0040000003`l?00l?3`000000D0l?3`00<000000?3`l03`l?00E@3`l?0g0?oo
ocT0clo?0P0000000`3oool000000?ooo`0g0?ooo`00LP3oool200000340l?3`00<000000?3`l03`
l?00103`l?000`000000l?3`0?3`l01F0?3`l3L0oooo>@3?cll300000080oooo00<000000?ooo`3o
ool0=03oool00780oooo0P00002A0?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo03L0oooo
000/0?ooo`<00000@`3oool2000000T0l?3`0`0000250?3`l3L0oooo>@3?cll300000080oooo00<0
00000?ooo`3oool0=03oool002/0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000001`3`
l?05000008D0l?3`=`3oooli0<o?c`80000000<0oooo0000003oool0=`3oool00300oooo00<00000
0?ooo`3oool0?`3oool2000000D0l?3`1`0000250?3`l3L0oooo>@3?cll300000080oooo00<00000
0?ooo`3oool0=03oool00240oooo1P0000000`3oool000000?ooo`030?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000000000000000
0`3oool4000002P0oooo0P0000030?3`l0P00000QP3`l?0g0?ooocT0clo?0P0000000`3oool00000
0?ooo`0g0?ooo`00803oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo02D0oooo0P0000000`3`l?00
000000000007000008L0l?3`=`3oooli0<o?c`<000000P3oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000070?oo
o`030000003oool0oooo02D0oooo300000270?3`l3L0oooo>@3?cll2000000030?ooo`000000oooo
03L0oooo000W0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000:03oool;
000008P0l?3`=`3oooli0<o?c`<00000>@3oool002D0oooo0P0000001@3oool000000?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool5000000030?oo
o`000000oooo0080oooo0P00000Z0?ooo`X00000R@3`l?0g0?ooocT0clo?0P00000j0?ooo`008@3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`X0
0000R@3`l?0g0?ooocT0clo?0`00000i0?ooo`00803oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02D0ooooo`000006000003X0oooo000P0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`80
000000H0oooo0000003oool0oooo0000003oool3000000@0oooo100000020?ooo`040000003oool0
oooo0?ooo`@00000:03ooooo000000H00000>P3oool00200oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo2000003o0?ooocP0oooo000Q0?oo
o`H0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0/0?ooo`<0000000<0oooo0000
000000000P00003o0?ooocT0oooo001`0?ooo`<000000`3oool2000002h0oooo0P00o`0<0?ooo`80
0?l0n`3oool006l0oooo0`00000d0?ooo`800?l0303oool2003o0?/0oooo001^0?ooo`<00000=@3o
ool3003o00/0oooo0`00o`0<0?ooo`<00?l0S@3oool20?l005`0oooo000;0?ooo`L0000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool3000000040?ooo`00000000000000
00l0oooo0`00000e0?ooo`@00?l02`3oool4003o00/0oooo1@00o`2;0?ooo`80o`002P3oool20?l0
00P0oooo0P3o00160?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0200000003
0?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool03@3oool3000003H0oooo1000o`0<0?ooo`@00?l02P3oool6
003o08T0oooo0`3o000:0?ooo`80o`00203oool20?l004H0oooo000;0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000003@3oool3000003L0oooo1@00o`0;0?oo
o`D00?l02P3oool7003o08H0oooo0`3o000:0?ooo`<0o`00203oool20?l004H0oooo000;0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303oool3000003P0
oooo1@00o`0;0?ooo`H00?l02@3oool9003o08<0oooo0`3o000;0?ooo`80o`002@3oool20?l004H0
oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool6000000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`D0000000<0oooo0000003oool02P3oool3000003T0oooo1@00o`0;0?ooo`L00?l0
2@3oool9003o0880oooo0P3o000<0?ooo`80o`002@3oool20?l004H0oooo000;0?ooo`L0000000<0
oooo0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0000000:
0?ooo`<00000>@3oool7003o00X0oooo2000o`080?ooo`/00?l0S@3oool30?l000T0oooo0P3o0016
0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool000000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000<0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002@3oool3000003X0oooo1`00o`0;
0?ooo`P00?l0203oool;003o08`0oooo0P3o000:0?ooo`80o`00AP3oool000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P00
00020?ooo`050000003oool000000000003oool00`0000060?ooo`8000000`3oool00`000000oooo
00000002000000<0oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`<00000
>`3oool7003o00/0oooo2@00o`070?ooo`/00?l0h03oool000/0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0`00000l0?ooo`P00?l02P3o
ool:003o00H0oooo2P00o`3Q0?ooo`002`3oool7000000l0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0`00000m0?ooo`P00?l02P3oool:
003o00L0oooo2000o`3R0?ooo`00H`3oool3000003d0oooo2@00o`0:0?ooo`P00?l02@3oool8003o
0>80oooo001R0?ooo`<00000?P3oool:003o00X0oooo1P00o`0;0?ooo`P00?l0N03oool20?l006L0
oooo001Q0?ooo`<00000?`3oool:003o00X0oooo0`00o`000`3oool00?l0003o000;0?ooo`@00?l0
0P3oool3003o07L0oooo0P3o001W0?ooo`00H@3oool200000400oooo2000o`0<0?ooo`800?l00P3o
ool3003o00/0oooo0P00o`040?ooo`800?l0MP3oool30?l006L0oooo001P0?ooo`<00000A@3oool2
003o0180oooo0`00o`0@0?ooo`<00?l0M03oool30?l00140oooo0P3o001E0?ooo`00G`3oool30000
04H0oooo0P00o`0C0?ooo`<00?l0403oool2003o07<0oooo0`3o000B0?ooo`80o`00303oool20?l0
04L0oooo001O0?ooo`800000A`3oool2003o01@0oooo0P00o`240?ooo`<0o`004P3oool30?l000`0
oooo0P3o00170?ooo`00GP3oool3000004L0oooo0P00o`2J0?ooo`80o`004`3oool20?l000d0oooo
0P3o00170?ooo`00G@3oool3000004P0oooo0P00o`2I0?ooo`<0o`004P3oool30?l000`0oooo0`3o
00170?ooo`00G@3oool2000004T0oooo0P00o`2H0?ooo`<0o`004`3oool20?l000d0oooo0P3o0018
0?ooo`00G03oool300000>80oooo0`3o000D0?ooo`80o`003@3oool20?l004P0oooo001K0?ooo`<0
0000NP3oool3003o06H0oooo0P3o000D0?ooo`<0o`003@3oool20?l004P0oooo001K0?ooo`800000
N`3oool4003o07/0oooo0P3o000>0?ooo`80o`00B03oool005X0oooo0`00001m0?ooo`<00?l0N@3o
ool30?l000d0oooo0`3o00180?ooo`00F@3oool3000007l0oooo1000o`1g0?ooo`80o`003P3oool2
0?l004T0oooo001H0?ooo`<00000J03oool2003o01L0oooo1000o`260?ooo`80o`00B@3oool005P0
oooo0P00001Y0?ooo`800?l06@3oool3003o08D0oooo0P3o00190?ooo`00E`3oool3000004l0oooo
0P00o`0H0?ooo`<00?l06@3oool3003o05T0oooo0P3o001d0?ooo`00EP3oool300000500oooo0P00
o`0I0?ooo`800?l06P3oool3003o05P0oooo0P3o001d0?ooo`00EP3oool200000540oooo0P00o`0I
0?ooo`<00?l06P3oool2003o05L0oooo0`3o001d0?ooo`00E@3oool300000540oooo0P00o`0J0?oo
o`800?l0LP3oool30?l001L0oooo0P3o001L0?ooo`00E03oool300000580oooo0`00o`0I0?ooo`<0
0?l0L03oool30?l001P0oooo0P3o001L0?ooo`00E03oool2000005@0oooo0P00o`0J0?ooo`<00?l0
KP3oool30?l001P0oooo0`3o001L0?ooo`00D`3oool3000005@0oooo0P00o`0K0?ooo`800?l0K@3o
ool30?l001T0oooo0P3o001M0?ooo`00DP3oool3000005D0oooo0P00o`0K0?ooo`<00?l0J`3oool3
0?l001T0oooo0`3o000B0?ooo`80o`00B@3oool00580oooo0P00001F0?ooo`800?l0703oool2003o
06X0oooo0`3o000J0?ooo`80o`004`3oool20?l004T0oooo001A0?ooo`<00000EP3oool2003o01`0
oooo0`00o`0M0?ooo`800?l0B@3oool30?l001X0oooo0`3o000C0?ooo`80o`00B@3oool00540oooo
0P00001G0?ooo`<00?l0703oool2003o01d0oooo0`00o`180?ooo`80o`006`3oool20?l001@0oooo
0P3o00190?ooo`00D@3oool2000005P0oooo0P00o`0l0?ooo`<00?l0H`3oool30?l001@0oooo0P3o
00190?ooo`00D03oool3000005P0oooo0P00o`0m0?ooo`<00?l0HP3oool20?l001D0oooo0P3o0019
0?ooo`00D03oool2000005T0oooo0P00o`0n0?ooo`<00?l0H03oool30?l001@0oooo0`3o00190?oo
o`00D03oool2000009X0oooo0`00o`1O0?ooo`80o`005@3oool20?l004X0oooo001?0?ooo`<00000
V`3oool3003o07D0oooo0P3o001:0?ooo`00C`3oool2000009d0oooo0`00o`0l0?ooo`80o`00=P3o
ool20?l004X0oooo001?0?ooo`800000WP3oool3003o03/0oooo0P3o000f0?ooo`80o`00BP3oool0
04h0oooo0`00001l0?ooo`800?l08@3oool3003o03T0oooo0`3o000f0?ooo`80o`00BP3oool004h0
oooo0P00001m0?ooo`800?l08P3oool2003o03P0oooo0`3o000g0?ooo`80o`00BP3oool004h0oooo
0P00001m0?ooo`<00?l0FP3oool30?l008@0oooo001=0?ooo`<00000F`3oool2003o0240oooo0P00
o`1I0?ooo`<0o`007`3oool20?l006@0oooo001=0?ooo`800000G03oool2003o0240oooo0P00o`1I
0?ooo`80o`00803oool20?l006@0oooo001=0?ooo`800000G03oool2003o0240oooo0`00o`1G0?oo
o`<0o`00803oool20?l006@0oooo001<0?ooo`<00000G03oool2003o0280oooo0P00o`1F0?ooo`<0
o`00803oool30?l006@0oooo001<0?ooo`800000G@3oool2003o0280oooo0`00o`0W0?ooo`800?l0
:`3oool30?l00240oooo0P3o001U0?ooo`00C03oool2000005d0oooo0P00o`0S0?ooo`800?l09`3o
ool3003o02X0oooo0P3o000R0?ooo`80o`00I@3oool004/0oooo0`00001M0?ooo`800?l08`3oool3
003o02L0oooo0`00o`1<0?ooo`<0o`00I@3oool004/0oooo0P00001N0?ooo`<00?l08`3oool2003o
02P0oooo0`00o`1;0?ooo`80o`00603oool20?l004`0oooo001;0?ooo`800000G`3oool2003o02<0
oooo0P00o`0Y0?ooo`<00?l0BP3oool20?l001P0oooo0P3o001<0?ooo`00BP3oool3000005l0oooo
0P00o`0S0?ooo`<00?l0:@3oool3003o04P0oooo0`3o000H0?ooo`80o`00C03oool004X0oooo0P00
001P0?ooo`800?l0903oool2003o02X0oooo0`00o`170?ooo`80o`006@3oool20?l004`0oooo001:
0?ooo`800000H03oool2003o0540oooo0`00o`160?ooo`80o`006@3oool20?l004`0oooo00190?oo
o`<00000H03oool2003o0580oooo0`00o`1P0?ooo`80o`00C03oool004T0oooo0P00001Q0?ooo`80
0?l0D`3oool3003o01X0oooo0P3o00120?ooo`<0o`00C03oool004T0oooo0P00002g0?ooo`800?l0
6P3oool20?l00480oooo0P3o001=0?ooo`00B03oool300000=80oooo0`3o00120?ooo`80o`00C@3o
ool004P0oooo0P00003B0?ooo`<0o`00@`3oool20?l004d0oooo00180?ooo`800000d@3oool30?l0
04@0oooo0P3o001=0?ooo`00B03oool2000008h0oooo0P00o`100?ooo`<0o`00:03oool20?l001/0
oooo0P3o001=0?ooo`00B03oool2000008h0oooo0P00o`100?ooo`80o`00:@3oool20?l001/0oooo
0P3o001=0?ooo`00A`3oool3000008h0oooo0`00o`0n0?ooo`<0o`00:03oool30?l006X0oooo0017
0?ooo`800000T03oool2003o02h0oooo0`00o`0<0?ooo`<0o`00:@3oool20?l006/0oooo00170?oo
o`800000I@3oool2003o02T0oooo0P00o`0^0?ooo`@00?l02P3oool30?l002T0oooo0`3o001[0?oo
o`00A`3oool2000006D0oooo0P00o`0Y0?ooo`<00?l0;`3oool3003o00T0oooo0P3o000Z0?ooo`80
o`00K03oool004H0oooo0`00001U0?ooo`800?l0:P3oool2003o0300oooo1000o`0c0?ooo`80o`00
K03oool004H0oooo0P00001V0?ooo`800?l0:P3oool3003o0300oooo1000o`0a0?ooo`<0o`00K03o
ool004H0oooo0P00001V0?ooo`800?l0:`3oool2003o0380oooo0`00o`0`0?ooo`80o`00K@3oool0
04H0oooo0P00001V0?ooo`800?l0:`3oool2003o03<0oooo0`00o`0^0?ooo`<0o`007P3oool20?l0
04d0oooo00160?ooo`800000IP3oool3003o02X0oooo0`00o`0c0?ooo`<00?l04P3oool<000000l0
oooo0P3o000O0?ooo`80o`00C@3oool004D0oooo0`00001W0?ooo`800?l0:`3oool2003o03@0oooo
0P00o`0O000002l0oooo0P3o001=0?ooo`00A@3oool2000006P0oooo0P00o`1?0?oooa4000000P3o
000D00000080oooo203`l?04000002`0oooo0`3o001=0?ooo`00A@3oool2000006P0oooo0P00o`0m
0?ooob<000000P3o00000`000000oooo0?ooo`0L0?3`l0@00000:`3oool20?l004h0oooo00150?oo
o`800000J03oool2003o02X0oooo9P0000030?ooo``0l?3`0`3o000Q0?3`l0@00000:@3oool20?l0
04h0oooo00140?ooo`<00000J03oool2003o01L0oooo9`0000020?oooah0l?3`0`3o000S0?3`l0@0
0000:03oool20?l004h0oooo00140?ooo`800000J@3oool2003o00D0oooo9P0000030?ooobl0l?3`
0`3o000V0?3`l0<0000000<0l?3`0?ooo`3oool0903oool20?l004h0oooo00140?ooo`800000G@3o
oolV000000<0oooo@@3`l?030?l002P0l?3`1000000T0?ooo`<0o`00CP3oool004@0oooo0P00001:
0?ooobL000000`3ooomB0?3`l0<0o`00303`l?02003o01`0l?3`100000000`3`l?00o`000?l0000P
0?ooo`80o`00C`3oool004@0oooo0P00000h0?ooobH000000`3ooomT0?3`l0<0o`003@3`l?02003o
01h0l?3`0`0000020?l00200oooo0P3o001?0?ooo`00@`3oool3000002D0oooo9P0000040?ooogD0
l?3`0`3o000>0?3`l0<00?l07P3`l?001@000000o`000?l0003o0000l?3`01l0oooo0P3o000=0?oo
o`80000000<0oooo0000000000000P00000k0?ooo`00@`3oool2000001<0oooo9`0000030?ooof00
l?3`0P00o`0U0?3`l0<0o`00403`l?03003o01h0l?3`0P3o0003000002d0oooo100000020?ooo`80
0000>P3oool004<0oooo0P00000:0?oooad00000103ooomb0?3`l0800?l09@3`l?020?l00180l?3`
0`00o`0H0?3`l0<0o`0000@0l?3`0?l0003o0000o`001000000/0?ooo`<000000`3oool3000003T0
oooo00130?ooo`8000002P3oool:000000@0ooooQ@3`l?03003o03T0l?3`0`00o`0G0?3`l0H0o`00
0`3`l?04000002X0oooo0P0000040?ooo`<00000>@3oool004<0oooo0P00000<0?ooo`H00000S03`
l?02003o03X0l?3`0`00o`0F0?3`l0L0o`000`3`l?04000002h0oooo1000000i0?ooo`00@`3oool2
000000l0oooo1P00000j0?3`l0l00000203`l?0200000080l?3`0P00o`0b0?3`l0<00?l0>P3`l?03
003o01D0l?3`2@3o00030?3`l0@00000:P3oool5000003X0oooo00130?ooo`8000004@3oool70000
02L0l?3`0P0000030?3`l08000000P3`l?02000000D0l?3`4P0000050?3`l08000000P3`l?02003o
03<0l?3`0P00o`0k0?3`l0<00?l04`3`l?0:0?l000@0l?3`1000000W0?ooo`H00000>`3oool004<0
oooo0P00000D0?ooo`H000009@3`l?02000000<0l?3`0P0000020?3`l08000004`3`l?0700000003
0?3`l000000000000080000000@0l?3`003o0000o`000?l0<P3`l?03003o03/0l?3`0`00o`0B0?3`
l0X0o`001P3`l?04000002@0oooo1@00000m0?ooo`00@`3oool2000001H0oooo00<0l?3`00000000
0000100000130?3`l0T000000P3`l?02003o03<0l?3`0P00o`0L0?3`l080o`007P3`l?02003o0180
l?3`2@3o00080?3`l0@000004`3oool20?l000h0oooo0`0000040?ooo`800000>@3oool004<0oooo
0P00000I0?ooo`H00000A03`l?0600000080l?3`0P00o`0c0?3`l0<00?l06`3`l?020?l00380l?3`
203o000;0?3`l0<0000000<0l?3`0?ooo`3oool03`3oool20?l000h0oooo0`0000030?ooo`<00000
>@3oool004<0oooo0P00000L0?ooo`H00000@03`l?08000000040?3`l000o`000?l0003o03<0l?3`
0P00o`0D0?3`l080o`00103`l?030?l00380l?3`1`3o000=0?3`l0@00000403oool20?l000l0oooo
0P0000020?ooo`@00000>@3oool004<0oooo0P00000N0?ooo`H00000?@3`l?0900000080l?3`0P00
o`0c0?3`l0<00?l04`3`l?030?l00080l?3`0`3o000c0?3`l0H0o`003`3`l?04000000030?3`l03o
ool0oooo00`0oooo0P3o000@0?ooo`@0000000<0oooo000000000000>@3oool004<0oooo0P00000Q
0?ooo`H00000>P3`l?09000003P0l?3`0P00o`0B0?3`l0P0o`00=03`l?050?l00180l?3`1000000=
0?ooo`80o`00D03oool004<0oooo0P00000S0?ooo`L00000>P3`l?07000002L0l?3`00<0d=3@0?3`
l03`l?001@3`l?000`2@T900d=3@0?3`l00I0?3`l0L0o`00=03`l?060?l001<0l?3`100000000`3`
l?00oooo0?ooo`090?ooo`80o`00D03oool004<0oooo0P00000V0?ooo`H00000?03`l?03000002H0
l?3`00<0/;2`061PH03`l?001P3`l?000`3@d=00D51@0?3`l00H0?3`l0P0o`00:P3`l?02003o00P0
l?3`1@3o000F0?3`l0@000001@3oool30?l00080oooo0P3o001@0?ooo`00@`3oool2000002T0oooo
1P00001R0?3`l003010@4030`<00l?3`00L0l?3`00<0820P0=3@d03`l?005`3`l?090?l002T0l?3`
0P00o`080?3`l0@0o`00603`l?04000000040?3`l03oool0oooo0?ooo`L0o`00D03oool004<0oooo
0P00000[0?ooo`H00000:P3`l?000`20P800l?3`0?3`l0060?3`l003071`L03@d=00l?3`00D0l?3`
1000000G0?3`l0<0000000@0l?3`00000000000000000P3`l?000`2`/;00410@0?3`l0020?3`l004
071`L0000000<30`0>3Ph080l?3`00<0L71`061PH03`l?005P3`l?0;0?l002P0l?3`0`00o`070?3`
l0<0o`006`3`l?0400000080oooo2P3o001=0?ooo`00@P3oool3000002h0oooo1P00000V0?3`l003
0;2`/010@400l?3`00L0l?3`00<0/;2`051@D03`l?000`3`l?08000001@0l?3`00<000000?3`l03`
l?000P0000030?3`l0040000003`l?00H61P061PH0<0l?3`00@00000010@402`/;00/;2`0P3`l?00
0`2`/;00820P0?3`l00F0?3`l0/0o`00:@3`l?03003o00H0l?3`0P3o000M0?3`l0@0000000<0l?3`
0?l0003o0000203o001=0?ooo`00@P3oool200000340oooo1`00000S0?3`l003020P802PX:00l?3`
00P0l?3`00<0410@0>3Ph03`l?000P3`l?08000001@0l?3`00D000000?3`l03`l?00l?3`00000003
0?3`l0040000003`l?00820P092@T0<0l?3`00<00000030`<03`l?000`3`l?000`3Ph>0000000?3`
l00F0?3`l0T0o`00;03`l?02003o02L0l?3`0`00000:0?l004d0oooo00120?ooo`800000=03oool6
000001T0l?3`00D0<30`051@D01PH600@4100<30`0020?3`l0030<30`0000000l?3`00<0l?3`00@0
L71`0000000P8200`<300P3`l?000`1@D500L71`0?3`l0020?3`l0P00000503`l?001@000000l?3`
0?3`l03`l?00000000<0l?3`00@000000?3`l0000000/;2`0`3`l?000`000000<30`0?3`l0040?3`
l00300000030`<00l?3`01@0l?3`203o000^0?3`l0<00?l09`3`l?02000000T0o`00CP3oool00480
oooo0P00000f0?ooo`030?3`l0000000000000@000005P3`l?001@1@D500l?3`0?3`l01PH600820P
0080l?3`00<0H61P030`<03`l?000`3`l?0200000080X:2P0P3`l?000`2@T900820P0?3`l0020?3`
l0P000000`3`l?03000000h0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0040000003`l?00
00000;2`/0<0l?3`00<00000030`<03`l?00103`l?000`000000d=3@0?3`l0090?3`l0800?l02@3`
l?070?l000X0l?3`00<0d=3@0?3`l03`l?005@3`l?000`1`L700h>3P0?3`l00;0?3`l0800?l0:@3`
l?000`000000o`000?l000060?l004h0oooo00120?ooo`800000>@3oool6000001@0l?3`00<0d=3@
0?3`l02`/;000P0000020?3`l003030`<01`L700l?3`00<0l?3`00<00000030`<03`l?000`3`l?00
0`3@d=0000000?3`l0040?3`l0@000001@3`l?05000000`0l?3`0P0000020?3`l0030000003`l?00
l?3`0080000000<0l?3`0000002`/;000`3`l?000`000000<30`0?3`l0030?3`l0030;2`/0000000
l?3`00X0l?3`0P00o`080?3`l0H0o`002`3`l?000`2`/;00H61P0?3`l00F0?3`l0030:2PX01`L700
l?3`03L0l?3`1`3o001?0?ooo`00@P3oool2000003`0oooo1P00000A0?3`l0050>3Ph010@4000000
0000001@D5000P3`l?000`000000/;2`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<00000
0;2`/03`l?003P3`l?05000000/0l?3`0P0000030?3`l08000000P3`l?001@0`<300T92@0?3`l03`
l?00H61P0080000000H0<30`092@T03`l?00l?3`092@T00`<30;0?3`l0800?l0203`l?040?l000d0
l?3`00<0410@0<30`03`l?005`3`l?000`0@4100h>3P0?3`l00f0?3`l0L0o`00C`3oool00480oooo
0P00000n0?ooo`H000003`3`l?001@1@D50000000000001@D500h>3P0080l?3`00<000000;2`/03`
l?000`3`l?000`000000<30`0?3`l0040?3`l0030000002`/;00l?3`0100l?3`1@00000B0?3`l003
071`L01PH600l?3`0080l?3`00<0D51@030`<03`l?000`3`l?000`1@D500P8200?3`l00:0?3`l080
0?l01`3`l?040?l000<0l?3`0`000000103`l?0000000000000000030?3`l0030;2`/00@4100l?3`
0080l?3`00@0L71`0000000`<300h>3P0`3`l?000`000000/;2`0?3`l0030?3`l0060;2`/01PH600
00000000001PH600T92@0`3`l?000`1@D500P8200?3`l00f0?3`l0H0o`0000<000000?ooo`3oool0
C@3oool00480oooo0P0000110?ooo`H00000303`l?02000000030<30`03`l?00l?3`0080l?3`00<0
00000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`l0030000002`/;00l?3`0180l?3`1@00
000@0?3`l0030=3@d00@4100l?3`00<0l?3`00<0T92@0?3`l03`l?000P3`l?000`000000h>3P0?3`
l00:0?3`l0<00?l01P3`l?020?l000@0l?3`00<000000?3`l03`l?000P0000030?3`l0030000003`
l?00l?3`0080H61P0`3`l?0010000000410@0;2`/02`/;030?3`l0030000002`/;00l?3`00D0l?3`
00<0<30`0000003`l?00103`l?000`20P800@4100?3`l00;0?3`l0D000009P3`l?060?l000800000
00<0l?3`0?ooo`3oool0B`3oool00480oooo0P0000130?ooo`L000002@3`l?001@0@4100L71`0?3`
l03`l?00D51@0080l?3`00<0820P092@T03`l?000`3`l?000`000000<30`0?3`l0030?3`l0030<30
`0000000l?3`01D0l?3`1@00000?0?3`l0030410@03@d=00l?3`00H0l?3`00<0X:2P061PH03`l?00
303`l?02003o00`0l?3`00D000000?3`l03`l?00l?3`000000030?3`l0050000003`l?00l?3`020P
802@T9000`3`l?0010000000<30`0?3`l03`l?030;2`/00500000020P800/;2`0;2`/03@d=000`3`
l?000`0`<30000000?3`l0040?3`l0030;2`/0000000l?3`00X0l?3`1`00000:0?3`l0L000001`3`
l?02000000/0l?3`1P3o0004000004`0oooo00120?ooo`800000AP3oool6000000L0l?3`00D0`<30
051@D01`L700D51@0410@0020?3`l003051@D01PH600l?3`0080l?3`00D0<30`0000000000000000
030`<0020?3`l003092@T00@4100l?3`01L0l?3`1@00000=0?3`l0030=3@d01PH600l?3`00H0l?3`
00<0`<300>3Ph03`l?00303`l?02003o00`0l?3`00D000000?3`l03`l?00l?3`000000030?3`l005
0000003`l?00l?3`0000002`/;000`3`l?0010000000<30`0?3`l03`l?0700000006071`L03`l?00
l?3`0?3`l00`<30000001@3`l?000`2`/;0000000?3`l00:0?3`l0L000001@3`l?0?000000@0l?3`
0P00000;0?3`l0D0o`000P3`l?04000000030?3`l03oool0oooo04P0oooo00120?ooo`800000B@3o
ool6000000/0l?3`00<0X:2P020P803`l?000`3`l?000`1@D500<30`0?3`l0030?3`l080D51@6P3`
l?05000000`0l?3`00<0h>3P0?3`l03`l?00503`l?02003o00`0l?3`00D000000?3`l03`l?00l?3`
000000030?3`l0050000003`l?00l?3`0000002`/;000`3`l?000`000000<30`0?3`l0040?3`l003
0000002`/;00l?3`00D0l?3`00<0<30`0000003`l?00103`l?000`2`/;0000000?3`l00:0?3`l0L0
00001@3`l?06000000D0l?3`1P0000020?3`l0<000002`3`l?040?l000@0l?3`100000190?ooo`00
@P3oool2000004/0oooo1P00000:0?3`l003010@403@d=00l?3`00<0l?3`00<0T92@0?3`l03`l?00
0P3`l?000`000000d=3@0?3`l00K0?3`l0D00000;`3`l?0200000080l?3`00<000000?3`l03`l?00
0P0000020?3`l0030000002`/;00l?3`0080l?3`00<00000030`<03`l?00103`l?000`000000/;2`
0?3`l0050?3`l003030`<0000000l?3`00@0l?3`00<0X:2P010@403`l?002P3`l?07000001<0l?3`
2@00000:0?3`l0<0o`001P3`l?04000000030?3`l03oool0oooo04D0oooo00120?ooo`800000CP3o
ool6000000L0l?3`00<0L71`092@T03`l?001`3`l?000`2PX:00<30`0?3`l00N0?3`l0H00000;@3`
l?02000000<0l?3`0P0000030?3`l005030`<02@T900l?3`0?3`l01PH6000P0000000`0`<300T92@
0?3`l0020?3`l0030000002`/;00l?3`00D0l?3`00<0<30`0000003`l?00103`l?00101`L700D51@
0?3`l03`l?0800000080l?3`1@00000F0?3`l0P000002@3`l?030?l000P0l?3`100000160?ooo`00
@P3oool200000500oooo1P0000050?3`l0030>3Ph00`<300l?3`00L0l?3`00<0L71`0=3@d03`l?00
803`l?07000003@0l?3`00<0L71`061PH03`l?000P3`l?000`1@D500<30`0?3`l00<0?3`l003030`
<0000000l?3`00@0l?3`00@0820P092@T03`l?00l?3`2000000N0?3`l0L000002@3`l?020?l000X0
l?3`100000000`3`l?00oooo0?ooo`120?ooo`00@P3oool2000005<0oooo1P0000030?3`l0030=3@
d03`l?00l?3`02`0l?3`2000000G0?3`l0D00000503`l?000`3@d=00410@0?3`l0030?3`l003092@
T03`l?00l?3`00T0l?3`00@0H61P0;2`/00`<3000000103`l?000`3@d=00410@0?3`l0020?3`l0P0
00007@3`l?09000001H0l?3`100000130?ooo`00@P3oool2000005D0oooo1`00000b0?3`l0P00000
203`l?03000000P0l?3`1`00000D0?3`l0030410@03@d=00l?3`00h0l?3`00@0h>3P071`L0000000
0000103`l?020820P0030?3`l0000000000000L000007@3`l?0;000001H0l?3`100000000`3`l?00
oooo0?ooo`0o0?ooo`00@P3oool2000005P0oooo1P00000d0?3`l0P00000103`l?05000000H0l?3`
1`00000D0?3`l0030=3@d01PH600l?3`0100l?3`00@0`<30010@403`l?00l?3`3P00000M0?3`l0/0
0000603`l?03000000030?3`l03oool0oooo03h0oooo00120?ooo`800000F`3oool6000003@0l?3`
200000000`3`l?00000000000005000000@0l?3`1`0000050?3`l0H000002P3`l?000`3Ph>00l?3`
0?3`l00>0?3`l0/000000P3`l?0500000480l?3`100000000`3`l?00oooo0?ooo`0l0?ooo`00@P3o
ool2000005d0oooo1`00000e0?3`l0d000000`3`l?07000000D0l?3`3@00000@0?3`l0X00000203`
l?04000002d0l?3`0P0000030?3`l08000000P3`l?02000000/0l?3`100000000`3`l?00oooo0?oo
o`0k0?ooo`00@P3oool3000005l0oooo1P00000f0?3`l0X00000103`l?05000000/0l?3`3`000004
0?3`l0X000003P3`l?02000002h0l?3`0P0000030?3`l08000000P3`l?02000000d0l?3`10000000
0`3`l?00oooo0?ooo`0i0?ooo`00@`3oool200000600oooo2000000e0?3`l0H000007@3`l?0B0000
05/0l?3`100000000`3`l?00oooo0?ooo`0h0?ooo`00@`3oool200000600oooo0P0000020?ooo`H0
0000<`3`l?04000002H0l?3`1P00001R0?3`l0@0000000<0l?3`0?ooo`3oool0=P3oool004<0oooo
0P00001O0?ooo`<000001@3oool600000300l?3`0P00002A0?3`l0@0000000<0l?3`0?ooo`3oool0
=@3oool004<0oooo0P00001O0?ooo`800000203oool600000840l?3`00<0P8200?3`l03`l?00603`
l?000`1PH600d=3@0?3`l00T0?3`l0@0000000<0l?3`0?ooo`3oool0<`3oool004<0oooo0P00001N
0?ooo`<000002`3oool6000007d0l?3`00<0X:2P051@D03`l?006@3`l?000`2`/;00D51@0?3`l00U
0?3`l0@0000000<0l?3`0?ooo`3oool0<P3oool004<0oooo0P00001N0?ooo`8000003P3oool60000
07/0l?3`00<0820P0:2PX03`l?006P3`l?000`0@4100h>3P0?3`l00V0?3`l0@0000000<0l?3`0?oo
o`3oool0<03oool004<0oooo0`00001`0?ooo`H00000=@3`l?000`20P800l?3`0?3`l00H0?3`l003
061PH03@d=00l?3`01d0l?3`00D0<30`051@D01PH600@4100<30`0020?3`l0030<30`0000000l?3`
00<0l?3`00@0L71`0000000`<300`<300`3`l?000`1`L70000000?3`l0030?3`l0L0000000H0@410
0?3`l03`l?00l?3`051@D020P80X0?3`l0@0000000<0l?3`0?ooo`3oool0;`3oool004@0oooo0P00
001b0?ooo`L00000<@3`l?000`2PX:00D51@0?3`l00I0?3`l0030;2`/01@D500l?3`01d0l?3`00D0
D51@0?3`l03`l?00H61P020P80020?3`l003061PH010@400l?3`00<0l?3`0P0000020:2PX0<0l?3`
00<0L71`0000003`l?000`3`l?000`2@T900000000000004030`<0060410@03`l?00l?3`0?3`l02@
T900820P:P3`l?03000000030?3`l03oool0oooo02h0oooo00140?ooo`800000M@3oool6000002l0
l?3`00<0820P0:2PX03`l?006P3`l?000`0@4100h>3P0?3`l00L0?3`l0030=3@d03`l?00/;2`0080
00000P3`l?000`0`<300L71`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`
l?00103`l?000`30`<0000000;2`/0030?3`l0060820P03`l?00l?3`0?3`l03@d=000000:`3`l?04
000000030?3`l03oool0oooo02`0oooo000P0?ooo`P000001@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00`0oooo0P00001h0?ooo`H00000903`l?001@0`<300D51@061PH010@400
`<300080l?3`00<0`<300000003`l?000`3`l?00101`L7000000030`<030`<030?3`l003071`L000
0000l?3`00D0l?3`00H0L71`0410@00000000000051@D02@T9030?3`l003051@D020P800l?3`01`0
l?3`00D0h>3P0410@00000000000051@D0020?3`l0030000002`/;00l?3`00<0l?3`00@00000030`
<03`l?00l?3`0`1`L7000`0`<3000000071`L002071`L0060;2`/03`l?00l?3`0<30`00@4100`<30
1`3`l?000`000000/;2`0?3`l00Z0?3`l0@0000000<0l?3`0?ooo`3oool0:`3oool00240oooo0P00
00030?ooo`800000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo0P00
001j0?ooo`H000008P3`l?001@1@D500l?3`0?3`l01PH600820P0080l?3`00<0H61P0410@03`l?00
0`3`l?0200000080X:2P0`3`l?000`1`L70000000?3`l0070?3`l08000001@3`l?000`2@T900820P
0?3`l00L0?3`l005051@D00000000000051@D03Ph>000P3`l?000`000000/;2`0?3`l0030?3`l004
0000000`<300l?3`0?3`l0P0000000L0L71`0?3`l03`l?00l?3`0;2`/0000000h>3P00H0l?3`00<0
00000;2`/03`l?00;03`l?04000000030?3`l03oool0oooo02T0oooo000Q0?ooo`800000203oool2
000000T0oooo0P00000<0?ooo`800000O@3oool6000001l0l?3`00<0d=3@0?3`l02`/;000P000002
0?3`l003030`<01`L700l?3`00<0l?3`00<00000030`<03`l?00103`l?000`1`L70000000?3`l007
0?3`l08000001@3`l?000`3@d=0000000?3`l00L0?3`l080000000<0`<300?3`l03`l?000P3`l?00
0`000000/;2`0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?001`3`l?00
0`1PH600<30`0?3`l0050?3`l0030000002`/;00l?3`02d0l?3`100000000`3`l?00oooo0?ooo`0X
0?ooo`008@3oool2000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`800000O`3oool6000001d0l?3`00D0h>3P0410@00000000000051@D0020?3`l0030000002`/;00
l?3`00<0l?3`00@00000030`<03`l?00l?3`0`1`L7000`0`<3000000071`L002071`L0030;2`/03`
l?00l?3`0080l?3`0P0000060?3`l0030000002`/;00l?3`01/0l?3`00@0410@071`L03`l?00D51@
0`3`l?000`0P8200X:2P0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?00
1`3`l?000`3@d=0000000;2`/0040?3`l0030<30`0000000l?3`0300l?3`100000000`3`l?00oooo
0?ooo`0V0?ooo`006@3oool5000000<0oooo0P0000000`3oool00000000000040?ooo`8000001@3o
ool2000000@0oooo0P00000;0?ooo`800000E`3oool2000002T0oooo1P00000J0?3`l003051@D000
00000000008000000P3`l?000`000000/;2`0?3`l0030?3`l0040000000`<300l?3`0?3`l0P00000
00<0L71`0?3`l03`l?000P3`l?02000000H0l?3`00<000000;2`/03`l?006`3`l?001030`<00<30`
071`L010@4030?3`l003051@D01PH600l?3`0080000000D0<30`0000000000000000030`<0030?3`
l003071`L0000000l?3`00P0l?3`00<0820P0410@03`l?000`3`l?000`2@T900410@0?3`l00a0?3`
l0@0000000<0l?3`0?ooo`3oool09@3oool001X0oooo0`0000040?ooo`D00000103oool2000000@0
oooo0`0000040?ooo`8000002`3oool3000005H0oooo0P00000[0?ooo`L000005`3`l?0200000003
0<30`000000000000080l?3`00<000000;2`/03`l?000`3`l?000`000000<30`0?3`l0040?3`l003
071`L0000000l?3`00L0l?3`0P0000060?3`l0030000002`/;00l?3`0280l?3`00<0T92@020P803`
l?000P0000000`3`l?00D51@030`<0050?3`l0030;2`/01`L700l?3`00P0l?3`0P0@41040?3`l003
051@D01PH600l?3`03<0l?3`100000000`3`l?00oooo0?ooo`0S0?ooo`006P3oool3000000@0oooo
0P0000000`3oool00000000000040?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000
E@3oool3000002h0oooo1P00000E0?3`l003010@401`L700l?3`008000000P3`l?000`0P8200X:2P
0?3`l0030?3`l0030000000`<300l?3`00@0l?3`00<0L71`0000003`l?001`3`l?02000000D0l?3`
00<0`<300000003`l?00903`l?0010000000h>3P0000000000020?3`l003092@T03`l?00l?3`00T0
l?3`00L0X:2P0<30`03`l?00l?3`0;2`/0000000410@00@0l?3`00<000000=3@d03`l?00=03`l?04
000000030?3`l03oool0oooo0280oooo000J0?ooo`<00000103oool2000000L0oooo0P0000040?oo
o`8000001@3oool2000000`0oooo0P00001E0?ooo`800000<P3oool600000180l?3`00<0`<30030`
<01`L7000P0000020?3`l003051@D01PH600l?3`0080l?3`00D0<30`0000000000000000030`<003
0?3`l003071`L0000000l?3`00L0l?3`0P0000050?3`l003092@T00@4100l?3`02@0l?3`00@0L71`
00000000000000003`3`l?000`0`<300H61P061PH00200000006051@D03`l?00l?3`0?3`l02PX:00
<30`>03`l?04000000030?3`l03oool0oooo0200oooo000J0?ooo`<00000103oool2000000<0oooo
0P0000020?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000E03oool3000003@0oooo
1P00000B0?3`l0<000000P3`l?000`2@T900820P0?3`l0030?3`l003051@D00`<300l?3`00@0l?3`
00<0/;2`071`L03`l?001`3`l?02000000D0l?3`00<0D51@061PH03`l?00903`l?000`3Ph>000000
0000000@0?3`l0060>3Ph01`L70000000000001@D500h>3P0`3`l?000`1`L700d=3@0?3`l00h0?3`
l0@0000000<0l?3`0?ooo`3oool07`3oool001X0oooo0`0000030?ooo`P000000P3oool2000000@0
oooo0P0000050?ooo`800000303oool2000005@0oooo0P00000h0?ooo`H000003`3`l?02000000@0
l?3`00<000000>3Ph03`l?000`3`l?000`2@T900l?3`0?3`l00:0?3`l0030<30`01@D500/;2`0080
00001@3`l?000`000000d=3@0?3`l00U0?3`l0800000EP3`l?0300000080l?3`7`3oool001X0oooo
0`00000=0?ooo`800000103oool2000000D0oooo0P00000<0?ooo`800000D`3oool3000003X0oooo
1P00000=0?3`l0800000103`l?000`1`L700T92@0?3`l00A0?3`l0040>3Ph01PH6000000000000@0
l?3`00<0X:2P030`<03`l?009P3`l?02000005L0l?3`100000000`3`l?00oooo0?ooo`0L0?ooo`00
6P3oool3000000d0oooo0P0000040?ooo`8000001@3oool2000000`0oooo0P00001B0?ooo`<00000
?P3oool6000000X0l?3`0P0000040?3`l0030>3Ph00`<300l?3`01<0l?3`00<0/;2`010@403`l?00
0`3`l?000`1`L700d=3@0?3`l0200?3`l0@000000P3`l?0L0?ooo`006P3oool3000000d0oooo0P00
00030?ooo`@00000103oool2000000`0oooo0`00001A0?ooo`800000@@3oool7000000h0l?3`00<0
d=3@0?3`l03`l?00W@3`l?04000000030?3`l03oool0oooo01T0oooo000J0?ooo`<000003P3oool0
10000000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3oool0303oool200000500oooo0`00
00140?ooo`H00000[@3`l?0400000080l?3`6@3oool001X0oooo0`00000>0?ooo`8000000`3oool2
000000@0oooo0P00000>0?ooo`800000D03oool2000004P0oooo1P00002/0?3`l0@0000000<0l?3`
0?ooo`3oool05P3oool001T0oooo1@00000>0?ooo`040000003oool0oooo0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`800000C`3oool3000004X0oooo1P00002[0?3`l0@000000P3`l?0F
0?ooo`00;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo0P00001?0?oo
o`800000CP3oool600000:X0l?3`100000000`3`l?00oooo0?ooo`0C0?ooo`00AP3oool300000:00
oooo1`00002X0?3`l0@000000P3`l?0C0?ooo`00A`3oool200000:<0oooo1P00000n0?3`l0800000
J03`l?04000000030?3`l03oool0oooo0100oooo00170?ooo`800000YP3oool6000003/0l?3`0P00
001Y0?3`l0@0000000<0l?3`0?ooo`3oool03`3oool004L0oooo0`00002W0?ooo`H00000>03`l?03
000006/0l?3`100000000`3`l?00oooo0?ooo`0=0?ooo`00B03oool2000009d0oooo0P00000;0?oo
o`H00000=@3`l?02000006d0l?3`100000000`3`l?00oooo0?ooo`0<0?ooo`00B03oool2000009d0
oooo0P00000=0?ooo`H00000<P3`l?03000006l0l?3`0`0000020?3`l0`0oooo00180?ooo`<00000
W03oool200000100oooo1P00000_0?3`l0800000L@3`l?04000000030?3`l03oool0oooo00T0oooo
00190?ooo`800000B03oool200000540oooo0`00000B0?ooo`L00000:`3`l?0300000780l?3`1000
00020?3`l0T0oooo00190?ooo`<00000A`3oool200000540oooo0P00000F0?ooo`H00000:@3`l?02
000007D0l?3`100000000`3`l?00oooo0?ooo`060?ooo`00BP3oool2000004H0oooo0`00001A0?oo
o`8000006@3oool6000002D0l?3`0`00001f0?3`l0@000000P3`l?060?ooo`00BP3oool2000004D0
oooo0`00001A0?ooo`<000006`3ooonW00000080l?3`1@3oool004X0oooo0`0000140?ooo`800000
DP3oool2000001l0ooooY00000030?3`l0@0oooo001;0?ooo`800000@`3oool300000580oooo0P00
000R0?ooob80l?3`0P0000200?3`l0@0oooo001;0?ooo`<00000@P3oool2000005<0oooo0P000013
0?ooo`<00000Q03oool004`0oooo0P0000110?ooo`<00000DP3oool3000004<0oooo0P0000250?oo
o`00C03oool200000400oooo0`00001C0?ooo`800000b`3oool004`0oooo0`00000o0?ooo`800000
E03oool2000008D0oooo1P0000020?ooo`80000000<0oooo0000003oool00`3oool3000000030?oo
o`000000oooo00<0oooo0P0000030?ooo`8000000P3oool3000000050?ooo`000000oooo0?ooo`00
00001@3oool3000000@0oooo1000000<0?ooo`00C@3oool2000003h0oooo0`0000090?ooo`800000
0`3oool300000<T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool2000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo008000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo001=0?oo
o`800000?P3oool2000000`0oooo00H000000?ooo`3oool000000?ooo`0000390?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo000000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo001=0?ooo`<00000B`3oool010000000oooo0?ooo`00003B0?ooo`030000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000H0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0
oooo0P00000<0?ooo`00CP3oool2000004/0oooo00@000000?ooo`3oool00000d03oool200000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000H0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`H00000
0`3oool2000000h0oooo001>0?ooo`<00000BP3oool010000000oooo0?ooo`0000270?ooo`800000
@`3oool4000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000@0?ooo`00C`3oool2000004P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`25
0?ooo`800000@P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00C`3o
ool2000004T0oooo1`0000240?ooo`<00000@P3oool00`000000oooo0?ooo`040?ooo`@0000000H0
oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo0080oooo0`0000001P3oool0
0000000000000000oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`800000
1@3oool4000000`0oooo001?0?ooo`<00000d`3oool2000004<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0000000E0?ooo`030000003oool0oooo02D0oooo001@0?ooo`800000dP3oool3
000004@0oooo1P0000020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09@3oool0
0500oooo0P00000e0?ooo`800000F03oool200000440oooo0P00002;0?ooo`00D03oool3000003@0
oooo0P00001H0?ooo`800000@03oool3000008/0oooo001A0?ooo`800000<`3oool3000005P0oooo
0P0000100?ooo`800000S03oool00540oooo0`00000a0?ooo`<00000F03oool300000400oooo0P00
002<0?ooo`00DP3oool200000340oooo0P00001I0?ooo`800000@03oool3000008`0oooo001B0?oo
o`<00000;`3oool3000005T0oooo0P0000100?ooo`800000S@3oool005<0oooo0`00000^0?ooo`80
0000FP3oool2000003l0oooo0`00002=0?ooo`00E03oool2000002d0oooo0`00001I0?ooo`<00000
?`3oool2000008h0oooo001D0?ooo`<00000:`3oool3000005X0oooo0P00003@0?ooo`00E@3oool2
000002/0oooo0P00001K0?ooo`800000d03oool005D0oooo0`00000Y0?ooo`<00000F`3oool20000
0=00oooo001F0?ooo`800000:@3oool2000005/0oooo0`00003@0?ooo`00EP3oool3000008D0oooo
0P00003A0?ooo`00E`3oool3000008@0oooo0P00003A0?ooo`00F03oool200000?l0ooooF03oool0
05P0oooo0`0000320?ooo`800000TP3oool005T0oooo0P0000320?ooo`800000TP3oool005T0oooo
0`0000300?ooo`<00000TP3oool005X0oooo0`00002o0?ooo`800000T`3oool005/0oooo0P00000O
0?ooo`800000W@3oool3000009<0oooo001K0?ooo`<000007P3oool2000009d0oooo0P00002D0?oo
o`00G03oool2000001d0oooo0`00002L0?ooo`<00000U03oool005`0oooo0`00000K0?ooo`<00000
GP3oool2000003d0oooo0P00002E0?ooo`00G@3oool2000001/0oooo0P00001O0?ooo`800000?03o
ool3000009D0oooo001M0?ooo`<000005P3oool6000005h0oooo0`0000060?ooo`h00000:03oool2
000009H0oooo001N0?ooo`<000005@3oool600000580oooo9000000V0?ooo`<00000UP3oool005l0
oooo0P00000E0?ooo`L00000?03oool[000000`0oooo1000000T0?ooo`800000U`3oool005l0oooo
0`00000C0?ooo`T000009@3oool/000000H0oooo1`00000E0?ooo`@00000_03oool00600oooo0P00
000C0?ooo`T00000403oool/000001/0oooo1`00000G0?ooo`@00000^P3oool007D0oooo;`00000a
0?ooo`P000005`3oool500000;P0oooo001T0?ooob/00000AP3oool9000001P0oooo1000002g0?oo
o`00CP3oool]000005X0oooo2@00000J0?ooo`@00000]@3oool003T0oooo;000000?0?ooo`H00000
F`3oool9000001/0oooo1000002d0?ooo`00903oool[000002@0oooo1P00001L0?ooo`P000007P3o
ool400000;80oooo000I0?ooob400000>@3oool5000005d0oooo2000000O0?ooo`@00000/@3oool0
01T0oooo3000001>0?ooo`@00000GP3oool700000280oooo1000002_0?ooo`006`3oool700000500
oooo1000001O0?ooo`H00000903oool500000100oooo0P00002K0?ooo`007P3oool6000004h0oooo
0`00001P0?ooo`H000009P3oool4000000l0oooo0P00002K0?ooo`008@3oool6000004/0oooo0P00
001Q0?ooo`D00000:@3oool4000000`0oooo0`00002K0?ooo`008`3oool700000:/0oooo1@00000Z
0?ooo`@000002P3oool3000009`0oooo000V0?ooo`H00000803oool5000008@0oooo1000000]0?oo
o`@00000203oool2000009d0oooo000Y0?ooo`H000007P3oool3000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1b0?ooo`<00000;`3oool4000000H0oooo0`00002M0?ooo`00
:`3oool7000001/0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
L@3oool300000340oooo100000040?ooo`800000:@3oool:000006/0oooo000^0?ooo`H000006@3o
ool3000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`800000<`3o
ool400000080oooo0`00000Z0?ooo`<000000`3oool3000006/0oooo000a0?ooo`H000005P3oool6
000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3oool0oooo3000
002J0?ooo`H00000:`3oool3000000@0oooo0P00001[0?ooo`00<`3oool7000001<0oooo1`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool<000009/0oooo1@00000[0?ooo`<00000L@3oool003H0oooo1P00000A0?ooo`<0000000<0oooo
0000000000000P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool2000000P0oooo0P00002L0?ooo`D00000:P3oool300000740oooo000i
0?ooo`H000003P3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000P0oooo0P00001M0?ooo``00000<`3o
ool2000000030?ooo`000000000000800000:03oool3000000<0oooo0P00001/0?ooo`00>`3oool7
000000/0oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000G@3oool<000003L0oooo1000
000W0?ooo`P00000K03oool003h0oooo1P0000090?ooo`<000000P3oool300000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000203o
ool2000005d0oooo0P0000080?ooo`800000>@3oool4000002D0oooo0`0000030?ooo`800000K03o
ool00440oooo1P0000050?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`800000G@3o
ool2000000P0oooo0P00000j0?ooo`@00000903oool300000740oooo00130?ooo`L00000103oool5
000000@0oooo00@000000?ooo`3oool0oooo100000030?ooo`040000003oool0oooo0?ooo`800000
203oool2000005d0oooo0P0000080?ooo`800000?03oool400000280oooo0`0000040?ooo`800000
J`3oool004H0oooo1`00000;0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo``000000`3oool40<o?cdX0oooo103?cll80?ooo`800000203oool2000000<0oooo
103?cllf0?ooo`@000008@3oool3000000<0oooo0`00001[0?ooo`00B@3oool6000000T0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo300000030?ooo`P0clo?
AP3oool70<o?c`D0oooo0P0000080?ooo`8000000`3oool70<o?ccD0oooo1000000N0?ooo`X00000
J`3oool004`0oooo1P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3o
ool90<o?cd80oooo203?cll40?ooo`800000203oool2000000H0oooo1`3?cllc0?ooo`D00000T@3o
ool004h0oooo1`00000W0?ooo`P0clo??03oool;0<o?c`@0oooo300000090?ooo`L0clo?7P3oool2
00000180oooo1000002@0?ooo`00D@3oool6000002T0oooo203?cllb0?ooo`l0clo?1P3oool<0000
00`0oooo1`3?cllK0?ooo`800000503oool4000008h0oooo001D0?ooo`H00000:@3ooolC0<o?cal0
oooo303?cll30?ooo`@0clo?8P3oool60<o?caT0oooo0P00000E0?ooo`@00000S@3oool005H0oooo
1`00000Z0?oooc@0clo?2@3oool30<o?cbH0oooo103?cllG0?ooo`<000005`3oool4000008/0oooo
001I0?ooo`H00000=P3ooolQ0<o?c`h0oooo0P3?cllY0?ooo`@0clo?5@3oool2000001T0oooo1000
002:0?ooo`00G03oool6000005T0oooo1@00000`0?ooo`@0clo?3`3oool4000000030?ooo`000000
000001/0oooo100000280?ooo`00GP3oool7000005L0oooo0`0000090?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool03`3oool30<o?c`h0oooo1`00000L0?ooo`D00000QP3oool00640
oooo1P00001E0?ooo`<00000203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0
oooo0P3?cll>0?ooo`T00000703oool4000008D0oooo001T0?ooo`H00000DP3oool3000000P0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`<0clo?3@3oool:000001d0oooo
100000230?ooo`00IP3oool7000004l0oooo1P0000040?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0?0?ooo`80clo?3@3oool:000001h0oooo100000220?ooo`00J@3oool6000004d0oooo1`000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool30<o?c``0oooo2P00000P
0?ooo`@00000P03oool006`0oooo1P00001:0?ooo`<0000000<0oooo0000000000000P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool20<o?c``0oooo2@00000R0?oo
o`@00000O`3oool006h0oooo1`0000170?ooo`<000000P3oool300000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`07000000H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`<0clo?2P3oool9000002D0oooo1000001m0?ooo`00L@3oool6000004D0oooo
0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo
0P3?cll:0?ooo`P000009`3oool4000007`0oooo001d0?ooo`H00000@P3oool300000080oooo0`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool60<o?c`H0oooo1`00
000Z0?ooo`@00000NP3oool007H0oooo1`00000n0?ooo`D0000000<0oooo0000000000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo203?cll60?ooo`H00000;03oool5
000007P0oooo001i0?ooo`H00000?P3oool5000000@0oooo00@000000?ooo`3oool0oooo1000000=
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool80<o?c`H0oooo1@00000_
0?ooo`@00000M`3oool007`0oooo1P0000150?ooo`050000003oool0oooo0?ooo`000000303oool4
000000D0oooo00<000000?ooo`3oool04@3oool70<o?c`H0oooo1000000b0?ooo`@00000M@3oool0
07h0oooo1`0000120?ooo`050000003oool0oooo0?ooo`0000003P3oool2000000D0oooo00<00000
0?ooo`3oool04P3oool60<o?c`H0oooo0`00000d0?ooo`@00000M03oool00840oooo1P0000110?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?oo
o`@0clo?1`3oool2000003L0oooo1000001b0?ooo`00Q03oool6000006h0oooo0`3?clm10?ooo`@0
0000L@3oool008H0oooo1`00001/0?ooo`80clo?@`3oool4000006l0oooo00290?ooo`H00000/03o
ool4000006h0oooo002<0?ooo`H00000H@3oool<000000D0oooo1@00000h0?ooo`@00000K03oool0
08h0oooo1`00001N0?ooo``000001P3oool3000000T0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0F0?ooo`D00000JP3oool00940oooo1P00001L0?ooo`800000203oool2000000H0
oooo0`0000080?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool4000006T0
oooo002D0?ooo`H00000F@3oool2000000P0oooo0P0000060?ooo`<00000203oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01T0oooo1000001W0?ooo`00UP3oool7000005H0oooo0P00
00080?ooo`8000001P3oool6000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<0
00000?ooo`3oool00`3oool7000000@0oooo00<000000?ooo`3oool06@3oool4000006H0oooo002I
0?ooo`L00000D`3oool2000000P0oooo0P0000060?ooo`L000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01/0oooo1000001T0?ooo`00W03oool600000540oooo0P0000080?oo
o`8000001P3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01`0oooo1000001S0?ooo`00W`3oool6000004h0oooo0P0000080?ooo`80
00001P3oool300000080oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`0000030?ooo`800000203oool00`000000oooo0?ooo`0N0?ooo`@00000H@3oool00:40oooo
1`00001;0?ooo`800000203oool2000000H0oooo0`0000020?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2000000H0oooo
00<000000?ooo`3oool07`3oool5000005l0oooo002T0?ooo`H00000B@3oool<000000H0oooo0`00
00020?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo1000
001N0?ooo`00Y`3oool6000004H0oooo300000050?ooo`D0000000<0oooo0000000000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo1000001L0?ooo`00Z@3oool70000
05H0oooo1@0000040?ooo`040000003oool0oooo0?ooo`@000002@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool4000005/0oooo002/0?oo
o`H00000GP3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000002T0oooo1000001I0?ooo`00[`3oool6000005/0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0X0?ooo`@00000F03oool00;40oooo1`00001I0?ooo`030000003oool0oooo00h0oooo0`00
00040?ooo`030000003oool0oooo02/0oooo1000001F0?ooo`00]03oool6000009h0oooo1000001E
0?ooo`00]`3oool6000009d0oooo1000001C0?ooo`00^@3oool7000009/0oooo1@00001A0?ooo`00
_03oool6000009/0oooo1000001@0?ooo`00_`3oool6000009X0oooo1000001>0?ooo`00`@3oool7
000009P0oooo1000001=0?ooo`00a03ooonQ000004`0oooo00370?oooih00000C03oool00?l0oooo
/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo/P3oool00?l0oooo
/P3oool00?l0oooo/P3oool00?l0oooo4@3oool7000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000001@3oool300000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool2000005L0oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000F03oool00?l0oooo
4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000F03oool00?l0oooo4@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo1P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000F03oool0
0?l0oooo4@3oool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0000
00040?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000005P0
oooo003o0?oooa40oooo00<000000?ooo`3oool01@3oool2000000<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000030?ooo`040000003oool0000000000080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`050000003oool0oooo0?ooo`00
0000F03oool00?l0oooo4@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000800000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000030?oo
o`<000000`3oool00`000000oooo0000000200000080oooo00D000000?ooo`00000000000?ooo`03
000000H0oooo0P0000030?ooo`030000003oool00000008000000`3oool3000005L0oooo003o0?oo
oa40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1F0?ooo`00o`3ooolA0?ooo`L0
00003`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05H0oooo003o0?oook80oooo
003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo
003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo
0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{433, 417.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->1,
  AnimationCycleOffset->-5,
  AnimationCycleRepetitions->Infinity]
}, Closed]],

Cell[TextData[{
  "Modelling of Adaptive Systems: An adaptation sequence\n\n",
  StyleBox["Double-click on the graphics to start the animation.",
    FontWeight->"Bold"]
}], "NumberedFigure",
  CellTags->"Adaptation sequence (Figure)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Evolutionary Algorithms \[LongDash] A Basic Scheme"], "Subsection"],

Cell[CellGroupData[{

Cell["Basic Scheme of an Evolutionary Algorithm", "Subsubsection"],

Cell[TextData[{
  "1.\t",
  Cell[BoxData[
      \(TraditionalForm\`t := 0\)]]
}], "ListNumbered"],

Cell[TextData[{
  "2.\t",
  StyleBox["Initialization of Structures",
    FontWeight->"Bold"],
  ": "
}], "ListNumbered"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalG](
        t) := \((\(s\_1\)(t), \[Ellipsis], \(s\_M\)(
            t))\) \[Element] \[ScriptCapitalS]\^M\)]]], "NumberedEquation"],

Cell[TextData[{
  "3.\t",
  StyleBox["Interpretation and Evaluation",
    FontWeight->"Bold"],
  ": "
}], "ListNumbered"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Mu]\_\[ScriptCapitalE]\)(\[ScriptCapitalG](
          t)) := \((\(\[Mu]\_\[ScriptCapitalE]\)(\(s\_1\)(
            t)), \(\[Ellipsis]\[Mu]\_\[ScriptCapitalE]\)(\(s\_M\)(
            t)))\)\)]]], "NumberedEquation"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Mu]\_\[ScriptCapitalE]\)(\(s\_i\)(
          t)) := \(\[Mu]\_\[ScriptCapitalE]\)(\(s\_i\)(
          t), \(\[CurlyPhi]\_\[ScriptCapitalE]\)(\[Pi](\(s\_i\)(
              t))))\)]]], "NumberedEquation"],

Cell[TextData[{
  "4.\t",
  StyleBox["Termination",
    FontWeight->"Bold"],
  ":"
}], "ListNumbered"],

Cell[TextData[{
  "\tIf ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          t, \[ScriptCapitalG](
            t), \(\[Mu]\_\[ScriptCapitalE]\)(\[ScriptCapitalG](t))) == 
        True\)]],
  " then STOP."
}], "ListNumbered"],

Cell[TextData[{
  "5.\t",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ":"
}], "ListNumbered"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[ScriptCapitalG]\_0\)(
        t) := \[Sigma](\[ScriptCapitalG](
          t), \(\[Mu]\_\[ScriptCapitalE]\)(\[ScriptCapitalG](
            t)))\)]]], "NumberedEquation"],

Cell[TextData[{
  "6.\t",
  StyleBox["Variation",
    FontWeight->"Bold"],
  ":"
}], "ListNumbered"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalG](
        t + 1) := \[CapitalOmega](\(\[ScriptCapitalG]\_0\)(
          t))\)]]], "NumberedEquation"],

Cell[TextData[{
  "7.\t",
  Cell[BoxData[
      \(TraditionalForm\`t := t + 1\)]]
}], "ListNumbered"],

Cell["8.\tContinue with Step 3.", "ListNumbered"]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure: EA Scheme", "Subsubsection"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005V0002J2000`400?l00000o`00003oo`3ooomW
0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW
0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00R@3oooll00000:40oooo0029
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0W`3oool008T0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`2O0?ooo`00R@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo09l0oooo00290?ooo`030000003oool0oooo00L0oooo00<0<c<c014A4@2ZZZX0
1@3oool00`0A4A40EEEE0?ooo`0;0?ooo`0303<c<`0A4A40ZZZZ00@0oooo00<08R8R0?ooo`3oool0
0P3oool01@3MgMd0ZZZZ0000002ZZZX0gMgM00X0oooo00<000000?ooo`3oool0W`3oool008T0oooo
00<000000?ooo`3oool01`3oool00`000000k^k^0?ooo`050?ooo`0405EEE@2IVIT0oooo0?ooo`D0
8R8R00<0EEEE0?ooo`3oool00P3oool00`000000k^k^0?ooo`040?ooo`03028R8P3oool0oooo00@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2O0?ooo`00R@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0<c<c002028R8P04
0000000R8R808R8R09VIV@<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2O0?oo
o`00R@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool00`0R8R80oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0W`3oool008T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`04014A
4@1EEED0oooo0?ooo`D08R8R00<0EEEE0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
028R8P3oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2O0?ooo`00
R@3oool00`000000oooo0?ooo`060?ooo`0407MgM`0000008R8R028R8PD0oooo00<0EEEE09VIV@3o
ool02P3oool0101gMgL00000028R8P0R8R840?ooo`03028R8P3oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2O0?ooo`002P3ooomg000000P0oooo00<000000?ooo`3o
ool01`3oool00`0c<c<0oooo0?ooo`0C0?ooo`0303<c<`3oool0oooo00T0oooo00<0k^k^0?ooo`00
0000303oool00`000000oooo0?ooo`2O0?ooo`002P3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00L0oooo00<0k^k^0?ooo`3oool04`3oool00`3^k^h0oooo0?ooo`090?ooo`0309VI
V@1gMgL0000000`0oooo00<000000?ooo`3oool0W`3oool000X0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0Z0?ooo`030>k^kP0R8R80oooo00/0oooo00<000000?ooo`3oool0W`3o
ool000X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo09l0oooo000:0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`2O0?ooo`002P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0W`3oool000X0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo09l0oooo000:0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`2O0?ooo`002P3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0W`3oool000X0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09l0oooo000:0?ooo`03
0000003oool0oooo07`0oooo?000002Q0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo
000:0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<000000?ooo`3oool0o`3ooomJ
0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:0?ooo`030000003oool0oooo0?l0
ooooFP3oool000X0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`002P3oool00`000000oooo0?oo
o`3o0?oooeX0oooo000:0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<000000?oo
o`3oool0o`3ooomJ0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0
oooo000:0?ooo`030000003oool0oooo09T0oooo0P00002n0?ooo`002P3oool00`000000oooo0?oo
o`2I0?ooo`800000_P3oool000X0oooo00<000000?ooo`3oool0V@3oool300000;d0oooo000:0?oo
o`030000003oool0oooo09P0oooo1000002m0?ooo`002P3oool00`000000oooo0?ooo`2H0?ooo`@0
0000_@3oool000X0oooo00<000000?ooo`3oool0V03oool400000;d0oooo000:0?ooo`030000003o
ool0oooo09P0oooo1@00002l0?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`H00000_03oool0
00X0oooo00<000000?ooo`3oool0U`3oool600000;`0oooo000:0?ooo`030000003oool0oooo09L0
oooo1`00002k0?ooo`002P3oool00`000000oooo0?ooo`2F0?ooo`P00000^`3oool000X0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0_03oool000X0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`00
2P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0_03oool000X0oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
0;`0oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0_03oool000X0oooo
00<000000?ooo`3oool0=`3ooomS0<k>cP030000003>c/h0c/k>05l0c/k>G@3oool000X0oooo00<0
00000?ooo`3oool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>c/iM
0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?ooo`3o
ool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/jl000000@0c/k>
G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo0;P0oooo00<0
00000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<00000
0?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo
03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0
oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo0;P0oooo00<000000<k>cP3>
c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0
^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>
c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<00000
0?ooo`3oool0=`3oool50<k>cP030000003oool0oooo07D0oooo00D0k^k^04A4A02ZZZX0IVIV0>k^
kP0n0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool5
0<k>cP030000003oool0oooo03@0oooo00<0ZZZZ0>k^kP3oool04P3oool00`3<c<`0gMgM0?ooo`0P
0?ooo`030:ZZZP3^k^h0oooo00H0oooo00D08R8R0>k^kP3oool0k^k^04A4A0020?ooo`030:ZZZP3^
k^h0oooo00@0oooo00<0c<c<0=gMg@3oool00P3oool00`3^k^h0^k^k0?ooo`0]0?ooo`030000003>
c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0
oooo03@0oooo00<0IVIV0?ooo`3oool04`3oool00`1VIVH0oooo0?ooo`0O0?ooo`0306IVIP3oool0
oooo00H0oooo00D08R8R0?ooo`3oool0oooo000000020?ooo`0306IVIP3oool0oooo00D0oooo00<0
IVIV0?ooo`3oool00P3oool00`1EEED0oooo0?ooo`0/0?ooo`030000003>c/h0c/k>0080c/k>G@3o
ool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo03<0oooo0P2ZZZXE
0?ooo`0305EEE@3^k^h0oooo01h0oooo0P2ZZZX80?ooo`060000003oool0oooo0?ooo`000000oooo
0P2ZZZX70?ooo`0305EEE@3^k^h0oooo0080oooo00<0MgMg0=gMg@3oool0;03oool00`000000c/k>
0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?oo
o`0^0?ooo`@0000000<0oooo04A4A03^k^h00P3oool00`0c<c<04A4A0:ZZZP040?ooo`03028R8P3o
ool0oooo0080oooo00D0gMgM0:ZZZP000000ZZZZ0=gMg@020?ooo`030:ZZZP2IVIT0oooo00D0oooo
00<04A4A05EEE@3oool02`3oool4000000030?ooo`0000000000008000000P3oool00`14A4@0k^k^
0?ooo`030?ooo`D000000`3oool0100R8R80oooo04A4A03^k^h30?ooo`0603<c<`0A4A40ZZZZ0?oo
o`2ZZZX0VIVI0`3oool00`3MgMd0IVIV0?ooo`0/0?ooo`030000003>c/h0c/k>0080c/k>G@3oool0
00X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo02d0oooo00<000000?oo
o`3oool00P3oool00`000000<c<c0?ooo`020?ooo`030000003^k^h0oooo00@0oooo00<08R8R0?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030>k^kP14A4@0oooo00D0oooo00<0EEEE09VI
V@3oool01@0R8R800`1EEED0oooo0?ooo`060?ooo`030000003oool0000000D0oooo00<0<c<c0?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003^k^h0oooo0>k^kP0R8R80oooo03<c
<`040?ooo`060000003^k^h0oooo0?ooo`3^k^h0A4A4103oool00`0R8R80oooo0?ooo`0[0?ooo`03
0000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000
003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000<c<c0?ooo`020?ooo`050000
003oool0oooo0?ooo`3<c<`00P0R8R80100000008R8R028R8P2IVIT30?ooo`030000003oool0oooo
00<0oooo00<08R8R0?ooo`3oool04`3oool2000000<0oooo0P0000030?ooo`0303<c<`3oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01`000000MgMg0:ZZZP14A4@0k^k^0?ooo`0c<c<0103o
ool00`000000oooo0?ooo`020?ooo`03028R8P3oool0oooo0080oooo00<0A4A40?ooo`3oool0:`3o
ool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<0000003<c<`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`03028R8P3oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`0R8R80oooo0?ooo`0B0?ooo`8000001@3oool200000080oooo00D0<c<c0?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00<0oooo00<0<c<c0?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`03028R8P3oool0oooo0080oooo00<08R8R0?ooo`3oool0:`3oool00`000000c/k>0<k>
cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00<0oooo00<0000004A4A03oool00P3oool00`000000oooo0?ooo`04
0?ooo`03028R8P3oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`0R8R80oooo0?ooo`04
0?ooo`03014A4@1EEED0oooo00D08R8R00<0EEEE0?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo04A4A0<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`0304A4A03oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`0R8R80oooo0?oo
o`020?ooo`0304A4A03oool0oooo02/0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool0
0`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0;03oool010000000oooo0?ooo`3o
ool30000000505EEE@3oool0oooo07MgM`0000000P0R8R840?ooo`03028R8P3oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`3<c<`0IVIV0?ooo`050?ooo`0305EEE@2IVIT0oooo00/0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`1EEED30?ooo`040000003oool0oooo0?oo
o`<000001@3oool01P1EEED0oooo0?ooo`3oool0MgMg000000808R8R00<0oooo0<c<c01VIVH0103o
ool00`14A4@0oooo0?ooo`0[0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<00000
0?ooo`3oool0=`3oool50<k>cP030000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool2
0:ZZZP80oooo00<0<c<c0?ooo`3oool02@3oool00`3^k^h0oooo000000040?ooo`0309VIV@3<c<`0
oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020:ZZZP80oooo00<00000
0?ooo`3oool02@3oool20:ZZZP<0oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`30?ooo`030;^k
^`2IVIT0oooo02`0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?oo
o`0g0?ooo`D0c/k>00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`0406IVIP3o
ool0oooo0>k^kP/0oooo00<0VIVI07MgM`000000103oool00`1EEED0oooo0?ooo`0D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0101VIVH0oooo0?ooo`00000<0?ooo`05
06IVIP3oool0oooo0?ooo`3^k^h00`3oool00`1EEED0oooo0?ooo`020?ooo`0306IVIP3^k^h0oooo
02`0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0
c/k>00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`030:ZZZP3^k^h0oooo00d0
oooo00<0k^k^028R8P3oool00P3oool00`3MgMd0ZZZZ0?ooo`0F0?ooo`D000001@3oool01@2ZZZX0
k^k^0?ooo`3oool0000000/0oooo00<0ZZZZ0>k^kP3oool0103oool00`3MgMd0ZZZZ0?ooo`020?oo
o`030>k^kP2IVIT0oooo02d0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000
oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`03
0000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000
003oool0oooo02h0oooo1000000o0?ooo`@00000@`3oool00`000000c/k>0<k>cP020<k>cUd0oooo
000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>
c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0
oooo0;P0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?oo
o`D0c/k>00<000000?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`03
0000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080
c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo0;P0oooo
00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<0
00000?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0
oooo03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool0
00X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_0;P0kno_00<000000<k>
cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_
knl0^03_knl00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo
1@3>c/h00`000000kno_0>o_k`2h0>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<0
00000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_0;P0kno_00<000000<k>cP3>c/h00P3>
c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0^03_knl0
0`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`00
0000kno_0>o_k`150>o_k`030;no_`1?Cdl0kno_0080kno_00P07alO02l_;`3Ogml000000;no_`3_
knl0gmoO01lO7`@0kno_00P07alO08n?S`3_knl07alO02l_;`3Ogml000000;no_`80kno_00H00000
04m?C`3Ogml0kno_00l?3`1_Kfl20>o_k`030;no_`2?Shl0[jn_0080WinO0P3_knl01P0O7al0clo?
0>o_k`3_knl0000008n?Sd<0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000
oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0A@3_knl00`1oOgl000000<o?c`020>o_k`09
0000003Ogml0_kno00l?3`2o_kl0gmoO0>o_k`0?3`l0clo?00<0kno_01@0?clo0:n_[`3?cll00000
0=oOg`2o_kl03`l?0;no_`3Ogml0kno_00l?3`2OWil0Ogmo0=oOg`0o?cl0_kno09nOW`3_knl0?clo
0=oOg`80kno_00D0?clo09nOW`3_knl0Ogmo06m_K`020>o_k`0301lO7`2o_kl0[jn_0480kno_00<0
00000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<00000
0>o_k`3_knl0A@3_knl00`1?Cdl0GemO06m_K`020>o_k`0504m?C`3Ogml0kno_04m?C`2?Shl00P3_
knl00`1OGel0Kfm_0>o_k`020>o_k`0808n?S`1_Kfl0kno_04m?C`3Ogml0kno_04m?C`2?Shl20>o_
k`0605mOG`1oOgl0kno_0=oOg`2?Shl0GemO0P3_knl03@000000gmoO0>o_k`3_knl0[jn_02l_;`3_
knl0clo?0000003Ogml0kno_05mOG`2_[jl0@`3_knl00`000000c/k>0<k>cP020<k>cUd0oooo000:
0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`150>o_k`0701lO7`2?Shl0
Shn?0;no_`3_knl0clo?07moO`020>o_k`0602l_;`3_knl0kno_09nOW`0O7al0gmoO0P3_knl01@3?
cll03`l?0>o_k`3?cll0Ogmo0080kno_00D0;bl_0>o_k`3_knl0WinO03lo?`020>o_k`060<o?c`00
0000kno_0>o_k`0_;bl0[jn_0P3_knl02@3Ogml000000>o_k`3_knl07alO05mOG`3_knl0[jn_06m_
K`130>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool5
0<k>cP030000003_knl0kno_04D0kno_00@000000;no_`3_knl0Cdm?0P3_knl01@2OWil0_kno0>o_
k`1OGel0[jn_0080clo?00d0;bl_07moO`2_[jl0kno_0;no_`0O7al0_kno0>o_k`2OWil0_kno0>o_
k`1OGel0[jn_0080kno_00T000000=oOg`3_knl0_kno01lO7`2OWil0kno_09nOW`1?Cdl00P3_knl0
2@3?cll0?clo0>o_k`1_Kfl0GemO08n?S`1_Kfl0gmoO02l_;`130>o_k`030000003>c/h0c/k>0080
c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_04@0kno_
00H0[jn_0000003_knl0kno_08n?S`2_[jl20>o_k`0=0;no_`2?Shl0;bl_04m?C`3_knl0Shn?0000
003?cll03`l?0<o?c`3Ogml0;bl_06m_K`020>o_k`0<0;no_`2?Shl0;bl_04m?C`3_knl0Ogmo00l?
3`1?Cdl0Ogmo0=oOg`0_;bl0GemO0P3_knl209nOW`0:0:n_[`2?Shl0_kno0>o_k`2o_kl0;bl_06m_
K`3Ogml0Cdm?00l?3d<0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo
0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0A03_knl00`1_Kfl0;bl_0>o_k`020>o_k`0304m?
C`3_knl0kno_01D0kno_00<0Shn?04m?C`3_knl0E03_knl00`000000c/k>0<k>cP020<k>cUd0oooo
000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`140>o_k`0303lo?`1_
Kfl0kno_0080kno_00<0Shn?0:n_[`3_knl05@3_knl00`3Ogml0?clo0>o_k`1D0>o_k`030000003>
c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0
kno_04<0kno_00T0WinO0000001?Cdl0clo?0>o_k`3Ogml0WinO01lO7`2o_kl0303_knl00`0o?cl0
kno_0>o_k`0;0>o_k`0303lo?`3_knl0kno_04l0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`00
2P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0^03_knl00`000000c/k>
0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_
k`2h0>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool5
0<k>cP030000003_knl0kno_0;P0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`00
0000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0^03_knl00`000000c/k>0<k>cP020<k>
cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`2h0>o_k`03
0000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000
003_knl0kno_0;P0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?oo
o`0g0?ooo`D0c/k>_00000040<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>c/iM
0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?ooo`3o
ool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>c/iM0?ooo`002P3o
ool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oooo5
0<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>c/iM0?ooo`002P3oool00`000000
oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3ooomS0<k>cP030000
003>c/h0c/k>05l0c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3ooomR0<k>cP800000H@3>
c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof80c/k>0P00001Q0<k>cUd0oooo000:0?oo
o`030000003oool0oooo03L0ooooHP3>c/h200000640c/k>G@3oool000X0oooo00<000000?ooo`3o
ool0=`3ooomR0<k>cP<00000H03>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof40c/k>
1000001P0<k>cPh0oooo0`0000040?ooo`800000AP3oool000X0oooo00<000000?ooo`3oool0=`3o
oomQ0<k>cP@00000H03>c/h<0?ooo`8000000`3oool2000000030?ooo`000000000000800000A@3o
ool000X0oooo00<000000?ooo`3oool0=`3ooomQ0<k>cPD00000G`3>c/h;0?ooo`8000001@3oool4
000000030?ooo`000000oooo04@0oooo000:0?ooo`030000003oool0oooo03L0ooooH03>c/h60000
05l0c/k>2`3oool2000000D0oooo0`0000180?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof00
c/k>1P00001O0<k>cPX0oooo0P0000070?ooo`800000B03oool000X0oooo00<000000?ooo`3oool0
=`3ooomP0<k>cPH00000G`3>c/h:0?ooo`8000001`3oool3000004L0oooo000:0?ooo`030000003o
ool0oooo03L0ooooH03>c/h7000005h0c/k>2P3oool2000000L0oooo0`0000170?ooo`002P3oool0
0`000000oooo0?ooo`0g0?oooel0c/k>2000001N0<k>cPX0oooo0P0000070?ooo`040000003oool0
0000000004H0oooo000:0?ooo`030000003oool0oooo03L0ooooH`3>c/h00`000000c/k>0<k>cP1O
0<k>cPX0oooo0P0000070?ooo`040000003oool00000000004H0oooo000:0?ooo`030000003oool0
oooo03L0ooooH`3>c/h00`000000c/k>0<k>cP1O0<k>cPX0oooo0P0000070?ooo`030000003oool0
oooo00800000A@3oool000X0oooo00<000000?ooo`3oool0=`3ooomS0<k>cP030000003>c/h0c/k>
05l0c/k>2`3oool2000000D0oooo00@000000?ooo`3oool0oooo0P0000150?ooo`002P3oool00`00
0000oooo0?ooo`0g0?ooof<0c/k>00<000000<k>cP3>c/h0G`3>c/h;0?ooo`<00000103oool01000
0000oooo0?ooo`3oool2000004D0oooo000:0?ooo`030000003oool0oooo03L0ooooH`3>c/h00`00
0000c/k>0<k>cP1O0<k>cPd0oooo1@00001;0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof<0
c/k>00<000000<k>cP3>c/h0G`3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof<0c/k>
00<000000<k>cP3>c/h0G`3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof<0c/k>00<0
00000<k>cP3>c/h0G`3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof<0c/k>00<00000
0<k>cP3>c/h0G`3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooof<0c/k>00<000000<k>
cP3>c/h0G`3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo
00<000000?ooo`3oool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>
c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?oo
o`3oool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/jl000000@0
c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003>c/h0c/k>0;P0c/k>
00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<0
00000?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0
oooo03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool0
00X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo0;P0oooo00<000000<k>
cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3o
ool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo
1@3>c/h00`000000oooo0?ooo`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<0
00000?ooo`3oool0=`3oool50<k>cP030000003oool0oooo0;P0oooo00<000000<k>cP3>c/h00P3>
c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool08`3oool0
103<c<`0MgMg08R8R03^k^h30?ooo`030:ZZZP3^k^h0oooo00@0oooo00<0c<c<0=gMg@3oool0703o
ool00`2ZZZX0k^k^0?ooo`080?ooo`030:ZZZP3^k^h0oooo00@0oooo00H0c<c<0=gMg@3oool0oooo
0<c<c03MgMd60?ooo`030000003oool0oooo00D0oooo100000020?ooo`030:ZZZP3^k^h0oooo00P0
oooo00<0ZZZZ0>k^kP3oool0103oool01P3<c<`0gMgM0?ooo`3oool0c<c<0=gMg@<0oooo00<0c<c<
0=gMg@3oool07P3oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo
03L0oooo1@3>c/h00`000000oooo0?ooo`0S0?ooo`04028R8P3oool0k^k^028R8P<0oooo00<0IVIV
0?ooo`3oool01@3oool00`1VIVH0oooo0?ooo`0K0?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV
0?ooo`3oool01@3oool01P1VIVH0oooo0?ooo`3oool0ZZZZ0;^k^`D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool0
1@3oool01@1VIVH0oooo0?ooo`3oool0IVIV00@0oooo00<0IVIV0?ooo`3oool07@3oool00`000000
c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo
0?ooo`0S0?ooo`04028R8P3oool0oooo028R8P80oooo0P2ZZZX70?ooo`0305EEE@3^k^h0oooo01X0
oooo0P2ZZZX90?ooo`80ZZZZ1`3oool01P1EEED0k^k^0?ooo`3oool0k^k^03<c<`D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80ZZZZ2@3oool20:ZZZPL0oooo00H0EEEE
0>k^kP3oool0oooo05EEE@3^k^h30?ooo`0305EEE@3^k^h0oooo01d0oooo00<000000<k>cP3>c/h0
0P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool07P3o
ool4000000050?ooo`000000oooo0?ooo`0000000P3oool01`14A4@0k^k^0?ooo`3oool0<c<c014A
4@2ZZZX00P3oool00`2ZZZX0VIVI0?ooo`040?ooo`03014A4@1EEED0oooo00/0oooo1@0000030?oo
o`0304A4A03^k^h0oooo00@0oooo100000001`14A4@0k^k^0?ooo`3oool0<c<c014A4@2ZZZX00P3o
ool01P2ZZZX0VIVI0?ooo`2ZZZX0000004A4A0D0oooo0`0000000`3oool00000000000020?ooo`03
0000003oool0oooo0080oooo00<0A4A40>k^kP3oool0103oool40000000304A4A03^k^h0oooo0080
oooo00H0<c<c014A4@2ZZZX0oooo0:ZZZP2IVIT20?ooo`030:ZZZP2IVIT0oooo0080oooo00<0ZZZZ
09VIV@3oool07@3oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo
03L0oooo1@3>c/h00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00D00000028R
8P3oool0oooo028R8P020?ooo`0603<c<`3oool0oooo0?ooo`000000k^k^0`3oool00`3^k^h0A4A4
0?ooo`040?ooo`0405EEE@2IVIT0oooo0?ooo`D08R8R00@0EEEE0?ooo`3oool0oooo0P0000040?oo
o`040000003oool0oooo03<c<`D0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`3o
ool000000>k^kP<0oooo00H0k^k^04A4A03oool0k^k^06IVIP3^k^h50?ooo`030000003oool0oooo
008000000`3oool300000080oooo00<0<c<c0?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00H000000>k^kP3oool0oooo0>k^kP14A4@20?ooo`030>k^kP14
A4@0oooo0080oooo00<0k^k^04A4A03oool07@3oool00`000000c/k>0<k>cP020<k>cUd0oooo000:
0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0080oooo00D00000028R8P3^k^h0oooo028R8P020?ooo`0503<c<`3oool0oooo0?ooo`000000
1@3oool00`0R8R80oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
<c<c1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`0R
8R80oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`0303<c<`3oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D08R8R0?ooo`3oool0oooo028R8P040?ooo`03028R8P3o
ool0oooo01`0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g
0?ooo`D0c/k>00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`050000003^k^h0
R8R807MgM`3<c<`00P3oool01@0c<c<0oooo0?ooo`3oool0000000D0oooo00<08R8R0?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo03<c<`@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<08R8R0?ooo`3oool01`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`0c<c<0oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`05028R8P3oool0oooo0?ooo`0R8R80103oool00`0R8R80oooo0?ooo`0L0?ooo`030000003>
c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`0504A4A03oool0
oooo0?ooo`0000001@3oool00`0R8R80oooo0?ooo`030?ooo`04014A4@1EEED0oooo0?ooo`D08R8R
00@0EEEE0?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?ooo`14A4@0103oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`0R8R80oooo0?ooo`07
0?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000030?ooo`14A4@0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
8R8R0?ooo`3oool0oooo028R8P040?ooo`03028R8P3oool0oooo01`0oooo00<000000<k>cP3>c/h0
0P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0703o
ool010000000oooo0?ooo`3oool3000000H0oooo00D0EEEE0?ooo`3oool0MgMg00000002028R8P80
oooo00<0c<c<06IVIP3oool0103oool00`1EEED0VIVI0?ooo`0<0?ooo`H0000000<0oooo05EEE@3o
ool00`3oool010000000oooo0?ooo`3oool300000080oooo00@0MgMg0000000R8R808R8R0P3oool0
0`3<c<`0IVIV0?ooo`080?ooo`050000003oool0oooo0?ooo`000000203oool00`1EEED0oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`<000000`3oool01`1gMgL00000028R8P0R8R80oooo0<c<
c01VIVH00P3oool00`3<c<`0IVIV0?ooo`020?ooo`030<c<c01VIVH0oooo01d0oooo00<000000<k>
cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0:0?ooo`80ZZZZ0P3oool00`0c<c<0oooo0?ooo`020?ooo`03
09VIV@3<c<`0oooo01X0oooo0P2ZZZX30?ooo`030000003oool0oooo00<0oooo0P2ZZZX20?ooo`03
03<c<`3oool0oooo0080oooo00<0VIVI0<c<c03oool05@3oool20:ZZZP<0oooo00<000000?ooo`3o
ool00`3oool20:ZZZP<0oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`20?ooo`0309VIV@3<c<`0
oooo0080oooo00<0VIVI0<c<c03oool07@3oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?oo
o`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00/0oooo00@0IVIV0?ooo`3oool0k^k^103oool00`1EEED0oooo0?ooo`0K0?ooo`0506IVIP3oool0
oooo0?ooo`0000001P3oool0101VIVH0oooo0?ooo`3^k^h40?ooo`0305EEE@3oool0oooo01H0oooo
00D0IVIV0?ooo`3oool0oooo000000060?ooo`0506IVIP3oool0oooo0?ooo`3^k^h00`3oool01@1E
EED0oooo0?ooo`3oool0EEEE00@0oooo00<0EEEE0?ooo`3oool07@3oool00`000000c/k>0<k>cP02
0<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00X0oooo00<0ZZZZ0>k^kP3oool0103oool00`3MgMd0ZZZZ0?ooo`0L0?oo
o`030:ZZZP3^k^h0oooo0080oooo00<000000?ooo`3oool00`3oool00`2ZZZX0k^k^0?ooo`040?oo
o`030=gMg@2ZZZX0oooo01L0oooo00<0ZZZZ0>k^kP3oool00P3oool00`000000oooo0?ooo`030?oo
o`030:ZZZP3^k^h0oooo00@0oooo00H0gMgM0:ZZZP3oool0oooo0=gMg@2ZZZX30?ooo`030=gMg@2Z
ZZX0oooo01h0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g
0?ooo`D0c/k>00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000c/k>0<k>cP020<k>cUd0oooo000:0?oo
o`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`0N0?ooo`@00000=03oool40000
02P0oooo1000000b0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3o
ool0=`3oool50<k>cP030000003oool0oooo0;P0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`00
2P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0^03oool00`000000c/k>
0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?oo
o`2h0?ooo`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool5
0<k>cP030000003oool0oooo0;P0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`00
0000oooo0?ooo`0g0?ooo`D0c/k>00<000000?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>
cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000oooo0?ooo`2h0?ooo`03
0000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000
003oool0oooo0;P0oooo00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?oo
o`0g0?ooo`D0c/k>00<000000?ooo`3oool0^03oool00`000000c/k>0<k>cP020<k>cUd0oooo000:
0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`2h0>o_k`030000003>c/h0
c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_
0;P0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0
c/k>00<000000>o_k`3_knl0^03_knl00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000
003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`2h0>o_k`030000003>c/h0c/k>0080c/k>
G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_0480kno_00/0
[jn_04m?C`1_Kfl0Kfm_05mOG`3Ogml0kno_08n?S`0?3`l0GemO0;no_`020>o_k`070000002?Shl0
kno_08n?S`0?3`l0GemO0;no_`030>o_k`0808n?S`000000GemO09nOW`3_knl0000004m?C`3Ogml2
0>o_k`0601lO7`3?cll0kno_0;no_`2?Shl0[jn_0P2OWil30>o_k`0501lO7`3?cll0kno_0000002?
Shl0A@3_knl00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo
1@3>c/h00`000000kno_0>o_k`120>o_k`0>0<o?c`1_Kfl0kno_0>o_k`3?cll0?clo0>o_k`0?3`l0
clo?0>o_k`2OWil0_kno0>o_k`0_;bl20:n_[`0500l?3`3?cll0kno_09nOW`2o_kl00P3_knl03`0?
3`l0clo?0>o_k`2o_kl0WinO00l?3`2OWil0Ogmo0=oOg`3_knl0?clo09nOW`3_knl0?clo0=oOg`02
0>o_k`0:03lo?`2OWil0kno_0>o_k`1oOgl0Kfm_0>o_k`0_;bl0_kno0:n_[d@0kno_00<000000<k>
cP3>c/h00P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_
knl0@`3_knl0202o_kl0kno_0>o_k`2o_kl000000>o_k`0?3`l0gmoO0P3_knl01`3Ogml0kno_05mO
G`2OWil0kno_00l?3`3Ogml00P3_knl01@3Ogml0kno_0>o_k`0O7al0clo?0080kno_00/0gmoO05mO
G`1oOgl0kno_0=oOg`3_knl0Ogmo0;no_`3_knl000000=oOg`020>o_k`090:n_[`0_;bl0kno_0>o_
k`3?cll000000=oOg`3?cll0Shn?04D0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3oool0
0`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0A@3_knl04P3Ogml07alO04m?C`3_
knl0Cdm?06m_K`2OWil0Shn?0=oOg`3_knl0WinO05mOG`3_knl0Cdm?06m_K`2OWil0Shn?0=oOg`80
kno_0P1_Kfl30>o_k`0309nOW`0o?cl0kno_0080kno_00D0_kno0:n_[`3_knl0;bl_0:n_[`020>o_
k`030=oOg`000000kno_0080kno_00D07alO05mOG`3_knl0Ogmo0=oOg`140>o_k`030000003>c/h0
c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_
04D0kno_0180;bl_01lO7`3Ogml0kno_0=oOg`0o?cl0gmoO0:n_[`0o?cl0kno_0=oOg`0O7al0kno_
0=oOg`0o?cl0gmoO0:n_[`0o?cl20>o_k`030=oOg`0_;bl0_kno00<0kno_00T000000=oOg`3_knl0
kno_0;no_`1_Kfl0kno_09nOW`1?Cdl00P3_knl02P3?cll0?clo0>o_k`3_knl0Kfm_05mOG`2?Shl0
Kfm_0=oOg`1?Cdm40>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3o
ool0=`3oool50<k>cP030000003_knl0kno_04@0kno_00<0Kfm_0000003Ogml00`3_knl0103Ogml0
Ogmo05mOG`0o?cl20>o_k`0701lO7`3Ogml0kno_0=oOg`1oOgl0GemO03lo?`040>o_k`0:08n?S`1O
Gel03`l?07moO`0?3`l0Cdm?07moO`3_knl0_kno06m_K`80kno_0P2OWil00`2_[jl0Shn?0;no_`02
0>o_k`060;no_`0_;bl0Kfm_0=oOg`1?Cdl03`l?A03_knl00`000000c/k>0<k>cP020<k>cUd0oooo
000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`140>o_k`0400l?3`2_
[jl0kno_0<o?c`P0kno_00<0Cdm?08n?S`3_knl0303_knl00`2?Shl0Cdm?0>o_k`1F0>o_k`030000
003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>cP030000003_
knl0kno_04@0kno_00D0;bl_0=oOg`3_knl0WinO0;no_`070>o_k`0308n?S`1?Cdl0kno_00`0kno_
00<0gmoO03lo?`3_knl0EP3_knl00`000000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003o
ool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`140>o_k`050;no_`1OGel0Kfm_0000001oOgl0
1`3_knl00`1_Kfl03`l?0>o_k`0A0>o_k`0303lo?`3_knl0kno_0540kno_00<000000<k>cP3>c/h0
0P3>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0D03_
knl00`3Ogml0Ogmo0<o?c`1U0>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<00000
0?ooo`3oool0=`3oool50<k>cP030000003_knl0kno_0;P0kno_00<000000<k>cP3>c/h00P3>c/iM
0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0^03_knl00`00
0000c/k>0<k>cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000
kno_0>o_k`2h0>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0
=`3oool50<k>cP030000003_knl0kno_0;P0kno_00<000000<k>cP3>c/h00P3>c/iM0?ooo`002P3o
ool00`000000oooo0?ooo`0g0?ooo`D0c/k>00<000000>o_k`3_knl0^03_knl00`000000c/k>0<k>
cP020<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0oooo1@3>c/h00`000000kno_0>o_k`2h
0>o_k`030000003>c/h0c/k>0080c/k>G@3oool000X0oooo00<000000?ooo`3oool0=`3oool50<k>
c[`00000103>c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo
00<000000?ooo`3oool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>
c/iM0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?oo
o`3oool0=`3oooo50<k>cUd0oooo000:0?ooo`030000003oool0oooo03L0ooooa@3>c/iM0?ooo`00
2P3oool00`000000oooo0?ooo`0g0?ooolD0c/k>G@3oool000X0oooo00<000000?ooo`3oool0o`3o
oomJ0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000:0?oo
o`030000003oool0oooo09T0oooo0P00002n0?ooo`002P3oool00`000000oooo0?ooo`2I0?ooo`80
0000_P3oool000X0oooo00<000000?ooo`3oool0V@3oool200000;h0oooo000:0?ooo`030000003o
ool0oooo09T0oooo0`00002m0?ooo`002P3oool00`000000oooo0?ooo`2H0?ooo`@00000_@3oool0
00X0oooo00<000000?ooo`3oool0V03oool4000000P0oooo00D0k^k^07MgM`000000ZZZZ0>k^kP03
0?ooo`030>k^kP0A4A40oooo00<0oooo00D0IVIV05EEE@1VIVH0MgMg06IVIP2R0?ooo`002P3oool0
0`000000oooo0?ooo`2H0?ooo`D000002@3oool00`1VIVH0oooo0?ooo`020?ooo`030>k^kP0A4A40
000000<0oooo00<04A4A04A4A03oool00P3oool00`2k^k/04A4A0?ooo`2P0?ooo`002P3oool00`00
0000oooo0?ooo`2G0?ooo`H000002@3oool01@1VIVH0oooo0?ooo`3oool0k^k^00804A4A00H0EEEE
0?ooo`3oool0IVIV0000003^k^h40?ooo`0303<c<`1VIVH0oooo09l0oooo000:0?ooo`030000003o
ool0oooo09L0oooo1P0000090?ooo`0406IVIP3oool0oooo0>k^kP804A4A00H0k^k^06IVIP3oool0
oooo00000014A4@50?ooo`0306IVIP000000oooo09l0oooo000:0?ooo`030000003oool0oooo09L0
oooo1P0000090?ooo`0806IVIP3oool0k^k^014A4@000000k^k^0?ooo`1VIVH20?ooo`030000001V
IVH0oooo00@0oooo00<0IVIV0000003oool0W`3oool000X0oooo00<000000?ooo`3oool0U`3oool7
000000P0oooo00D0IVIV0?ooo`0c<c<000000<c<c0020?ooo`0506IVIP3oool0oooo0000001VIVH0
1@3oool00`14A4@000000?ooo`2O0?ooo`002P3oool00`000000oooo0?ooo`2F0?ooo`P00000203o
ool0101VIVH0A4A40000003<c<`30?ooo`0506IVIP3oool0oooo06IVIP0c<c<0103oool00`3^k^h0
000006IVIP2P0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00T0oooo
0P0000000`3<c<`0oooo0?ooo`020?ooo`0606IVIP3oool0oooo0?ooo`0A4A40^k^k0`3oool00`14
A4@04A4A0?ooo`2P0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00L0
oooo00@0gMgM05EEE@000000c<c<0`3oool01@3^k^h0ZZZZ0000001gMgL0k^k^0080oooo00D0IVIV
07MgM`1VIVH0EEEE06IVIP2R0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo0;`0oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0_03oool000X0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0_03oool000X0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l
0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool0_03oool000X0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:
0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<000000?ooo`3oool0o`3ooomJ0?oo
o`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:0?ooo`030000003oool0oooo0?l0oooo
FP3oool000X0oooo00<000000?ooo`3oool0V@3oool300000;d0oooo000:0?ooo`030000003oool0
oooo09L0oooo0P0000030?ooo`800000^`3oool000X0oooo00<000000?ooo`3oool0U@3oool20000
00L0oooo00<000000?ooo`3oool0^03oool000X0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`080?ooo`800000^03oool000X0oooo00<000000?ooo`3oool0TP3oool2000000d0oooo
0P00002f0?ooo`002P3oool00`000000oooo0?ooo`2@0?ooo`8000004@3oool200000;@0oooo000:
0?ooo`030000003oool0oooo08h0oooo0P00000E0?ooo`030000003oool0oooo0;40oooo000:0?oo
o`030000003oool0oooo08`0oooo0P00000H0?ooo`800000/@3oool000X0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0J0?ooo`800000[`3oool000X0oooo00<000000?ooo`3oool0
R@3oool2000001l0oooo0P00002]0?ooo`002P3oool00`000000oooo0?ooo`270?ooo`8000008`3o
ool200000:/0oooo000:0?ooo`030000003oool0oooo08D0oooo0P00000W0?ooo`030000003oool0
oooo0:P0oooo000:0?ooo`030000003oool0oooo08<0oooo0P00000Z0?ooo`800000Z03oool000X0
oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0/0?ooo`800000YP3oool000X0oooo
00<000000?ooo`3oool0P03oool200000340oooo0P00002T0?ooo`002P3oool00`000000oooo0?oo
o`1n0?ooo`800000=@3oool00`000000oooo0?ooo`2Q0?ooo`002P3oool00`000000oooo0?ooo`1l
0?ooo`800000>03oool200000:40oooo000:0?ooo`030000003oool0oooo07X0oooo0P00000l0?oo
o`800000W`3oool000X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0n0?ooo`80
0000W@3oool000X0oooo00<000000?ooo`3oool0M`3oool2000004<0oooo00<000000?ooo`3oool0
VP3oool000X0oooo00<000000?ooo`3oool0M@3oool2000004H0oooo0P00002J0?ooo`002P3oool0
0`000000oooo0?ooo`1c0?ooo`800000BP3oool2000009P0oooo000:0?ooo`030000003oool0oooo
0740oooo0P00000G0?ooo`090=gMg@1VIVH000000:ZZZP3oool0^k^k0000002k^k/0k^k^00<0oooo
00/0IVIV0000001VIVH0^k^k0000002ZZZX0k^k^028R8P000000<c<c0<c<c0050?ooo`03014A4@1E
EED0oooo01P0oooo0P00002F0?ooo`002P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0
oooo01P0oooo00<0^k^k0000003oool00P3oool00`000000oooo0?ooo`030?ooo`080000003^k^h0
oooo0=gMg@000000oooo04A4A00c<c<20?ooo`030:ZZZP3oool0oooo00<0oooo00<0EEEE09VIV@3o
ool06P3oool00`000000oooo0?ooo`2C0?ooo`002P3oool00`000000oooo0?ooo`1^0?ooo`800000
6`3oool00`2k^k/000000?ooo`020?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool0
oooo0000003oool000000<c<c2H0oooo0P00002C0?ooo`002P3oool00`000000oooo0?ooo`1/0?oo
o`8000007@3oool00`2k^k/000000?ooo`020?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000X0oooo00<0^k^k0?ooo`3oool0703oool200000940oooo000:
0?ooo`030000003oool0oooo06X0oooo0P00000O0?ooo`030;^k^`000000oooo0080oooo00@00000
0<c<c03MgMd0k^k^0P3oool01P000000oooo0>k^kP2IVIT000000?ooo`80A4A40P1VIVH00`000000
oooo0?ooo`040?ooo`0300000014A4@0c<c<01h0oooo0P00002?0?ooo`002P3oool00`000000oooo
0?ooo`1X0?ooo`8000008@3oool0302k^k/000000?ooo`3oool0ZZZZ0000002IVIT000000:ZZZP3o
ool0^k^k000000<0oooo00L0IVIV0?ooo`3^k^h0IVIV07MgM`1EEED0ZZZZ00H0oooo00<0ZZZZ04A4
A00A4A40803oool2000008d0oooo000:0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool08@3oool00`2k^k/000000?ooo`0K0?ooo`0307MgM`3oool0oooo0200oooo00<000000?ooo`3o
ool0RP3oool000X0oooo00<000000?ooo`3oool0I@3oool200000240oooo00D0^k^k0?ooo`3oool0
^k^k000000020?ooo`0309VIV@3oool0oooo01H0oooo00<0gMgM09VIV@3oool08P3oool2000008X0
oooo000:0?ooo`030000003oool0oooo06<0oooo0P00000S0?ooo`050000001VIVH0IVIV04A4A000
00000P1VIVH00`0A4A40oooo0?ooo`0D0?ooo`0309VIV@000000EEEE02H0oooo0P0000280?ooo`00
2P3oool00`000000oooo0?ooo`1Q0?ooo`8000009@3oool00`3MgMd0oooo0?ooo`040?ooo`030=gM
g@3oool0oooo03l0oooo0P0000260?ooo`002P3oool00`000000oooo0?ooo`1O0?ooo`800000LP3o
ool00`000000oooo0?ooo`230?ooo`002P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo07<0oooo0P0000230?ooo`002P3oool00`000000oooo0?ooo`1L0?ooo`800000N03oool20000
0840oooo000:0?ooo`030000003oool0oooo05X0oooo0P00000@0?ooo`030:ZZZP3^k^h0oooo00<0
oooo00<0c<c<0=gMg@3oool03@3oool00`2ZZZX0k^k^0?ooo`040?ooo`060<c<c03MgMd0oooo0?oo
o`3<c<`0gMgM1P3oool00`000000oooo0?ooo`050?ooo`@000000P3oool00`2ZZZX0k^k^0?ooo`08
0?ooo`030:ZZZP3^k^h0oooo00@0oooo00H0c<c<0=gMg@3oool0oooo0<c<c03MgMd30?ooo`030<c<
c03MgMd0oooo01L0oooo0P00001o0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`8000004P3o
ool00`1VIVH0oooo0?ooo`040?ooo`030:ZZZP2k^k/0oooo00`0oooo00<0IVIV0?ooo`3oool01@3o
ool01P1VIVH0oooo0?ooo`3oool0ZZZZ0;^k^`D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`0306IVIP3oool0oooo00P0oooo00<0IVIV0?ooo`3oool01@3oool01@1VIVH0
oooo0?ooo`3oool0IVIV00@0oooo00<0IVIV0?ooo`3oool0603oool00`000000oooo0?ooo`1l0?oo
o`002P3oool00`000000oooo0?ooo`1F0?ooo`8000004`3oool20:ZZZPH0oooo00<0k^k^03<c<`3o
ool02`3oool20:ZZZPL0oooo00H0EEEE0>k^kP3oool0oooo0>k^kP0c<c<50?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool20:ZZZPT0oooo0P2ZZZX70?ooo`0605EEE@3^k^h0
oooo0?ooo`1EEED0k^k^0`3oool00`1EEED0k^k^0?ooo`0I0?ooo`800000O03oool000X0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0=0?ooo`800000103oool01P14A4@0k^k^0?oo
o`3oool0<c<c014A4@80ZZZZ00<0000004A4A03oool01`3oool40000000704A4A03^k^h0oooo0?oo
o`0c<c<04A4A0:ZZZP020?ooo`060:ZZZP2IVIT0oooo0:ZZZP000000A4A41@3oool3000000030?oo
o`00000000000080oooo00<000000?ooo`3oool00P3oool00`14A4@0k^k^0?ooo`040?ooo`@00000
00<0A4A40>k^kP3oool00P3oool01P0c<c<04A4A0:ZZZP3oool0ZZZZ09VIV@80oooo00<0ZZZZ09VI
V@3oool00P3oool00`2ZZZX0VIVI0?ooo`0K0?ooo`800000NP3oool000X0oooo00<000000?ooo`3o
ool0D`3oool200000100oooo00<000000?ooo`0000000`3oool02P0c<c<0oooo0?ooo`3oool00000
0>k^kP3oool0k^k^06IVIP3^k^h70?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0
oooo0000003^k^h30?ooo`060>k^kP14A4@0oooo0>k^kP1VIVH0k^k^1@3oool00`000000oooo0?oo
o`02000000<0oooo0`0000020?ooo`0303<c<`3oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003^k^h0oooo0?ooo`3^k^h0A4A40P3oool00`3^k^h0
A4A40?ooo`020?ooo`030>k^kP14A4@0oooo00@0oooo1@0R8R800`1EEED0oooo0?ooo`0A0?ooo`80
0000N03oool000X0oooo00<000000?ooo`3oool0D@3oool200000180oooo00<000000?ooo`3oool0
0`3oool01@0c<c<0oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<08R8R0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`0c<c<0oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`05028R8P3oool0
oooo0?ooo`0R8R80103oool00`0R8R80oooo0?ooo`0N0?ooo`030000003oool0oooo07D0oooo000:
0?ooo`030000003oool0oooo04l0oooo0P00000D0?ooo`030000003oool0oooo00<0oooo00D0<c<c
0?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`03028R8P3oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<0<c<c0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@0R8R80oooo0?ooo`3oool08R8R
00@0oooo00<08R8R0?ooo`3oool07`3oool2000007D0oooo000:0?ooo`030000003oool0oooo04d0
oooo0P00000F0?ooo`030000003oool0oooo00<0oooo00D0A4A40?ooo`3oool0oooo0000000;0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`03028R8P3oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`@0000000<0oooo04A4A03oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@0R8R80oooo0?ooo`3oool08R8R00@0oooo00<08R8R0?ooo`3oool00`3oool5028R8P0305EE
E@3oool0oooo01H0oooo0P0000130?oooa`00000503oool000X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0D0?ooo`D000000`3oool01@1EEED0oooo0?ooo`1gMgL0000000808R8R
2@3oool010000000oooo0?ooo`3oool300000080oooo00@0MgMg0000000R8R808R8R0P3oool00`3<
c<`0IVIV0?ooo`080?ooo`050000003oool0oooo0?ooo`000000203oool00`1EEED0oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`<000000`3oool01`1gMgL00000028R8P0R8R80oooo0<c<c01V
IVH00P3oool00`3<c<`0IVIV0?ooo`020?ooo`030<c<c01VIVH0oooo02@0oooo0P00000n0?ooo`<0
0000703oool300000140oooo000:0?ooo`030000003oool0oooo04X0oooo0P00000O0?ooo`80ZZZZ
0P3oool00`0c<c<0oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0P2ZZZX20?ooo`0303<c
<`3oool0oooo0080oooo00<0VIVI0<c<c03oool05@3oool20:ZZZP<0oooo00<000000?ooo`3oool0
0`3oool20:ZZZP<0oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`20?ooo`0309VIV@3<c<`0oooo
0080oooo00<0VIVI0<c<c03oool09P3oool00`000000oooo0?ooo`0i0?ooo`8000008P3oool20000
00l0oooo000:0?ooo`030000003oool0oooo04P0oooo0P00000R0?ooo`0406IVIP3oool0oooo0>k^
kP/0oooo00<000000?ooo`3oool0103oool0101VIVH0oooo0?ooo`3^k^h40?ooo`0305EEE@3oool0
oooo01H0oooo00D0IVIV0?ooo`3oool0oooo000000060?ooo`0506IVIP3oool0oooo0?ooo`3^k^h0
0`3oool01@1EEED0oooo0?ooo`3oool0EEEE00@0oooo00<0EEEE0?ooo`3oool09`3oool2000003P0
oooo0P00000T0?ooo`8000003P3oool000X0oooo00<000000?ooo`3oool0AP3oool2000002@0oooo
00<0ZZZZ0>k^kP3oool03@3oool00`000000oooo0?ooo`030?ooo`030:ZZZP3^k^h0oooo00@0oooo
00<0gMgM0:ZZZP3oool05`3oool00`2ZZZX0k^k^0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<0ZZZZ0>k^kP3oool0103oool01P3MgMd0ZZZZ0?ooo`3oool0gMgM0:ZZZP<0oooo00<0gMgM0:ZZ
ZP3oool0:P3oool2000003D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?oo
o`002P3oool00`000000oooo0?ooo`140?ooo`800000=P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`80
0000<P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000:0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0=`3oool4000002P0oooo100000120?ooo`800000
;`3oool2000002X0oooo0P00000;0?ooo`002P3oool00`000000oooo0?ooo`110?ooo`800000[P3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0?`3oool200000;40oooo0P00000[0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0?@3oool20000
0;D0oooo0P00000Y0?ooo`030000003oool0oooo00H0oooo00@0k^k^09VIV@0000004A4A0P1VIVH0
1@0R8R80ZZZZ0?ooo`3<c<`000000080c<c<00d000000<c<c03oool0c<c<028R8P000000A4A40:ZZ
ZP000000EEEE0?ooo`0A4A40EEEE00`0oooo00<000000?ooo`3oool0203oool000X0oooo00<00000
0?ooo`3oool0>`3oool200000;T0oooo0P00000D0?ooo`8000004@3oool00`000000oooo0?ooo`08
0?ooo`030000002k^k/0oooo0080oooo00@0MgMg0?ooo`3oool000000P3oool01@000000oooo0?oo
o`0c<c<0A4A40080oooo00H0k^k^0000003oool0oooo05EEE@2IVIT<0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`0A0?ooo`D000003@3oool00`000000oooo0?ooo`090?ooo`030000002k^k/0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000gMgM0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0>03oool200000;l0
oooo0P00000A0?ooo`P000002P3oool00`000000oooo0?ooo`090?ooo`040000002k^k/0oooo0<c<
c0@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0=`3oool20000
0<40oooo0P00000@0?ooo`/000001`3oool00`000000oooo0?ooo`090?ooo`0400000014A4@0IVIV
014A4@<0oooo00D0k^k^0000003^k^h0k^k^000000020?ooo`0609VIV@1gMgL0oooo0?ooo`3^k^h0
00004@3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`80kno_
0P00002m0>o_k`8000000P3_knl40?oooaX00000103oool00`000000oooo0?ooo`090?ooo`040000
002k^k/0oooo07MgM`<0oooo00D0VIVI014A4@2ZZZX04A4A06IVIP030?ooo`050:ZZZP1gMgL0IVIV
04A4A00000004@3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0i0?oo
o`80kno_00<000000>o_k`3_knl0^@3_knl00`000000kno_0>o_k`0B0?ooo``000001P3oool00`00
0000oooo0?ooo`090?ooo`030000002k^k/0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0k0?ooo`030>o_k`00000000000;L0
kno_0P0000000`3_knl0oooo0?ooo`0B0?ooo`T000002@3oool00`000000oooo0?ooo`090?ooo`05
0000002k^k/0oooo0?ooo`1gMgL03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00L0oooo000:0?ooo`030000003oool0oooo03d0oooo00<0kno_000000000000M@3_knl00`1?Cdl0
kno_0>o_k`0k0>o_k`8000000P3_knlE0?ooo`D000003@3oool00`000000oooo0?ooo`070?ooo`07
0>k^kP2ZZZX0000004A4A01VIVH0A4A40000000=0?ooo`030;^k^`000000oooo0100oooo00<00000
0?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0?P3oool20>o_k`800000L`3_knl00`0O
7al0kno_0>o_k`0i0>o_k`8000000P3_knlG0?ooo`800000403oool00`000000oooo0?ooo`0K0?oo
o`030=gMg@0c<c<0oooo0100oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3o
ool0@03oool20>o_k`030000003_knl0kno_0700kno_00<0Cdm?0:n_[`3_knl0>03_knl00`000000
kno_0>o_k`0[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool000X0oooo
00<000000?ooo`3oool0@P3oool00`3_knl000000000000Q0>o_k`090;no_`1OGel0Kfm_07moO`1O
Gel0_kno0>o_k`3Ogml07alO00@0kno_00/07alO0<o?c`3_knl0000004m?C`3Ogml0kno_08n?S`0?
3`l0GemO0;no_`020>o_k`030=oOg`0O7al0kno_00<0kno_00H07alO0<o?c`3_knl0_kno08n?S`2_
[jl209nOW`80kno_00H07alO0<o?c`3_knl0kno_0000002?Shl40>o_k`0A0:n_[`1?Cdl0Kfm_06m_
K`1OGel0gmoO0>o_k`0O7al0000006m_K`3_knl000000;no_`3_knl0000004m?C`3Ogml00P3_knl0
2P0O7al0clo?0>o_k`1OGel03`l?04m?C`2o_kl0kno_07moO`1_Kfl20>o_k`070000002?Shl0kno_
08n?S`0?3`l0GemO0;no_`020>o_k`0605mOG`0?3`l0Kfm_0<o?c`000000Shn?0P3_knl00`0O7al0
GemO0>o_k`0Q0>o_k`80000000<0kno_0?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo04@0oooo00<0kno_000000000000
7P3_knl00`3?cll03`l?0=oOg`020>o_k`060=oOg`1OGel0kno_0>o_k`0?3`l0clo?0`3_knl0300o
?cl0WinO0>o_k`0?3`l0WinO07moO`3Ogml03`l?0<o?c`3_knl0WinO0;no_`80kno_00<03`l?0<o?
c`3_knl00P3_knl01@0o?cl0WinO0>o_k`0o?cl0gmoO0080kno_00D0?clo09nOW`3_knl0Ogmo06m_
K`020>o_k`0301lO7`2o_kl0[jn_00<0kno_01L0clo?06m_K`3_knl0kno_0<o?c`0o?cl0kno_0000
003Ogml0clo?08n?S`0O7al0_kno0=oOg`0?3`l0WinO07moO`3Ogml0kno_03lo?`2OWil0kno_06m_
K`020>o_k`0403lo?`3_knl0[jn_02l_;`80kno_00h03`l?0:n_[`2_[jl03`l?0<o?c`3_knl0WinO
0;no_`3_knl000000<o?c`3_knl0Ogmo00000080[jn_00<0kno_05mOG`2?Shl0803_knl200000080
kno_;`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000
003oool0oooo04H0oooo00<0kno_000000000000703_knl00`1?Cdl0GemO0>o_k`030>o_k`0509nO
W`3_knl0kno_05mOG`1_Kfl00`3_knl02@1oOgl0_kno0>o_k`1OGel0Ogmo0>o_k`3Ogml03`l?0=oO
g`020>o_k`050=oOg`3_knl0kno_05mOG`1_Kfl00`3_knl01@1oOgl0_kno0>o_k`000000gmoO0080
kno_00T0[jn_02l_;`3_knl0clo?0000003Ogml0kno_05mOG`2_[jl01@3_knl0202o_kl0kno_0>o_
k`2o_kl000000>o_k`1?Cdl0clo?0P3_knl02P0_;bl0Shn?0>o_k`1OGel0Ogmo0>o_k`3Ogml0kno_
07moO`2o_kl20>o_k`030=oOg`0o?cl0;bl_0080kno_00P000000>o_k`3_knl0Cdm?08n?S`3_knl0
3`l?0=oOg`80kno_00@0gmoO0>o_k`0_;bl0clo?0P3_knl01`0?3`l0[jn_0>o_k`3_knl0_kno04m?
C`1_Kfl07P3_knl00`000000kno_0>o_k`0a0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0203oool000X0oooo00<000000?ooo`3oool0A`3oool20>o_k`8000006P3_knl00`0?3`l0
[jn_0>o_k`060>o_k`0309nOW`0O7al0gmoO0080kno_00D0_kno0:n_[`3_knl0WinO03lo?`020>o_
k`0504m?C`1_Kfl0WinO08n?S`3Ogml00P3_knl00`2OWil07alO0=oOg`020>o_k`050;no_`2_[jl0
kno_02l_;`2_[jl00P3_knl02@3Ogml000000>o_k`3_knl07alO05mOG`3_knl0[jn_06m_K`070>o_
k`060=oOg`0O7al0Cdm?0>o_k`3Ogml0GemO0P3_knl01@3Ogml07alO0>o_k`2OWil0?clo00<0kno_
00L0_kno0:n_[`3_knl0kno_02l_;`1?Cdl0gmoO0080kno_00h07alO0;no_`3_knl0Shn?03lo?`3_
knl0Cdm?06m_K`2OWil0Shn?0=oOg`3_knl0Shn?06m_K`80kno_00D0Ogmo06m_K`3_knl0kno_08n?
S`0N0>o_k`80000000<0kno_0?ooo`3oool0<P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo04T0oooo0P3_knl00`000000kno_0>o_k`0G
0>o_k`030000002_[jl0kno_00D0kno_0P3?cll01P0_;bl0Ogmo0:n_[`3_knl0_kno06m_K`80kno_
00T000000=oOg`3_knl0gmoO03lo?`3Ogml0[jn_03lo?`3_knl00P3?cll02@0_;bl0Ogmo0:n_[`3_
knl0_kno06m_K`3_knl0WinO04m?C`020>o_k`090<o?c`0o?cl0kno_06m_K`1OGel0Shn?06m_K`3O
gml0;bl_00L0kno_00<0;bl_01lO7`3Ogml00P3_knl02@2o_kl0[jn_0>o_k`3_knl0GemO0:n_[`3_
knl000000=oOg`020>o_k`060;no_`1_Kfl0kno_0>o_k`1?Cdl0kno_0P3Ogml0303_knl0Cdm?07mo
O`3_knl0clo?0000003?cll0gmoO03lo?`3Ogml0[jn_03lo?`80kno_00D0GemO0;no_`3_knl0[jn_
02l_;`020>o_k`0300l?3`1oOgl0clo?01X0kno_0P0000000`3_knl0oooo0?ooo`0M0?ooo`050=gM
g@1VIVH000000:ZZZP3MgMd00P3oool0103^k^h0VIVI0000000A4A4206IVIP08028R8P2ZZZX0oooo
03<c<`1VIVH0MgMg06IVIP3^k^h20?ooo`800000:P3oool2000000/0oooo000:0?ooo`030000003o
ool0oooo04/0oooo00<0kno_0000000000005`3_knl00`0o?cl0Kfm_0>o_k`060>o_k`0A08n?S`00
0000clo?00l?3`3?cll0_kno06m_K`3_knl0Ogmo00l?3`1?Cdl0Ogmo0>o_k`3Ogml0Ogmo05mOG`0o
?cl00P3_knl01`2?Shl000000<o?c`0?3`l0clo?0;no_`1_Kfl00P3_knl209nOW`0:0:n_[`2?Shl0
_kno0>o_k`2o_kl0;bl_06m_K`3Ogml0Cdm?00l?3`H0kno_00<0Kfm_0000003Ogml0103_knl0303O
gml0WinO08n?S`0O7al0Cdm?07moO`0?3`l0Cdm?07moO`3_knl0_kno06m_K`80kno_00D0clo?05mO
G`0?3`l0_kno09nOW`0202l_;`80Kfm_00L0000007moO`3_knl0gmoO07moO`1OGel0?clo00<0kno_
00@0WinO07moO`0_;bl000000P3_knl01@2o_kl0?clo0000000?3`l0[jn_01H0kno_0P0000000`3_
knl0oooo0?ooo`0P0?ooo`030;^k^`000000oooo00D0oooo00<000000;^k^`3oool00P3oool00`1g
MgL0gMgM07MgM`020?ooo`030<c<c00c<c<0oooo0080oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`1=0?ooo`030>o_k`000000000001D0
kno_00<0WinO00l?3`3_knl00`3_knl00`2o_kl0kno_0>o_k`090>o_k`0308n?S`1?Cdl0kno_0280
kno_00D03`l?0:n_[`3_knl0kno_0<o?c`080>o_k`0308n?S`1?Cdl0kno_00X0kno_00<0clo?0000
003_knl03P3_knl00`0?3`l0[jn_0>o_k`030>o_k`0309nOW`0o?cl0kno_01@0kno_00<000000>o_
k`3_knl08`3oool00`2k^k/000000?ooo`050?ooo`030000002k^k/0oooo00<0oooo00H0k^k^0?oo
o`3oool0oooo0>k^kP0000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02`3o
ool000X0oooo00<000000?ooo`3oool0C`3oool00`3_knl000000000000D0>o_k`80Cdm?0`3_knl0
0`1oOgl0[jn_0>o_k`090>o_k`030=oOg`0o?cl0kno_0280kno_00D0;bl_0=oOg`3_knl0kno_0:n_
[`080>o_k`030=oOg`0o?cl0kno_00/0kno_00<07alO0<o?c`3_knl03@3_knl00`1?Cdl0Kfm_0>o_
k`040>o_k`0307moO`3_knl0kno_0140kno_0P0000000`3_knl0oooo0?ooo`0S0?ooo`030;^k^`00
0000oooo00D0oooo00@000000;^k^`3oool0c<c<1@3oool00`3MgMd04A4A028R8P050?ooo`800000
903oool2000000h0oooo000:0?ooo`030000003oool0oooo0500oooo0P3_knl00`000000kno_0>o_
k`0B0>o_k`0608n?S`1OGel0Kfm_07moO`1_Kfl0_kno1`3_knl00`0o?cl0kno_0>o_k`0@0>o_k`03
03lo?`3_knl0kno_0180kno_00<0_kno05mOG`1_Kfl00P1OGel=0>o_k`0303lo?`3_knl0kno_00H0
kno_00D0_kno04m?C`3_knl0kno_07moO`0:0>o_k`030=oOg`0o?cl0;bl_0080kno_00@0Cdm?02l_
;`1_Kfl0_kno4@3_knl2000000030>o_k`3oool0oooo02D0oooo00<0VIVI0000003^k^h01@3oool0
10000000A4A406IVIP0A4A430?ooo`050>k^kP14A4@0000003<c<`3^k^h01P3oool200000280oooo
0P00000?0?ooo`002P3oool00`000000oooo0?ooo`1B0?ooo`030>o_k`000000000006<0kno_00@0
_kno07moO`1OGel0;bl_2`3_knl00`3?cll0Kfm_0>o_k`0D0>o_k`80000000<0kno_0?ooo`3oool0
9P3oool0103MgMd0000006IVIP1EEED50?ooo`040000002k^k/0oooo07MgM`<0oooo00<0<c<c014A
4@2k^k/02P3oool3000001`0oooo0`00000A0?ooo`002P3oool00`000000oooo0?ooo`1D0?ooo`03
0>o_k`000000000008H0kno_00<000000>o_k`3_knl0:@3oool2028R8P030?ooo`3<c<`0EEEE00@0
oooo00<000000;^k^`3oool0103oool00`000000gMgM0?ooo`0=0?oooa`00000503oool000X0oooo
00<000000?ooo`3oool0EP3oool00`3_knl00000000000220>o_k`80000000<0kno_0?ooo`3oool0
:03oool00`1VIVH000000>k^kP020?ooo`030<c<c01gMgL0oooo0080oooo00D000000;^k^`3oool0
oooo07MgM`020?ooo`05028R8P3MgMd0oooo0?ooo`2k^k/0>`3oool000X0oooo00<000000?ooo`3o
ool0F03oool00`3_knl000000>o_k`1n0>o_k`80000000<0kno_0?ooo`3oool0:03oool01@3^k^h0
MgMg00000014A4@0k^k^0080oooo00X0c<c<014A4@1gMgL0k^k^0:ZZZP000000A4A406IVIP14A4@0
00000P3oool01@3<c<`0EEEE06IVIP1EEED0VIVI03/0oooo000:0?ooo`030000003oool0oooo05T0
oooo00<0kno_000000000000703_knl0102_[jl03`l?03lo?`2o_kl30>o_k`0708n?S`0?3`l0GemO
0;no_`3_knl0gmoO01lO7`040>o_k`0901lO7`3Ogml0kno_09nOW`1?Cdl0kno_0<o?c`000000_kno
0080kno_00D07alO0<o?c`3_knl07alO0<o?c`020>o_k`0@0000002?Shl0kno_01lO7`000000Kfm_
0>o_k`000000_kno0>o_k`000000Cdm?0=oOg`3_knl03`l?06m_K`80kno_00<0_kno08n?S`2_[jl0
0P2OWil20>o_k`0601lO7`3?cll0kno_0>o_k`000000Shn?703_knl2000000030>o_k`3oool0oooo
07d0oooo000:0?ooo`030000003oool0oooo05/0oooo00<0kno_0000000000006`3_knl00`1OGel0
Cdm?0>o_k`030>o_k`0800l?3`3?cll0kno_09nOW`2o_kl0kno_00l?3`3?cll30>o_k`0903lo?`2?
Shl0kno_0=oOg`000000gmoO0>o_k`0O7al0WinO0080kno_00D0?clo09nOW`3_knl0Ogmo06m_K`02
0>o_k`0D01lO7`2o_kl0[jn_0000003Ogml0Shn?04m?C`0O7al0clo?0=oOg`0?3`l0WinO07moO`3O
gml0?clo0;no_`2OWil0kno_03lo?`3Ogml20>o_k`0503lo?`2OWil0kno_07moO`1_Kfl00P3_knl0
0`0O7al0_kno0:n_[`0J0>o_k`030000003_knl0kno_0800oooo000:0?ooo`030000003oool0oooo
05d0oooo00<0kno_0000000000006@3_knl00`2?Shl0;bl_0>o_k`030>o_k`0800l?3`3Ogml0kno_
0>o_k`3Ogml0kno_05mOG`1_Kfl30>o_k`0907moO`0?3`l0gmoO0>o_k`0o?cl0Kfm_0>o_k`1?Cdl0
_kno0080kno_01L0Ogmo0;no_`3_knl0clo?0000003Ogml0kno_05mOG`2_[jl0kno_04m?C`3Ogml0
kno_06m_K`000000_kno0>o_k`1OGel0Ogmo0>o_k`3Ogml0Shn?05mOG`020>o_k`0=0000003Ogml0
kno_0>o_k`2_[jl0;bl_0>o_k`3?cll000000=oOg`3_knl0GemO0:n_[`0I0>o_k`80000000<0kno_
0?ooo`3oool0P03oool000X0oooo00<000000?ooo`3oool0G`3oool00`3_knl000000000000G0>o_
k`030:n_[`000000kno_00<0kno_00T0Cdm?06m_K`2OWil0Shn?0=oOg`3_knl0WinO01lO7`3Ogml0
0P3_knl02@2o_kl0;bl_04m?C`3_knl0Shn?03lo?`3?cll0Shn?07moO`020>o_k`0<0;no_`2_[jl0
kno_0>o_k`0O7al0GemO0>o_k`2_[jl0Kfm_0>o_k`3?cll0Ogmo0P3_knl01@0?3`l0Shn?0>o_k`2O
Wil0?clo0080kno_00H0clo?0000003_knl0kno_02l_;`2_[jl20>o_k`090=oOg`000000kno_0>o_
k`0O7al0GemO0>o_k`2_[jl0Kfm_01L0kno_0P0000000`3_knl0oooo0?ooo`220?ooo`002P3oool0
0`000000oooo0?ooo`1Q0?ooo`030>o_k`000000kno_01H0kno_00<000000;no_`3_knl00P3_knl0
1@3Ogml0?clo0=oOg`2_[jl0?clo0080clo?00<0;bl_07moO`2_[jl00P2o_kl0200O7al0_kno05mO
G`3?cll0?clo09nOW`3?cll0?clo0P3_knl02@2o_kl0Kfm_0>o_k`1_Kfl0GemO08n?S`1_Kfl0gmoO
02l_;`020>o_k`0309nOW`2o_kl0kno_0080GemO0P3_knl02@000000gmoO0>o_k`2o_kl07alO09nO
W`3_knl0WinO04m?C`020>o_k`090<o?c`0o?cl0kno_06m_K`1OGel0Shn?06m_K`3Ogml0;bl_01H0
kno_00<000000>o_k`3oool0Q@3oool000X0oooo00<000000?ooo`3oool0HP3oool00`3_knl00000
0000000E0>o_k`0300l?3`2OWil0kno_00<0kno_01<0gmoO07moO`1OGel0?clo0>o_k`2?Shl00000
0<o?c`0?3`l0clo?08n?S`000000kno_0<o?c`0o?cl03`l?0>o_k`1_Kfl03`l?0080kno_00T0_kno
06m_K`3_knl0_kno02l_;`1_Kfl0gmoO04m?C`0?3`l00`3_knl0302o_kl0Shn?02l_;`0o?cl0kno_
07moO`0?3`l0Cdm?07moO`3Ogml0;bl_05mOG`80kno_0P2OWil02P2_[jl0Shn?0;no_`3_knl0_kno
02l_;`1_Kfl0gmoO04m?C`0?3`lD0>o_k`80000000<0kno_0?ooo`3oool0Q@3oool000X0oooo00<0
00000?ooo`3oool0I03oool00`3_knl000000000000?0>o_k`80gmoO0P3_knl00`0o?cl0Kfm_0>o_
k`0Z0>o_k`0308n?S`1?Cdl0kno_02<0kno_0P0000000`3_knl0oooo0?ooo`270?ooo`002P3oool0
0`000000oooo0?ooo`1V0?ooo`030>o_k`000000000000d0kno_00H0gmoO09nOW`3_knl0kno_06m_
K`0_;bl20>o_k`030:n_[`3_knl0kno_02H0kno_00<0gmoO03lo?`3_knl08@3_knl2000000030>o_
k`3oool0oooo08T0oooo000:0?ooo`030000003oool0oooo06P0oooo00<0kno_0000003_knl0303_
knl01@0o?cl0Kfm_06m_K`0o?cl03`l?0080Kfm_00<07alO0=oOg`3_knl05@3_knl00`0o?cl0kno_
0>o_k`0C0>o_k`0303lo?`3_knl0kno_01/0kno_00<000000>o_k`3oool0S03oool000X0oooo00<0
00000?ooo`3oool0JP3oool2000005`0kno_0P00002?0?ooo`002P3oool00`000000oooo0?ooo`1[
0?ooo`030>o_k`000000000005P0kno_0P0000000`3_knl0oooo0?ooo`2>0?ooo`002P3oool00`00
0000oooo0?ooo`1]0?ooo`030>o_k`000000000005@0kno_0P0000000`3_knl0oooo0?ooo`2@0?oo
o`002P3oool00`000000oooo0?ooo`1_0?ooo`030>o_k`000000kno_0540kno_00<000000>o_k`3o
ool0T`3oool000X0oooo00<000000?ooo`3oool0L@3oool2000004h0kno_0P00002F0?ooo`002P3o
ool00`000000oooo0?ooo`1c0?ooo`800000BP3_knl2000000030>o_k`3oool0oooo09D0oooo000:
0?ooo`030000003oool0oooo07@0oooo00<0kno_000000000000A`3_knl00`000000kno_0?ooo`2H
0?ooo`002P3oool00`000000oooo0?ooo`1f0?ooo`030>o_k`000000000004<0kno_0P00002K0?oo
o`002P3oool00`000000oooo0?ooo`1h0?ooo`030>o_k`000000kno_03l0kno_0P00002M0?ooo`00
2P3oool00`000000oooo0?ooo`1j0?ooo`800000?03_knl2000000030>o_k`3oool0oooo09`0oooo
000:0?ooo`030000003oool0oooo07`0oooo0P00000i0>o_k`030000003_knl0oooo09l0oooo000:
0?ooo`030000003oool0oooo07d0oooo00<0kno_000000000000=@3_knl200000:80oooo000:0?oo
o`030000003oool0oooo07l0oooo00<0kno_0000003_knl0<@3_knl200000:@0oooo000:0?ooo`03
0000003oool0oooo0840oooo0P00000^0>o_k`80000000<0kno_0?ooo`3oool0X`3oool000X0oooo
00<000000?ooo`3oool0P`3oool2000002/0kno_00<000000>o_k`3oool0YP3oool000X0oooo00<0
00000?ooo`3oool0Q@3oool2000002L0kno_0P00002Y0?ooo`002P3oool00`000000oooo0?ooo`26
0?ooo`030>o_k`000000kno_02<0kno_0P00002[0?ooo`002P3oool00`000000oooo0?ooo`280?oo
o`800000803_knl2000000030>o_k`3oool0oooo0:X0oooo000:0?ooo`030000003oool0oooo08X0
oooo0P00000M0>o_k`030000003_knl0oooo0:d0oooo000:0?ooo`030000003oool0oooo08`0oooo
0P00000I0>o_k`800000/03oool000X0oooo00<000000?ooo`3oool0SP3oool2000001D0kno_0P00
002b0?ooo`002P3oool00`000000oooo0?ooo`2?0?ooo`030>o_k`000000kno_0180kno_00<00000
0?ooo`3oool0/P3oool000X0oooo00<000000?ooo`3oool0T@3oool2000000l0kno_0P00002e0?oo
o`002P3oool00`000000oooo0?ooo`2C0?ooo`8000002`3_knl200000;L0oooo000:0?ooo`030000
003oool0oooo09D0oooo0P0000070>o_k`800000^@3oool000X0oooo00<000000?ooo`3oool0U`3o
ool00`000000kno_0>o_k`030>o_k`030000003oool0oooo0;T0oooo000:0?ooo`030000003oool0
oooo09P0oooo0P0000000`3_knl000000000002l0?ooo`002P3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo0;`0oooo000:0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo
00<000000?ooo`3oool0o`3ooomJ0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:
0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<000000?ooo`3oool0o`3ooomJ0?oo
o`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:0?ooo`030000003oool0oooo09X0oooo
00<000000?ooo`3oool0_03oool000X0oooo00<000000?ooo`3oool0V@3oool200000;h0oooo000:
0?ooo`030000003oool0oooo09T0oooo0P00002n0?ooo`002P3oool00`000000oooo0?ooo`2I0?oo
o`800000_P3oool000X0oooo00<000000?ooo`3oool0V@3oool300000;d0oooo000:0?ooo`030000
003oool0oooo09P0oooo1000002m0?ooo`002P3oool00`000000oooo0?ooo`2H0?ooo`@00000_@3o
ool000X0oooo00<000000?ooo`3oool0V03oool400000;d0oooo000:0?ooo`030000003oool0oooo
09P0oooo1@00002l0?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`H00000_03oool000X0oooo
00<000000?ooo`3oool0U`3oool600000;`0oooo000:0?ooo`030000003oool0oooo09L0oooo1P00
002l0?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`L00000^`3oool000X0oooo00<000000?oo
o`3oool0UP3oool800000;/0oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0_03oool000X0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`002P3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0_03oool000X0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;`0
oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0_03oool000X0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`2l0?ooo`002P3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0;`0oooo000:0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0_03oool000X0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`002P3oool00`000000oooo
0?ooo`3o0?oooeX0oooo000:0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<00000
0?ooo`3oool0o`3ooomJ0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooeX0oooo000:0?ooo`03
0000003oool0oooo02h0oooof@00001B0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool0D03oool000X0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0500oooo000:0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`002P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0D03oool000X0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0500
oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool0D03oool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`2ZZZX0k^k^0?ooo`090?ooo`03
0:ZZZP3^k^h0oooo00@0oooo00H0c<c<0=gMg@3oool0oooo0<c<c03MgMdE0?ooo`030000003oool0
oooo00/0oooo00<0ZZZZ0>k^kP3oool02@3oool00`2ZZZX0k^k^0?ooo`040?ooo`060<c<c03MgMd0
oooo0?ooo`3<c<`0gMgM2@3oool00`000000oooo0?ooo`080?ooo`030:ZZZP3^k^h0oooo00T0oooo
00<0ZZZZ0>k^kP3oool02@3oool00`2ZZZX0k^k^0?ooo`040?ooo`060<c<c03MgMd0oooo0?ooo`3<
c<`0gMgM0`3oool01P3<c<`0gMgM0?ooo`3oool0c<c<0=gMgAX0oooo00<000000?ooo`3oool0D03o
ool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo100000020?ooo`0306IVIP3oool0oooo00@0oooo00<0^k^k0000003<c<`00P3oool0
0`1VIVH0oooo0?ooo`050?ooo`0506IVIP3oool0oooo0?ooo`1VIVH05@3oool00`000000oooo0?oo
o`050?ooo`@000000P3oool00`1VIVH0oooo0?ooo`040?ooo`030;^k^`000000c<c<0080oooo00<0
IVIV0?ooo`3oool01@3oool01P1VIVH0oooo0?ooo`3oool0ZZZZ0;^k^`P0oooo00<000000?ooo`3o
ool00P3oool400000080oooo00<0IVIV0?ooo`3oool02@3oool00`1VIVH0oooo0?ooo`040?ooo`03
0;^k^`000000c<c<0080oooo00<0IVIV0?ooo`3oool01@3oool01@1VIVH0oooo0?ooo`3oool0IVIV
00@0oooo00D0IVIV0?ooo`3oool0oooo06IVIP0J0?ooo`030000003oool0oooo0500oooo000:0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo0P2ZZZX70?ooo`030000003oool0oooo0080ZZZZ1`3oool01P1E
EED0k^k^0?ooo`3oool0EEEE0>k^kQ@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`80ZZZZ1`3oool00`000000oooo0?ooo`020:ZZZPL0oooo00H0EEEE0>k^kP3oool0oooo
0>k^kP0c<c<80?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20:ZZZPX0
oooo0P2ZZZX70?ooo`030000003oool0oooo0080ZZZZ1`3oool01P1EEED0k^k^0?ooo`3oool0EEEE
0>k^kP<0oooo00H0EEEE0>k^kP3oool0oooo05EEE@3^k^hI0?ooo`030000003oool0oooo0500oooo
000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05P3oool3000000030?ooo`00
000000000080oooo00<000000?ooo`3oool00P3oool02P14A4@0k^k^0?ooo`3oool0A4A406IVIP1E
EED0VIVI0?ooo`0000020?ooo`0704A4A03^k^h0oooo0?ooo`0c<c<04A4A0:ZZZP020?ooo`060:ZZ
ZP2IVIT0oooo0?ooo`2ZZZX0VIVI1P3oool00`0A4A40EEEE0?ooo`0;0?ooo`<0000000<0oooo0000
000000000P3oool00`000000oooo0?ooo`020?ooo`0:04A4A03^k^h0oooo0?ooo`14A4@0IVIV05EE
E@2IVIT0oooo00000080oooo00<0A4A40>k^kP3oool00P3oool02P0c<c<04A4A0:ZZZP3oool0ZZZZ
09VIV@3oool0ZZZZ00000014A4@60?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`0404A4
A03^k^h0oooo0?ooo`8000000P3oool3000000030?ooo`14A4@0k^k^0080oooo00H0A4A406IVIP1E
EED0VIVI0?ooo`0000020?ooo`0304A4A03^k^h0oooo0080oooo00H0<c<c014A4@2ZZZX0oooo0:ZZ
ZP2IVIT20?ooo`030:ZZZP2IVIT0oooo0080oooo00H0ZZZZ09VIV@3oool0oooo0:ZZZP2IVITI0?oo
o`030000003oool0oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool02P0c<c<0
oooo0?ooo`3oool0VIVI0?ooo`3^k^h000000?ooo`0000020?ooo`0603<c<`3oool0oooo0?ooo`00
0000k^k^0`3oool01P3^k^h0A4A40?ooo`3oool0k^k^04A4A0H0oooo00<0EEEE09VIV@3oool01@0R
8R800`1EEED0oooo0?ooo`030?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`020?ooo`0:03<c<`3oool0oooo0?ooo`2IVIT0oooo0>k^kP000000oooo00000080oooo00<0<c<c
0?ooo`3oool00P3oool02P000000k^k^0?ooo`3oool0k^k^04A4A03oool0k^k^06IVIP3^k^h50?oo
o`80000000<0oooo0000003oool00P0000000`3oool000000?ooo`030?ooo`0303<c<`3oool0oooo
00<0oooo00L000000?ooo`000000oooo0000003oool0<c<c00<0oooo00H0VIVI0?ooo`3^k^h00000
0?ooo`0000020?ooo`0303<c<`3oool0oooo0080oooo00H000000>k^kP3oool0oooo0>k^kP14A4@2
0?ooo`030>k^kP14A4@0oooo0080oooo00H0k^k^04A4A03oool0oooo0>k^kP14A4@I0?ooo`030000
003oool0oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo0`0000020?ooo`0303<c<`3oool0oooo0080oooo
00D0^k^k028R8P0R8R80ZZZZ028R8P020?ooo`0503<c<`3oool0oooo0?ooo`0000001@3oool01@0R
8R80oooo0?ooo`3oool08R8R01@0oooo00D000000?ooo`3oool0oooo000000030?ooo`<000000P3o
ool00`0c<c<0oooo0?ooo`020?ooo`050;^k^`0R8R808R8R0:ZZZP0R8R800P3oool00`0c<c<0oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<08R8R0?ooo`3oool01`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool00000008000000P3oool00`0c<c<0oooo0?ooo`030?ooo`03
0000003oool0000000<0oooo00<0<c<c0?ooo`3oool00P3oool01@2k^k/08R8R028R8P2ZZZX08R8R
0080oooo00<0<c<c0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`05028R8P3oool0oooo
0?ooo`0R8R80103oool01@0R8R80oooo0?ooo`3oool08R8R01T0oooo00<000000?ooo`3oool0D03o
ool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`0703<c<`3oool0oooo0?ooo`1EEED0
8R8R07MgM`050?ooo`0503<c<`3oool0oooo0?ooo`0000001@3oool01@0R8R80oooo0?ooo`3oool0
8R8R01@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00L0
<c<c0?ooo`3oool0oooo05EEE@0R8R80MgMg00D0oooo00<0<c<c0?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`03028R8P3oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000040?ooo`0303<c<`3oool0oooo00<0oooo00<000000?ooo`0000000`3oool01`0c
<c<0oooo0?ooo`3oool0EEEE028R8P1gMgL01@3oool00`0c<c<0oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D08R8R0?ooo`3oool0oooo028R8P040?ooo`05028R8P3oool0oooo0?ooo`0R
8R806@3oool00`000000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00L0A4A40?ooo`3oool0oooo028R8P3oool0ZZZZ0080oooo00@000000?ooo`3oool0A4A40`3o
ool00`000000oooo0?ooo`030?ooo`05028R8P3oool0oooo0?ooo`0R8R801P3oool00`0A4A40EEEE
0?ooo`05028R8P0305EEE@3oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00L0A4A40?ooo`3oool0oooo028R8P3oool0ZZZZ0080oooo00@00000
0?ooo`3oool0A4A4103oool00`000000oooo0?ooo`020?ooo`03028R8P3oool0oooo00L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000040?ooo`0904A4A03oool0oooo0?ooo`00
0000oooo0000003oool0000000<0oooo00L0A4A40?ooo`3oool0oooo028R8P3oool0ZZZZ0080oooo
00@000000?ooo`3oool0A4A4103oool00`000000oooo0?ooo`020?ooo`05028R8P3oool0oooo0?oo
o`0R8R80103oool01@0R8R80oooo0?ooo`3oool08R8R01T0oooo00<000000?ooo`3oool0D03oool0
00X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`0000000`3oool4000000030?ooo`1EEED0oooo0080oooo00<0VIVI06IVIP1EEED01@3oool0
1@1EEED0oooo0?ooo`1gMgL0000000808R8R0P3oool01P3<c<`0IVIV0?ooo`3oool0c<c<06IVIPH0
oooo00<0EEEE09VIV@3oool02`3oool01@000000oooo0?ooo`3oool0000000<0oooo100000000`3o
ool0EEEE0?ooo`020?ooo`0309VIV@1VIVH0EEEE00D0oooo00H0EEEE0?ooo`3oool0oooo07MgM`00
0002028R8P030?ooo`3<c<`0IVIV00X0oooo0P0000000`3oool00000000000020?ooo`@0000000<0
oooo05EEE@3oool00`3oool6000000030?ooo`1EEED0oooo0080oooo00<0VIVI06IVIP1EEED01@3o
ool01P1EEED0oooo0?ooo`3oool0MgMg000000808R8R00<0oooo0<c<c01VIVH00P3oool00`3<c<`0
IVIV0?ooo`020?ooo`060<c<c01VIVH0oooo0?ooo`3<c<`0IVIV6@3oool00`000000oooo0?ooo`1@
0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02<0oooo0P2ZZZX:0?oo
o`80ZZZZ0P3oool00`0c<c<0oooo0?ooo`020?ooo`0609VIV@3<c<`0oooo0?ooo`2IVIT0c<c<8@3o
ool20:ZZZPX0oooo0P2ZZZX30?ooo`0603<c<`3oool0oooo0?ooo`2IVIT0c<c<5P3oool20:ZZZPX0
oooo0P2ZZZX:0?ooo`80ZZZZ0`3oool01P0c<c<0oooo0?ooo`3oool0VIVI0<c<c080oooo00<0VIVI
0<c<c03oool00P3oool01P2IVIT0c<c<0?ooo`3oool0VIVI0<c<c1T0oooo00<000000?ooo`3oool0
D03oool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0T0?ooo`0306IVIP3o
ool0oooo00T0oooo00@0IVIV0?ooo`3oool0k^k^103oool01@1EEED0oooo0?ooo`3oool0EEEE02<0
oooo00<0IVIV0?ooo`3oool02@3oool01@1VIVH0oooo0?ooo`3oool0k^k^00<0oooo00<0EEEE0?oo
o`3oool05P3oool00`1VIVH0oooo0?ooo`090?ooo`0306IVIP3oool0oooo00T0oooo00D0IVIV0?oo
o`3oool0oooo0>k^kP030?ooo`0505EEE@3oool0oooo0?ooo`1EEED0103oool01@1EEED0oooo0?oo
o`3oool0EEEE01X0oooo00<000000?ooo`3oool0D03oool000X0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0T0?ooo`030:ZZZP3^k^h0oooo00T0oooo00<0ZZZZ0>k^kP3oool0103o
ool01P3MgMd0ZZZZ0?ooo`3oool0gMgM0:ZZZR<0oooo00<0ZZZZ0>k^kP3oool02@3oool00`2ZZZX0
k^k^0?ooo`040?ooo`030=gMg@2ZZZX0oooo01L0oooo00<0ZZZZ0>k^kP3oool02@3oool00`2ZZZX0
k^k^0?ooo`090?ooo`030:ZZZP3^k^h0oooo00@0oooo00H0gMgM0:ZZZP3oool0oooo0=gMg@2ZZZX3
0?ooo`060=gMg@2ZZZX0oooo0?ooo`3MgMd0ZZZZ6P3oool00`000000oooo0?ooo`1@0?ooo`002P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0D03o
ool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool0D03oool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`3E0?ooo`030000003oool0oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0D03oool000X0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0500oooo000:0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`00
2P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
D03oool000X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0500oooo000:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?ooo`0E0?ooo`<000005P3oool00`00
0000oooo0?ooo`0E0?ooo`@00000>P3oool4000000`0oooo00<0ZZZZ0000002ZZZX0<P3oool40000
00X0oooo00<0k^k^03<c<`14A4@00P3^k^h01P0c<c<0oooo0;^k^`000000IVIV0>k^kR@0oooo00<0
00000?ooo`3oool0D03oool000X0oooo00<000000?ooo`3oool05@3oool6000001<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0ZZZZ
0>k^kP3oool01`3oool00`2ZZZX0k^k^0?ooo`040?ooo`060<c<c03MgMd0oooo0?ooo`3<c<`0gMgM
5@3oool01@2ZZZX0k^k^0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool00`2ZZZX0
k^k^0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0ZZZZ0>k^kP3oool00`3oool00`3<c<`0
gMgM0?ooo`020?ooo`030<c<c03MgMd0oooo0100oooo00<0c<c<0=gMg@3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0ZZZZ0>k^kP3oool01P3oool0203<c<`0
ZZZZ0?ooo`14A4@000000<c<c03oool000000`3oool00`2ZZZX0k^k^0?ooo`040?ooo`060<c<c03M
gMd0oooo0?ooo`3<c<`0gMgM0`3oool00`3<c<`0gMgM0?ooo`0@0?ooo`030000003oool0oooo0500
oooo000:0?ooo`030000003oool0oooo01D0oooo2@00000@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`0306IVIP3oool0oooo00L0oooo
00<0IVIV0?ooo`3oool01@3oool01@1VIVH0oooo0?ooo`3oool0IVIV01D0oooo00D0IVIV0?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00@0oooo00<0IVIV0?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`0306IVIP3oool0oooo00@0oooo00<0IVIV0?ooo`3oool00P3oool00`2Z
ZZX0^k^k0?ooo`0@0?ooo`030:ZZZP2k^k/0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`0306IVIP3oool0oooo00L0oooo00L0ZZZZ0<c<c0000000oooo04A4A03o
ool0000000<0oooo00<0IVIV0?ooo`3oool01@3oool01@1VIVH0oooo0?ooo`3oool0IVIV00@0oooo
00<0IVIV0?ooo`3oool03`3oool00`000000oooo0?ooo`1@0?ooo`002P3oool00`000000oooo0?oo
o`0E0?ooo``000003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool20:ZZZPP0oooo0P2ZZZX70?ooo`0605EEE@3^k^h0oooo0?ooo`1EEED0
k^k^4`3oool20:ZZZP<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`80
ZZZZ2@3oool00`000000oooo0?ooo`020?ooo`80ZZZZ1P3oool00`1EEED0k^k^0?ooo`020?ooo`03
0>k^kP0c<c<0oooo0100oooo00<0k^k^03<c<`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo0P2ZZZX90?ooo`070:ZZZP0R8R80MgMg0?ooo`1gMgL0c<c<00000002
0?ooo`80ZZZZ1`3oool01P1EEED0k^k^0?ooo`3oool0EEEE0>k^kP<0oooo00<0EEEE0>k^kP3oool0
3`3oool00`000000oooo0?ooo`1@0?ooo`002P3ooolW000000X0oooo00<000000?ooo`3oool03@3o
ool3000000030?ooo`00000000000080oooo0`0000030?ooo`0304A4A03^k^h0oooo00<0oooo1000
00000`14A4@0k^k^0?ooo`020?ooo`0603<c<`0A4A40ZZZZ0?ooo`2ZZZX0VIVI0P3oool00`2ZZZX0
VIVI0?ooo`040?ooo`03014A4@1EEED0oooo00/0oooo00<0A4A40>k^kP3oool00P3oool300000004
0?ooo`00000000000?ooo`<000000`3oool02014A4@0k^k^0?ooo`3oool0A4A406IVIP1EEED0VIVI
0`3oool00`000000oooo0?ooo`020?ooo`0:04A4A03^k^h0oooo0?ooo`0c<c<04A4A0:ZZZP3oool0
ZZZZ09VIV@80oooo00<0ZZZZ00000014A4@0103oool01P0A4A40EEEE0?ooo`3oool04A4A05EEE@80
oooo00L04A4A05EEE@3oool0oooo0:ZZZP000000A4A400D0oooo0`0000000`3oool0000000000002
0?ooo`<000000P3oool02014A4@0k^k^0?ooo`3oool0A4A406IVIP1EEED0VIVI0`3oool00`1gMgL0
00000?ooo`020?ooo`0607MgM`000000oooo0?ooo`14A4@0k^k^0P3oool00`0c<c<04A4A0:ZZZP02
0?ooo`060:ZZZP2IVIT0oooo0?ooo`2ZZZX0VIVI0`3oool00`2ZZZX0VIVI0?ooo`0?0?ooo`030000
003oool0oooo0500oooo000R0?ooo`h000002`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo008000000`3oool00`000000oooo0?ooo`030?ooo`0303<c<`3oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003^k^h0oooo0?ooo`3^k^h0
A4A40P3oool00`3^k^h0A4A40?ooo`040?ooo`0405EEE@2IVIT0oooo0?ooo`D08R8R00<0EEEE0?oo
o`3oool00P3oool00`0c<c<0oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`030?ooo`0903<c<`3oool0oooo0?ooo`2IVIT0oooo0>k^kP000000oooo0080^k^k
00<000000?ooo`3oool00P3oool01P0c<c<0oooo0?ooo`3oool000000>k^kP80oooo00L0k^k^04A4
A03oool0oooo0>k^kP1VIVH0k^k^00@0oooo00H0EEEE09VIV@3oool0oooo05EEE@2IVIT20?ooo`07
05EEE@2IVIT0oooo0?ooo`3^k^h0IVIV0>k^kP050?ooo`030000003oool0oooo008000000`3oool0
0`000000oooo0?ooo`020?ooo`0803<c<`3oool0oooo0?ooo`2IVIT0oooo0>k^kP0000030?ooo`03
00000014A4@0oooo0080oooo00D0MgMg0000003oool0oooo03<c<`030?ooo`030000003^k^h0oooo
0080oooo00H0k^k^04A4A03oool0oooo0>k^kP14A4@30?ooo`030>k^kP14A4@0oooo00l0oooo00<0
00000?ooo`3oool0D03oool00280oooo2P00000?0?ooo`030000003oool0oooo00d0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<0<c<c0?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@0R8R80oooo0?ooo`3oool08R8R01<0oooo00<0<c<c0?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`0c<c<0oooo0?ooo`020?ooo`03
0;^k^`0R8R808R8R0080oooo00<0k^k^0000003oool00`3oool01@0c<c<0oooo0?ooo`3oool00000
00@0oooo00<08R8R0?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`0c<c<0oooo0?ooo`020?ooo`030;^k^`0R8R808R8R0080oooo00<0R8R8
0000003^k^h00`3oool01@3^k^h000000:ZZZP3oool0<c<c00<0oooo00<000000?ooo`3oool00`3o
ool01@0R8R80oooo0?ooo`3oool08R8R00@0oooo00<08R8R0?ooo`3oool03P3oool00`000000oooo
0?ooo`1@0?ooo`008P3oool6000001<0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?oo
o`3oool0000000<0oooo100000020?ooo`0503<c<`3oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D08R8R0?ooo`3oool0oooo028R8P0C0?oo
o`0303<c<`3oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`@000000P3oool0
1`0c<c<0oooo0?ooo`3oool0EEEE028R8P1gMgL02@3oool01@0c<c<0oooo0?ooo`3oool0000000@0
oooo00<08R8R0?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0000000<0oooo100000000`3o
ool0<c<c0?ooo`020?ooo`0305EEE@0R8R80MgMg00d0oooo00D0<c<c0?ooo`3oool0oooo00000005
0?ooo`05028R8P3oool0oooo0?ooo`0R8R80103oool00`0R8R80oooo0?ooo`0>0?ooo`030000003o
ool0oooo0500oooo000R0?ooo`8000005`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`0000002@3oool01@14A4@0oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`05028R8P3oool0oooo0?ooo`0R8R801@3oool0100A4A40
EEEE0?ooo`3oool5028R8P0305EEE@3oool0oooo0080oooo00<0A4A40?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000P0oooo00L0A4A40?ooo`3oool0oooo028R8P3oool0ZZZZ00T0oooo
00D0A4A40?ooo`3oool0oooo000000040?ooo`03028R8P3oool0oooo01/0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`0704A4A03oool0oooo0?ooo`0R8R80oooo0:ZZZP0=0?ooo`0504A4A03o
ool0oooo0?ooo`0000001@3oool01@0R8R80oooo0?ooo`3oool08R8R00@0oooo00<08R8R0?ooo`3o
ool03P3oool00`000000oooo0?ooo`1@0?ooo`00>`3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`0000002@3oool01@1EEED0oooo0?ooo`3oool0000000<0oooo0`0000030?oo
o`0707MgM`0000008R8R028R8P3oool0c<c<06IVIP020?ooo`030<c<c01VIVH0oooo00@0oooo00<0
EEEE09VIV@3oool02`3oool00`1EEED0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
203oool01`1EEED0oooo0?ooo`3oool0VIVI06IVIP1EEED02@3oool01@1EEED0oooo0?ooo`1gMgL0
000000808R8R00<0oooo0<c<c01VIVH07@3oool01@000000oooo0?ooo`3oool0000000P0oooo00L0
EEEE0?ooo`3oool0oooo09VIV@1VIVH0EEEE00d0oooo00D0EEEE0?ooo`3oool0MgMg00000002028R
8P80oooo00H0c<c<06IVIP3oool0oooo0<c<c01VIVH30?ooo`030<c<c01VIVH0oooo00l0oooo00<0
00000?ooo`3oool0D03oool003/0oooo00<000000?ooo`3oool06`3oool20:ZZZP80oooo00<00000
0?ooo`3oool00`3oool20:ZZZP<0oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`20?ooo`0309VI
V@3<c<`0oooo0180oooo0P2ZZZX@0?ooo`80ZZZZ3P3oool20:ZZZP80oooo00H0<c<c0?ooo`3oool0
oooo09VIV@3<c<`Z0?ooo`80ZZZZ4P3oool20:ZZZP80oooo00<0<c<c0?ooo`3oool00P3oool01P2I
VIT0c<c<0?ooo`3oool0VIVI0<c<c0<0oooo00<0VIVI0<c<c03oool03`3oool00`000000oooo0?oo
o`1@0?ooo`00>`3oool00`000000oooo0?ooo`0L0?ooo`0406IVIP3oool0oooo000000H0oooo00D0
IVIV0?ooo`3oool0oooo0>k^kP030?ooo`0505EEE@3oool0oooo0?ooo`1EEED05@3oool00`1VIVH0
oooo0?ooo`0?0?ooo`0306IVIP3oool0oooo00d0oooo00@0IVIV0?ooo`3oool0k^k^0`3oool00`1E
EED0oooo0?ooo`0Z0?ooo`0306IVIP3oool0oooo0140oooo00@0IVIV0?ooo`3oool0k^k^103oool0
1@1EEED0oooo0?ooo`3oool0EEEE00@0oooo00<0EEEE0?ooo`3oool03`3oool00`000000oooo0?oo
o`1@0?ooo`00>`3oool00`000000oooo0?ooo`0L0?ooo`050:ZZZP3^k^h0oooo0?ooo`0000001@3o
ool00`2ZZZX0k^k^0?ooo`040?ooo`060=gMg@2ZZZX0oooo0?ooo`3MgMd0ZZZZ5@3oool00`2ZZZX0
k^k^0?ooo`0?0?ooo`030:ZZZP3^k^h0oooo00d0oooo00<0ZZZZ0>k^kP3oool00`3oool00`3MgMd0
ZZZZ0?ooo`0[0?ooo`030:ZZZP3^k^h0oooo0140oooo00<0ZZZZ0>k^kP3oool0103oool01P3MgMd0
ZZZZ0?ooo`3oool0gMgM0:ZZZP<0oooo00<0gMgM0:ZZZP3oool0403oool00`000000oooo0?ooo`1@
0?ooo`00>`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`1@0?ooo`00>`3oool00`000000oooo0?ooo`0Q0?ooo`@0
0000/03oool00`000000oooo0?ooo`1@0?ooo`00>`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0500oooo000k0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0D03o
ool003/0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`00>`3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0500oooo000k0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool0D03oool003/0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`1@0?ooo`00>`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0500oooo000k
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0D03oool003/0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`1@0?ooo`00>`3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0500oooo000k0?ooo`030000003_knl0kno_0=D0kno_00<000000?ooo`3oool0
D03oool003/0oooo00<000000>o_k`3_knl0e03_knl00`3oool000000?ooo`1A0?ooo`00>`3oool0
0`000000kno_0>o_k`0`0>o_k`80GemO00<0gmoO0>o_k`3_knl0W`3_knl00`3oool000000?ooo`1A
0?ooo`00>`3oool00`000000kno_0>o_k`0`0>o_k`0308n?S`0o?cl0kno_0:40kno_00<0oooo0000
003oool0D@3oool003/0oooo00<000000>o_k`3_knl0<03_knl00`3Ogml03`l?0>o_k`2Q0>o_k`03
0?ooo`000000oooo0540oooo000k0?ooo`030000003_knl0kno_01D0kno_00L0[jn_0000001?Cdl0
clo?0>o_k`0O7al0clo?0080kno_00l0000008n?S`3_knl0kno_0000001?Cdl0gmoO0>o_k`2?Shl0
3`l?05mOG`2o_kl0kno_0=oOg`0O7al0103_knl0100O7al0Kfm_0:n_[`1oOgl20>o_k`030=oOg`0O
7al0kno_00<0kno_00@0Shn?00l?3`1OGel0_kno0P3_knl02@000000Cdm?0=oOg`3_knl07alO02l_
;`3Ogml000000;no_`020>o_k`060000001?Cdl0gmoO0>o_k`0?3`l0Kfm_0P3_knl00`2o_kl0Shn?
0:n_[`0209nOW`80kno_00H07alO0<o?c`3_knl0kno_0000002?Shl40>o_k`0901lO7`000000Kfm_
0>o_k`000000_kno0>o_k`0O7al0clo?0080kno_00T0000008n?S`3_knl0GemO00l?3`1_Kfl0clo?
0000002?Shl01@3_knl00`2_[jl0?clo01lO7`0306m_K`80Cdm?00@0kno_02l_;`0_;bl0Ogmo0`3_
knl02@0O7al0000006m_K`3_knl000000;no_`3_knl0000008n?S`020>o_k`0<00l?3`1OGel0gmoO
0>o_k`000000Shn?0>o_k`0O7al0;bl_0=oOg`000000_kno0P3_knl01P000000Cdm?0=oOg`3_knl0
3`l?06m_K`80kno_00<0_kno08n?S`2_[jl00P2OWil20>o_k`0601lO7`3?cll0kno_0>o_k`000000
Shn?5`3_knl00`3oool000000?ooo`1A0?ooo`00>`3oool00`000000kno_0>o_k`0F0>o_k`0603lo
?`1_Kfl0kno_0>o_k`1oOgl0Kfm_0P3_knl0400O7al0_kno0:n_[`3_knl03`l?09nOW`1oOgl0gmoO
00l?3`3?cll0kno_09nOW`2o_kl0kno_00l?3`3?cll30>o_k`0505mOG`2OWil0kno_0;no_`1?Cdl0
0P3_knl00`0?3`l0clo?0>o_k`020>o_k`0K00l?3`3?cll0kno_09nOW`2o_kl0kno_00l?3`2OWil0
Ogmo0=oOg`000000gmoO0;no_`0?3`l0_kno0=oOg`3_knl03`l?09nOW`1oOgl0gmoO03lo?`2o_kl0
WinO0>o_k`0o?cl0gmoO0080kno_00D0?clo09nOW`3_knl0Ogmo06m_K`020>o_k`0301lO7`2o_kl0
[jn_00<0kno_00T000000=oOg`3?cll0Shn?01lO7`2o_kl0gmoO07moO`1_Kfl00P3_knl0200O7al0
_kno0:n_[`000000clo?0>o_k`1oOgl000000P2_[jl50>o_k`0309nOW`1OGel0kno_00<0kno_0100
Shn?0>o_k`0O7al0clo?0=oOg`1_Kfl0gmoO0>o_k`000000gmoO0<o?c`2?Shl07alO0;no_`3Ogml0
;bl_0P2_[jl06@3_knl0?clo0;no_`1_Kfl0gmoO01lO7`2_[jl0_kno0000003Ogml0_kno00l?3`2o
_kl0gmoO0>o_k`0?3`l0WinO07moO`3Ogml0?clo0;no_`2OWil0kno_03lo?`3Ogml00P3_knl01@0o
?cl0WinO0>o_k`1oOgl0Kfm_0080kno_00<07alO0;no_`2_[jl05P3_knl00`3oool000000?ooo`1A
0?ooo`00>`3oool00`000000kno_0>o_k`0F0>o_k`0:06m_K`0o?cl0kno_0>o_k`3?cll000000=oO
g`3_knl0GemO0:n_[`80kno_00H0GemO07moO`3_knl0gmoO00l?3`3Ogml20>o_k`040=oOg`3_knl0
GemO06m_K`<0kno_00T0[jn_05mOG`3_knl0kno_04m?C`2?Shl0kno_05mOG`1_Kfl00`3_knl03`0?
3`l0gmoO0>o_k`3_knl0gmoO0>o_k`1OGel0Ogmo0>o_k`3Ogml0Cdm?0=oOg`3_knl0Cdm?08n?S`02
0>o_k`0605mOG`1oOgl0kno_0=oOg`2?Shl0GemO0P3_knl03@000000gmoO0>o_k`3_knl0[jn_02l_
;`3_knl0clo?0000003Ogml0kno_05mOG`2_[jl0103_knl0401?Cdl0clo?0>o_k`3_knl0;bl_08n?
S`3_knl0clo?0000003Ogml0kno_05mOG`2_[jl0kno_02l_;`3?cll20>o_k`0300l?3`2_[jl0kno_
00D0kno_00<0_kno02l_;`3_knl00`3_knl02P3Ogml0kno_0;no_`1OGel0kno_0=oOg`1_Kfl0kno_
04m?C`3?cll20>o_k`0502l_;`2?Shl0kno_05mOG`2OWil00P3_knl0301oOgl0GemO0>o_k`1_Kfl0
GemO08n?S`3_knl0Cdm?0=oOg`3_knl0Cdm?08n?S`80kno_00H0GemO07moO`3_knl0gmoO08n?S`1O
Gel20>o_k`0=0000003Ogml0kno_0>o_k`2_[jl0;bl_0>o_k`3?cll000000=oOg`3_knl0GemO0:n_
[`0G0>o_k`030?ooo`000000oooo0540oooo000k0?ooo`030000003_knl0kno_01H0kno_00<0[jn_
00l?3`3_knl00P3_knl01@0O7al0GemO0>o_k`2_[jl0Kfm_0080kno_00d0WinO03lo?`3_knl0kno_
04m?C`1_Kfl0WinO08n?S`3Ogml0kno_09nOW`0O7al0gmoO00<0kno_00T0;bl_0>o_k`3_knl0_kno
02l_;`3_knl0WinO01lO7`3Ogml00P3_knl0201?Cdl0Kfm_09nOW`2?Shl0gmoO0>o_k`2OWil0?clo
0P3_knl01@3?cll0Ogmo0>o_k`3_knl0;bl_0080kno_00H0WinO03lo?`3_knl0kno_0<o?c`000002
0>o_k`0602l_;`2_[jl0kno_0>o_k`3Ogml000000P3_knl01@0O7al0GemO0>o_k`2_[jl0Kfm_00@0
kno_00H0gmoO05mOG`3_knl0kno_0=oOg`0O7al20>o_k`0801lO7`1OGel0kno_0:n_[`1_Kfl0kno_
08n?S`1_Kfl20>o_k`0307moO`1_Kfl0kno_00H0kno_00D000000>o_k`3_knl0_kno0=oOg`030>o_
k`0306m_K`2o_kl0kno_0080WinO00T0gmoO05mOG`3_knl0kno_0=oOg`0O7al0kno_09nOW`1OGel0
0P3_knl02@3?cll000000>o_k`3Ogml0;bl_03lo?`3_knl0clo?07moO`020>o_k`0502l_;`3_knl0
kno_09nOW`0o?cl00P3_knl01P3?cll000000>o_k`3_knl0;bl_0:n_[`80kno_00T0gmoO0000003_
knl0kno_01lO7`1OGel0kno_0:n_[`1_Kfl05`3_knl00`3oool000000?ooo`1A0?ooo`00>`3oool0
0`000000kno_0>o_k`0F0>o_k`0:0<o?c`000000kno_0>o_k`1_Kfl0GemO08n?S`1_Kfl0gmoO02l_
;`<0kno_00P000000=oOg`3_knl0gmoO03lo?`3Ogml0[jn_03lo?`80clo?00X0;bl_07moO`2_[jl0
kno_09nOW`0o?cl0clo?0>o_k`3Ogml000000P3?cll02@0_;bl0Ogmo0:n_[`3_knl0gmoO03lo?`3O
gml0[jn_03lo?`020>o_k`090000003Ogml0kno_0>o_k`2OWil0_kno0>o_k`1OGel0[jn_0080kno_
00T000000=oOg`3_knl0_kno01lO7`2OWil0kno_09nOW`1?Cdl00P3_knl02@3?cll0?clo0>o_k`1_
Kfl0GemO08n?S`1_Kfl0gmoO02l_;`050>o_k`0<0;no_`2_[jl0kno_0>o_k`1OGel0[jn_06m_K`1O
Gel0Shn?06m_K`3Ogml0;bl_0P3_knl01@1OGel0_kno0>o_k`2_[jl0;bl_00L0kno_00D0;bl_06m_
K`1_Kfl0?clo0:n_[`020>o_k`030<o?c`2o_kl0;bl_0080kno_00@0?clo0>o_k`2o_kl0[jn_0P3_
knl0101OGel0[jn_0=oOg`0O7al20>o_k`0=0;no_`0?3`l0Shn?0>o_k`2_[jl000000=oOg`3_knl0
WinO0;no_`3_knl0GemO0:n_[`020>o_k`090000003Ogml0kno_0;no_`0O7al0WinO0>o_k`2OWil0
Cdm?0080kno_00T0clo?03lo?`3_knl0Kfm_05mOG`2?Shl0Kfm_0=oOg`0_;bl05`3_knl00`3oool0
00000?ooo`1A0?ooo`00>`3oool00`000000kno_0>o_k`0G0>o_k`090000002_[jl0kno_0;no_`0_
;bl0Kfm_0=oOg`1?Cdl03`l?0080kno_00h0Ogmo00l?3`1?Cdl0Ogmo0>o_k`3Ogml0Ogmo05mOG`0o
?cl0kno_08n?S`000000clo?00l?3`80clo?01D0?clo05mOG`1_Kfl0?clo07moO`3_knl0Shn?0000
003?cll03`l?0<o?c`3_knl0gmoO07moO`1OGel0?clo0>o_k`1oOgl03`l?04m?C`1oOgl00P3_knl0
302o_kl0Shn?02l_;`1?Cdl0kno_07moO`0?3`l0Cdm?07moO`3Ogml0;bl_05mOG`80kno_0P2OWil0
2P2_[jl0Shn?0;no_`3_knl0_kno02l_;`1_Kfl0gmoO04m?C`0?3`l60>o_k`0;0=oOg`2OWil0Shn?
01lO7`1?Cdl0_kno02l_;`1_Kfl0gmoO04m?C`0?3`l00`3_knl0102OWil0Ogmo02l_;`0000070>o_
k`0504m?C`2_[jl0kno_0=oOg`2?Shl00`3_knl01@2OWil000000>o_k`3_knl07alO0080kno_00`0
gmoO09nOW`2?Shl07alO04m?C`3_knl07alO0=oOg`3_knl0gmoO02l_;`1?Cdl20>o_k`0@04m?C`2_
[jl0kno_0>o_k`2o_kl0Shn?02l_;`1?Cdl0kno_07moO`0?3`l0Cdm?07moO`3Ogml0;bl_05mOG`80
kno_0P2OWil02P2_[jl0Shn?0;no_`3_knl0_kno02l_;`1_Kfl0gmoO04m?C`0?3`lG0>o_k`030?oo
o`000000oooo0540oooo000k0?ooo`030000003_knl0kno_01L0kno_00<0;bl_07moO`3_knl02@3_
knl00`2?Shl0Cdm?0>o_k`0<0>o_k`030:n_[`0o?cl0kno_00l0kno_00<0Shn?04m?C`3_knl0203_
knl00`2?Shl0Cdm?0>o_k`0X0>o_k`0300l?3`2_[jl0kno_00D0kno_00D0Ogmo06m_K`3_knl0kno_
0=oOg`0@0>o_k`0304m?C`2?Shl0kno_00l0kno_00<0Shn?04m?C`3_knl0:03_knl00`3oool00000
0?ooo`1A0?ooo`00>`3oool00`000000kno_0>o_k`0G0>o_k`80GemO2P3_knl00`3Ogml0?clo0>o_
k`0=0>o_k`030:n_[`3_knl0kno_00h0kno_00<0gmoO03lo?`3_knl0203_knl00`3Ogml0?clo0>o_
k`0X0>o_k`0304m?C`1_Kfl0kno_00D0kno_00<0[jn_04m?C`3_knl00P3_knl00`2o_kl0kno_0>o_
k`0=0>o_k`0308n?S`1?Cdl0kno_00l0kno_00<0gmoO03lo?`3_knl0:03_knl00`3oool000000?oo
o`1A0?ooo`00>`3oool00`000000kno_0>o_k`0F0>o_k`040<o?c`1?Cdl03`l?0:n_[cX0kno_00<0
?clo0>o_k`3_knl08P3_knl00`3Ogml0?clo02l_;`050>o_k`030<o?c`1_Kfl03`l?00<0Kfm_00<0
7alO0>o_k`3_knl03@3_knl00`1_Kfl03`l?0>o_k`0D0>o_k`0303lo?`3_knl0kno_02<0kno_00<0
oooo0000003oool0D@3oool003/0oooo00<000000>o_k`3_knl0NP3_knl00`3?cll0Kfm_0>o_k`0J
0>o_k`030=oOg`1oOgl0clo?03X0kno_00<0oooo0000003oool0D@3oool003/0oooo00<000000>o_
k`3_knl0e03_knl00`3oool000000?ooo`1A0?ooo`00>`3oool00`000000kno_0>o_k`3D0>o_k`03
0?ooo`000000oooo0540oooo000k0?ooo`030000003_knl0kno_0=@0kno_00<0oooo0000003oool0
D@3oool003/0oooo00<000000>o_k`3_knl0e03_knl00`3oool000000?ooo`1A0?ooo`00>`3oool0
0`000000kno_0>o_k`3D0>o_k`030?ooo`000000oooo0540oooo000k0?ooomT00000DP3oool00?l0
ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0
ooooI`3oool00?l0ooooI`3oool00:L0oooo00<000000?ooo`3oool0_03oool00:H0oooo0P00002n
0?ooo`00YP3oool200000;h0oooo002V0?ooo`<00000_@3oool00:D0oooo1000002m0?ooo`00Y@3o
ool400000;d0oooo002U0?ooo`@00000_@3oool00:D0oooo1@00002l0?ooo`00Y03oool600000;`0
oooo002T0?ooo`H00000_03oool00:@0oooo1`00002k0?ooo`00X`3oool800000;/0oooo002W0?oo
o`030000003oool0oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0oooo002W0?ooo`030000
003oool0oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0oooo002W0?ooo`030000003oool0
oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0
oooo002W0?ooo`030000003oool0oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0oooo002W
0?ooo`030000003oool0oooo0;`0oooo002W0?ooo`030000003oool0oooo0;`0oooo003o0?ooofL0
oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo00190?oook`0
0000H@3oool004T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`1O0?ooo`00B@3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003oool0
oooo0;P0oooo00<000000?ooo`3oool0G`3oool004T0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`1O0?ooo`00B@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo05l0
oooo00190?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0G`3oool004T0oooo00<0
00000?ooo`3oool0503oool00`2ZZZX0k^k^0?ooo`030?ooo`030<c<c03MgMd0oooo01H0oooo00<0
ZZZZ0>k^kP3oool0303oool00`2ZZZX0k^k^0?ooo`040?ooo`030<c<c03MgMd0oooo0080oooo00<0
c<c<0=gMg@3oool04@3oool00`3<c<`0gMgM0?ooo`0F0?ooo`030:ZZZP3^k^h0oooo00@0oooo00H0
c<c<0=gMg@3oool0oooo0<c<c03MgMd`0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000
003oool0oooo01@0oooo00<0IVIV0?ooo`3oool0103oool00`1VIVH0oooo0?ooo`0E0?ooo`0306IV
IP3oool0oooo00H0oooo00<0ZZZZ0000002ZZZX00`3oool00`1VIVH0oooo0?ooo`050?ooo`0306IV
IP3oool0oooo0080oooo00<0ZZZZ0;^k^`3oool04@3oool00`2ZZZX0^k^k0?ooo`090?ooo`030>k^
kP0c<c<0A4A40080k^k^00P0<c<c0?ooo`2k^k/0000006IVIP3^k^h0oooo06IVIPL0oooo00D0IVIV
0?ooo`3oool0oooo06IVIP0`0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003oool0
oooo01<0oooo0P2ZZZX60?ooo`0305EEE@3^k^h0oooo01@0oooo0P2ZZZX90?ooo`040000003oool0
oooo0?ooo`80ZZZZ1`3oool00`1EEED0k^k^0?ooo`020?ooo`030>k^kP0c<c<0oooo0140oooo00<0
k^k^03<c<`3oool02P3oool0203<c<`0ZZZZ0?ooo`14A4@000000<c<c03oool000000P3oool20:ZZ
ZPL0oooo00H0EEEE0>k^kP3oool0oooo05EEE@3^k^h_0?ooo`030000003oool0oooo05l0oooo0019
0?ooo`030000003oool0oooo00h0oooo100000000`3oool0A4A40>k^kP020?ooo`0603<c<`0A4A40
ZZZZ0?ooo`2ZZZX0VIVI1P3oool00`0A4A40EEEE0?ooo`0<0?ooo`0804A4A03^k^h0oooo0?ooo`14
A4@0IVIV05EEE@2IVIT30?ooo`060000003oool0oooo0?ooo`14A4@0k^k^0`3oool01P0c<c<04A4A
0:ZZZP3oool0ZZZZ09VIV@80oooo00<0ZZZZ00000014A4@01@3oool01P0A4A40EEEE0?ooo`3oool0
4A4A05EEE@80oooo00L04A4A05EEE@3oool0oooo0:ZZZP000000A4A400D0oooo00@0A4A406IVIP1E
EED0VIVI0`3oool01`2ZZZX0c<c<0000003oool0A4A40?ooo`0000000P3oool01`14A4@0k^k^0?oo
o`3oool0<c<c014A4@2ZZZX00P3oool01P2ZZZX0VIVI0?ooo`3oool0ZZZZ09VIV@H0oooo1`000006
0?ooo`D000005`3oool00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0080oooo00<0000003<c<`3oool00P3oool01P000000k^k^0?ooo`3oool0
k^k^04A4A0H0oooo00@0EEEE09VIV@3oool0oooo1@0R8R800`1EEED0oooo0?ooo`030?ooo`0803<c
<`3oool0oooo0?ooo`2IVIT0oooo0>k^kP0000030?ooo`050000003oool0oooo0?ooo`0c<c<0103o
ool01P000000k^k^0?ooo`3oool0k^k^04A4A080oooo00<0k^k^06IVIP3^k^h01@3oool01P1EEED0
VIVI0?ooo`3oool0EEEE09VIV@80oooo00L0EEEE09VIV@3oool0oooo0>k^kP1VIVH0k^k^00D0oooo
00@0VIVI0?ooo`3^k^h000000`3oool01`2ZZZX08R8R07MgM`3oool0MgMg0<c<c00000000P3oool0
1P0c<c<0oooo0?ooo`3oool000000>k^kP<0oooo00H0k^k^04A4A03oool0oooo0>k^kP14A4@50?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo05l0oooo00190?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00P3oool00`000000<c<c0?ooo`020?ooo`030000003oool0oooo0080oooo00<08R8R0?ooo`3o
ool04`3oool00`0c<c<0oooo0?ooo`020?ooo`030;^k^`0R8R808R8R00<0oooo00D000000?ooo`3o
ool0oooo03<c<`040?ooo`030000003oool0oooo0080oooo00<08R8R0?ooo`3oool07@3oool00`2k
^k/08R8R028R8P030?ooo`0307MgM`000000oooo0080oooo00D0MgMg0000003oool0oooo03<c<`03
0?ooo`030000003oool0oooo00<0oooo00D08R8R0?ooo`3oool0oooo028R8P040?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1O0?ooo`00B@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<0000003<c<`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`03028R8P3oool0oooo01<0oooo00L0<c<c0?ooo`3oool0oooo05EE
E@0R8R80MgMg0080oooo0P2k^k/01@000000oooo0?ooo`3oool0<c<c00@0oooo00<000000?ooo`3o
ool00P3oool00`0R8R80oooo0?ooo`0L0?ooo`0305EEE@0R8R80MgMg00@0oooo00<0000004A4A03o
ool00P3oool01@1gMgL000000?ooo`3oool0<c<c00<0oooo00<000000?ooo`3oool00`3oool01@0R
8R80oooo0?ooo`3oool08R8R00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00`3oool00`000000A4A40?ooo`020?ooo`030000003oool0oooo0080oooo00<08R8R0?oo
o`3oool0103oool0100A4A40EEEE0?ooo`3oool5028R8P0305EEE@3oool0oooo00<0oooo00L0A4A4
0?ooo`3oool0oooo028R8P3oool0ZZZZ00<0oooo00<0k^k^0000003oool00P3oool00`14A4@0oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<08R8R0?ooo`3oool0703oool00`0R8R80oooo
0:ZZZP030?ooo`0308R8R0000000k^k^00<0oooo00D0k^k^0000002ZZZX0oooo04A4A0030?ooo`03
0000003oool0oooo00<0oooo00D08R8R0?ooo`3oool0oooo028R8P040?ooo`T000002P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool0oooo0`0000001@1EEED0oooo0?ooo`1gMgL0000000808R8R00<0oooo
0<c<c01VIVH01P3oool00`1EEED0VIVI0?ooo`0<0?ooo`0705EEE@3oool0oooo0?ooo`2IVIT0IVIV
05EEE@080?ooo`0605EEE@3oool0oooo0?ooo`1gMgL000000P0R8R800`3oool0c<c<06IVIP0N0?oo
o`0309VIV@1VIVH0EEEE00d0oooo00D0EEEE0?ooo`3oool0MgMg00000002028R8P80oooo00H0c<c<
06IVIP3oool0oooo0<c<c01VIVH40?ooo`030000003oool0oooo00d0oooo0`00000H0?ooo`030000
003oool0oooo05l0oooo00190?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool20:ZZZP80oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`E0?ooo`80ZZZZ3@3oool20:ZZZP<0
oooo00H0<c<c0?ooo`3oool0oooo09VIV@3<c<`^0?ooo`80ZZZZ0P3oool00`0c<c<0oooo0?ooo`02
0?ooo`0609VIV@3<c<`0oooo0?ooo`2IVIT0c<c<1@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo00<0k^k^03<c<`14A4@00P3^k^h01P0c<c<0oooo0;^k^`000000IVIV0>k^
kP`0oooo00<000000?ooo`3oool0G`3oool004T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`0406IVIP3oool0oooo0>k^kP<0oooo00<0EEEE0?ooo`3oool05@3oool00`1V
IVH0oooo0?ooo`0<0?ooo`0506IVIP3oool0oooo0?ooo`3^k^h00`3oool00`1EEED0oooo0?ooo`0^
0?ooo`0406IVIP3oool0oooo0>k^kP@0oooo00D0EEEE0?ooo`3oool0oooo05EEE@070?ooo`L00000
1@3oool00`000000oooo0?ooo`040?ooo`080<c<c02ZZZX0oooo04A4A0000000c<c<0?ooo`00000>
0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0103oool00`2ZZZX0k^k^0?ooo`030?ooo`030=gMg@2ZZZX0oooo01H0oooo00<0ZZZZ0>k^
kP3oool0303oool00`2ZZZX0k^k^0?ooo`040?ooo`030=gMg@2ZZZX0oooo02l0oooo00<0ZZZZ0>k^
kP3oool0103oool01P3MgMd0ZZZZ0?ooo`3oool0gMgM0:ZZZQ<0oooo00<000000?ooo`3oool01@3o
ool01`2ZZZX0c<c<0000003oool0A4A40?ooo`0000003P3oool00`000000oooo0?ooo`1O0?ooo`00
B@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`030?ooo`090000003oool0ZZZZ028R8P1gMgL0oooo07MgM`3<c<`0
000000h0oooo00<000000?ooo`3oool0G`3oool004T0oooo00<000000?ooo`3oool03P3oool40000
08X0oooo1@0000020?ooo`0307MgM`000000oooo0080oooo00<0MgMg0000003oool03@3oool00`00
0000oooo0?ooo`1O0?ooo`00B@3oool00`000000oooo0?ooo`2S0?ooo`0300000014A4@0oooo0080
oooo00<0MgMg0000003oool03@3oool00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000oooo
0?ooo`2R0?ooo`0308R8R0000000k^k^00<0oooo00<0k^k^0000002ZZZX03@3oool00`000000oooo
0?ooo`1O0?ooo`00B@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo05l0oooo0019
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0G`3oool004T0oooo00<000000?oo
o`3oool0^03oool00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo05l0oooo00190?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
G`3oool004T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`1O0?ooo`00B@3oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo05l0oooo00190?ooo`030000003_knl0kno_
0;P0kno_00<000000?ooo`3oool0G`3oool004T0oooo00<000000>o_k`3_knl0F@3_knl00`0_;bl0
kno_0>o_k`1L0>o_k`030000003oool0oooo05l0oooo00190?ooo`030000003_knl0kno_05T0kno_
00<0Cdm?0;no_`3_knl0G03_knl00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000kno_0>o_
k`0_0>o_k`0308n?S`0O7al0WinO02L0kno_0P1oOgmM0>o_k`030000003oool0oooo05l0oooo0019
0?ooo`030000003_knl0kno_00P0kno_00@0[jn_0000001?Cdl0clo?0P3_knl01@0O7al0clo?0>o_
k`000000Shn?00<0kno_00H07alO0<o?c`3_knl0000004m?C`3Ogml20>o_k`0;01lO7`3?cll07alO
0000001_Kfl0kno_0000002o_kl0kno_0000002?Shl00P3_knl03@0O7al0clo?08n?S`2?Shl03`l?
0;no_`1oOgl07alO0000001_Kfl0kno_0000002o_kl00P3_knl02P000000Cdm?0=oOg`3_knl07alO
0<o?c`3_knl0_kno08n?S`2_[jl209nOW`<0kno_00D07alO0<o?c`3_knl0000008n?S`050>o_k`03
0;no_`2?Shl0[jn_0080WinO00<0kno_0;no_`0o?cl01@3_knl03@2_[jl0Cdm?06m_K`1_Kfl0GemO
0=oOg`3_knl0000004m?C`3Ogml0kno_0=oOg`0O7al0103_knl01@0?3`l0Shn?0>o_k`000000Shn?
00<0kno_00@0Shn?0000001OGel0WinO0P3_knl00`000000Cdm?0=oOg`020>o_k`0800l?3`2?Shl0
kno_0000002?Shl0kno_0=oOg`0O7al40>o_k`0408n?S`0?3`l0GemO0;no_`80kno_00@0GemO00l?
3`1?Cdl0_kno7P3_knl00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000kno_0>o_k`090>o_
k`0303lo?`1_Kfl0kno_0080kno_00H0Ogmo06m_K`3_knl0;bl_0;no_`2_[jl20>o_k`0B03lo?`2O
Wil0kno_00l?3`2OWil0Ogmo0=oOg`3_knl0?clo09nOW`000000gmoO08n?S`1?Cdl07alO0<o?c`3O
gml0;bl_0P2_[jl06@3_knl0?clo09nOW`2_[jl0;bl_0=oOg`3_knl0[jn_0000003Ogml0Shn?04m?
C`0O7al0clo?0=oOg`3_knl03`l?09nOW`1oOgl0gmoO03lo?`2OWil0kno_03lo?`3Ogml00P3_knl0
2P0o?cl0WinO0>o_k`3_knl0Ogmo06m_K`3_knl0;bl_0;no_`2_[jl40>o_k`0803lo?`3Ogml0kno_
0>o_k`0o?cl0WinO0>o_k`0?3`l50>o_k`0>0<o?c`1_Kfl0kno_0>o_k`3?cll0?clo0>o_k`0?3`l0
WinO07moO`3Ogml0kno_00l?3`3?cll30>o_k`0603lo?`2OWil0_kno01lO7`2_[jl0_kno0P3_knl0
500?3`l0clo?0>o_k`2o_kl0WinO0>o_k`0?3`l0WinO07moO`3Ogml0kno_03lo?`2OWil0_kno01lO
7`2_[jl0_kno0>o_k`0?3`l0clo?0`3_knl01`0?3`l0clo?0>o_k`2OWil0_kno0>o_k`1_Kfl00P3_
knl00`0o?cl0kno_0>o_k`0L0>o_k`030000003oool0oooo05l0oooo00190?ooo`030000003_knl0
kno_00T0kno_00<0Kfm_03lo?`3_knl00P3_knl01@3?cll000000=oOg`3?cll0Shn?00<0kno_01<0
Ogmo0;no_`3_knl0GemO07moO`3_knl0gmoO0>o_k`1oOgl0_kno04m?C`3Ogml0kno_06m_K`000000
_kno0>o_k`1OGel0WinO0080kno_00d0Ogmo0;no_`3_knl0_kno05mOG`3Ogml0kno_04m?C`3Ogml0
kno_06m_K`000000_kno0080kno_00T0GemO07moO`3_knl0gmoO07moO`2o_kl0kno_0000003Ogml0
0P3_knl02@2_[jl0;bl_0>o_k`3_knl0clo?0000003Ogml0clo?08n?S`050>o_k`090000003Ogml0
kno_0>o_k`2_[jl0;bl_0>o_k`0o?cl0[jn_00D0kno_00d0_kno0>o_k`3_knl0_kno0000003_knl0
GemO07moO`3_knl0gmoO0>o_k`1OGel0Kfm_00<0kno_00D0Ogmo08n?S`2o_kl0Cdm?08n?S`030>o_
k`0@01lO7`3?cll0kno_0>o_k`3Ogml0kno_05mOG`1oOgl0kno_0=oOg`3_knl0Ogmo08n?S`2o_kl0
Cdm?08n?S`80kno_00<0GemO06m_K`3_knl00P3_knl01@0?3`l0gmoO0>o_k`3_knl0gmoO0080kno_
00<0gmoO03lo?`0_;bl07P3_knl00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000kno_0>o_
k`090>o_k`030:n_[`0?3`l0kno_00<0kno_00D07alO05mOG`3_knl0Ogmo0=oOg`020>o_k`050;no
_`2_[jl0kno_09nOW`0o?cl00`3_knl0102o_kl0[jn_0<o?c`1oOgl20>o_k`0500l?3`2?Shl0kno_
09nOW`1OGel00P3_knl02@2o_kl0[jn_0>o_k`3_knl0clo?04m?C`2o_kl0clo?07moO`020>o_k`06
00l?3`2?Shl0kno_0>o_k`2OWil0?clo0P3_knl01@2o_kl0[jn_0>o_k`0_;bl0[jn_0080kno_00<0
gmoO0000003_knl00P3_knl01@0O7al0GemO0>o_k`1oOgl0gmoO00@0kno_00T0;bl_0:n_[`3_knl0
kno_0=oOg`000000kno_07moO`1_Kfl01`3_knl01P3Ogml07alO04m?C`3_knl0WinO03lo?`<0kno_
00<0WinO01lO7`3Ogml00P3_knl01@2o_kl0Cdm?0>o_k`1?Cdl0?clo00<0kno_0P1_Kfl40>o_k`03
09nOW`0o?cl0kno_0080kno_00D0_kno04m?C`3_knl0Cdm?03lo?`020>o_k`0309nOW`0O7al0gmoO
0080kno_00D0Cdm?06m_K`2OWil0Shn?0=oOg`020>o_k`0302l_;`1?Cdl0gmoO01h0kno_00<00000
0?ooo`3oool0G`3oool004T0oooo00<000000>o_k`3_knl02@3_knl00`3?cll000000>o_k`020>o_
k`0606m_K`1OGel0Shn?06m_K`3Ogml0Cdm?0P3_knl01P2o_kl0Kfm_0>o_k`3_knl000000=oOg`80
kno_00H0_kno06m_K`3_knl0WinO0;no_`3_knl205mOG`030>o_k`3Ogml07alO0080kno_00/0_kno
06m_K`3_knl0Ogmo0>o_k`0o?cl000000:n_[`2OWil0_kno0>o_k`0205mOG`<0kno_00P000000=oO
g`3_knl0_kno06m_K`3_knl0WinO04m?C`80kno_00X0clo?03lo?`3_knl0kno_06m_K`1OGel0Shn?
06m_K`3Ogml0Cdm?103_knl02@2OWil0Cdm?0>o_k`3_knl0clo?03lo?`3_knl0[jn_02l_;`070>o_
k`0302l_;`0O7al0gmoO0080kno_00<000000=oOg`3_knl00P3?cll02P0_;bl0Ogmo0:n_[`3_knl0
_kno01lO7`3_knl0clo?0000003Ogml20>o_k`030=oOg`0_;bl0_kno00@0kno_00X000000=oOg`3_
knl0kno_0;no_`0O7al0kno_0<o?c`000000gmoO0P3?cll02@0_;bl0Ogmo0:n_[`3_knl0gmoO03lo
?`3Ogml0[jn_03lo?`020>o_k`0404m?C`3_knl0gmoO0=oOgad0kno_00<000000?ooo`3oool0G`3o
ool004T0oooo00<000000>o_k`3_knl02P3_knl02P000000[jn_0>o_k`3_knl0_kno02l_;`1_Kfl0
gmoO04m?C`0?3`l20>o_k`0:0;no_`1_Kfl0kno_07moO`0?3`l0Cdm?07moO`3_knl0_kno06m_K`80
kno_00@0_kno08n?S`0_;bl0?clo0P3_knl0400O7al0gmoO0>o_k`2o_kl0Kfm_0>o_k`2OWil0;bl_
01lO7`2_[jl0WinO0>o_k`2o_kl0Shn?02l_;`0o?cl20>o_k`0607moO`0?3`l0Cdm?07moO`2o_kl0
Kfm_0P3_knl209nOW`030:n_[`2?Shl0_kno0080kno_00H0_kno02l_;`1_Kfl0gmoO04m?C`0?3`l5
0>o_k`80WinO00P0[jn_08n?S`2o_kl0gmoO06m_K`000000Kfm_0:n_[`@0kno_00<0Kfm_0000003O
gml00P3_knl02@1oOgl03`l?04m?C`1oOgl0kno_08n?S`000000clo?00l?3`020<o?c`0500l?3`3O
gml0kno_04m?C`2_[jl0103_knl06P2?Shl0GemO00l?3`3_knl0Ogmo00l?3`1?Cdl0Ogmo0>o_k`3?
cll03`l?0=oOg`3_knl0Cdm?0:n_[`3_knl0Shn?0000003?cll03`l?0<o?c`3_knl0gmoO07moO`1O
Gel0?clo0P3_knl0103?cll0GemO00l?3`2o_klM0>o_k`030000003oool0oooo05l0oooo00190?oo
o`030000003_knl0kno_00X0kno_00<0;bl_07moO`3_knl03@3_knl00`2?Shl0Cdm?0>o_k`0;0>o_
k`0304m?C`2?Shl0kno_0100kno_00<0Shn?04m?C`3_knl07@3_knl00`0o?cl0WinO0>o_k`040>o_
k`0400l?3`2_[jl0kno_0<o?c`80kno_00<0Shn?04m?C`3_knl05@3_knl00`2?Shl0Cdm?0>o_k`0e
0>o_k`030000003oool0oooo05l0oooo00190?ooo`030000003_knl0kno_00X0kno_0P1OGel>0>o_
k`030=oOg`0o?cl0kno_00/0kno_00<0Shn?04m?C`3_knl0403_knl00`3Ogml0?clo0>o_k`0M0>o_
k`0308n?S`1OGel0kno_00@0kno_00P0;bl_0=oOg`3_knl0WinO0;no_`3_knl0gmoO03lo?aH0kno_
00<0gmoO03lo?`3_knl0=@3_knl00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000kno_0>o_
k`090>o_k`040<o?c`1?Cdl03`l?0:n_[`X0kno_00<0?clo0>o_k`3_knl01@3_knl00`0o?cl0kno_
0>o_k`060>o_k`0506m_K`0?3`l0kno_0>o_k`0o?cl04P3_knl00`0o?cl0kno_0>o_k`0J0>o_k`03
04m?C`3_knl0kno_00<0kno_00D0_kno05mOG`1_Kfl0000007moO`1A0>o_k`030000003oool0oooo
05l0oooo00190?ooo`030000003_knl0kno_02P0kno_00<0gmoO07moO`3?cll0<@3_knl00`3Ogml0
Ogmo01lO7`1I0>o_k`030000003oool0oooo05l0oooo00190?ooo`030000003_knl0kno_0;P0kno_
00<000000?ooo`3oool0G`3oool004T0oooo00<000000>o_k`3_knl0^03_knl00`000000oooo0?oo
o`1O0?ooo`00B@3oool00`000000kno_0>o_k`2h0>o_k`030000003oool0oooo05l0oooo00190?oo
o`030000003_knl0kno_0;P0kno_00<000000?ooo`3oool0G`3oool004T0oooo00<000000>o_k`3_
knl0^03_knl00`000000oooo0?ooo`1O0?ooo`00B@3oool00`000000kno_0>o_k`2h0>o_k`030000
003oool0oooo05l0oooo00190?oook`00000H@3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0
ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00:L0
oooo00<000000?ooo`3oool0_03oool00:H0oooo0P00002n0?ooo`00YP3oool200000;h0oooo002V
0?ooo`800000_P3oool00:H0oooo0`00002m0?ooo`00Y@3oool400000;d0oooo002U0?ooo`@00000
_@3oool00:D0oooo1@00002l0?ooo`00Y03oool600000;`0oooo002T0?ooo`H00000_03oool00:@0
oooo1P00002l0?ooo`00Y03oool700000;/0oooo002S0?ooo`P00000^`3oool00:L0oooo00<00000
0?ooo`3oool0_03oool00:L0oooo00<000000?ooo`3oool0_03oool00:L0oooo00<000000?ooo`3o
ool0_03oool00:L0oooo00<000000?ooo`3oool0_03oool00:L0oooo00<000000?ooo`3oool0_03o
ool00:L0oooo00<000000?ooo`3oool0_03oool00:L0oooo00<000000?ooo`3oool0_03oool00:L0
oooo00<000000?ooo`3oool0_03oool00:L0oooo00<000000?ooo`3oool0_03oool00:L0oooo00<0
00000?ooo`3oool0_03oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0ooooI`3oool00?l0oooo
I`3oool00?l0ooooI`3oool008h0oooo<P00002V0?ooo`00SP3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0:@0oooo002>0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0Y03oool008h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2T0?ooo`00SP3o
ool00`000000oooo0?ooo`080?ooo`0303<c<`0A4A40ZZZZ00D0oooo00<04A4A05EEE@3oool0303o
ool306IVIP`0oooo00<000000?ooo`3oool0Y03oool008h0oooo00<000000?ooo`3oool0203oool0
0`000000k^k^0?ooo`050?ooo`0405EEE@2IVIT0oooo0?ooo`D08R8R00<0EEEE0?ooo`3oool00P3o
ool209VIV@030?ooo`2IVIT0ZZZZ00/0oooo00<000000?ooo`3oool0Y03oool008h0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`05028R8P3<c<`0oooo0<c<c00c<c<02`3o
ool00`000000oooo0?ooo`2T0?ooo`00SP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01<0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0:@0oooo002>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0100A4A40EEEE0?ooo`3o
ool5028R8P0305EEE@3oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000
003oool0oooo0:@0oooo002>0?ooo`030000003oool0oooo00L0oooo00@0MgMg0000000R8R808R8R
1@3oool00`1EEED0VIVI0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000
oooo0?ooo`2T0?ooo`00SP3oool00`000000oooo0?ooo`080?ooo`0303<c<`3oool0oooo01<0oooo
00D0<c<c0<c<c03oool0c<c<03<c<`0;0?ooo`030000003oool0oooo0:@0oooo002>0?ooo`030000
003oool0oooo00P0oooo00<0k^k^0?ooo`3oool04`3oool00`2k^k/0VIVI0?ooo`0209VIV@/0oooo
00<000000?ooo`3oool0Y03oool008h0oooo00<000000?ooo`3oool07`3oool207MgM`0306IVIP3o
ool0oooo00X0oooo00<000000?ooo`3oool0Y03oool008h0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2T0?ooo`00SP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0:@0oooo002>0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0Y03oool008h0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2T0?ooo`00SP3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0:@0oooo002>0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0Y03oool008h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2T0?oo
o`00SP3ooolb00000:H0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?oo
ofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo0000\
\>"], "Graphics",
  CellMargins->{{Inherited, 322}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageSize->{358, 616.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Optimization and Multi-Modal Functions", "Section"],

Cell[CellGroupData[{

Cell["Example of a Multimodal Testfunction", "Subsection"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000610001;R000`400?l00000o`00003oo`3ooon2
0?ooo`00o`3ooon20?ooo`00o`3ooon20?ooo`00o`3ooon20?ooo`00o`3ooon20?ooo`00o`3ooon2
0?ooo`00eP3oool4000000D0oooo0P00002P0?ooo`00e`3oool00`000000oooo0?ooo`030?ooo`80
00000P3oool2000009h0oooo003G0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`800000
WP3oool00=L0oooo00<000000?ooo`3oool00`3oool200000080oooo0P00002N0?ooo`00e`3oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool2000009h0oooo003G0?ooo`030000003oool0oooo
00<0oooo0P0000020?ooo`800000WP3oool00=H0oooo0P0000050?ooo`8000000P3oool2000001@0
oooo0`0000270?ooo`00eP3oool2000000D0oooo0P0000020?ooo`800000503oool3000008L0oooo
003G0?ooo`030000003oool0oooo00D0oooo0P00000B0?ooo`@000000P3oool00`000000oooo0?oo
o`250?ooo`00l@3oool2000000L0oooo00<000000?ooo`3oool0Q03oool00>d0oooo1000000:0?oo
o`030000003oool0oooo08<0oooo003Y0?ooo`@0000000<0oooo0000000000002`3oool00`000000
oooo0?ooo`230?ooo`00j@3oool4000000030?ooo`000000000000/0oooo00<000000?ooo`3oool0
P`3oool00>H0oooo0`00000C0?ooo`800000403oool4000000H0oooo0P00001W0?ooo`00h`3oool3
000001D0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`030?ooo`8000000P3o
ool00`000000oooo0?ooo`1T0?ooo`00h03oool300000080oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`040?ooo`L00000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool0
0`000000oooo0?ooo`1T0?ooo`00h03oool300000080oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`040?ooo`L00000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`00
0000oooo0?ooo`1T0?ooo`00g03oool4000001l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`1T0?ooo`00f03oool4000002@0oooo
0P00000>0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo06@0oooo
002Z0?ooo`@00000:03oool200000080oooo00<000000?ooo`3oool08`3oool2000000`0oooo0`00
00050?ooo`8000000P3oool00`000000oooo0?ooo`1T0?ooo`00ZP3oool4000002P0oooo0P000002
0?ooo`030000003oool0oooo02<0oooo0P00000<0?ooo`<000001@3oool200000080oooo00<00000
0?ooo`3oool0I03oool00:T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?oo
o`@00000;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo0P00001W0?oo
o`00J03oool3000000030?ooo`00000000000400oooo00<000000?ooo`3oool07P3oool3000002h0
oooo0`00001n0?ooo`00J@3oool2000000030?ooo`000000oooo0400oooo00<000000?ooo`3oool0
6P3oool600000380oooo00<000000?ooo`3oool0N`3oool006/0oooo00<000000?ooo`3oool0>`3o
ool5000001/0oooo0P00000i0?ooo`030000003oool0oooo07X0oooo001[0?ooo`030000003oool0
oooo03/0oooo1@00000K0?ooo`800000>@3oool00`000000oooo0?ooo`1j0?ooo`00J@3oool20000
00030?ooo`000000oooo03/0oooo00<000000?ooo`3oool06@3oool4000003/0oooo00<000000?oo
o`3oool0NP3oool006P0oooo0`0000000`3oool000000000000k0?ooo`H000004P3oool400000003
0?ooo`000000oooo03d0oooo0P00001j0?ooo`00_P3oool3000004@0oooo0`00001i0?ooo`00_P3o
ool3000004@0oooo0`00001i0?ooo`00^`3oool3000004T0oooo00<000000?ooo`3oool0M`3oool0
0;P0oooo0`0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo07H0oooo002d0?ooo`@0
0000@@3oool00`2=SHd0oooo0?ooo`0=0?ooo`800000MP3oool00;00oooo100000120?ooo`0508V9
R@1VIYT0IVJI08V9R@1VIYT03P3oool2000007H0oooo002`0?ooo`@00000@P3oool01@29RHT0IVJI
06IVV@29RHT0IVJI00h0oooo0P00001f0?ooo`00[P3oool2000000<0oooo00<000000?ooo`3oool0
?`3oool01`2ZEJX0SHf=0:YEZP2ZEJX0SHf=0:YEZP2=SHd03`3oool00`000000oooo0?ooo`1c0?oo
o`00ZP3oool4000004L0oooo00L0IVJI08V9R@1VIYT0IVJI08V9R@1VIYT0RHV900d0oooo0P000000
0`3oool000000?ooo`1c0?ooo`00Y`3oool3000004T0oooo0`2ZEJX01P2=SHd0ZUFZ0:YEZP2=SHd0
ZUFZ08f=SA00oooo00<000000?ooo`3oool0LP3oool00:L0oooo0`0000190?ooo`<0ZUFZ00H0SHf=
0:YEZP2ZEJX0SHf=0:YEZP2=SHd@0?ooo`030000003oool0oooo0780oooo001j0?ooo`<000009P3o
ool400000080oooo00<000000?ooo`3oool0A`3oool30<bIV@0608V9R@1VIYT0IVJI08V9R@1VIYT0
c9VI4@3oool00`000000oooo0?ooo`1a0?ooo`00N@3oool01@000000oooo0?ooo`3oool0000002<0
oooo0P00001@0?ooo`80ZUFZ00L0c9VI08f=S@2ZEJX0ZUFZ08f=S@2ZEJX0ofJI0080c9VI403oool2
00000740oooo001i0?ooo`050000003oool0oooo0?ooo`0000007`3oool400000540oooo103<VIT0
1@29RHT0IVJI06IVV@29RHT0IVJI00<0c9VI403oool200000740oooo001i0?ooo`050000003oool0
oooo0?ooo`0000006`3oool4000000030?ooo`000000oooo03H0oooo00H0EEFZ0:YEZP1EEJX0EEFZ
0:YEZP3<<`040?ooo`030<`c003oool0oooo00l0oooo00D0c9VI0:YEZP2ZEJX0c9VI08f=S@020:YE
ZP0308f=S@3<VIT0ofJI0080c9VI403oool300000700oooo001i0?ooo`050000003oool0oooo0?oo
o`0000006`3oool4000000030?ooo`000000oooo03H0oooo00H0EEFZ0:YEZP1EEJX0EEFZ0:YEZP3<
<`040?ooo`030<`c003oool0oooo00l0oooo00D0c9VI0:YEZP2ZEJX0c9VI08f=S@020:YEZP0308f=
S@3<VIT0ofJI0080c9VI403oool300000700oooo001i0?ooo`050000003oool0oooo0?ooo`000000
603oool3000003d0oooo00L0SHf=0:YEZP2=SHd0SHf=0:YEZP2=SHd0ZUD00080oooo0P2ZE@020<`c
<`H0oooo00<0ZUEE0?ooo`3oool01@3oool50<bIV@0408V9R@1VIYT0IVJI08V9R@@0c9VI4`3oool0
0`000000oooo0?ooo`1]0?ooo`00N@3oool01@000000oooo0?ooo`3oool0000001D0oooo0`00000n
0?ooo`80ZUFZ00L0EEFZ0:YEZP1EEJX0EEFZ0:YEZP1EEJX0VC<00080c3<000D0VC<00<`c003<VC<0
c9Tc0:YEE@040?ooo`040000V@2ZZUD0c3<c0<`c<`D0oooo00H0ZUFZ0<bIV@2ZEJX0ZUFZ0<bIV@2=
SHd20:YEZP0308f=S@3<VIT0ofJI0080c9VI4`3oool00`000000oooo0?ooo`1]0?ooo`00NP3oool3
000001<0oooo0`0000020?ooo`030000003oool0oooo03/0oooo00D0ofJI0:YEZP2ZEJX0ofJI0:YE
ZP0208f=S@030:YEZP2=SHd0ZUFZ00@0ZUD00P3<<c<00`2ZEED0c3<c0?ooo`020000V@050000IP2Z
EED0c9UV0<bIIP2ZEED0103oool60<bIV@80IVJI1@3<VITD0?ooo`800000K@3oool007X0oooo0`00
000C0?ooo`<000000P3oool00`000000oooo0?ooo`0k0?ooo`050?mVV@2ZEJX0ZUFZ0?mVV@2ZEJX0
0P2=SHd00`2ZEJX0SHf=0:YEZP040:YE0080c3<c00<0ZUEE0<`c<`3oool00P0009T01@0006H0ZUEE
0<bIIP3<VFH0ZUEE00@0oooo1P3<VIT206IVV@D0c9VI503oool2000006d0oooo002<0?ooo`@00000
@`3oool01@2ATI40ZUFZ0:YEZP2ATI40ZUFZ0080EEFZ00<0ZUFZ05EEZP2ZEED00P2ATI401`2I<`00
ZUEE0<bI<`3<VC<0ZUEE0<bI<`2ZEED00P0007L01P3<<c<0ZZYE0<`c<`3<<c<0ZZYE0<`c<`80oooo
00<0c9VI0:YEZP3<VIT00P2ZEJX01`3<VIT0ZUFZ0:YEZP2ZEJX0ofJI0<bIV@3oIYT00P3<VIT00`3o
IYT0oooo0?ooo`0A0?ooo`800000K@3oool008P0oooo1@0000150?ooo`060:YEZP3oIYT0ZUFZ0:YE
ZP3oIYT0ZUFZ0P2=SHd00`2ZEJX0SHf=0:YEZP0208f=S@070:YE002ZEED0c3<c0<`c<`2ZEED0c3<c
0:YEE@020<`c<`060<bIIP2ZEED0c9UV0<bIIP2ZEED0c9UV0P2ZEED70<bIV@80IVJI1P3<VIT00`00
09T0oooo0?ooo`0@0?ooo`<000004@3oool4000005L0oooo00260?ooo`800000B@3oool00`2ATI40
ZUFZ096AT@020:YEZP07096AT@2ZEJX0EEFZ05EEZP2ZEJX0c9VI0:YEE@020<bIV@0706Hcc02ZEED0
c9Tc0<bI<`2ZEED0c9Tc0:YEE@020<bI<`060<`c<`2ZZUD0c3<c0<`c<`2ZZUD0c3<c0P3oZZX00`3<
VIT0ZUFZ0<bIV@020:YEZP070<bIV@2ZEJX0c9VI0<bIV@3oIYT0c9VI0?mVV@020<bIV@040?mVV@00
09T0ZUEE0:YEEA<0oooo00<000000?ooo`3oool0303oool2000000@0oooo00<000000?ooo`3oool0
E03oool00880oooo1000001;0?ooo`030?mVV@2ZEJX0ofJI0080ZUFZ00L0ofJI0:YEZP2=SHd0SHf=
0:YEZP2=SHd0ZUFZ0080SHf=00L0VC>I0:YEE@3<<c<0c3<c0:YEE@3<<c<0ZUEE0080c3<c00H0E@00
0:YEE@3<VFH0c9UV0:YEE@3<VFH30?o<V@h0c9VI00@0002I0<bIIP3<VFH0c9Tc4P3oool00`000000
oooo0?ooo`050?ooo`H000001`3oool00`000000oooo0?ooo`1D0?ooo`00PP3oool4000004/0oooo
00<0ofJI0:YEZP3oIYT00P2ZEJX01`3oIYT0ZUFZ08f=S@2=SHd0ZUFZ08f=S@2ZEJX00P2=SHd01`2I
<iT0ZUEE0<`c<`3<<c<0ZUEE0<`c<`2ZEED00P3<<c<01P1E0000ZUEE0<bIIP3<VFH0ZUEE0<bIIP<0
olbI3P3<VIT0100009T0c9UV0<bIIP3<VC<B0?ooo`030000003oool0oooo00D0oooo1P0000070?oo
o`030000003oool0oooo05@0oooo001o0?ooo`@00000C03oool208f=S@03096AT@2ZEJX0TI6A0080
ZUFZ00L0TI6A0:YEZP1EEJX0EEFZ0:YEZP3<VIT0ZUEE0080c9VI00L0IS?<096AT@3<VC<0c9Tc0:YE
E@3<VC<0ZUEE0080c9Tc00H0E@1E0:ZZE@3<<c<0c3<c0:ZZE@3<<c<20?nZZP030?ooZP2ZEJX0c9VI
0080ZUFZ0P3<VIT20?ooZP030?mVV@3<VIT0ofJI0080c9VI00L0ofJI0<`c<`2ZEED0ZUEE0<`c<`3<
<`00VC<00080c3<000@0VC<009VIc02ZEJX0ZUFZ2`3oool200000180oooo00<000000?ooo`3oool0
E03oool007/0oooo100000040?ooo`030000003oool0oooo04T0oooo0P3<VIT00`3oIYT0ZUFZ0?mV
V@020:YEZP070?mVV@2ZEJX0SHf=08f=S@2ZEJX0SHf=0:YEZP0208f=S@0709TcV@2ZEJX0c3<c0<`c
<`2ZEED0c3<c0:YEE@0209Tc<`0505D0002I<c<0c9UV0<bIIP2ZEED0103oc9T50<bIV@030?o<V@3o
ofH0oomV00D0c9VI0P3oc9T20<bIIP030<bI<`3<VFH0VC<000<0VC<000<0IVJI05FZZP1EZZX03@3o
ool00`000000oooo0?ooo`090?ooo`H00000E`3oool007T0oooo0P00000i0?ooo`040<`c003oIVH0
ofIV0:YEE@P0oooo00@0ZUD00:YEE@1nOWh0OWin2`3oool208f=S@030<bIV@2ZEJX0TI6A0080ZUFZ
00L0TI6A0:YEZP1EEJX0EEFZ0:YEE@3<VIT0ZUEE0080c9VI00L0IS?<096AT@1V<l`0IS?<0:YEE@3<
VC<0ZUEE0080VC<c00H0E@1E09Tc<`3<<c<0c3<c0:ZZE@3oojX20?nZZP030?ooZP2ZEJX0c9VI0080
ZUFZ00L0oonZ0<bIV@3oojX0oonZ0?mVV@3<VIT0ofJI0080c9VI00L0ojYE0?ooZP2ZEED0ZUEE0<`c
<`2ZEED0VC<00080c3<000@0VC<009VIc02ZEJX0ZUFZ3@3oool2000000X0oooo0P00001K0?ooo`00
N@3oool2000003T0oooo00@0c3<00?mVIP3oIVH0ZUEE203oool0102ZE@00ZUEE07inOP1nOWh;0?oo
o`80SHf=00<0c9VI0:YEZP2ATI400P2ZEJX01`2ATI40ZUFZ05EEZP1EEJX0ZUEE0<bIV@2ZEED00P3<
VIT01`1V<l`0TI6A06Hcc01V<l`0ZUEE0<bI<`2ZEED00P2I<c<01P1E05D0VC<c0<`c<`3<<c<0ZZYE
0?ooZP80ojZZ00<0oonZ0:YEZP3<VIT00P2ZEJX01`3oojX0c9VI0?ooZP3oojX0ofJI0<bIV@3oIYT0
0P3<VIT01`3oZUD0oonZ0:YEE@2ZEED0c3<c0:YEE@2I<`000P3<<`00102I<`00VIW<0:YEZP2ZEJX=
0?ooo`8000002P3oool2000005/0oooo001:0?ooo`@000009`3oool5000003P0oooo00<0ZUD009Tc
<`2ZE@000P2I<c<00`2I<fH0VC<c0?ooo`040?ooo`80ZUD000D0c3<00:YEE@3<<c<0c3<c0:YEE@04
0?ooo`060<`c003<V@00c3<00<`c003<V@00ZUFZ0P3<VIT20:YEZP050?mVV@2ZEJX0ZUFZ0?mVV@2Z
EJX00P2=SHd00`2ZEJX0SHf=0:YEZP0208f=S@0709TcV@2ZEJX0c9VI0<bIV@2ZEJX0c3<c0:YEE@02
09Tc<`0405D0002I<c<0E@0005D000D0olbI103<VIT01@3oofH0olbI0?ooIP3oofH0olbI00@0c9VI
0P3oc9T20<bIIP030<bI<`3<VFH0c9Tc0080VC<000D0EJZZ06IVV@2ZEJX0ZUFZ0<bIV@0:0?ooo`80
000000<0oooo0000003oool02@3oool7000005H0oooo00190?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0803oool4000002d0oooo00D0TI6A08f=S@2=SHd0ZUFZ08f=S@020:YEZP03
06Hcc00cI/`0oooo00@0oooo0P2I<fH00`3<<`00VC=V0:YEE@020?mVIP070:YEE@3oIVH0c3<00<`c
002ZE@00c3<00:YE00020<`c00070:YE002ZEED0OWin07inOP2ZEED0OWin0?ooo`020<bI<`060<`c
<`3<VC<0c3<c0<`c<`3<VC<0c9VI0P2=SHd00`3<VIT0ZUFZ096AT@020:YEZP07096AT@2ZEJX0c9VI
0<bIV@2ZEED0c9VI0:YEE@020<bIV@070:YEE@2ATI40ZUEE0:YEE@3<VIT0c9Tc0:YEE@0209Tc<`06
05D0E@2I<c<0E@1E05D0E@3oZZX0oonZ0P3oZZX00`3oojX0ojZZ0<bIV@020:YEZP040?ooZP3<VIT0
oonZ0?ooZP80c9VI00D0ofJI0?ooZP3oojX0ojYE0?ooZP020?nZE@030<`c<`2ZEED0c3<c0080ZUEE
00D0ZUFZ09VIc03<VIT0c9VI08f=S@0>0?ooo`030000003oool0oooo06@0oooo00110?ooo`L00000
1P3oool00`000000oooo0?ooo`0M0?ooo`<00000;@3oool01@2I<iT0VC?<09Tcc02I<iT0VC?<0080
EEFZ00D0EJZZ05EEZP1EZZX0EJZZ05EEZP0403=Vc0070?ooo`2ZE@00VC<c09Tc<`2ZE@00VC<c09Tc
IP0209Tc<`0709TcIP2I<c<0ZUEE0:YEE@3<<`00ZUD00<`c00020:YE00070<`c<`2ZEED0c3<c0<`c
<`2ZEED0c3<c0<`c00020<bI00060<`c003<V@00c3<00<`c003<VIT0ZUFZ0P3<VIT20:YEZP050?mV
V@2ZEJX0ZUFZ0?mVV@3oZZX00P2=SHd00`2ZEJX0SHf=0:YEZP0208f=S@80ZUFZ0P3<VIT00`2ZEJX0
c9VI05D0000209Tc<`0405D0002I<c<0E@0005D000H0olbI00D0c9VI0?o<V@3oc9T0oomV0?o<V@02
0?ooIP030?o<V@3<VIT0c9VI00H0olbI00<0c9Tc0<bIIP3<VC<00P3<VFH01@1EZZX0c9VI0:YEZP2Z
EJX0c9VI00h0oooo00<000000?ooo`3oool0I03oool00440oooo1`0000060?ooo`030000003oool0
oooo01d0oooo0`00000]0?ooo`0509TcV@2I<l`0VC?<09TcV@2I<l`00P1EEJX01@1EZZX0EEFZ05FZ
ZP1EZZX0EEFZ00@0<fK<00L0oooo0:YE002I<c<0VC<c0:YE002I<c<0VC=V0080VC<c00L0VC=V09Tc
<`2ZEED0ZUEE0<`c002ZE@00c3<00080ZUD000L0c3<c0:YEE@3<<c<0c3<c0:YEE@3<<c<0c3<00080
c9T000H0c3<00<bI003<<`00c3<00<bIV@2ZEJX20<bIV@80ZUFZ00D0ofJI0:YEZP2ZEJX0ofJI0?nZ
ZP0208f=S@030:YEZP2=SHd0ZUFZ0080SHf=0P2ZEJX20<bIV@030:YEZP3<VIT0E@000080VC<c00@0
E@0009Tc<`1E0000E@001P3oc9T01@3<VIT0olbI0?o<V@3oofH0olbI0080oomV00<0olbI0<bIV@3<
VIT01P3oc9T00`3<VC<0c9UV0<bI<`020<bIIP0505FZZP3<VIT0ZUFZ0:YEZP3<VIT03P3oool00`00
0000oooo0?ooo`1T0?ooo`00CP3oool00`000000oooo0?ooo`0J0?ooo`<000000P3oool00`000000
oooo0?ooo`0Z0?ooo`06096AT@2ZEJX0TI6A096AT@1VIYT0TI6A0P1VIYT01`2ZEJX0SHf=0:YEZP2Z
EJX0SHf=03=Vc01V<l`00P0cI/`01`2I<fH0c3<009TcIP2I<fH0c3<009TcIP2ZEED00P3oIVH01`2Z
EED0ofIV09TcIP2I<fH0CTi>0<`c002ZE@000P3<<`001`1nOWh0ZUEE07inOP1nOWh0ZUEE07inOP2I
<fH00P3<VC<01P3<<c<0c9Tc0<`c<`3<<c<0SHf=0<bIV@80SHf=00<0c9VI0:YEZP2ATI400P2ZEJX0
1`2ATI40/K6a0<bIV@3<VIT0ZUEE0<bIV@2ZEED00P3<VIT01`2ZEED0c9VI0:YEE@2ZEED0c9VI0:YE
E@3<VIT00P2I<iT01P2ATI40VC>I0<bIV@3<VIT0VC>I0<bIV@80ofJI00<0TI6A0?nZZP3<VIT00P3<
VIT01`3oojX0c9VI0?ooZP3oojX0c9VI0?ooZP3oIYT00P3oojX01`3oZUD0oonZ0?nZE@3oZUD0c3<c
0:YEE@3<<c<00P2ZEED01P2ZEJX0SHf=0<bIV@3<VIT0SHf=0<bIV@h0oooo0P00001T0?ooo`00B@3o
ool5000001X0oooo0`00000a0?ooo`<0VC>I0P2I<l`01P2I<iT0VC?<09TcV@2I<iT0EJZZ05EEZP80
EJZZ00<0EEFZ05FZZP0cI/`00P2ZEJX01`2I<iT0ZUD009Tc<`2I<c<0ZUD009Tc<`2I<fH00P2I<c<0
0`2I<fH0VC<c0:YEE@030:YEE@050<`c002ZE@00ZUD00<`c<`2ZEED00P3<<c<00`2ZEED0c3<c0:YE
E@020:YEE@060<`c003<V@00c3<00<`c003<VIT0ZUFZ0P3<VIT20:YEZP050?mVV@2ZEJX0ZUFZ0?mV
V@3oZZX00P3<VIT00`2ZEJX0SHf=0:YEZP0208f=S@80ZUFZ0P3<VIT00`2ZEJX0c9VI0:YEZP030:YE
ZPD0c9VI0`2ZEJX50<bIV@050:YEZP3<I/`0c6K<0<bIV@3oofH0203oc9T01P3<VFH0c9Tc06IVV@1V
IYT0EJZZ0<bIV@80ZUFZ00<0c9VI0:YEZP3oool03`3oool00`000000oooo0?ooo`1Q0?ooo`00B@3o
ool00`000000oooo0?ooo`0H0?ooo`@00000<P3oool2096AT@030:YEZP2ATI40ZUFZ0080TI6A00H0
IVJI096AT@1VIYT0IVJI0:YEZP2=SHd20:YEZP0308f=S@2ZEJX0ZUFZ0080TI6A00L0ZUFZ096AT@2I
<fH0VC=V0<`c003oIVH0ZUEE0080ofIV00L0ZUEE04i>CP2I<fH0VC=V04i>CP2I<fH0CTi>0080ZUEE
00@0OWin0:YEE@1nOWh0OWin0P2ZEED01@2I<fH0ZUEE0:YEE@3<<c<0c9Tc0080c9VI00L0SHf=0<bI
V@2=SHd0SHf=0<bIV@2ZEJX0TI6A0080ZUFZ00L0c9VI0;6a/@3<VIT0c9VI0:YEE@3<VIT0ZUEE0080
c9VI00L0ZUEE0<bIV@2ZEED0ZUEE0<bIV@2ZEED0c9VI0080ZUEE00H0TI6A09TcV@3<VIT0c9VI09Tc
V@3<VIT20?mVV@03096AT@3oIYT0c9VI0080ofJI00L0c9VI0:YEZP2ATI40TI6A0?mVV@3<VIT0ofJI
0080oonZ00L0ojYE0?ooZP3oZUD0ojYE0?ooZP2ZEED0c3<c0080VIW<00H0c9VI08f=S@3<VIT0c9VI
08f=S@3<VIT>0?ooo`<00000H`3oool004T0oooo1P00000C0?ooo`8000000`3oool00`000000oooo
0?ooo`0_0?ooo`H0VC>I0P2I<l`01P2I<iT0VC?<09TcV@2I<iT0EJZZ05EEZP80EJZZ00<0EEFZ05FZ
ZP2I<iT00P2ZEJX01`2I<iT0ZUFZ09TcV@2I<iT0ZUD009Tc<`2I<fH00P2I<c<00`2I<fH0ZUEE0:YE
E@060:YEE@040<`c<`2ZEED0c3<c0<`c<`H0ZUEE00D0c9T00:YEZP2ZEJX0c9VI0:YEZP020<bIV@03
0:YEZP3<VIT0ofJI0080ZUFZ00L0c9VI0?nZZP3<VIT0c9VI0:YEZP2=SHd0ZUFZ0080SHf=00L0olbI
0:YEZP3<VIT0c9VI0:YEZP3<VIT0ZUFZ00P0c9VI0`2ZEJX50<bIV@030:YEZP3<I/`0c6K<00D0c9VI
0P2ZEJX30<bIV@060<bIIP3<VC<0IVJI06IVV@2ZEJX0c9VI0P2ZEJX00`3<VIT0ZUFZ0?ooo`0@0?oo
o`030000003oool0oooo0600oooo00190?ooo`H000004`3oool2000000<0oooo00<000000?ooo`3o
ool0;`3oool609TcV@80VC?<00H0VC>I09Tcc02I<iT0VC>I05FZZP1EEJX205FZZP0305EEZP1EZZX0
VC>I0080ZUFZ00L0VC>I0:YEZP2I<iT0VC>I0:YE002I<c<0VC=V0080VC<c00<0VC=V0:YEE@2ZEED0
1P2ZEED0103<<c<0ZUEE0<`c<`3<<c<60:YEE@050<bI002ZEJX0ZUFZ0<bIV@2ZEJX00P3<VIT00`2Z
EJX0c9VI0?mVV@020:YEZP070<bIV@3oZZX0c9VI0<bIV@2ZEJX0SHf=0:YEZP0208f=S@070?o<V@2Z
EJX0c9VI0<bIV@2ZEJX0c9VI0:YEZP080<bIV@<0ZUFZ1@3<VIT00`2ZEJX0c6K<0<aVc0050<bIV@80
ZUFZ0`3<VIT01P3<VFH0c9Tc06IVV@1VIYT0ZUFZ0<bIV@80ZUFZ00<0c9VI0:YEZP3oool0403oool0
0`000000oooo0?ooo`1P0?ooo`00GP3oool4000003H0oooo00L0TI6A09TcV@2ATI40TI6A0:YEZP2A
TI40ZUFZ0080TI6A00H0IVJI096AT@1VIYT0IVJI0:YEZP2=SHd20:YEZP0308f=S@2ZEJX0ZUFZ0080
TI6A00L0ZUFZ096AT@2ZEJX0ZUFZ0:YEE@3oIVH0ZUEE0080ofIV00L0ZUEE04i>CP2I<fH0VC=V04i>
CP2I<fH0CTi>0080VC=V00@0OWin0:YEE@1nOWh0OWin0P2ZEED01@2I<fH0ZUEE0:YEE@2I<fH0c9W<
0080c9VI00L0SHf=0<bIV@2=SHd0SHf=0<bIV@2=SHd0TI6A0080/K6a00L0c9VI0;6a/@3<VIT0c9VI
0:YEE@3<VIT0ZUEE0080c9VI00L0VLbI0?nZZP2ZEED0ZUEE0<bIV@2ZEED0c9VI0080ZUEE00H0c9VI
09TcV@3<VIT0c9VI09TcV@3<VIT209TcV@03096AT@3oIYT0c9VI0080ofJI00L0c9VI0?mVV@2ATI40
TI6A0?mVV@3<VIT0ofJI0080c9VI00L0ofJI096AT@2ZEJX0ZUFZ0<bIV@2ZEJX0c9VI0080SHf=00H0
c9VI08f=S@3<VIT0c9VI08f=S@3<VITB0?ooo`800000H03oool005X0oooo1@00000g0?ooo`T0VC>I
0P2I<l`01P2I<iT0VC?<09TcV@2I<iT0VC?<05EEZP80EJZZ00<0SHf=07inOP2I<iT00P2ZEJX01`2I
<iT0ZUFZ09TcV@2I<iT0VC?<09Tc<`2I<fH00P2I<c<00`2I<fH0ZUEE0:YEE@040:YEE@80ZP1E00@0
?clo0:YEE@3<<c<0c3<c1P2ZEED01@2m_Kd0olc<0?o<c03<VIT0ZUFZ0080c9VI00<0ZUFZ0<bIV@3o
IYT00P3oZZX01`3<VIT0ojZZ0<bIV@3<VIT0ZUFZ08f=S@2ZEJX00P2=SHd01`3oc9T0VLbI0<bIV@3<
VIT0ZUFZ0<bIV@2ZEJX08@3<VIT0102ZEJX0c9VI0:YEZP2ZEJX20<bIV@030<bIIP3oool0oooo00l0
oooo0P00001P0?ooo`00E`3oool3000003X0oooo00H0VC>I096AT@2I<iT0VC>I096AT@2I<iT2096A
T@030:YEZP2ATI40ZUFZ0080TI6A00H0IVJI096AT@1VIYT0IVJI096AT@2=SHd20:YEZP030<bIIP2Z
EJX0c9UV0080TI6A00L0ZUFZ096AT@2ZEJX0ZUFZ096AT@1EEJX0ZUEE0080ofIV00L0ZUEE04i>CP2I
<fH0VC=V04i>CP2I<fH0VC<c0080VC=V00@0VC<c0:YEE@1nOWh0OWin0P2ZEED01@2I<fH0ZUEE0:YE
E@3oc9T0c9W<0080olbI00L0SHf=0<bIV@2=SHd0SHf=0<bIV@2=SHd0TI6A0080/K6a00L0c9VI0;6a
/@3<VIT0c9VI0:YEE@3<VIT0ZUEE0080ojZZ00L0VLbI0?nZZP2ZEED0ZUEE0<bIV@2ZEED0c9VI0080
c<c<00H0c9VI09TcV@3<VIT0c9VI09TcV@3<VIT209TcV@030<bIV@3oIYT0c9VI0080ofJI00L0c9VI
0?mVV@3<VIT0c9VI0?mVV@3<VIT0ofJI0080c9VI00L0ofJI0<bIV@2ZEJX0ZUFZ0<bIV@2ZEJX0c9VI
0080ojZZ00L0c9VI08f=S@3<VIT0c9VI08f=S@3oZZX0VLbI01<0oooo00<000000?ooo`3oool0G@3o
ool005L0oooo0`00000j0?ooo`0609TcV@2ATI40VC>I09TcV@2ATI40VC>I0P2ATI400`2ZEJX0TI6A
0:YEZP02096AT@0606IVV@2ATI40IVJI06IVV@2ATI40SHf=0P2ZEJX00`3<VFH0ZUFZ0<bIIP02096A
T@070:YEZP2ATI40ZUFZ0:YEZP2ATI40EEFZ0:YEE@020?mVIP070:YEE@1>CTh0VC=V09TcIP1>CTh0
VC=V09Tc<`0209TcIP0409Tc<`2ZEED0OWin07inOP80ZUEE00D0VC=V0:YEE@2ZEED0olbI0<bIc002
0?o<V@0708f=S@3<VIT0SHf=08f=S@3<VIT0SHf=096AT@020;6a/@070<bIV@2a/K40c9VI0<bIV@2Z
EED0c9VI0:YEE@020?nZZP0709W<V@3oZZX0ZUEE0:YEE@3<VIT0ZUEE0<bIV@020<c<c0060<bIV@2I
<iT0c9VI0<bIV@2I<iT0c9VI0P2I<iT00`3<VIT0ofJI0<bIV@020?mVV@070<bIV@3oIYT0c9VI0<bI
V@3oIYT0c9VI0?mVV@020<bIV@070?mVV@3<VIT0ZUFZ0:YEZP3<VIT0ZUFZ0<bIV@020?nZZP070<bI
V@2=SHd0c9VI0<bIV@2=SHd0ojZZ09W<V@0C0?ooo`030000003oool0oooo05d0oooo001C0?ooo`@0
0000?03oool?09TcV@0509Tcc02I<iT0VC>I09Tcc02=SHd00P1nOWh00`2=SHd0OWin08f=S@020:YE
ZP0709TcV@2ZEJX0VC>I09TcV@2I<l`0VC>I09Tcc00209Tc<`H0ZUEE00D0?clo0:X0E@2Z05D0?clo
0:X0E@020<`c<`D0ZUEE00H0olc<0;fm_@3oc<`0olc<0<bIV@2ZEJX20<bIV@030:YEZP3<VIT0c9VI
0080ojZZ00L0c9VI0?nZZP3<VIT0c9VI0?nZZP2=SHd0ZUFZ0080VLbI00L0olbI09W<V@3<VIT0c9VI
0:YEZP3<VIT0ZUFZ0080olbI00<0c<c<0<bIV@3<VIT0703<VIT0102ZEJX0c9VI0:YEZP2ZEJX20<bI
V@030<bIIP3oool0oooo00l0oooo0`00001O0?ooo`00D@3oool2000000<0oooo00<000000?ooo`3o
ool0>03oool209TcV@03096AT@2I<iT0TI6A0080VC>I00L0TI6A09TcV@2ATI40TI6A0:YEZP2ATI40
ZUFZ0080TI6A00H0IVJI096AT@1VIYT0IVJI096AT@3<VFH20:YEZP030<bIIP2ZEJX0c9UV0080TI6A
00L0ZUFZ096AT@2ZEJX0ZUFZ096AT@1EEJX0TI6A0080ZUFZ00L0VC=V04i>CP2I<fH0VC=V04i>CP2I
<fH0VC<c0080VC=V00L0VC<c09TcIP2I<c<0VC<c09TcIP2ZEED0VC=V0080ZUEE00H0olbI0<bIc03o
c9T0olbI08f=S@3<VIT208f=S@030<bIV@2=SHd0c9VI0080/K6a00L0c9VI0;6a/@3<VIT0c9VI0;6a
/@3<VIT0VLbI0080ojZZ00L0VLbI0?nZZP2ZEED0ZUEE0<bIV@2ZEED0c9VI0080c<c<00H0olbI09Tc
V@3<VIT0c9VI09TcV@3<VIT20<bIIP030<bIV@3oIYT0c9VI0080ofJI103<VIT00`3oIYT0c9VI0?mV
V@020<bIV@070:6QX@3<VIT0ZUFZ0:YEZP3<VIT0ZUFZ0?o<V@020?nZZP070<bIV@2=SHd0c9VI0<bI
V@2=SHd0ojZZ09W<V@0D0?ooo`030000003oool0oooo0280oooo1000000f0?ooo`00C@3oool40000
03l0oooo4P2I<iT01@2I<l`0VC>I09TcV@3<09T0SHf=0080OWin00<0SHf=07inOP2=SHd00P2ZEJX0
1`2I<iT0ZUFZ09TcV@2I<iT0ZUFZ09TcV@3oIYT00P2ZEJX00`3oIYT0ZUEE0:YEE@030:YEE@0503lo
?`2Z05D0ZP1E03lo?`2Z05D00P0o?cl30:YEE@80_Kfm00H0olc<0;fm_@3oc<`0olc<0<bIV@2ZEJX2
0<bIV@030:YEZP3oc9T0Z_mE0080ojZZ00L0c9VI0?nZZP3<VIT0c9VI0?nZZP2=SHd0olbI0080VLbI
00L0olbI09W<V@3<VIT0c9VI0:YEZP3<VIT0c<c<0080olbI00<0c<c<0<bIV@3<VIT00`3<VIT30?nZ
ZPD0c9VI00<0oonZ0?nZZP3oZZX01@3<VIT00`3oc9T0ojZZ0<bIV@060<bIV@040:YEZP3<VIT0ZUFZ
0:YEZP80c9VI00<0c9UV0?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03D0oooo000H0?ooo`@000001@3oool3000002D0oooo100000120?ooo`0709TcV@2ATI40VC>I
09TcV@2ATI40VC>I096AT@0209TcV@07096AT@2I<iT0TI6A096AT@2ZEJX0TI6A0:YEZP02096AT@06
06IVV@2ATI40c9VI0<bIV@2ATI40c9UV0P2ZEJX00`3<VFH0ZUFZ0<bIIP02096AT@070:YEZP2ATI40
ZUFZ0:YEZP2ATI40EEFZ096AT@020:YEZP07096AT@2ZEJX0VC=V09TcIP1>CTh0VC=V09Tc<`0209Tc
IP0709Tc<`2I<fH0VC<c09Tc<`030`<0ZUEE09TcIP020<bIc0060?o<V@3<VL`0olbI0?o<V@2=SHd0
c9VI0P2=SHd00`3<VIT0VLbI0<coV@020;6a/@070<bIV@2a/K40c9VI0<bIV@2a/K40c9VI09W<V@02
0?nZZP0709W<V@3oZZX0ZUEE0:YEE@3<VIT0ZUEE0?o<V@020<c<c0060?o<V@2I<iT0c9VI0<bIV@2I
<iT0oonZ0P3<VFH00`3oojX0ofJI0<bIV@020?mVV@80c9VI0P3oc9T00`3oIYT0c9VI0?mVV@020<bI
V@070:6QX@3oc9T0ZUFZ0:YEZP3<VIT0ZUFZ0?o<V@020?nZZP070?o<V@2=SHd0c9VI0<bIV@2Ic9T0
ojZZ09W<V@020?nZZQ<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d0?ooo`00
603oool4000000D0oooo0`00000U0?ooo`@00000@P3oool01`2I<iT0TI6A09TcV@2I<iT0TI6A09Tc
V@2ATI400P2I<iT01`2ATI40VC>I096AT@2ATI40ZUFZ096AT@2ZEJX00P2ATI401P1VIYT0TI6A0<bI
V@3<VIT0TI6A0<bIIP80ZUFZ00<0c9UV0:YEZP3<VFH00P2ATI401`2ZEJX0TI6A0:YEZP2ZEJX0TI6A
05EEZP2ATI400P2ZEJX01`2ATI40ZUFZ09TcIP2I<fH0CTi>09TcIP2I<c<00P2I<fH01`2I<c<0VC=V
09Tc<`2I<c<00`<30:YEE@2I<fH00P3<VL`01P3oc9T0c9W<0?o<V@3oc9T0SHf=0<bIV@80SHf=00<0
c9VI09W<V@3<oiT00P2a/K401`3<VIT0/K6a0<bIV@3<VIT0/K6a0<bIV@2Ic9T00P3oZZX01`2Ic9T0
ojZZ0:YEE@2ZEED0c9VI0:YEE@3oc9T00P3<c<`01P3oc9T0VC>I0<bIV@3<VIT0VC>I0?ooZP80c9UV
00<0oonZ0?mVV@3<VIT00P3oIYT20<bIV@80olbI00<0ofJI0<bIV@3oIYT00P3<VIT01`2QXJ40olbI
0:YEZP2ZEJX0c9VI0:YEZP3oc9T00P3oZZX01`3oc9T0SHf=0<bIV@3<VIT0VLbI0?nZZP2Ic9T00P3o
ZZXC0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=03oool001T0oooo0P000005
0?ooo`050000003oool0oooo0?ooo`0000008@3oool3000000@0oooo00<000000?ooo`3oool0?@3o
oolE09TcV@0509Tcc02ZEJX0ZUFZ0<`0V@2ZEJX00P1nOWh00`2=SHd0OWin08f=S@020:YEZP0409Tc
V@2ZEJX0VC>I09TcV@80ZUFZ00D0ofJI0:YEZP2ZEJX0ofJI0:YEZP0208f=S@030:YEE@2Z05D0?clo
0080ZP1E00L0?clo0:X0E@030`<00`<30140002ZEJX0olc<0080_Kfm00H0olc<0;fm_@3oc<`0olc<
0;fm_@2ZEJX20<bIV@030:[oE@3oc9T0Z_mE0080ojZZ00L0c9VI0?nZZP3<VIT0c9VI0?nZZP2Ic9T0
olbI0080VLbI00L0olbI09W<V@3oc9T0olbI0:YEZP3oc9T0c<c<0080olbI00<0c<c<0<bIV@3<VIT0
0P3<VIT40?nZZP@0c9VI00@0ojZZ0?ooZP3oZZX0ojZZ0`3<VIT20?nZZP030?o<V@3oZZX0c9VI00P0
c9VI0P2ZEJX00`3<VFH0c9VI0<bIIP020<bIV@0309Tc003oool0oooo0140oooo0`00000S0?ooo`03
0000003oool0oooo03@0oooo000?0?ooo`H00000103oool2000000D0oooo00D000000?ooo`3oool0
oooo0000000N0?ooo`<00000A@3oool01P2ATI40VC>I096AT@2ATI40VC>I096AT@80VC>I00<0TI6A
09TcV@2ATI400P2I<iT01`2ATI40VC>I096AT@2ATI40ZUFZ096AT@2ZEJX00P2ATI401P1VIYT0TI6A
0<bIV@3<VIT0TI6A0<bIV@80ZUFZ00<0c9UV0:YEZP3<VFH00P2ATI401`2ZEJX0TI6A0:YEZP2ZEJX0
TI6A0:YEZP2ATI400P2ZEJX01`2ATI40ZUFZ0:YEZP2ZEJX0c9UV09TcIP2I<c<00P2I<fH0102I<c<0
VC=V0140000A00020<bIV@05096AT@3<VL`0c9W<0?o<V@3<VL`00P3oc9T01`3<VL`0c9VI09W<V@2I
c9T0c9VI096AT@3<oiT00P2a/K401`3<VIT0/K6a0<bIV@3<VIT0ZUFZ00<30`2Ic9T00P3oZZX01`2I
c9T0ojZZ09W<V@2Ic9T0c9VI0<c<c03oc9T00P3<c<`01P3oc9T0c<c<0<bIV@3<VIT0VC>I0?ooZP80
c9UV00<0oonZ0?mVV@3<VIT00P3oIYT01`3oc9T0c9VI0?o<V@3oc9T0ofJI0<bIV@3oIYT00P3oc9T0
1`2QXJ40olbI0:YEZP2ZEJX0c9VI0?nZZP3oc9T00P3oZZX01`3oc9T0SHf=0<bIV@3<VIT0VLbI0?nZ
ZP2Ic9T00P3oZZX01@3<<`00VC<00<bI<`3<VC<0ofHc0140oooo00<000000?ooo`3oool0803oool0
0`000000oooo0000000e0?ooo`006@3oool2000000D0oooo00D000000?ooo`3oool0oooo0000000K
0?ooo`D00000A@3ooolG09TcV@060:YEZP3<09T0ZUFZ0:YEZP3<09T0ZUFZ0P1nOWh00`2=SHd0OWin
08f=S@020:YEZP0309TcV@2ZEJX0VC>I0080VC>I00H0ZUFZ0?mVV@2ZEJX0ZUFZ0?mVV@2ZEJX508f=
S@80ZUFZ00L0?clo0:X0E@2I<iT0VC>I08f=S@2ZEJX0c02I0080ZUFZ00H0olc<0;fm_@3oc<`0olc<
0;fm_@2ZEJX209TcV@0308f=S@2I<iT0SHf=0080olbI00L0c9VI0?nZZP2=SHd0SHf=0:YEZP030`<0
olbI0080VLbI00L0olbI09W<V@3oc9T0olbI0:YEZP3oc9T0c<c<0080olbI00@0c<c<0?o<V@3<VIT0
c9VI1@3oZZX40<bIV@040?nZZP3oojX0ojZZ0?nZZP<0c9VI0P3oZZX00`3oc9T0ojZZ0<bIV@080<bI
V@80ZUFZ00<0c9UV0<bIV@3<VFH00P3<VIT209Tc0080ZUEE00<0ZUD00<bI003oool03`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0000003D0oooo000I0?ooo`8000001@3oool01@000000
oooo0?ooo`3oool0000001/0oooo1@0000150?oooaL0VC>I00H0ZUFZ0<`0V@2ZEJX0ZUFZ0<`0V@2Z
EJX207inOP0308f=S@1nOWh0SHf=0080ZUFZ00<0VC>I0:YEZP2I<iT00P2I<iT01P2ZEJX0ofJI0:YE
ZP2ZEJX0ofJI0:YEZPD0SHf=0P2ZEJX01`0o?cl0ZP1E09TcV@2I<iT0SHf=0:YEZP3<09T00P2ZEJX0
1P3oc<`0_Kfm0?o<c03oc<`0_Kfm0:YEZP80VC>I00<0SHf=09TcV@2=SHd00P3oc9T01`3<VIT0ojZZ
08f=S@2=SHd0ZUFZ00<30`3oc9T00P2Ic9T01`3oc9T0VLbI0?o<V@3oc9T0ZUFZ0?o<V@3<c<`00P3o
c9T0103<c<`0olbI0<bIV@3<VIT50?nZZP@0c9VI00@0ojZZ0?ooZP3oZZX0ojZZ0`3<VIT20?nZZP03
0?o<V@3oZZX0c9VI00P0c9VI0P2ZEJX00`3<VFH0c9VI0<bIIP020<bIV@80VC<00P2ZEED00`2ZE@00
c9T00?ooo`0?0?ooo`030000003oool0oooo0200oooo00<000000?ooo`000000=@3oool001T0oooo
0P0000050?ooo`050000003oool0oooo0?ooo`0000005`3oool4000004P0oooo0P2ATI400`2I<iT0
TI6A09TcV@02096AT@0709TcV@2ATI40VC>I09TcV@2ATI40VC>I096AT@0209TcV@07096AT@2I<iT0
TI6A096AT@2I<iT0TI6A0:YEZP02096AT@060<bIV@2ATI40c9VI0<bIV@2ATI40c9VI0P2ZEJX00`3<
VFH0ZUFZ0<bIIP030:YEZP06096AT@2ZEJX0ZUFZ0<bIV@2ZEJX0TI6A0P2ZEJX01`2ATI40ZUFZ0:YE
ZP2ZEJX0c9UV0:YEZP3<VFH00P3<VIT01@2ATI40c9VI096AT@2ATI40c9VI0080TI6A0`3<VIT01@2A
TI40c9VI0<bIV@2ATI40c9VI0080TI6A00<0c9VI096AT@3<VIT00P3oIVH01`3<VIT0ofIV0<bIV@3<
VIT0ofIV096AT@2Ic9T00P3oZZX01`2Ic9T0ojZZ06IVV@1VIYT0UIFE0<c<c03oc9T00P3<c<`01P3o
c9T0c<c<0<bIV@3<VIT0c9UV0?ooZP80c9UV00<0oonZ0<bIIP3<VIT00P3<VIT0103oc9T0c9VI0?o<
V@3oc9T20<bIV@050:6QX@3oc9T0olbI0:6QX@3oc9T00P2QXJ400`3<VIT0ojZZ0?o<V@020?nZZP07
0?o<V@3oZZX0c9VI0<bIV@2Ic9T0ojZZ09W<V@020?nZZP060<`c002I<`00VIUV09VIIP3oIS<0c9Tc
0P2ZE@000`2I<`00oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo0`000000103oool00000
00000000000c0?ooo`00603oool3000000D0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`80
0000BP3oool00`29RHT0VC>I09TcV@0F09TcV@80ofJI00H0ZUFZ0<`0V@2ZEJX0ZUFZ0<`0V@2ZEJX2
07inOP0308f=S@1nOWh0SHf=0080OWin00L0VC>I0:YEZP2ATI40TI6A09TcV@2ATI40ofJI0080ZUFZ
00<0ofJI0:YEZP2=SHd00`2=SHd01@3<VIT0ZUFZ0:YEZP3<VIT0SHf=0080VC>I00<0SHf=09TcV@3<
09T00P3<VIT00`2I<iT0c9VI09TcV@0209TcV@0608f=S@2I<iT0VC>I08f=S@3<VIT0SHf=0P2ZEJX0
1`2=SHd0ZUFZ08f=S@2=SHd0ZUFZ0?mVV@3<VIT00P2Ic9T01`3<VIT0ZUFZ0?mVV@3oIYT0ZUFZ0<bI
V@3<c<`00P3oc9T0103<VIT0TI6A09TcV@2I<iT60?nZZP050<bIV@3oojX0oonZ0?nZZP3oojX00P3o
ZZX00`3oojX0c9VI0?o<V@020?nZZP040?o<V@3oZZX0olbI0?o<V@T0c9VI00<0c9UV0<bIV@3<VFH0
0P3<VIT01P3oojX0c9Tc0:YEE@2ZEED0ZUD00<bI0080ZUD000<0c3<009Tc003<<`003@3oool20000
05L0oooo000I0?ooo`8000001P3oool300000180oooo100000000`3oool000000?ooo`160?ooo`03
09TcV@29RHT0RHV90080VC>I0P2ATI400`2I<iT0TI6A09TcV@02096AT@0709TcV@2ATI40VC>I09Tc
V@2ATI40VC>I096AT@0209TcV@07096AT@2I<iT0TI6A096AT@2I<iT0TI6A09TcV@02096AT@060<bI
V@2ATI40c9VI0<bIV@2ATI40c9VI0P2ZEJX00`3<VFH0ZUFZ0<bIIP030:YEZP060<bIV@2I<l`0VC?<
0<bIV@2I<l`0TI6A0P2ZEJX01`2ATI40ZUFZ096AT@2ATI40c9UV0:YEZP1VIYT00P3<VIT01@1VIYT0
c9VI096AT@2ATI40c9VI00@0TI6A00H0c9VI096AT@3<VIT0c9VI096AT@3<VIT2096AT@030<bIV@3<
VL`0c9VI0080ofIV00L0c9VI0?mVIP3<VIT0c9VI0?mVIP2ATI40ZUEE0080c9VI00L0ZUEE0<bIV@2Z
EED0ZUEE09FEU@2I<iT0c9VI0080VC>I00H0c9VI09Tcc03<VIT0c9VI0?mVV@3oojX20<bIIP030?oo
ZP3<VFH0c9VI0080c9VI00@0olbI0<bIV@3oc9T0olbI0P3<VIT01@2QXJ40olbI0?o<V@2QXJ40olbI
0080XJ6Q00<0olbI0?nZZP3oc9T00P3oZZX01`3oc9T0ojZZ0?nZZP3oZZX0VLbI0?nZZP2Ic9T00`3o
c9T01@3oIS<0VIUV09VIIP3oIS<0c9Tc0080ofHc00<0VC<00:YE002I<`000P2ZE@000`0cI/`0/K6a
0?ooo`080?ooo`<000002@3oool2000004/0oooo000b0?ooo`@00000;03oool00`0cI/`0IVJI05FZ
ZP0206IVV@@0VC>I5@3oool208V9R@0508f=S@29RHT0SHf=08f=S@29RHT05`2I<iT01@2ZEJX0ofJI
0?mVV@2ZEJX0c02I0080ZUFZ00L0c02I0:YEZP1nOWh0OWin08f=S@1nOWh0SHf=0080OWin0P2I<iT2
096AT@0309TcV@2ATI40ofJI0080ZUFZ00@0ofJI0:YEZP3oIYT0ofJI0P2=SHd01@3<VIT0ZUFZ0:YE
ZP3<VIT0SHf=0080VC>I00<0SHf=09TcV@3<09T00P3<VIT00`2I<iT0c9VI09TcV@0209TcV@0408f=
S@2I<iT0VC>I08f=S@80c9VI0P2ZEJX0102=SHd0ZUFZ08f=S@2=SHd20:YEZP050<bIV@2ZEJX0ZUFZ
0<bIV@2ZEJX00P3<VIT00`2ZEJX0c9VI0<bIV@030<bIV@03096AT@2I<iT0VC>I00@0c9VI00<0VC>I
096AT@3oIYT00P3<VIT01`3oZZX0oonZ0?mVV@3oIYT0c9VI0?nZZP3oc9T00P3oZZX0103oc9T0ojZZ
01<C4`0C4a<90<bIV@030<bIIP3<VIT0c9UV0080olbI00H0oonZ0?mV<`2ZEED0ZUEE0<bI<`3<V@02
0:YE00030<bI002I<`00c3<00080VC<000<0ZUFZ0<bIc03oool02P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00800000B@3oool00380oooo1000000/0?ooo`0303=Vc01VIYT0EJZZ
0080IVJI102I<iTE0?ooo`80RHV900D0SHf=08V9R@2=SHd0SHf=08V9R@0G09TcV@050:YEZP3oIYT0
ofJI0:YEZP3<09T00P2ZEJX01`3<09T0ZUFZ07inOP1nOWh0SHf=07inOP2=SHd00P1nOWh209TcV@80
TI6A00<0VC>I096AT@3oIYT00P2ZEJX0103oIYT0ZUFZ0?mVV@3oIYT208f=S@050<bIV@2ZEJX0ZUFZ
0<bIV@2=SHd00P2I<iT00`2=SHd0VC>I0<`0V@020<bIV@0309TcV@3<VIT0VC>I0080VC>I00@0SHf=
09TcV@2I<iT0SHf=0P3<VIT20:YEZP0408f=S@2ZEJX0SHf=08f=S@80ZUFZ00D0c9VI0:YEZP2ZEJX0
c9VI0:YEZP020<bIV@030:YEZP3<VIT0c9VI00<0c9VI00<0TI6A09TcV@2I<iT0103<VIT00`2I<iT0
TI6A0?mVV@020<bIV@070?nZZP3oojX0ofJI0?mVV@3<VIT0ojZZ0?o<V@020?nZZP040?o<V@3oZZX0
4a<C01<C4`T0c9VI00<0c9UV0<bIV@3<VFH00P3oc9T01P3oojX0ofHc0:YEE@2ZEED0c9Tc0<bI0080
ZUD000<0c9T009Tc003<<`000P2I<`000`2ZEJX0c9W<0?ooo`0:0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P0000190?ooo`00;`3oool5000002X0oooo00L0c9W<0:YEZP2IVL`0
VIW<0:YEZP2ATI40VC>I0080TI6A00L0IVJI07IfMP1VIYT0IVJI07IfMP1VIYT0VC=V0080IVJI2`3o
ool209TcV@03096AT@2I<iT0IVJI0080VC>I00@0RHV909TcV@29RHT0RHV90P2I<iT2096AT@0309Tc
V@2ATI40VC>I0080TI6A00L0VC>I096AT@2I<iT0VC>I096AT@2I<iT0TI6A0080VC>I00L0TI6A09Tc
V@2ATI40TI6A09TcV@2ATI40VC>I0080TI6A00H0VC>I096AT@3<VIT0c9VI096AT@3<VIT20:YEZP03
0<bIIP2ZEJX0c9UV0080ZUFZ00L0VC?<0<bIV@2I<l`0VC?<0<bIV@2I<l`0TI6A0080ZUFZ00L0TI6A
0:YEZP2ATI40TI6A0<bIIP3<VIT0IVJI0080c9VI00L0IVJI0<bIV@2ATI40TI6A0<bIV@2ATI40c9VI
0080TI6A00H0c9VI096AT@3<VIT0c9VI096AT@3<VIT2096AT@030<bIV@3<VL`0c9VI0080ofIV00L0
c9VI0?mVIP3<VIT0c9VI0?mVIP3<VIT0ZUEE0080c9VI00L0ZUEE0<bIV@2ZEED0ZUEE09FEU@2I<iT0
c9VI0080VC>I00H0c9VI09Tcc03<VIT0c9VI0?mVV@3<VIT20?mVV@030<bIV@2I<l`0c9VI0080VIUV
00L0c9VI09VIIP3<VIT0c9VI0:YEZP3<VIT0XJ6Q0080olbI00L0XJ6Q0<bIV@0c03<0<`0c0140003o
ZZX0olbI0080ojZZ00L0olbI0:ZZE@3<ofH0c?mV09W<V@3oZZX0VLbI00@0olbI0P2IVFH01`3oIS<0
VIUV0?mV<`3oIS<0c9Tc0:YE002I<`000P2ZE@00102IVL`0/K6a0<bIV@3<VIT:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P0000190?ooo`00:`3oool4000002d0oooo0P2IVOl0
1`3<VL`0<fK<08f=S@2=SHd0<fK<06IVV@1EZZX00P1VIYT>09TcV@0607inOP1VIYT0OWin07inOP1V
IYT0OWin0P1VIYT00`1nOWh0RHV908F5Q@0208V9R@0508f=S@29RHT0SHf=08f=S@29RHT05P2I<iT0
1P3oIYT0ZUFZ0?mVV@3oIYT0ZUFZ0<`0V@80ZUFZ00L0c02I0:YEZP1nOWh0OWin08f=S@1nOWh0SHf=
0080OWin00L0TI6A09TcV@2ATI40TI6A09TcV@2ATI40ofJI0080ZUFZ00L0ofJI0:YEZP3oIYT0ofJI
08f=S@2ZEJX0c9VI0080ZUFZ00D0c9VI08f=S@2I<iT0VC>I08f=S@0209TcV@80c9VI00<0VC>I0<bI
V@2I<iT00P2I<iT00`2=SHd0VC>I09TcV@030<bIV@80ZUFZ00L0SHf=0:YEZP2=SHd0SHf=0?nZZP2Z
EJX0c9VI0080ZUFZ00<0c9VI0:YEZP3<VIT0203<VIT209TcV@D0c9VI00H0TI6A0?mVV@3<VIT0c9VI
0?mVV@3<VIT20?mVV@<0c9VI0P3oZZX01@3<VIT0olbI0<bIV@3<VIT0<`0000@0c9VI00L0XJ6Q09W<
IP2QXJ40XJ6Q0<bIIP3<VIT0oonZ0080olbI00H0oonZ0?o<V@3<<c<0c3<c0<bI<`2ZEED20:YE0003
0<bI002ZE@00c3<00080c9W<00<0ZUFZ09fMW@2MWId00P2MWId90?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P0000190?ooo`00:@3oool200000300oooo00D0c9W<0;Vi^@2i^KT0
c9W<0:YEZP0209VIc0030:YEZP2ATI40VC>I0080TI6A00L0IVJI07IfMP1VIYT0IVJI07IfMP1VIYT0
VC=V0080IVJI00L0VIUV06IVV@2IVFH0VIUV06IVV@1EZZX0VC>I0080EJZZ00L0VC>I096AT@2I<iT0
VC>I096AT@2I<iT0IVJI0080VC>I00@0RHV909TcV@29RHT0RHV90P2I<iT2096AT@0309TcV@2ATI40
VC>I0080TI6A00L0VC>I096AT@2I<iT0VC>I096AT@2I<iT0TI6A0080VC>I00L0TI6A09TcV@2ATI40
TI6A0?mVIP2ATI40VC>I0080TI6A00H0VC>I096AT@3<VIT0c9VI096AT@3<VIT2096AT@030<bIIP2Z
EJX0c9UV0080c9VI00L0VC?<0<bIV@2I<l`0VC?<0<bIV@2I<l`0TI6A0080ZUFZ00L0TI6A0:YEZP2A
TI40TI6A06IVV@3<VIT0IVJI0080c9VI00L0IVJI0<bIV@2ATI40TI6A0<bIV@2MWId0ojZZ0080TI6A
00H0c9VI096AT@3<VIT0c9VI096AT@3<VIT2096AT@030<bIV@3<VL`0c9VI0080ofIV00L0c9VI0?mV
IP3<VIT0c9VI0;Fe]@3<VIT0ZUEE0080c9VI00L0ZUEE0<bIV@2ZEED0ZUEE0<bIV@2I<iT0c9VI0080
VC>I00H0c9VI09TcV@3<VIT0c9VI0?mVV@3<VIT20?mVV@030<bIV@2IVFH0c9VI0080VIUV00L0c9VI
09VIIP3<VIT0c9VI0:YEZP3<VIT0ZUFZ0080c9VI00<0c9UV0<bIV@3<VIT00P3<VIT01P3oZZX0olbI
0?nZZP3oZZX0c9VI0:ZZE@80c?mV00<0VLbI0?nZZP3oc9T0103oc9T209VIIP070?mV<`2IVFH0ofHc
0?mV<`3<VC<0ofHc09VIc0020;6a/@0509VIc03oZZX0c9VI0<bIV@3oZZX02P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00800000B@3oool002T0oooo0P00000`0?ooo`050<bIc02i
^KT0^KVi0<bIc02ZEJX00P2IVL`00`2ZEJX0TI6A09TcV@02096AT@0706IVV@1fMWH0IVJI06IVV@1f
MWH0IVJI09TcIP0206IVV@0709VIIP1VIYT0VIUV09VIIP1VIYT0EJZZ09TcV@0205FZZP0709TcV@2A
TI40VC>I09TcV@2ATI40VC>I06IVV@0209TcV@0408V9R@2I<iT0RHV908V9R@80VC>I0P2ATI400`2I
<iT0TI6A09TcV@02096AT@0709TcV@2ATI40VC>I09TcV@2ATI40VC>I096AT@0209TcV@07096AT@2I
<iT0TI6A096AT@3oIVH0TI6A09TcV@02096AT@0609TcV@2ATI40c9VI0<bIV@2ATI40c9VI0P2ATI40
0`3<VFH0ZUFZ0<bIIP020<bIV@0709Tcc03<VIT0VC?<09Tcc03<VIT0VC?<096AT@020:YEZP07096A
T@2ZEJX0TI6A096AT@1VIYT0c9VI06IVV@020<bIV@0706IVV@3<VIT0TI6A096AT@3<VIT0WIfM0?nZ
ZP02096AT@060<bIV@2ATI40c9VI0<bIV@2ATI40c9VI0P2ATI400`3<VIT0c9W<0<bIV@020?mVIP07
0<bIV@3oIVH0c9VI0<bIV@2e]KD0c9VI0:YEE@020<bIV@070:YEE@3<VIT0ZUEE0:YEE@3<VIT0VC>I
0<bIV@0209TcV@060<bIV@2I<iT0c9VI0<bIV@3oIYT0c9VI0P3oIYT00`3<VIT0VIUV0<bIV@0209VI
IP070<bIV@2IVFH0c9VI0<bIV@2ZEJX0c9VI0:YEZP020<bIV@030<bIIP3<VIT0c9VI0080c9VI00H0
ojZZ0?o<V@3oZZX0ojZZ0<bIV@2ZZUD20<coIP0309W<V@3oZZX0olbI00@0olbI0P2IVFH01`3oIS<0
VIUV0?mV<`3oIS<0c9Tc0?mV<`2IVL`00P2a/K401@2IVL`0ojZZ0<bIV@3<VIT0ojZZ00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`02000004T0oooo000U0?ooo`@000000P3oool2
000002d0oooo00H0VIWo0<bIc02IVOl0VIWo0<bIc00cI/`208f=S@0303=Vc01VIYT0EJZZ0080IVJI
00<0EJZZ09TcV@2I<iT02`2I<iT01P1nOWh0IVJI07inOP1nOWh0IVJI07inOP80IVJI00<0OWin08V9
R@25QHD00P29RHT01@25QHD0RHV908f=S@2=SHd0RHV901<0VC>I0P2ZEJX00`3<I/`0ofJI0:YEZP02
0?mVV@060:YEZP3<09T0ZUFZ0:YEZP3<09T0ZUFZ0P3<09T00`2=SHd0OWin08f=S@020<aVc0070:6Q
X@2I<iT0TI6A096AT@2I<iT0TI6A0?mVV@020:YEZP070?mVV@2ZEJX0ofJI0?mVV@3<VIT0ZUFZ0<bI
V@020:YEZP060<bIV@2=SHd0VC>I09TcV@2=SHd0ZJVY0`3<VIT01P2I<iT0c9VI09TcV@2I<iT0c9VI
08f=S@D0c9VI0P2ZEJX01`2=SHd0ZUFZ08f=S@2=SHd0ojZZ0?o<V@3<VIT00P2ZEJX00`3<VIT0ZUFZ
0<bIV@0@0<bIV@050?mVV@3<VIT0c9VI0?mVV@3<VIT00P3oIYT50<bIV@050?nZZP3oc9T0c9VI0<bI
V@2ZEJX00P3<VIT20?nZZP070<bIIP3oZZX0ZUFZ0:YEZP2Ic6H0c9VI0?ooZP020?o<V@060?ooZP3o
c9T0oonZ0?ooZP3oIS<0ZUEE0P3<VC<00`3<V@00ZUD00:YEZP020<bIc0030:YEZP2MWId0WIfM0080
WIfM00<0c9VI0?ooo`3oool01P3oool4000000@0oooo00<000000?ooo`3oool00P0000190?ooo`00
8@3oool4000003<0oooo0P3<oiT01P3<ol`0c9W<0;Vi^@2i^KT0c9W<0;Vi^@80VIW<00<0ZUFZ096A
T@2I<iT00P2ATI401`2I<iT0MWIf06IVV@1VIYT0MWIf06IVV@2I<fH00P1VIYT01`2IVFH0IVJI09VI
IP2IVFH0IVJI05FZZP2I<iT00P1EZZX01`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@1VIYT00P2I<iT0
101VIYT0VC>I08V9R@29RHT209TcV@80TI6A00<0VC>I096AT@2I<iT00P2ATI401`2I<iT0TI6A09Tc
V@2I<iT0TI6A09TcV@2ATI400P2I<iT01`2ATI40ofIV096AT@2ATI40ofIV096AT@2I<iT00P2ATI40
1P2I<iT0TI6A0<bIV@3<VIT0TI6A0<bIV@80TI6A00<0c9UV0:YEZP2ZEJX00P3<VIT01`2ZEJX0c9VI
09Tcc02I<l`0c9VI09Tcc02ATI400P2ZEJX01`2ATI40ZUFZ0?nZZP3oZZX0IVJI0<bIV@1VIYT00P3<
VIT01`1VIYT0c9VI096AT@2ATI40c9VI09fMW@3oZZX00P2ATI401P3<VIT0TI6A0<bIV@3<VIT0TI6A
0<bIV@80c9W<00<0c9VI0<bIc03<VIT00P3oIVH01`3<VIT0ofIV0<bIV@3<VIT0]KFe0<bIV@2ZEED0
0P3<VIT01`2ZEED0c9VI0?o<V@3oc9T0c9VI09TcV@3<VIT00P2I<iT01P3<VIT0VC>I0<bIV@3<VIT0
ofJI0<bIV@80ofJI00<0c9VI09VIIP3<VIT00P2IVFH01`3<VIT0VIUV0?nZZP3oZZX0c9UV0<bIV@2Z
EJX00P3<VIT0103<VFH0c9VI0<bIIP3<VFH90<bIV@030?mVV@3oc9T0olbI00H0olbI00L0ZUEE09VI
IP3oIS<0ofHc0<bI<`3oIS<0VIW<0080/K6a00H0c9VI0?nZZP3<VIT0c9VI0?nZZP3<VC<:0?ooo`80
00001@3oool2000004/0oooo000N0?ooo`@00000=@3oool01@3oojX0c?nI0<coV@3oojX0c9W<0080
VIWo00L0c9W<09VIo`2=SHd0SHf=03=Vc02=SHd0EJZZ0080IVJI00<0EJZZ09TcV@2I<iT02`2I<iT0
1P1nOWh0IVJI07inOP1nOWh0IVJI07inOP80IVJI00<0OWin08V9R@25QHD00P29RHT01@25QHD0RHV9
08f=S@2=SHd0RHV90140VC>I00L0ZUFZ0<aVc02ZEJX0ZUFZ0<aVc03oIYT0ZUFZ0080ofJI00H0ZUFZ
0<`0V@2ZEJX0ZUFZ0<`0V@2ZEJX20<`0V@0308f=S@3<I/`0XJ6Q0080c6K<00L0XJ6Q09TcV@2ATI40
TI6A09TcV@2ATI40VC>I0080ZUFZ00L0ofJI0:YEZP2UYJD0YJFU0:VYZ@2ZEJX0c9VI0080ZUFZ00H0
c9VI0:YEZP2I<iT0VC>I0<bIV@2YZJT30<bIV@0609TcV@3<VIT0VC>I09TcV@3<VIT0SHf=1@3<VIT2
0:YEZP0708f=S@2ZEJX0olbI0?o<V@3oZZX0olbI0<bIV@020:YEZP050<bIV@2ZEJX0c9VI0<bIV@3<
oiT01@3<VIT00`3oZZX0c9VI0<bIV@060<bIV@050?mVV@3<VIT0c9VI0?mVV@3<VIT00P3<ofH50<bI
V@070?nZZP3oc9T0ojZZ0?nZZP2ZEJX0c9VI0<bIIP020?nZZP030<bIIP3oZZX0c9VI00<0c9VI00D0
oonZ0?o<V@3oc9T0oonZ0?o<V@0203<000070?mV<`2ZEED0c9Tc0<bI<`2ZEED0c9VI0:YEZP020<bI
c0@0WIfM00<0/K6a0<bIV@2a/K402`3oool00`000000oooo0?ooo`1?0?ooo`006`3oool3000000@0
oooo0P00000b0?ooo`060<coV@2IVL`0VC>I09TcV@1VIYT0VC>I0P2i^KT01`3<VL`0^KVi09VIc02I
VL`0ZUFZ09VIc02I<iT00P2ATI401`2I<iT0MWIf06IVV@1VIYT0MWIf06IVV@2I<fH00P1VIYT01`2I
VFH0IVJI09VIIP2IVFH0IVJI05FZZP2I<iT00P1EZZX01`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@1V
IYT00P2I<iT01P1VIYT0VC>I08V9R@29RHT0VC>I08V9R@80TI6A00<0VC>I096AT@2I<iT00P2ATI40
1`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@2ATI400P3<VIT01`2ATI40ofIV096AT@2ATI40ofIV096A
T@2I<iT00P2ATI401P2I<iT0TI6A0<bIV@3<VIT0TI6A0<bIV@80TI6A00<0c9UV0<bIV@2ZEJX00P3<
VIT01`2ZEJX0c9VI09Tcc02I<l`0c9VI09Tcc03<VIT00P2ZEJX01`2ATI40VIW<0?nZZP3oZZX0VIW<
0<bIV@1VIYT00P3<VIT01`1VIYT0c9VI096AT@2ATI40ojZZ09fMW@3oZZX00P2MWId01P3<VIT0TI6A
0<bIV@3<VIT0TI6A0<bIV@80c9W<00<0c9VI0<bIc03<VIT00P3<VL`01`3<VIT0ofIV0<bIV@3<VIT0
]KFe0<bIV@2ZEED00P3<VIT01`2ZEED0c9VI0?o<V@3oc9T0ojZZ09TcV@3<VIT00P2I<iT01P3<VIT0
WIfM0?o<V@3oc9T0ofJI0<bIV@80ofJI00<0olbI0<bIc03<VIT00P2IVFH01`3<VIT0VIUV0?nZZP3o
ZZX0c9UV0<bIV@2ZEJX00P3<VIT0103<VFH0c9VI0<bIIP3<VFH90<bIV@030?mVV@3<VIT0ofJI0080
olbI00H0VIVI0?nZZP0c0000<`000:YEE@2IVFH20?mV<`0309VIIP3oZZX0/K6a0080/K6a00L0c9VI
0?nZZP3<VIT0c9VI0?nZZP3<VC<0ojZZ00`0oooo00<000000?ooo`3oool0CP3oool001/0oooo0`00
00040?ooo`800000<P3oool01P3<oiT0VIW<09TcV@2I<iT0IVJI09TcV@80^KVi00L0c9W<0;Vi^@2I
VL`0VIW<0:YEZP2IVL`0VC>I0080TI6A00L0VC>I07IfMP1VIYT0IVJI07IfMP1VIYT0VC=V0080IVJI
00L0VIUV06IVV@2IVFH0VIUV06IVV@1EZZX0VC>I0080EJZZ00L0VC>I096AT@2I<iT0VC>I096AT@2I
<iT0IVJI0080VC>I00H0IVJI09TcV@29RHT0RHV909TcV@29RHT2096AT@0309TcV@2ATI40VC>I0080
TI6A00L0VC>I096AT@2I<iT0VC>I096AT@2I<iT0TI6A0080c9VI00L0TI6A0?mVIP2ATI40TI6A0?mV
IP2ATI40VC>I0080TI6A00H0VC>I096AT@3<VIT0c9VI096AT@3<VIT2096AT@030<bIIP3<VIT0ZUFZ
0080c9VI00L0ZUFZ0<bIV@2I<l`0VC?<0<bIV@2I<l`0c9VI0080ZUFZ00L0TI6A09VIc03oZZX0ojZZ
09VIc03<VIT0IVJI0080c9VI00L0IVJI0<bIV@2ATI40TI6A0?nZZP2MWId0ojZZ0080WIfM00H0c9VI
096AT@3<VIT0c9VI096AT@3<VIT20<bIc0030<bIV@3<VL`0c9VI0080c9W<00L0c9VI0?mVIP3<VIT0
c9VI0;Fe]@3<VIT0ZUEE0080c9VI00L0ZUEE0<bIV@3oc9T0olbI0?nZZP2I<iT0c9VI0080VC>I00H0
c9VI09fMW@3oc9T0olbI0?mVV@3<VIT20?mVV@030?o<V@3<VL`0c9VI0080VIUV00L0c9VI09VIIP3o
ZZX0ojZZ0<bIIP3<VIT0ZUFZ0080c9VI00@0c9UV0<bIV@3<VFH0c9UV2@3<VIT00`3oIYT0c9VI0?mV
V@020?o<V@0609VIV@3oZZX0<`0003<0002ZEED0VIUV0P3oIS<00`2IVFH0ojZZ0;6a/@020;6a/@07
0<bIV@3oZZX0c9VI0<bIV@3oZZX0c9Tc0?nZZP0<0?ooo`030000003oool0oooo04h0oooo000I0?oo
o`800000>P3oool00`2I<iT0TI6A09TcV@0209TcV@0605EEZP2I<iT0LW9b079bLP1VIYT0VIWo0P2=
SHd00`0cI/`0SHf=05FZZP0206IVV@0305FZZP2I<iT0VC>I00/0VC>I00H0OWin06IVV@1nOWh0OWin
06IVV@1nOWh206IVV@0307inOP29RHT0QHF50080RHV900H0QHF508V9R@2=SHd0SHf=08V9R@2=SHd=
09TcV@@0ZUFZ00@0c6K<0:YEZP2ZEJX0c6K<0P2ZEJX20?mVV@060:YEZP3<09T0ZUFZ0:YEZP3<09T0
ZUFZ0P3<09T00`2QXJ40c6K<0:6QX@020<aVc0070:6QX@2I<iT0TI6A096AT@2I<iT0TI6A09TcV@02
0:YEZP070:FUY@2YZJT0YJFU0:FUY@2YZJT0ZUFZ0<bIV@020:YEZP070<bIV@2ZEJX0VC>I09TcV@3<
VIT0ZJVY0<bIV@020:VYZ@0609TcV@3<VIT0VC>I09TcV@3<VIT0_Kfm1`3<VIT01`2=SHd0ojZZ0?o<
V@3oc9T0ojZZ0?o<V@3<VIT00P2ZEJX01@3<VIT0c?nI0<bIV@3<VIT0c?nI00D0c9VI00<0ojZZ0:FU
Y@2UYJD01P3<VIT01@3oIYT0c9VI0<bIV@3oIYT0c9VI0080c?mV0`3<VIT20?o<V@070?nZZP3oc9T0
ojZZ0?nZZP2ZEJX0c9VI0<bIIP020?nZZP040<bIIP3oZZX0olbI0?o<V@D0c9VI00H0c9UV0<bIV@3<
VIT0c9VI03<0<`3<<c<20<bI<`030:YEE@3<VIT0c9UV00H0WIfM00<0/K6a0<bIV@2a/K400P3<VFH:
0?ooo`<00000CP3oool005<0oooo0P0001400`2IVL`0VC?<09VIc00209TcV@0306IVV@2I<iT0IS>I
00<0IS>I0P2IVL`00`2ZEJX0VIW<09TcV@02096AT@0709TcV@1fMWH0IVJI06IVV@1fMWH0IVJI09Tc
IP0206IVV@0709VIIP1VIYT0VIUV09VIIP1VIYT0EJZZ09TcV@0205FZZP0709TcV@2ATI40VC>I09Tc
V@2ATI40VC>I06IVV@0209TcV@0606IVV@2I<iT0RHV908V9R@2I<iT0RHV90P2ATI400`2I<iT0TI6A
09TcV@02096AT@0709TcV@2ATI40VC>I09TcV@2ATI40c9VI0:6QX@020<bIV@070:6QX@3oIVH0TI6A
096AT@3oIVH0TI6A09TcV@02096AT@0609TcV@2ATI40c9VI0<bIV@2ATI40c9VI0P2ATI400`2ZEJX0
c9VI0:YEZP020<bIV@070:YEZP3<VIT0VC?<09Tcc03<VIT0VC?<0<bIV@020:YEZP070?nZZP2IVL`0
ojZZ0?nZZP2IVL`0c9VI06IVV@020<bIV@0706IVV@3<VIT0WIfM09fMW@3oZZX0WIfM0?nZZP0209fM
W@060<bIV@2ATI40c9VI0<bIV@3oc9T0ooo<0P3<VL`00`3<VIT0c9W<0<bIV@020<bIc0070<bIV@2e
]KD0c9VI0<bIV@2e]KD0c9VI0:YEE@020<bIV@070:YEE@3oZZX0olbI0?o<V@3oZZX0VC>I0<bIV@02
09TcV@060?o<V@2MWId0olbI0?o<V@3oIYT0c9VI0P3oIYT00`3oc9T0c9W<0<bIV@0209VIIP070<bI
V@2IVFH0ojZZ0?nZZP3<VFH0c9VI0:YEZP020<bIV@040<bIIP3<VIT0c9UV0<bIIPH0c9VI00H0VLbI
0?nZZP3oZZX0ofJI0<bIV@2IVIT20?nZZP0609VIV@3oZZX0ojZZ0?nZZP3<VIT0VIUV0P2ZEED00`2a
/K40ojZZ0;6a/@020?nZZP070<bIV@3oZZX0c9VI0<bIV@3oZZX0c9Tc0?nZZP020<coV@X0oooo0`00
001>0?ooo`00DP3oool01@000140c?o<0<coc03Hf=P0TI6A00<0VC>I00H0EEFZ09TcV@1bLW80LW9b
06IVV@1bLW8206IVV@0303=Vc02=SHd0EJZZ0080IVJI00<0EJZZ09TcV@2I<iT02`2I<iT01P1nOWh0
IVJI07inOP1nOWh0IVJI07inOP80IVJI00<0OWin06IVV@25QHD00P29RHT01P25QHD0RHV908f=S@2=
SHd0RHV908f=S@T0VC>I0P3<VIT60:YEZP040<aVc02ZEJX0ZUFZ0<aVc080ZUFZ0P3oIYT01P2ZEJX0
ofJI0:YEZP2ZEJX0c02I0:YEZP80c9W<00<0ojZZ0<aVc02QXJ400P3<I/`01`2QXJ40VC>I096AT@2A
TI40VC>I096AT@2I<iT00P2YZJT01`2UYJD0ZJVY0:FUY@2UYJD0ZJVY0:YEZP3<VIT00P2ZEJX01`3<
VIT0ZUFZ0:VYZ@2YZJT0c9VI0:VYZ@3<VIT00P2YZJT01P2I<iT0c9VI09TcV@2I<iT0olbI0;fm_@L0
c9VI00L0SHf=0?nZZP3oc9T0olbI0?nZZP3oc9T0ojZZ0080ZUFZ00D0c9VI0<coV@3<VIT0c9VI0<co
V@040<bIV@040:FUY@3oZZX0YJFU0:FUY@T0c9VI00@0ofJI0<bIV@3<ofH0c?mV0`3<VIT20?o<V@07
0?nZZP3oc9T0ojZZ0?nZZP3oc9T0ojZZ0<bIIP020?nZZP80c9UV0P3oc9T20<bIV@040<bIIP3<VIT0
c9VI0<bIIP<0c9VI00L0ojZZ0<bIV@3oZZX0ojZZ0<bIIP3<VIT0c9UV0080olbI0P2MWId20<bIV@03
0;6a/@3<VIT0olbI0080c9UV00<0olbI0?ooo`3oool0203oool2000004h0oooo001B0?ooo`050000
4@3<ol`0c?o<0=SHf02ATI400`2I<iT01P1EEJX0VC>I079bLP1bLW80IVJI079bLP80IVJI00<0<fK<
08f=S@1EZZX00P1VIYT00`1EZZX0VC>I09TcV@0;09TcV@0607inOP1VIYT0OWin07inOP1VIYT0OWin
0P1VIYT00`1nOWh0IVJI08F5Q@0208V9R@0608F5Q@29RHT0SHf=08f=S@29RHT0SHf=2@2I<iT20<bI
V@H0ZUFZ00@0c6K<0:YEZP2ZEJX0c6K<0P2ZEJX20?mVV@060:YEZP3oIYT0ZUFZ0:YEZP3<09T0ZUFZ
0P3<VL`00`3oZZX0c6K<0:6QX@020<aVc0070:6QX@2I<iT0TI6A096AT@2I<iT0TI6A09TcV@020:VY
Z@070:FUY@2YZJT0YJFU0:FUY@2YZJT0ZUFZ0<bIV@020:YEZP070<bIV@2ZEJX0ZJVY0:VYZ@3<VIT0
ZJVY0<bIV@020:VYZ@0609TcV@3<VIT0VC>I09TcV@3oc9T0_Kfm1`3<VIT01`2=SHd0ojZZ0?o<V@3o
c9T0ojZZ0?o<V@3oZZX00P2ZEJX01@3<VIT0c?nI0<bIV@3<VIT0c?nI00@0c9VI00@0YJFU0?nZZP2U
YJD0YJFU2@3<VIT0103oIYT0c9VI0<coIP3<ofH30<bIV@80olbI00L0ojZZ0?o<V@3oZZX0ojZZ0?o<
V@3oZZX0c9UV0080ojZZ0P3<VFH20?o<V@80c9VI00@0c9UV0<bIV@3<VIT0c9UV0`3<VIT01`3oZZX0
c9VI0?nZZP3oZZX0c9UV0<bIV@3<VFH00P3oc9T209fMW@80c9VI00<0/K6a0<bIV@3oc9T00P3<VFH0
0`3oc9T0oooo0?ooo`080?ooo`800000CP3oool00540oooo00L0000A00L71`3<c<`0c<c<0?ooc02I
<l`0VIW<0080VC>I00<0IVJI09TcV@1V<iT01P1V<iT01P2IVL`0VC>I096AT@2ATI40VC>I07IfMP80
IVJI00<0MWIf06IVV@2I<fH00P1VIYT01`2I<fH0IVJI09VIIP2IVFH0IVJI09VIIP2I<iT00P1EZZX0
1`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@1VIYT00P2I<iT01P1VIYT0VC>I08V9R@29RHT0VC>I08V9
R@80TI6A00<0VC>I096AT@2I<iT00P2ATI401`2I<iT0VIW<0:YEE@2ZEED0XJ6Q0<bIV@2QXJ400P3<
VIT01`2QXJ40ofIV096AT@2ATI40ofIV096AT@2I<iT00P2ATI401P2I<iT0TI6A0<bIV@3<VIT0TI6A
0<30`080_Kfm00<0`<300<bIV@2ZEJX00P3<VIT01`2ZEJX0c9VI09Tcc02I<l`0c9VI09Tcc03<VIT0
0P2ZojX01`3oZZX0VIW<0?nZZP3oZZX0VIW<0<bIV@1VIYT00P3<VIT01`1VIYT0c9VI0<coc03<ol`0
ojZZ09fMW@3oZZX00P2MWId01P3<VIT0TI6A0?ooc03ool`0olbI0?ooc080olbI00<0c9VI0<bIc03<
VIT00P3<VL`01`3<VIT0]KFe0<bIV@3<VIT0]KFe0<bIV@2e]KD00P3<VIT01`3oc9T0ojZZ0?o<V@3o
c9T0ojZZ09TcV@3<VIT00P2I<iT01P3oc9T0WIfM0?o<V@3oc9T0ofJI0<bIV@80c9W<00<0olbI0<bI
c03oc9T00P2IVFH01`3<VIT0c9UV0?nZZP3oZZX0c9UV0?nZZP2ZEJX00P3<VIT0103<VFH0c9VI0<bI
IP3<VFH60<bIV@0609W<V@3oZZX0ojZZ0?mVV@3<VIT0VIVI0P3oZZX01P2IVIT0ojZZ0?mVV@3oIYT0
c9VI0?nZZP80c9VI00<0/K6a0?nZZP2a/K400P3oZZX01`3<VIT0ojZZ0<bI<`3<VC<0ojZZ0<bI<`3o
ZZX00P3<oiT00`3oZZX0oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo001?0?ooo`<0000A
00D0OWin05EEZP1EEJX0f=SH096AT@0309TcV@0605EEZP2I<iT0LW9b079bLP1VIYT0LW9b0P1VIYT0
0`1V<fH0IVJI05FZZP0206IVV@0305FZZP1VIYT0VC>I00`0VC>I00D0IVJI07inOP1nOWh0IVJI07in
OP0206IVV@0307inOP1VIYT0QHF50080RHV900H0QHF508V9R@2=SHd0SHf=08V9R@2=SHd709TcV@04
0<bIV@2ZEJX0c9VI0<bIV@H0ZUFZ00@0c6K<0:YEZP2ZEJX0c6K<0P2ZEJX20?mVV@060:YEZP3oIYT0
ZUFZ0:YEZP3<VL`0ojZZ0P3<VL`00`3oZZX0c6K<0:6QX@020<aVc0070:6QX@3<I/`0TI6A096AT@2I
<iT0TI6A0?ooZP020?ooc0070:FUY@2YZJT0YJFU0:FUY@2YZJT0YJFU0<bIV@020:YEZP070<bIV@38
b<P0c?nI0<coV@3<VIT0ZJVY0<bIV@020:VYZ@80c9VI0P2m_Kd0103oc9T0_Kfm0?o<V@3oc9T50<bI
V@0709W<IP3oZZX0olbI0?o<V@3oZZX0olbI0?nZZP020:YEZP050<bIV@3<oiT0c9VI0<bIV@3<oiT0
0P3<VIT20?nZZP040:FUY@3oZZX0YJFU0:FUY@T0c9VI00L0ofJI0<bIV@3<ofH0c?mV0<bIV@3<ofH0
c9VI0080olbI00L0ojZZ0?o<V@3oZZX0ojZZ0?o<V@3oZZX0c9UV0080ojZZ0P3<VFH20?o<V@80c9VI
00@0c9UV0<bIV@3<VIT0c9UV0`3<VIT01`3oZZX0c9VI0?nZZP3oZZX0c9UV0<bIV@3<VFH00P3oc9T2
09fMW@80c9VI00<0/K6a0<bIV@3oc9T00P3<VFH00`3oc9T0oooo0?ooo`0;0?ooo`030000003oool0
oooo04X0oooo001>0?ooo`05000000071`L01`L706IVV@2IVL`00P1V<fH00`1V<iT0c<c<09VIc002
09Tcc00306IVV@2I<iT0IS>I00X0IS>I00L0VC>I096AT@1VIYT0IVJI07IfMP1VIYT0VC=V0080IVJI
00L0VC=V06IVV@2IVFH0VIUV06IVV@2IVFH0VC>I0080EJZZ00L0VC>I096AT@2I<iT0VC>I096AT@2I
<iT0IVJI0080VC>I00H0IVJI09TcV@29RHT0RHV909TcV@29RHT2096AT@0309TcV@2ATI40VIW<0080
VIW<00L0ZUEE09VIc02ZEED0ZUEE09VIc03<VIT0XJ6Q0080c9VI00L0XJ6Q0?mVIP2ATI40TI6A0?mV
IP2ATI40VC>I0080TI6A00H0VC>I0<coc030`<00`<300;fm_@30`<020;fm_@030<30`03<VIT0ZUFZ
0080c9VI00L0ZUFZ0<bIV@2I<l`0VC?<0<bIV@2ZojX0c?o<0080Z_nZ00L0ojZZ09VIc03oZZX0ojZZ
09VIc03oZZX0IVJI0080c9VI00L0ofJI096AT@3<ol`0c?o<0?nZZP2MWId0ojZZ0080WIfM00H0ojZZ
096AT@3ool`0ooo<0?o<V@3ool`20?o<V@030<bIV@3<VL`0c9VI00<0VLaV00H0]KFe0<bIV@3<VIT0
]KFe0<bIV@2e]KD20?nZZP070?o<V@3oZZX0olbI0?o<V@3oZZX0olbI0<bIV@0209fMW@060?o<V@2M
WId0olbI0?o<V@2MWId0c9VI0P3<VL`00`3oc9T0c9W<0?o<V@0209VIIP070<bIV@3<VFH0ojZZ0?nZ
ZP3<VFH0ojZZ0<bIIP020<bIV@060<bIIP3<VIT0c9UV0<bIIP3<VIT0_Kfm103<VIT01P2Ic9T0ojZZ
0?nZZP2Ic9T0c9VI09VIV@80ojZZ00H0VIVI0?nZZP3oIYT0ofJI0?o<V@3oZZX20<bIV@030;6a/@3o
ZZX0/K6a0080ojZZ00L0c?mV0?nZZP3<VC<0c9Tc0?nZZP3<VC<0ojZZ0080c?nI00<0ojZZ0<bIV@3o
ool02`3oool2000004/0oooo001>0?ooo`<0000A00L0ZUFZ07inOP1EEJX0EEFZ06IVV@1EEJX0VC>I
0080TI6A00H0EEFZ09TcV@1bLW80LW9b06IVV@1bLW8206IVV@0306HcIP1VIYT0LW9b0080IVJI00<0
LW9b06IVV@2I<iT0302I<iT01@1VIYT0OWin07inOP1VIYT0OWin0080IVJI00<0OWin06IVV@25QHD0
0P29RHT01P25QHD0RHV908f=S@2=SHd0RHV908f=S@<0VC>I00H0ZUFZ0<bIV@2ZEJX0ZUFZ0<bIV@2Z
EJX20<bIV@H0ZUFZ00@0c6K<0:YEZP2ZEJX0c6K<0P2ZEJX20?mVV@060<coc02Zool0c?o<0<coc03<
VL`0ojZZ0P3<VL`00`3oZZX0c6K<0:6QX@020<aVc0070:6QX@3<I/`0TI6A096AT@3<09T0ZUFZ0<`0
V@020?ooc0070?ooZP2YZJT0YJFU0:FUY@2YZJT0YJFU0<bIV@0208V9R@070:YEZP3oIYT0ZUFZ0:YE
ZP38b<P0ZJVY0<bIV@020:VYZ@0608F5Q@2ZEJX0QHF508F5Q@3oc9T0_Kfm0P3oc9T00`2m_Kd0c9VI
08V9R@020:YEZP0609W<IP3oZZX0olbI0?o<V@3oZZX0olbI0`0000001@3<VIT0c?nI0<bIV@3<VIT0
c?nI0080c9VI0P3oZZX01@2UYJD0ojZZ0:FUY@2UYJD0ojZZ00P0c9VI00L0ofJI0<bIV@3<ofH0c?mV
0<bIV@3<ofH0ojZZ0080olbI00L0ojZZ0?o<V@3oZZX0ojZZ0<bIV@3oc9T0c9UV0080ojZZ00L0olbI
0<bIIP3oc9T0olbI0<bIIP3<VIT0c9UV0080c9VI0P3<VFH20<bIV@070<bIIP3<VIT0c9VI0<bIV@3<
VFH0c9VI0<bIIP020?o<V@070<bIIP2a/K40c9VI0<bIV@2a/K40c9VI0?o<V@020<bIIP030?o<V@3<
VIT0oooo00`0oooo00<000000?ooo`3oool0B@3oool004h0oooo0`0001401`2ZEJX0OWin05EEZP1E
EJX0IVJI05EEZP2I<iT00P2ATI401P1EEJX0VC>I079bLP1bLW80IVJI079bLP80IVJI00<0IS=V06IV
V@1bLW800P1VIYT00`1bLW80IVJI09TcV@0<09TcV@0506IVV@1nOWh0OWin06IVV@1nOWh00P1VIYT0
0`1nOWh0IVJI08F5Q@0208V9R@0608F5Q@29RHT0SHf=08f=S@29RHT0SHf=0`2I<iT01P2ZEJX0c9VI
0:YEZP2ZEJX0c9VI0:YEZP80c9VI1P2ZEJX0103<I/`0ZUFZ0:YEZP3<I/`20:YEZP80ofJI00H0c?o<
0:[oo`3<ol`0c?o<0<bIc03oZZX20<bIc0030?nZZP3<I/`0XJ6Q0080c6K<00L0XJ6Q0<aVc02ATI40
TI6A0<`0V@2ZEJX0c02I0080ooo<00L0oonZ0:VYZ@2UYJD0YJFU0:VYZ@2UYJD0c9VI0080RHV900L0
ZUFZ0?mVV@2ZEJX0ZUFZ0<S8b02YZJT0c9VI0080ZJVY00H0QHF50:YEZP25QHD0QHF50?o<V@2m_Kd2
0?o<V@030;fm_@3<VIT0RHV90080ZUFZ00H0VLaV0?nZZP3oc9T0olbI0?nZZP3oc9T3000000050<bI
V@3<oiT0c9VI0<bIV@3<oiT00P3<VIT20?nZZP050:FUY@3oZZX0YJFU0:FUY@3oZZX0203<VIT01`3o
IYT0c9VI0<coIP3<ofH0c9VI0<coIP3oZZX00P3oc9T01`3oZZX0olbI0?nZZP3oZZX0c9VI0?o<V@3<
VFH00P3oZZX01`3oc9T0c9UV0?o<V@3oc9T0c9UV0<bIV@3<VFH00P3<VIT20<bIIP80c9VI00L0c9UV
0<bIV@3<VIT0c9VI0<bIIP3<VIT0c9UV0080olbI00L0c9UV0;6a/@3<VIT0c9VI0;6a/@3<VIT0olbI
0080c9UV00<0olbI0<bIV@3oool0303oool00`000000oooo0?ooo`190?ooo`00C@3oool01P000000
000A09VIc02IVL`0IVJI09VIc080IS=V00<0IS>I06HcIP2IVL`00P2I<l`00`1VIYT0VC>I06HcV@0<
06HcV@80IVJI00<0MWIf06IVV@2I<fH00P1VIYT01`2I<fH0IVJI09VIIP2IVFH0IVJI09VIIP2I<iT0
0P1EZZX01`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@1VIYT00P2I<iT01P1VIYT0VC>I08V9R@29RHT0
VC>I08V9R@80TI6A1@2IVL`01`2ZEED0VIW<0:YEE@2ZEED0VIW<0<bIV@2QXJ400P3<VIT01`2QXJ40
c9VI096AT@2ATI40ofIV096AT@2I<iT00P3<ol`01P3<ool0c?o<0<coo`3<ool0_Kfm0<30`080_Kfm
00<0`<300;fm_@2ZEJX00P3<VIT01`2ZEJX0TI6A0<bIV@3<VIT0TI6A0<bIV@2ATI400P3<VIT01`2A
TI40VIW<0?nZZP3oZZX0TI6A0<bIV@2ATI400P3<VIT01`3oIYT0TI6A0?mVV@3oIYT0c9VI09fMW@3<
VIT00P2ZEED01P3<VIT0ZUEE0<bIV@3<VIT0ofJI0<bIV@80PH6100<0ooo<0<bIc03<VIT00P2ZEED0
1@3<VIT0VLaV0<bIV@3<VIT0]KFe0080c9VI0P0000001`3oc9T0ojZZ0?o<V@3oc9T0ojZZ03<0003o
c9T00P2MWId01P3oc9T0WIfM0?o<V@3oc9T0WIfM0?o<V@80c9W<00<0olbI0<bIc03oc9T00P3<VL`0
1`3oZZX0c9UV0?nZZP3oZZX0c9UV0?nZZP2k^k/00P3<VIT01P3<VFH0c9VI0<bIIP3<VFH0olbI0;fm
_@<0c9VI00L0ojZZ09W<V@3oZZX0ojZZ09W<V@3oZZX0VIVI0080ojZZ00D0VIVI0?o<V@3oIYT0ofJI
0?o<V@030?nZZP030;6a/@3oZZX0c?mV0080ojZZ00L0c?mV0?nZZP3<VC<0c9Tc0?nZZP3<oiT0ojZZ
0080c?nI00<0olbI0<bIV@3oool03@3oool2000004T0oooo001<0?ooo`03000000000140000A0080
OWin00L0ZUFZ07inOP1EEJX0EEFZ06IVV@1EEJX005EE0080TI6A00H0EEFZ09TcV@1EEJX0EEFZ06IV
V@1bLW8206IVV@0306HcIP1VIYT0LW9b0080IVJI00<0LW9b06IVV@1VIYT00P1VIYT:09TcV@0506IV
V@1nOWh0OWin06IVV@1nOWh00P1VIYT00`1nOWh0IVJI08F5Q@0208V9R@0608F5Q@29RHT0SHf=08f=
S@29RHT0/K6a0P2ZEJX00`3<VIT0ZUFZ0<bIV@020:YEZP040<bIV@2ZEJX0c9VI0<bIV@T0ZUFZ00<0
c6K<09TcV@2I<iT01P2I<iT01`2ZEJX0ojZZ0<bIc03<VL`0ojZZ0<bIc02QXJ400P3<09T01`2ZEJX0
c02I0:YEZP2ZEJX0c02I0:YEZP3<09T00P2ZEJX01`3<09T0TI6A08V9R@29RHT0VC>I08V9R@2I<iT0
0P29RHT00`2ZEJX0ofJI0:YEZP020:YEZP06096AT@25QHD0ZUFZ0:YEZP25QHD0ZUFZ0P25QHD01`2Z
EJX0VC>I0<bIV@3<VIT0VC>I0<bIV@29RHT00P2ZEJX01`29RHT0c9VI0?o<V@3oc9T0TI6A0<`0V@2A
TI400P3<09T01`3<VIT0c?nI0<bIV@3<VIT0VC>I0<bIV@0C4a<00P3oZZX01@2UYJD0ojZZ0:FUY@2U
YJD0000000P0c9VI00H0c?mV0<bIV@3<ofH0c?mV0<bIV@3oojX30?o<V@070?nZZP3oc9T0ojZZ0?nZ
ZP3<VIT0olbI0<bIIP020?nZZP070?o<V@3<VFH0olbI0?o<V@3<VFH0c9VI0<bIIP020<bIV@80c9UV
0P3<VIT01`3<VFH0c9VI0<bIV@3<VIT0c9UV0<bIV@3<VFH00P3oc9T01`3<VFH0/K6a0<bIV@3<VIT0
/K6a0<bIIP3oc9T00P3<VFH00`3oZUD0c9VI0?ooo`0=0?ooo`800000B@3oool00380oooo00<0Z_oo
0?ooo`3oool05@3oool20000000300004@071`L0IS=V0080ooo<00L0IVJI09VIc01V<fH0IS=V06Hc
V@1V<fH0IS>I0080VC?<00@0IVJI09TcV@1VIYT0IVJI3@1V<iT00`2ZEJX0IS>I09TcIP0206IVV@07
09TcIP1VIYT0VIUV09VIIP1VIYT0VIUV09TcV@0205FZZP0709TcV@2ATI40VC>I09TcV@2ATI40VC>I
06IVV@0209TcV@0606IVV@2IVL`0ZUFZ0:YEZP2IVL`0ZUFZ1`2IVL`01`2ZEED0VIW<0:YEE@2ZEED0
VIW<0:YEE@2QXJ400P3<VIT01`2QXJ40c9VI096AT@2ATI40VC>I096AT@2ZEJX00P2ATI401P2ZEJX0
TI6A09TcV@2I<iT0TI6A09TcV@80TI6A00<0c9VI096AT@3<VIT00P2ATI401`3<VIT0TI6A0<bIV@3<
VIT0TI6A0<bIV@2ATI400`3<VIT01P2Z0:X0c9VI0<bIV@2ATI40c9VI096AT@80c9VI00L0ofJI096A
T@3oIYT0ofJI0<bIV@3oIYT0c9VI0080ZUEE00H0c9VI0:YEE@3<VIT0c9VI0861P@3<VIT20861P@03
0<bIV@21PH40c9VI0080ZUEE00<0c9VI07inOP3<VIT01P3<VIT01`2ZEJX0ojZZ096AT@2ATI40c9VI
096AT@3<VIT00P2MWId0103oc9T0WIfM0<bIV@3<VIT200000080c9W<00<0olbI0<bIc03oc9T00P3<
VL`01`000000c9UV0?nZZP3oZZX0c9UV0?ooZP2k^k/00P3<VIT01P3<VFH0c9VI0;fm_@2m_Kd0olbI
0;fm_@<0c9VI00L0ojZZ09W<V@3oZZX0ojZZ09W<V@3oc9T0VIVI0080ojZZ00H0VIVI0?o<V@3oIYT0
ofJI0?o<V@3oIYT20?nZZP030;6a/@3oZZX0c?mV0080ojZZ00L0c?mV0?o<V@3<VC<0c9Tc0?nZZP3<
oiT0ojZZ0080c?nI00@0olbI0<bIV@3oc9T0olbI3P3oool2000004L0oooo000b0?ooo`030:[oo`3o
ool0oooo01D0oooo0P0000000`0001401`L706HcIP020?ooc00706IVV@2IVL`0IS=V06HcIP1V<iT0
IS=V06HcV@0209Tcc00406IVV@2I<iT0IVJI06IVV@d0IS>I00<0ZUFZ06HcV@2I<fH00P1VIYT01`2I
<fH0IVJI09VIIP2IVFH0IVJI09VIIP2I<iT00P1EZZX01`2I<iT0TI6A09TcV@2I<iT0TI6A09TcV@1V
IYT00P2I<iT01P1VIYT0VIW<0:YEZP2ZEJX0VIW<0:YEZPL0VIW<00L0ZUEE09VIc02ZEED0ZUEE09VI
c02ZEED0XJ6Q0080c9VI00L0XJ6Q0<bIV@2ATI40TI6A09TcV@2ATI40ZUFZ0080TI6A00H0ZUFZ096A
T@2I<iT0VC>I096AT@2I<iT2096AT@030<bIV@2ATI40c9VI0080TI6A00L0c9VI096AT@3<VIT0c9VI
096AT@3<VIT0TI6A00<0c9VI00H0ZP2Z0<bIV@3<VIT0TI6A0<bIV@2ATI420<bIV@070?mVV@2ATI40
ofJI0?mVV@3<VIT0ofJI0<bIV@020:YEE@060<bIV@2ZEED0c9VI0<bIV@21PH40c9VI0P21PH400`3<
VIT0PH610<bIV@020:YEE@030<bIV@1nOWh0c9VI00H0c9VI00L0ZUFZ0?nZZP2ATI40TI6A0<bIV@2A
TI40c9VI0080WIfM00@0olbI09fMW@3<VIT0c9VI0P0000020<bIc0030?o<V@3<VL`0olbI0080c9W<
00L000000<bIIP3oZZX0ojZZ0<bIIP3oojX0^k^k0080c9VI00H0c9UV0<bIV@2m_Kd0_Kfm0?o<V@2m
_Kd30<bIV@070?nZZP2Ic9T0ojZZ0?nZZP2Ic9T0olbI09VIV@020?nZZP0609VIV@3oc9T0ofJI0?mV
V@3oc9T0ofJI0P3oZZX00`2a/K40ojZZ0<coIP020?nZZP070<coIP3oc9T0c9Tc0<bI<`3oZZX0c?nI
0?nZZP020<coV@040?o<V@3<VIT0olbI0?o<V@h0oooo0P0000170?ooo`00<03oool20<c<c0030=CD
e00c09T0oooo01@0oooo0`0000000`071`L0000A06HcV@0206HcV@070:YEZP1nOWh0ZUFZ0:YEZP1V
IYT0EEFZ001EE@0206HcV@0605EEZP2I<iT0EEFZ05EEZP1VIYT0LW9b0P1VIYT00`1V<fH0IVJI06Hc
IP0206IVV@03079bLP1VIYT0IVJI00<0IVJI00<0VC>I05EEZP1EEJX01P2I<iT01@1VIYT0OWin07in
OP1VIYT0OWin0080IVJI00<0OWin06IVV@25QHD00P2ZEJX01P2IVL`0ZUFZ09VIc02IVL`0c6K<0;6a
/@80c6K<00<0c9VI0:YEZP3<VIT00P2ZEJX01P3<VIT0ZUFZ0<bIV@3<VIT0ZUFZ0<bIV@@0ZUFZ302I
<iT01`2ZEJX0VC>I0<`0V@3<09T0ZUFZ0<`0V@2ZEJX00P3<09T01`2ZEJX0c02I0:YEZP2ZEJX0c02I
0:YEZP3<09T00P2ZEJX00`2I<iT0TI6A09TcV@0209TcV@0608V9R@2I<iT0RHV908V9R@2ZEJX0ofJI
0P2ATI400`2ZEJX0TI6A08F5Q@020:YEZP0608F5Q@2ZEJX0QHF508F5Q@3<VIT0VC>I0P3<VIT00`2I
<iT0c9VI08V9R@030:YEZP060<bIV@2ZEJX0ZUFZ096AT@3<09T0TI6A1P3<VIT00`2I<iT0c9VI0<bI
V@020<bIV@030:FUY@3<VIT0c9VI0080c9VI00<000000<bIV@3<VIT00`3<VIT3000000060<bIV@3<
ofH0c?mV0<bIV@3oojX0olbI0P3oojX01`3oZZX0olbI0?o<V@3oc9T0c9VI0?o<V@3<VIT00P3oZZX0
1`3oc9T0c9UV0?o<V@3oc9T0c9UV0?o<V@3<VFH00P3<VIT20<bIIP80c9VI00L0c9UV0<bIV@3<VIT0
c9VI0<bIIP3<VIT0c9UV0080olbI0P3<VFH20<bIV@030;6a/@3<VFH0olbI0080c9UV00@0ojYE0<bI
V@3oZZX0ojZZ3P3oool2000004L0oooo000_0?ooo`050:[oo`3Hf=P0f=SH0:[oo`1V<iT00P0c06HC
0?ooo`06000000000140000A00004@2m_Kd0IS=V0P1EEJX01`1VIYT0VIW<06IVV@1VIYT0IS>I06Hc
IP1V<iT00P0c09T0101VIYT0VC>I06IVV@1VIYT=06HcV@030:YEZP1V<iT0ZUFZ0080IVJI00L0ZUFZ
06IVV@0cI/`0<fK<06IVV@2IVFH0VC>I0080EJZZ00L0VC>I096AT@2I<iT0VC>I05EEo`2IVL`0c9VI
0080VIW<00H0c9VI09VIc03<VIT0c9VI09VIc02ZEJX909VIc080ZUEE00<0VIW<0:YEE@2QXJ400P1V
<iT01`2ATI40VC>I096AT@2ATI40VC>I096AT@2ZEJX00P2ATI401P2ZEJX0TI6A09TcV@2I<iT0TI6A
0<bIV@80TI6A00<0c9VI096AT@3<VIT00P2ATI401`3<VIT0TI6A0<bIV@3<VIT0TI6A0<bIV@2ATI40
0P2Z0:X01`3<VIT0ZP2Z0<bIV@3<VIT0TI6A0<bIV@2ATI400P3<VIT01`3oIYT0c9VI0?mVV@3oIYT0
c9VI0?mVV@3<VIT00P2ZEED01P3<VIT0ZUEE0<bIV@3<VIT0PH610<bIV@80PH6100<0c9VI0861P@3<
VIT00P2ZEED00`3<VIT0OWin0<bIV@060<bIV@070:YEZP3<VIT0TI6A096AT@3<VIT0ofJI0<bIV@02
0?mVV@060<bIV@2ZEJX0c9VI0<bIV@3oIYT0c9VI0P3<VL`00`3oc9T0c9W<0<bIV@020?mVV@070000
003<VFH0ojZZ0?nZZP2k^k/0oonZ0;^k^`020?ooZP070<bIIP3<VIT0_Kfm0;fm_@3oc9T0_Kfm0?o<
V@0209W<V@070?nZZP2Ic9T0ojZZ0?nZZP30`<00olbI09VIV@020?nZZP0609VIV@3oc9T0ofJI0?mV
V@3oc9T0ofJI0P3oc9T00`2a/K40ojZZ0<coIP020?nZZP070<coIP3oc9T0c9Tc0<bI<`3oZZX0c?nI
0?nZZP020<coV@050?o<V@3<VIT0olbI0?o<V@2QXJ403P3oool00`000000oooo0?ooo`150?ooo`00
;P3oool01P3<VC<0/K6a0<bI<`3<VC<0e=CD03<0V@8005FZ4P3oool2000000<0000A00H0ZZ[o06Hc
V@1V<iT0IS>I0000M`1nOWh20:YEZP0306IVV@1EEJX005EE0080IS>I00H005EE09TcV@1EEJX0EEFZ
06IVV@1bLW8206IVV@0306HcIP1VIYT0IS=V0080IVJI00<0LW9b06IVV@1VIYT00`1VIYT01@2I<iT0
EEFZ05EEZP2I<iT0c6K<0080ZUFZ00<0c6K<0:YEZP1EEOl00P2I<l`01P1EEOl0ZUFZ08f=S@2=SHd0
ZUFZ08f=S@<0ZUFZ00H0VIW<0:YEZP2IVL`0VIW<0<aVc02a/K420<aVc0030;6a/@2ZEJX0c9VI0080
ZUFZ00D0c9VI0:YEZP3<VIT0c9VI08V9R@0A09TcV@070<`0V@2ZEJX0c02I0<`0V@2ZEJX0c02I0:YE
ZP020<`0V@070:YEZP3<09T0ZUFZ0:YEZP3<09T0ZUFZ0<`0V@02096AT@0309TcV@2ATI40VC>I0080
VC>I00@0RHV909TcV@29RHT0RHV90P2ZEJX2096AT@030:YEZP2ATI40QHF50080ZUFZ00H0QHF50:YE
ZP2ZEJX0ZUFZ0<bIV@2I<iT20<bIV@0309TcV@3<VIT0VC>I00<0ZUFZ00D0c9VI0:YEZP2ZEJX0c9VI
0<`0V@070<bIV@0309TcV@3<VIT0c9VI0100c9VI00H000000<coIP3<ofH0olbI0?ooZP3oc9T20?oo
ZP070?nZZP3oc9T0olbI0?o<V@3<VIT0olbI0<bIV@020<bIIP030?o<V@3<VFH0olbI00@0olbI0P3<
VIT20<bIIP80c9VI00L0c9UV0?o<V@3<VIT0c9VI0<bIIP3<VIT0c9UV0080olbI00L0ojZZ0<bIIP3o
ZZX0ojZZ0?o<V@3<VFH0olbI0080c9VI00D0ojYE0<bIV@3oZZX0ojZZ0?nZE@0?0?ooo`800000A@3o
ool002h0oooo00H0c9Tc0;6a/@3<VC<0c9Tc0=CDe00c09T2001EZQ80oooo0P00000300004@060:ZZ
o`1V<iT0IS>I06HcV@0007L0OWin0P2ZEJX00`1VIYT0EEFZ001EE@0206HcV@06001EE@2I<iT0EEFZ
05EEZP1VIYT0LW9b0P1VIYT00`1V<fH0IVJI06HcIP0206IVV@03079bLP1VIYT0IVJI00<0IVJI00D0
VC>I05EEZP1EEJX0VC>I0<aVc0020:YEZP030<aVc02ZEJX0EEGo0080VC?<00H0EEGo0:YEZP2=SHd0
SHf=0:YEZP2=SHd30:YEZP0609VIc02ZEJX0VIW<09VIc03<I/`0/K6a0P3<I/`00`2a/K40ZUFZ0<bI
V@020:YEZP050<bIV@2ZEJX0c9VI0<bIV@29RHT04@2I<iT01`3<09T0ZUFZ0<`0V@3<09T0ZUFZ0<`0
V@2ZEJX00P3<09T01`2ZEJX0c02I0:YEZP2ZEJX0c02I0:YEZP3<09T00P2ATI400`2I<iT0TI6A09Tc
V@0209TcV@0408V9R@2I<iT0RHV908V9R@80ZUFZ0P2ATI400`2ZEJX0TI6A08F5Q@020:YEZP0608F5
Q@2ZEJX0ZUFZ0:YEZP3<VIT0VC>I0P3<VIT00`2I<iT0c9VI09TcV@030:YEZP050<bIV@2ZEJX0ZUFZ
0<bIV@3<09T01`3<VIT00`2I<iT0c9VI0<bIV@0@0<bIV@060000003<ofH0c?mV0?o<V@3oojX0olbI
0P3oojX01`3oZZX0olbI0?o<V@3oc9T0c9VI0?o<V@3<VIT00P3<VFH00`3oc9T0c9UV0?o<V@040?o<
V@80c9VI0P3<VFH20<bIV@070<bIIP3oc9T0c9VI0<bIV@3<VFH0c9VI0<bIIP020?o<V@070?nZZP3<
VFH0ojZZ0?nZZP3oc9T0c9UV0?o<V@020<bIV@050?nZE@3<VIT0ojZZ0?nZZP3oZUD03`3oool20000
04D0oooo000^0?ooo`060<coIP2IVL`0VIW<09VIc02Zool0IS>I0P0c06H00`0009T0oooo0?ooo`0?
0?ooo`07000000000140000A00004@3<VOl0_Kfm06HcIP0205EEZP07001EE@2IVL`0IVJI06IVV@1V
<iT0IS=V06HcV@0203<0V@0406HcV@0c09T0IVJI06IVV@d0IS>I00<0ZUFZ06HcV@2ZEJX00P1VIYT0
1`2ZEJX0IVJI03=Vc00cI/`0IVJI03=Vc02=SHd00P2IVL`01`2=SHd0VIW<09VIc02IVL`0EEGo09VI
c01EEOl00P2IVL`01P3<VIT0VIW<0<bIV@3<VIT0VIW<0:YEZP80VIW<00<0ZUFZ09VIc02IVL`00P2I
<iT01`1VIYT0VC>I06IVV@1VIYT0VC>I06IVV@2ATI400P1V<iT01`2ATI40VC>I096AT@2ATI40VC>I
096AT@2ZEJX00P2ATI401P2ZEJX0TI6A0<bIV@3<VIT0TI6A0<bIV@80TI6A00<0c9VI096AT@3<VIT0
0P2ATI401@3<VIT0TI6A0<bIV@3<VIT0TI6A0080c9VI0P2Z0:X01`3<VIT0ZP2Z0<bIV@3<VIT0TI6A
0<bIV@2ATI400P3<VIT01`3oIYT0c9VI0?mVV@3oIYT0c9VI0?mVV@3<VIT00P2ZEED00`3<VIT0ZUEE
0<bIV@030<bIV@80PH6100<0c9VI0861P@3<VIT00P1nOWh01`3<VIT0OWin0<bIV@3<VIT0OWin0<bI
V@2ZEJX00P3<VIT01`2ZEJX0c9VI0:YEZP2ZEJX0c9VI0?mVV@3<VIT00P3oIYT01P3<VIT0ofJI0<bI
V@3<VIT0ofJI0<bIV@80ofJI00<0c9VI0?o<V@3<VIT00P3oIYT20<bIV@80ojZZ00<0^k^k0?ooZP2k
^k/00P3oojX01`2k^k/0olbI0;fm_@2m_Kd0olbI0;fm_@3oc9T00P3<VFH01`3oZZX0VLbI0?nZZP3o
ZZX0`<300?o<V@30`<000P3oZZX01P3oIYT0olbI0?mVV@3oIYT0olbI0<bIV@80olbI00<0/K6a0?nZ
ZP3<ofH00P3oZZX01`3<VFH0olbI0<bIIP3<VFH0ojZZ0<coV@3oZZX00P3<VIT01P3oc9T0XJ6Q0?o<
V@3oc9T0XJ6Q0?o<VA00oooo00<000000?ooo`3oool01`3oool4000003L0oooo000]0?ooo`0309VI
c02IVOl0VIW<0080VIWo00D0<`1V0<c<c000EJX005FZ03lo?`0?0?ooo`<0000000D01`L700004@00
0140<fJI0:ZZo`0306HcV@070000M`1V<iT0ZUFZ0:YEZP1VIYT0EEFZ001EE@0206HcV@06001EE@1V
<iT0EEFZ05EEZP1VIYT0LW9b0P1VIYT00`1V<fH0IVJI06HcIP0206IVV@03079bLP1VIYT0IVJI00<0
IVJI00D0VC>I05EEZP1EEJX0VC>I05EEZP020:YEZP030<aVc02ZEJX0c6K<0080VC?<00H0EEGo09Tc
c02=SHd0SHf=0:YEZP2=SHd30:YEZP0609VIc02ZEJX0VIW<09VIc02ZEJX0/K6a0P3<I/`206IVV@04
08F5Q@1VIYT0IVJI08F5Q@D0RHV93@2I<iT30:YEZP070<`0V@2ZEJX0c02I0<`0V@2ZEJX0c02I0:YE
ZP020<`0V@070:YEZP3<09T0ZUFZ0:YEZP3<09T0ZUFZ09TcV@02096AT@0309TcV@2ATI40VC>I0080
VC>I00H0RHV909TcV@29RHT0RHV9096AT@2ZEJX2096AT@030:YEZP2ATI40QHF50080ZUFZ00H0QHF5
0:YEZP2ZEJX0ZUFZ0<bIV@2I<iT20<bIV@0309TcV@3<VIT0VC>I0080c9VI00H0ZUFZ0<bIV@2ZEJX0
ZUFZ0<bIV@3<09T70<bIV@0309TcV@3<VIT0c9VI00X0c9VI00<0c9UV0?nZZP3<VIT00P3<VIT01`3<
VFH0ojZZ0<bIIP3<VFH0ojZZ0<bIIP3oZZX00P3<VFH01`3oZZX0c9VI0?o<V@3oc9T0c9VI0?o<V@3<
ofH00P2Ic6H00`3oc9T0c9UV0?o<V@040?o<V@<0c9VI00D0c9UV0<bIV@3<VIT0c9UV0?o<V@020<bI
V@030<bIIP3oc9T0c9UV0080olbI00L0ojZZ0<bIIP3oZZX0ojZZ0?o<V@3<VFH0olbI0080c9VI0P3o
ZUD20?nZZP030?nZE@3<VIT0ojYE00l0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0=03oool002d0oooo00<0c9VI09VIc02IVL`00P2IVL`01P00EJX0f=SH03<0IP0c
06H0002I03<0V@h0oooo0`0000001P000140OWin07inOP0cIVH0_Kfm06HcIP80EEFZ00L005EE06Hc
V@1VIYT0IVJI06HcV@1V<fH0IS>I0080<`2I00<0IS>I03<0V@1V<iT03P1V<iT00`2ZEJX0IS>I0:YE
ZP0206IVV@070:YEZP1VIYT0<fK<03=Vc01VIYT0<fK<06IVV@0209VIc00708f=S@2IVL`0VIW<09VI
c01EEOl0VIW<05EEo`0209VIc0060<bIV@2IVL`0OWin07inOP1VIYT0I/bI0P2I<iT00`1Vc9T0VC>I
05FZZP0209TcV@0705FZZP2I<iT0IVJI06IVV@2I<iT0IVJI096AT@0206HcV@07096AT@1V<iT0TI6A
096AT@2I<iT0TI6A0:YEZP02096AT@060<`0V@2ATI40c9VI0<bIV@2ATI40c9VI0P2ATI400`3<VIT0
TI6A0<bIV@02096AT@040<bIV@2ATI40c9VI0<bIV@80TI6A00D0c9VI0:X0ZP2Z0:X0c9VI0:X0ZP02
0<bIV@03096AT@3<VIT0TI6A0080c9VI00L0ofJI0<bIV@3oIYT0ofJI0<bIV@3oIYT0c9VI0080ZUEE
1P3<VIT20861P@030<bIV@21PH40c9VI0080OWin00L0c9VI07inOP3<VIT0c9VI07inOP3<VIT0ZUFZ
0080c9VI00L0ZUFZ0<bIV@2ZEJX0ZUFZ0<bIV@3oIYT0c9VI0080ofJI00H0c9VI0?mVV@3<VIT0c9VI
0?mVV@3<VIT20?mVV@030<bIV@3oc9T0c9VI0080ofJI2P3<VIT01P1E0000_Kfm0;fm_@3oc9T0c9UV
0:[oZP80c9UV00L0ojZZ09W<V@3oc9T0olbI0<30`03oc9T0`<300080olbI00H0ofJI0?o<V@3oIYT0
ofJI0?o<V@3<VIT20?o<V@030<bIV@3oZZX0c?mV0080ojZZ00L0c9UV0?o<V@3<VFH0c9UV0?o<V@3<
oiT0ojZZ0080c9VI00D0olbI0:6QX@3oc9T0olbI0:6QX@020?o<VA00oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0d0?ooo`00:`3oool20<bIIP030?ooIP3<VFH0VIW<0080VIWo00H0
<`1V0<c<c000EJX005FZ03lo?`0c06H=0?ooo`<0000000L0000A00L71`2IVOl0VIWo03=VV@0c06H0
_Kfm0080IS>I00L0001g06HcV@0007L0001g06IVV@1EEJX0IVJI0080IS>I00H005EE06HcV@00EED0
05EE06IVV@1bLW8206IVV@0306HcIP1VIYT0IS=V0080IVJI00@0LW9b06IVV@1bLW80LW9b0`1VIYT2
05EEZP0709TcV@1EEJX0ZUFZ0:YEZP3<I/`0ZUFZ0<aVc00209Tcc00705EEo`2I<l`0EEGo05EEo`2Z
EJX0SHf=0:YEZP0709TcV@0306IVV@21PH40PH610080IVJI00@0QHF506IVV@1VIYT0QHF51@29RHT:
09TcV@H0ZUFZ00L0c02I0:YEZP3<09T0c02I0:YEZP3<09T0ZUFZ0080c02I00L0ZUFZ0<`0V@2ZEJX0
ZUFZ0<`0V@2ZEJX0VC>I0080TI6A00<0VC>I096AT@2I<iT00P2I<iT01P29RHT0VC>I0:YEZP2ZEJX0
c9VI0:YEZP80TI6A00<0ZUFZ096AT@2ZEJX00P2ZEJX01P25QHD0c9VI0:YEZP2ZEJX0c9VI09TcV@80
c9VI00<0VC>I0<bIV@3oZZX00P3<VIT0102ZEJX0c9VI0:YEZP2ZEJX?0<bIV@030?nZZP3<VIT0c9VI
00@0c9VI00<0c9UV0?nZZP3<VIT00P3<VIT01`3<VFH0ojZZ0<bIIP3<VFH0ojZZ0<bIIP3oZZX00P3<
VFH01`3oZZX0c9VI0?o<V@3oc9T0c9VI0?o<V@3<VIT00P2Ic6H00`3<ofH0c9UV0?o<V@060?o<V@03
0<bIV@3<VFH0c9VI0080c9VI00<0olbI0<bIV@3<VIT00P3oc9T01@3<VFH0olbI0?o<V@3oZZX0c9UV
0080ojZZ00<0c9VI0<bIIP3oc9T00P3<VIT20?nZE@80ojZZ00<0ojYE0<bIV@3oZUD00P3oZUD?0?oo
o`8000002P3oool00`000000oooo0?ooo`0d0?ooo`00:`3oool20<bIIP030?ooIP3<VFH0VIW<0080
VIWo00H0<`1V0<c<c000EJX005FZ03lo?`0c06H=0?ooo`<0000000L0000A00L71`2IVOl0VIWo03=V
V@0c06H0_Kfm0080IS>I00L0001g06HcV@0007L0001g06IVV@1EEJX0IVJI0080IS>I00H005EE06Hc
V@00EED005EE06IVV@1bLW8206IVV@0306HcIP1VIYT0IS=V0080IVJI00@0LW9b06IVV@1bLW80LW9b
0`1VIYT205EEZP0709TcV@1EEJX0ZUFZ0:YEZP3<I/`0ZUFZ0<aVc00209Tcc00705EEo`2I<l`0EEGo
05EEo`2ZEJX0SHf=0:YEZP0709TcV@0306IVV@21PH40PH610080IVJI00@0QHF506IVV@1VIYT0QHF5
1@29RHT:09TcV@H0ZUFZ00L0c02I0:YEZP3<09T0c02I0:YEZP3<09T0ZUFZ0080c02I00L0ZUFZ0<`0
V@2ZEJX0ZUFZ0<`0V@2ZEJX0VC>I0080TI6A00<0VC>I096AT@2I<iT00P2I<iT01P29RHT0VC>I0:YE
ZP2ZEJX0c9VI0:YEZP80TI6A00<0ZUFZ096AT@2ZEJX00P2ZEJX01P25QHD0c9VI0:YEZP2ZEJX0c9VI
09TcV@80c9VI00<0VC>I0<bIV@3oZZX00P3<VIT0102ZEJX0c9VI0:YEZP2ZEJX?0<bIV@030?nZZP3<
VIT0c9VI00@0c9VI00<0c9UV0?nZZP3<VIT00P3<VIT01`3<VFH0ojZZ0<bIIP3<VFH0ojZZ0<bIIP3o
ZZX00P3<VFH01`3oZZX0c9VI0?o<V@3oc9T0c9VI0?o<V@3<VIT00P2Ic6H00`3<ofH0c9UV0?o<V@06
0?o<V@030<bIV@3<VFH0c9VI0080c9VI00<0olbI0<bIV@3<VIT00P3oc9T01@3<VFH0olbI0?o<V@3o
ZZX0c9UV0080ojZZ00<0c9VI0<bIIP3oc9T00P3<VIT20?nZE@80ojZZ00<0ojYE0<bIV@3oZUD00P3o
ZUD?0?ooo`8000002P3oool00`000000oooo0?ooo`0d0?ooo`00:`3oool20<coV@0306K<c01VIYT0
I/c<0080VIW<00H005FZ0000V@0c06H0<`1V0000V@0c09T=0?ooo`<0000000L0000A0<coV@1nOWh0
OWin03=VIP0c09T0c9Wo0080EEFZ00L005EE06HcV@00EED005EE06HcV@1V<fH0IS>I0080<`2I00D0
IS>I03<0V@1V<iT0IS>I03=VV@0<06HcV@030:YEZP1V<iT0ZUFZ0080IVJI00L0ZUFZ06IVV@0cI/`0
<fK<06IVV@0cI/`0IVJI0080<fK<00L0SHf=09VIc02=SHd0SHf=05EEo`1VIYT0PH610080IVJI00H0
PH6106IVV@1nOWh0OWin06IVV@1Vc9T209TcV@0306K<V@2I<iT0EJZZ0080VC>I00L0EJZZ09TcV@1V
IYT0IVJI09TcV@1VIYT0TI6A0080IS>I00L0TI6A06HcV@2ATI40TI6A09TcV@2ATI40c02I0080TI6A
00H0c02I096AT@3<09T0c02I096AT@3<VIT2096AT@030<bIV@2ATI40c9VI0080TI6A00<0c9VI096A
T@3<VIT00P3<VIT01P2ATI40c9VI0:X0ZP2Z0:X0c9VI0:X0ZP80c9VI00<0TI6A0<bIV@2ATI400P3<
VIT01`2IVL`0c9VI0?mVV@3oIYT0c9VI0?mVV@3<VIT00P2ZEED60<bIV@80PH6100<0c9VI0861P@3<
VIT00P2a/K401`3<VIT0OWin0<bIV@3<VIT0OWin0<bIV@2ZEJX00P3<VIT01`2ZEJX0c9VI0:YEZP2Z
EJX0c9VI0?mVV@3<VIT00P3oIYT01P3<VIT0c9UV0<bIV@3<VIT0ofJI0<bIV@80ofJI00<0c9VI0?o<
V@3<VIT00P3oIYT50<bIV@060?nZZP3<VIT0c9VI0<bIV@2Ic9T0ojZZ0P2Ic9T00`3oZZX0VLbI0<bI
V@030?nZZP060<30`03oc9T0olbI0<30`03oc9T0`<300`3<oiT01@3oc9T0ofJI0?mVV@3oc9T0c9VI
0080olbI00<0c9VI0?nZZP3<ofH00P3oZZX01`3<VFH0olbI0<bIIP3<VFH0olbI0<coV@3oc9T00P3<
VIT00`3oc9T0XJ6Q0?o<V@060?o<V@l0oooo0P0000050?ooo`D00000=`3oool002X0oooo00H0/K6a
0<bIIP3<VFH0c?mV09VIo`1EEOl209VIo`0603<0IP0o?cl005FZ001EZP0o?cl0<`1V0P0o?cl:0?oo
o`@0000000L0000A05EEZP2IVOl0VIWo03=VV@0c06H0<fJI00@0IS>I0P0007L205EEZP0506IVV@1V
<iT0IS>I001EE@1V<iT00P00EED01`1EEJX0<`1V06IVV@1VIYT0IS=V06IVV@1V<fH00P1VIYT0101b
LW80IVJI079bLP1bLW8306IVV@80EEFZ00L0VC>I05EEZP2I<iT0VC>I0<aVc02ZEJX0c6K<0080ZUFZ
00H0EEGo09Tcc01EEJX0EEFZ079bLP1EEJX809TcV@0306IVV@21PH40PH610080IVJI00@0QHF506IV
V@1VIYT0QHF51@29RHT809TcV@P0ZUFZ00L0c02I0:YEZP3<09T0c02I0:YEZP3<09T0ZUFZ0080c02I
00L0ZUFZ0<`0V@2ZEJX0ZUFZ08f=S@2ZEJX0SHf=0080TI6A00L0VC>I096AT@2I<iT0VC>I096AT@29
RHT0VC>I0080ZUFZ00H0c9VI0:YEZP2ATI40TI6A0:YEZP2ATI440:YEZP050<bIV@2ZEJX0ZUFZ0<bI
V@2I<iT00P3<VIT00`2I<iT0c9VI0?nZZP020<bIV@040:YEZP3<VIT0ZUFZ0:YEZPL0c9VI0P3oZZX5
0<bIV@030?o<V@3oZZX0c9VI00D0c9VI00<0c9UV0?nZZP3<VFH00P3<VIT01`3<VFH0ojZZ0<bIIP3<
VFH0c9VI0<bIIP3oZZX00`3<VFH01P3<VIT0c9UV0<bIIP3<VIT0c9UV0<bIV@<0olbI00<0c9UV0?o<
V@3oc9T00P3oc9T01@3<ol`0_Kfm0;fm_@3<ol`0c9UV00<0c9VI00H0olbI0<bIV@3<VIT0olbI0?o<
c03<VFH20?o<V@070?nZZP3<VFH0olbI0?o<V@3<VIT0olbI0?nZE@020<bIV@80ojYE0P3oZZX00`3o
ZUD0c9VI0?nZE@020?nZE@030?o<V@3oool0oooo00h0oooo0P0000030?ooo`030000003oool0oooo
03T0oooo000H0?ooo`0306K<c03oool0oooo00l0oooo00H0c9VI0?ooZP3oojX0c9UV06IVV@1Vc<`3
09VIc0050000V@0c06H0<`1V06HcV@0c09T00P0009T90?ooo`<000000P0001401`1EEJX0E@2Z07in
OP1nOWh0ZUGo03<0V@0cIVH00P1EEJX01`1V<fH0IS>I001EE@00EED0<`2I06HcIP1V<iT00P0c09T0
1P1V<iT0<`2I06HcV@1V<iT0<`2I06HcV@80<fJI2@1V<iT00`2ZEJX0IS>I0:YEZP0206IVV@060:YE
ZP1VIYT0ZUFZ0:YEZP1VIYT0<fK<0`1VIYT01`1V<iT0IVJI06HcV@1V<iT0VC>I06HcV@2I<iT00P1V
IYT01P21PH40IVJI07inOP1nOWh0IVJI06K<V@80VC>I00<0I/bI09TcV@1EZZX00P2I<iT01`1EZZX0
VC>I06IVV@1VIYT0VC>I06IVV@2ATI400P1V<iT01`2ATI40IS>I096AT@2ATI40VC>I096AT@3<09T0
0P2ATI401P3<09T0TI6A0<`0V@3<09T0TI6A0<bIV@80TI6A00<0c9VI096AT@3<VIT00P2ATI401`3<
VIT0TI6A096AT@2ATI40c9VI096AT@3<VIT00P2Z0:X01`3<VIT0ZP2Z0<bIV@3<VIT0ZP2Z0<bIV@2I
VL`00P3<VIT01`2IVL`0c9VI0?mVV@3oIYT0c9VI0?mVV@3<VIT00P2ZEED60<bIV@80PH6100<0c9VI
0;6a/@3<VIT00P2a/K401`3<VIT0OWin0<bIV@3<VIT0`<300<bIV@2ZEJX00P3<VIT01`2ZEJX0c9VI
0:6QX@2QXJ40c9VI0?mVV@3<VIT00P3oIYT01P3<VIT0c9UV0<bIV@3<VIT0ofJI0<bIV@80olbI00<0
c9VI0?o<V@3<VIT01P3<VIT00`3<ofH0ojZZ0<bIV@020<bIV@0709W<V@3oZZX0VLbI09W<V@3oZZX0
VLbI0<bIV@030?nZZP0409W<V@3oZZX0ojZZ0<30`0D0c?nI00D0olbI0?mVV@3oIYT0olbI0<bIV@02
0?o<V@030<bIV@3oojX0c?mV0080ojZZ00L0c9UV0?o<V@3<VFH0c9UV0?o<V@3<VFH0olbI0080c9VI
00<0olbI0:6QX@3oc9T01P3oc9T00`3<VC<0olbI0?ooo`0<0?ooo`80000000<0oooo0000003oool0
0P3oool6000003H0oooo000H0?ooo`0306K<c03oool0oooo00l0oooo00H0c9VI0?ooZP3oojX0c9UV
06IVV@1Vc<`309VIc0050000V@0c06H0<`1V06HcV@0c09T00P0009T90?ooo`<000000P0001401`1E
EJX0E@2Z07inOP1nOWh0ZUGo03<0V@0cIVH00P1EEJX01`1V<fH0IS>I001EE@00EED0<`2I06HcIP1V
<iT00P0c09T01P1V<iT0<`2I06HcV@1V<iT0<`2I06HcV@80<fJI2@1V<iT00`2ZEJX0IS>I0:YEZP02
06IVV@060:YEZP1VIYT0ZUFZ0:YEZP1VIYT0<fK<0`1VIYT01`1V<iT0IVJI06HcV@1V<iT0VC>I06Hc
V@2I<iT00P1VIYT01P21PH40IVJI07inOP1nOWh0IVJI06K<V@80VC>I00<0I/bI09TcV@1EZZX00P2I
<iT01`1EZZX0VC>I06IVV@1VIYT0VC>I06IVV@2ATI400P1V<iT01`2ATI40IS>I096AT@2ATI40VC>I
096AT@3<09T00P2ATI401P3<09T0TI6A0<`0V@3<09T0TI6A0<bIV@80TI6A00<0c9VI096AT@3<VIT0
0P2ATI401`3<VIT0TI6A096AT@2ATI40c9VI096AT@3<VIT00P2Z0:X01`3<VIT0ZP2Z0<bIV@3<VIT0
ZP2Z0<bIV@2IVL`00P3<VIT01`2IVL`0c9VI0?mVV@3oIYT0c9VI0?mVV@3<VIT00P2ZEED60<bIV@80
PH6100<0c9VI0;6a/@3<VIT00P2a/K401`3<VIT0OWin0<bIV@3<VIT0`<300<bIV@2ZEJX00P3<VIT0
1`2ZEJX0c9VI0:6QX@2QXJ40c9VI0?mVV@3<VIT00P3oIYT01P3<VIT0c9UV0<bIV@3<VIT0ofJI0<bI
V@80olbI00<0c9VI0?o<V@3<VIT01P3<VIT00`3<ofH0ojZZ0<bIV@020<bIV@0709W<V@3oZZX0VLbI
09W<V@3oZZX0VLbI0<bIV@030?nZZP0409W<V@3oZZX0ojZZ0<30`0D0c?nI00D0olbI0?mVV@3oIYT0
olbI0<bIV@020?o<V@030<bIV@3oojX0c?mV0080ojZZ00L0c9UV0?o<V@3<VFH0c9UV0?o<V@3<VFH0
olbI0080c9VI00<0olbI0:6QX@3oc9T01P3oc9T00`3<VC<0olbI0?ooo`0<0?ooo`80000000<0oooo
0000003oool00P3oool6000003H0oooo000G0?ooo`0306K<o`30`<00oooo0100oooo00H0c9UV06Hc
c01V<l`0EEFZ09VIo`1EEOl20000M`0609VIc00o?cl005FZ001EZP0c09T0<`1V0P0o?cl00`0c06H0
oooo0?ooo`060?ooo`<000000P3<ol`01`000:X0EEFZ09VIo`2IVOl0EEGo03<0IP0cIYT0101V<iT2
0000M`0305EEZP1>CTh0IVJI0080IS>I00H005EE06HcV@00EED005EE06HcV@0c06H205EEZP0306Hc
V@1EEJX0IS=V0080IVJI00@0LW9b06IVV@1bLW80LW9b0`1VIYT205EEZP0709TcV@1EEJX0VC>I09Tc
V@3<I/`0IVJI06HcV@0206IVV@0706HcIP1VIYT0EEFZ05EEZP1bLW80EEFZ06IVV@020861P@D0VC>I
00H0IVJI0861P@21PH40IVJI0861P@25QHD206IVV@0308F5Q@29RHT0RHV900<0RHV91@2I<iT;0:YE
ZP070<`0V@2ZEJX0c02I0<`0V@2ZEJX0c02I0:YEZP020<`0V@070:YEZP2=SHd0ZUFZ0:YEZP2=SHd0
ZUFZ08f=S@02096AT@0709TcV@2ATI40VC>I09TcV@2ATI40RHV90<bIV@020:YEZP070<bIV@2ZEJX0
TI6A096AT@2ZEJX0TI6A0:YEZP020<bIV@060:YEZP3<VIT0ZUFZ0:YEZP3<VIT0ZUFZ0P3<VIT00`2I
<iT0c9VI0?nZZP020<bIV@050:YEZP3<VIT0ZUFZ0:YEZP3oZZX01P3<VIT20?nZZP030?o<V@3<VIT0
c9VI0080c9VI00@0olbI0?nZZP3oc9T0olbI0P3<VIT20?nZZP030<bIIP3oZZX0c9UV0080ojZZ00L0
c9UV0?nZZP3<VFH0c9UV0<bIV@3<VFH0ojZZ00<0c9UV00H0c9VI0<bIIP3<VFH0olbI0<bIIP3oc9T2
0<bIIP070?o<V@3<VFH0c9UV0<bIIP3<VIT0c9UV0?nZZP020<bIIP060?nZZP2m_Kd0olbI0?o<V@3<
VIT0olbI0P3<VIT00`3oc9T0olc<0<bIIP020<bIIP070?nZZP3<VFH0olbI0?o<V@3<VIT0olbI0;fm
_@020<bIV@80ojYE0P3oZZX00`3oZUD0c9VI0?o<V@020?nZE@030?o<V@3oZUD0oooo00l0oooo00<0
00000?ooo`3oool0?@3oool001P0oooo00<0I/c<0000IP0006H03P3oool01`3<oiT0c9UV0?ooZP3o
ojX0EEFZ03=Vc01Vc<`00P0007L01P2IVL`0002I03<0IP0c06H0IS>I03<0V@80002I00<0IS>I0?oo
o`3oool0103oool500000080002I00L0ooo<05D0ZP0009T0002I0:YEo`0c09T0<fIV0080<`2I00L0
IS=V06HcV@00EED005EE03<0V@000:X0IS>I0080<`2I00H0IS>I03<0V@1V<iT0IS>I03<0V@1V<iT2
03=VV@0305EEZP1V<iT0EEFZ00H0IS>I00<0ZUFZ06HcV@2ZEJX00P1VIYT01`2ZEJX0IS>I03=VIP0c
IVH0IVJI079bLP1V<iT00P1VIYT01`1V<iT0IVJI06HcV@1V<iT0VC>I06HcV@2I<iT00P1V<iT01P2I
<iT0IVJI07inOP1nOWh0IVJI06K<V@80VC>I00<0I/bI09TcV@1EZZX00P2I<iT01`1EZZX0VC>I06IV
V@1VIYT0VC>I06IVV@2ATI400P2I<l`01`2ATI40VC?<096AT@2ATI40VC>I096AT@2I<iT00P2ATI40
1P3<09T0TI6A0<`0V@3<09T0TI6A0<bIV@80TI6A00<0c9VI096AT@3<VIT00P2ATI420<bIV@80TI6A
00<0c9VI096AT@3<VIT00P2Z0:X01`3<VIT0ZP2Z0<bIV@3<VIT0ZP2Z0<bIV@2IVL`00P3<VIT01P2I
VL`0c9VI0?mVV@3oIYT0c9VI0?mVV@T0c9VI0P21PH400`3<VIT0/K6a0<bIV@020;6a/@070<bIV@1n
OWh0c9VI0<bIV@30`<00c9VI0:YEZP020<bIV@070:YEZP3<VIT0XJ6Q0:6QX@3<VIT0ofJI0<bIV@02
0<bIIP060<bIV@3<VFH0c9VI0<bIV@3oIYT0c9VI0P3oc9T00`3<VIT0olbI0<bIV@060<bIV@030<co
IP3oZZX0c9VI0080c9VI00L0VLbI0?nZZP2Ic9T0VLbI0?nZZP2Ic9T0ojZZ0080VLbI00L0ojZZ09W<
V@3oc9T0olbI0?nZZP3oc9T0c9UV0080olbI00H0/K6a0?o<V@3<VIT0c9VI0?o<V@3<VIT20?ooZP03
0<bIV@3oojX0c9VI0080olbI00L0c9UV0?o<V@3<VFH0c9UV0?o<V@3<VFH0olbI0080c9VI00<0olbI
0:6QX@3oc9T00`3oc9T01@3<VFH0olbI0?o<V@3<VC<0olbI0080oomV3`3oool00`000000oooo0?oo
o`0l0?ooo`00603oool00`30`<00001V0000IP0>0?ooo`0709W<IP3<ofH0olbI0?o<V@1EEJX0IS?<
05EEo`020000M`0609VIc00o?cl0001g0000M`0c09T0<`1V0P0o?cl00`0c06H0oooo0?ooo`040?oo
o`@0000000D0c?o<001EZP00EJX0<fJI05EEZP020000IP0305EEo`0c06H0<fJI0080<fIV0P1V<iT2
0000M`0305EEZP1>CTh0EEFZ0080IS>I00H005EE06HcV@00EED005EE06HcV@0c06H205EEZP0303<0
IP1EEJX0IS>I0080EEFZ101EZ_l206IVV@0505FZo`00EJX005FZ06HcV@0007L00P1V<iT00`2I<l`0
IVJI06HcV@0206IVV@0706HcIP1VIYT0EEFZ05EEZP1bLW80EEFZ06IVV@020861P@0306IVV@2I<iT0
VC>I0080VC>I00H0IVJI0861P@21PH40IVJI0861P@25QHD206IVV@0708F5Q@29RHT0RHV908V9R@2I
<l`0VC>I0:YEZP0209TcV@030:YEZP2I<iT0ZUFZ00X0ZUFZ00L0c02I0:YEZP3<09T0c02I0:YEZP3<
09T0ZUFZ0080c02I00L0ZUFZ08f=S@2ZEJX0ZUFZ08f=S@2ZEJX0SHf=0080TI6A00L0VC>I096AT@2I
<iT0VC>I096AT@2ZEJX0c9VI0080ZUFZ00L0c9VI0:YEZP2ATI40TI6A0:YEZP2ATI40ZJVY0080c9VI
00H0ZUFZ0<bIV@2ZEJX0ZUFZ0<bIV@2ZEJX20<bIV@030?nZZP3<VIT0ojZZ0080c9VI00D0ZUFZ0<bI
V@3<VIT0c9VI0?nZZP050<bIV@040?o<V@3oZZX0ojZZ0?o<V@80c9VI0P3oZZX0103oc9T0ojZZ0?o<
V@3oc9T20<bIV@80ojZZ00<0c9UV0?nZZP3<VFH00P3oZZX01P3<VFH0ojZZ0<bIIP3<VFH0c9VI0<bI
IP<0c9VI00L0c9UV0<bIV@3<VFH0c9UV0?o<V@3<VFH0olbI0080c9UV00L0olbI0<bIIP3<VFH0c9UV
0<bIV@3<VFH0ojZZ0080c9UV00H0ojYE0?nZZP2I<c<0VC<c0<bIV@3oc9T20?o<c0030?o<V@3oc<`0
olbI0080c9UV00L0ojZZ0<bIV@3oc9T0olbI0<bIV@3oc9T0_Kfm0080c9VI00L0ojZZ0?nZE@3oZZX0
ojZZ0?nZE@3<VIT0olbI0080ojYE00H0olbI0?nZE@3oZUD0ojYE0?mVIP3oofH=0?ooo`<00000?03o
ool001P0oooo00<0I/c<0000IP0006H0303oool30<coIP0609W<V@3oojX0oonZ05EEZP0cI/`0I/c<
0`0007L01@0009T0<`1V03<0IP1V<iT0<`2I0080002I00<0IS>I0000V@3oool00`3oool01P000000
VLbI09W<V@000000b<S80?ooc080002I00L0<`2I05D0ZP0009T0002I0:YEo`0c09T0<fIV0080<`2I
00H0IS=V06HcV@00EED005EE03<0V@000:X303<0V@0606HcV@0c09T0IS>I06HcV@0c09T0IS>I0P0c
IYT206HcV@0505EEZP1V<iT0IS>I05EEZP1EEOl00P1VIYT00`1EEOl0IVJI09TcV@0206HcV@0703lo
?`1V<iT0<fIV03=VIP1V<iT0LW9b06HcV@0206IVV@0706HcV@1VIYT0IS>I06HcV@2I<iT0IS>I09Tc
V@0206HcV@0309TcV@1VIYT0IVJI0080IVJI00H0EJZZ09TcV@2I<iT0EJZZ09TcV@1EZZX209TcV@07
08f=S@2ATI40EEFZ05EEZP2ATI40EEFZ096AT@0209Tcc007096AT@2I<l`0TI6A096AT@2I<iT0TI6A
09TcV@02096AT@060<`0V@2ATI40c02I0<`0V@2ATI40c9VI0P2ATI400`3<VIT0TI6A0<bIV@020<bI
V@070;6a/@3<VIT0TI6A096AT@3<VIT0TI6A0<bIV@020:X0ZP070<bIV@2Z0:X0c9VI0<bIV@2Z0:X0
c9VI09VIc0020<bIV@0709VIc03<VIT0ofJI0?mVV@3<VIT0ofJI0?nZZP020:ZZZPH0c9VI0P21PH40
0`3<VIT0/K6a0<bIV@020;6a/@070<bIV@1nOWh0c9VI0<bIV@30`<00c9VI0:YEZP020<bIV@070:YE
ZP3<VIT0XJ6Q0:6QX@3<VIT0ofJI0<bIV@020<bIIP060<bIV@3<VFH0c9VI0<bIV@3<VFH0c9VI0P3o
c9T00`3<VIT0olbI0<bIV@040<bIV@80ojZZ00<0c?mV0?nZZP3<ofH00P3oZZX01P2Ic9T0ojZZ09W<
V@2Ic9T0ojZZ09W<V@@0ojZZ00H0VLbI0?o<V@3oc9T0ojZZ0?o<V@3<VFH20?o<V@060;6a/@3oc9T0
c9UV0<bIIP3oc9T0c9VI0P3oojX00`3<VIT0oonZ06K<c0020?o<V@040<bIIP3oc9T0c9UV0<bIIPH0
olbI00<0XJ6Q0?o<V@3oc9T00P3oc9T01@3<VFH0olbI0?o<V@3<VC<0olbI0080oomV00<0olbI0?nZ
E@3oc9T0303oool3000003`0oooo000H0?ooo`0306K<c00006H0001V00`0oooo0`3<ofH01P2Ic9T0
oonZ0?ooZP1EEJX0<fK<06K<c0<0001g00D0002I03<0IP0c06H0IS>I03<0V@020000V@0306HcV@00
09T0oooo00<0oooo00H0000009W<V@2Ic9T000000<S8b03ool`20000V@0703<0V@1E0:X0002I0000
V@2ZEOl0<`2I03=VIP0203<0V@0606HcIP1V<iT005EE001EE@0c09T0002Z0`0c09T01P1V<iT0<`2I
06HcV@1V<iT0<`2I06HcV@80<fJI0P1V<iT01@1EEJX0IS>I06HcV@1EEJX0EEGo0080IVJI00<0EEGo
06IVV@2I<iT00P1V<iT01`0o?cl0IS>I03=VIP0cIVH0IS>I079bLP1V<iT00P1VIYT01`1V<iT0IVJI
06HcV@1V<iT0VC>I06HcV@2I<iT00P1V<iT00`2I<iT0IVJI06IVV@0206IVV@0605FZZP2I<iT0VC>I
05FZZP2I<iT0EJZZ0P2I<iT01`2=SHd0TI6A05EEZP1EEJX0TI6A05EEZP2ATI400P2I<l`01`2ATI40
VC?<096AT@2ATI40VC>I096AT@2I<iT00P2ATI401P3<09T0TI6A0<`0V@3<09T0TI6A0<bIV@80TI6A
00<0c9VI096AT@3<VIT00P3<VIT01`2a/K40c9VI096AT@2ATI40c9VI096AT@3<VIT00P2Z0:X01`3<
VIT0ZP2Z0<bIV@3<VIT0ZP2Z0<bIV@2IVL`00P3<VIT01`2IVL`0c9VI0?mVV@3oIYT0c9VI0?mVV@3o
ZZX00P2ZZZX60<bIV@80PH6100<0c9VI0;6a/@3<VIT00P2a/K401`3<VIT0OWin0<bIV@3<VIT0`<30
0<bIV@2ZEJX00P3<VIT01`2ZEJX0c9VI0:6QX@2QXJ40c9VI0?mVV@3<VIT00P3<VFH01P3<VIT0c9UV
0<bIV@3<VIT0c9UV0<bIV@80olbI00<0c9VI0?o<V@3<VIT0103<VIT20?nZZP030<coIP3oZZX0c?mV
0080ojZZ00H0VLbI0?nZZP2Ic9T0VLbI0?nZZP2Ic9T40?nZZP0609W<V@3oc9T0olbI0?nZZP3oc9T0
c9UV0P3oc9T01P2a/K40olbI0<bIIP3<VFH0olbI0<bIV@80oonZ00<0c9VI0?ooZP1Vc<`00P3oc9T0
103<VFH0olbI0<bIIP3<VFH60?o<V@030:6QX@3oc9T0olbI0080olbI00D0c9UV0?o<V@3oc9T0c9Tc
0?o<V@020?ooIP030?o<V@3oZUD0olbI00`0oooo0`00000l0?ooo`00603oool0100005D0I/co06K<
o`0007L;0?ooo`80c9UV00L0olbI03=Vc01V<l`0IS?<03=Vc01V<l`0001g0080VIWo00H0001g03lo
?`0007L0001g03<0V@0c06H203lo?`0303<0IP0cIYT0oooo00<0oooo0`0000000`3oofH0002I0<co
c002001EZP0403=VV@1EEJX0001V0000IP80<`1V00D0<fJI03=VIP0cIVH0001V06HcV@020000M`03
06HcV@1>CTh0EEFZ0080EEFZ00H005EE06HcV@00EED005EE06HcV@0c06H205EEZP0303<0IP1EEJX0
IS>I0080EEFZ00<0IS>I05FZo`1EZ_l00P1EZ_l01P1V<iT0EEFZ001EZP00EJX0IS>I0000M`80IS>I
00<0001g06IVV@1V<iT00P1VIYT01`1V<fH0IVJI06HcIP1V<fH0LW9b05EEZP1VIYT00P21PH400`1V
IYT0VC>I09TcV@0209TcV@0506IVV@2ATI40TI6A06IVV@2ATI40102ZEJX01P2I<l`0VC>I09TcV@2I
<l`0VC>I0:YEZP80VC>I00<0ZUFZ09TcV@2ZEJX02P2ZEJX01`3<09T0ZUFZ0<`0V@3<09T0ZUFZ0<`0
V@2ZEJX00P2IVL`01`2ZEJX0VIW<0:YEZP2ZEJX0SHf=0:YEZP2=SHd00P2ZEJX01`2I<iT0TI6A09Tc
V@2I<iT0c9VI0?mVc03<VIT00P2ZEJX01`3<VIT0ZUFZ096AT@2ATI40ZUFZ0:ZZZP2YZJT00P2ZZZX0
1P2ZEJX0c9VI0:YEZP2ZEJX0c9VI0:YEZP80c9VI00<0ojZZ0<bIV@3oZZX00P3<VIT01@3oZZX0c9VI
0<bIV@3<VIT0ojZZ00@0c9VI00L0ojZZ0?o<V@3oZZX0ojZZ0?o<V@3oZZX0c9VI0080ojZZ00H0olbI
0?nZZP3oc9T0olbI0?nZZP3<VFH20?nZZP030<bIIP3oZZX0c9VI0080c9VI00H0c9UV0?nZZP3<VFH0
c9UV0<bIV@3<VFH30<bIV@070<bIIP3<VIT0c9UV0<bIIP3oc9T0c9UV0?o<V@020<bIV@070?o<V@3<
VFH0c9UV0<bIIP3<VIT0c9UV0?nZZP020<bIIP060?nZE@3oZZX0olbI0?o<V@3oZUD0olbI0P3oc<`0
0`2Zool0Z_nZ0:[oo`020<bIIP070?nZZP3<VIT0olbI0?o<V@3<VIT0olbI0;fm_@020?o<V@070?nZ
ZP3oZUD0ojZZ0?nZZP3oZUD0c9VI0?o<V@020?nZE@050?o<V@3oZUD0ojYE0?nZE@3oIVH00P3oofH2
0?nZE@040?nZZP3oZUD0c?mV0<coIPT0oooo00<000000?ooo`3oool0>@3oool001P0oooo00@0001V
0:ZZo`2ZZ_l0001V2P3oool30<coIP030?ooZP2ZZUD0<fK<00<0<fK<00D0001g06IVV@1VIYT0001g
0000V@0203<0IP070000M`0c09T0002I0000V@0c09T0002I06HcV@0203=Vo`0706Hcc0000000IS?<
06Hcc03ool`0oonZ0000V@020<S8b00703<0V@0006H0EEFZ05EEZP0cIVH0<`2I03=VIP0203<0V@80
IS>I0P00EED00`1V<iT0002Z03<0V@0203=VV@0606HcV@0c09T0IS>I06HcV@0c09T0IS>I0P0cIYT2
06HcV@0505EEZP1V<iT0IS>I05EEZP1V<iT00P1VIYT00`0cIYT0<`2I09TcV@0206HcV@0703lo?`1V
<iT0<fIV03=VIP1V<iT0002I06HcV@02079bLP0706HcV@1VIYT0IS>I06HcV@2I<iT0IS>I09TcV@02
06HcV@0309TcV@1VIYT0IVJI0080IVJI00H0EJZZ09TcV@2I<iT0EJZZ09TcV@2=SHd206IVV@0708f=
S@2ATI40EEFZ05EEZP2ATI40EEFZ096AT@0209Tcc007096AT@2I<l`0TI6A096AT@2I<iT0TI6A09Tc
V@02096AT@060<`0V@2ATI40c02I0<`0V@2ATI40c9VI0P2ATI400`3<VIT0TI6A0;6a/@020<bIV@07
0;6a/@3<VIT0TI6A096AT@3<VIT0TI6A0<bIV@02096AT@070<bIV@2Z0:X0^k^k0;^k^`3oZZX0^k^k
09VIc0020<bIV@0709VIc03<VIT0VIW<09VIc03<VIT0ZZZZ0?nZZP020:ZZZPH0c9VI0P2a/K400`3<
VIT0/K6a0<bIV@020;6a/@070<bIV@1nOWh0c9VI0<bIV@30`<00c9VI0<30`0020<bIV@070:6QX@3<
VIT0XJ6Q0:6QX@3<VIT0XJ6Q0<bIV@020<bIIP060<bIV@3<VFH0c9VI0<bIV@3<VFH0c9VI0P3oc9T0
0`3<VIT0olbI0?o<V@040<bIV@80ojZZ00<0c?mV0?nZZP3<ofH00P3oZZX01`2Ic9T0ojZZ09W<V@2I
c9T0ojZZ09W<V@3oc9T00`3oZZX01P2Ic9T0olbI0?o<V@3oZZX0olbI0<bIIP80olbI00H0/K6a0?o<
V@3<VFH0c9UV0?o<V@3oVC<20?o<V@030?ooIP3oc9T0I/c<0080c?o<00@0c9UV0?o<V@3<VFH0c9UV
1@3oc9T00`3oojX0XJ6Q0?o<V@030?o<V@050<bIIP3oc9T0olbI0<bI<`3oc9T00P3oofH00`3oc9T0
ojYE0?o<V@020?ooE@040?ooIP3oIVH0ojYE0?nZE@T0oooo00<000000?ooo`3oool0>@3oool001P0
oooo00@0001E06K<o`1Vc?l0001g2@3oool01P3<VFH0VLaV0<coIP3<ofH0olbI0<coIP80IS?<00<0
<fK<06Hcc00007L00P2IVOl01P0007L0?clo03<0IP0c06H0002I03<0IP80?clo00<0<`1V03=VV@0c
06H00P0cIYT01`0cc<`0<fK<0<coc03<ol`0c?nI0<coc000EJX00P0009T0100cIYT0001g0000ZP00
0:X203<0IP0503=VV@0c06H0<`1V0000IP1V<iT00P0007L00`1V<iT0CTi>05EEZP0205EEZP0603=V
IP1V<iT005EE001EE@1V<iT005EE0P1EEJX00`0c06H0EEFZ06HcV@0205EEZP0706HcV@0c06H0<fJI
03=VV@0009T0IS>I05EEZP02001EZP0706HcV@0007L0IS>I06HcV@0007L0IS>I03=VIP0206IVV@07
06HcIP1VIYT0IS=V06HcIP1bLW80EEFZ06IVV@020861P@0306IVV@2I<iT0VC>I0080VC>I00D0IVJI
096AT@2ATI40IVJI096AT@050:YEZP80VC>I00<0VC?<09TcV@2I<l`00P2I<iT00`2ZEJX0VC>I0:YE
ZP0<0:YEZP80c02I0`2ZEJX209VIc0070:YEZP2IVL`0ZUFZ0:YEZP2=SHd0ZUFZ08f=S@020:YEZP07
09TcV@2ATI40ofK<0?mVc03<VIT0ofK<0<bIV@020:YEZP070<bIV@2ZEJX0c9VI0<bIV@2ZEJX0ZZZZ
0:VYZ@020:ZZZP060:YEZP3<VIT0ZUFZ0:YEZP3<VIT0]KFe0P3oc9T00`3oZZX0c9VI0?nZZP020<bI
V@80ojZZ0P3<VIT00`3oZZX0c9VI0?nZZP020<bIV@070?nZZP3oc9T0ojZZ0?nZZP3oc9T0ojZZ0?o<
V@020?nZZP060?o<V@3oZZX0olbI0?o<V@3oZZX0c9UV0P3oZZX00`3<VFH0ojZZ0<bIV@020<bIV@06
0<bIIP3oZZX0c9UV0<bIIP3<VIT0c9UV0`3<VIT01@3<VFH0c9VI0<bIIP3<VFH0olbI0080c9UV0P3<
VIT01P3<VFH0c9VI0<bIIP3<VFH0c9VI0<bIIP<0ojZZ00H0ojYE0?nZZP3oc9T0olbI0?nZE@3oc9T2
0?mVIP030?ooIP3oojX0oonZ0080ZP0000L0olbI0<bIV@3oc9T0olbI0;fm_@3oc9T0_Kfm0080ojZZ
00L0c9VI0?nZE@3<VIT0c9VI0?nZE@3<VIT0olbI0080ojYE0P3oc9T20?nZE@030?mVIP3oofH0oomV
0080ojYE00D0ojZZ0?nZE@3<ofH0c?mV0<bIIP090?ooo`030000003oool0oooo03P0oooo000H0?oo
o`040000E@1Vc?l0I/co0000M`T0oooo00H0c9UV09W<IP3<ofH0c?mV0?o<V@3<ofH206Hcc00303=V
c01V<l`0001g0080VIWo00H0001g03lo?`0c06H0<`1V0000V@0c06H203lo?`0303<0IP0cIYT0<`1V
0080<fJI00L0<lc<03=Vc03<ol`0c?o<0<coV@3<ol`005FZ0080002I00@0<fJI0000M`000:X0002Z
0P0c06H01@0cIYT0<`1V03<0IP0006H0IS>I0080001g00<0IS>I04i>CP1EEJX00P1EEJX01P0cIVH0
IS>I001EE@00EED0IS>I001EE@80EEFZ00<0<`1V05EEZP1V<iT00P1EEJX01`1V<iT0<`1V03=VV@0c
IYT0002I06HcV@1EEJX00P00EJX01`1V<iT0001g06HcV@1V<iT0001g06HcV@0cIVH00P1VIYT01`1V
<fH0IVJI06HcIP1V<fH0LW9b05EEZP1VIYT00P21PH400`1VIYT0VC>I09TcV@0209TcV@0506IVV@2A
TI40TI6A06IVV@2ATI401@2ZEJX209TcV@0309Tcc02I<iT0VC?<0080VC>I00<0ZUFZ09TcV@2ZEJX0
302ZEJX20<`0V@<0ZUFZ0P2IVL`01`2ZEJX0VIW<0:YEZP2ZEJX0SHf=0:YEZP2=SHd00P2ZEJX01`2I
<iT0TI6A0?mVc03oI/`0c9VI0?mVc03<VIT00P2ZEJX01`3<VIT0ZUFZ0<bIV@3<VIT0ZUFZ0:ZZZP2Y
ZJT00P2ZZZX01P2ZEJX0c9VI0:YEZP2ZEJX0c9VI0;Fe]@80olbI00<0ojZZ0<bIV@3oZZX00P3<VIT2
0?nZZP80c9VI00<0ojZZ0<bIV@3oZZX00P3<VIT01`3oZZX0olbI0?nZZP3oZZX0olbI0?nZZP3oc9T0
0P3oZZX01P3oc9T0ojZZ0?o<V@3oc9T0ojZZ0<bIIP80ojZZ00<0c9UV0?nZZP3<VIT00P3<VIT01P3<
VFH0ojZZ0<bIIP3<VFH0c9VI0<bIIP<0c9VI00D0c9UV0<bIV@3<VFH0c9UV0?o<V@020<bIIP80c9VI
00H0c9UV0<bIV@3<VFH0c9UV0<bIV@3<VFH30?nZZP060?nZE@3oZZX0olbI0?o<V@3oZUD0olbI0P3o
IVH00`3oofH0oonZ0?ooZP020:X000070?o<V@3<VIT0olbI0?o<V@2m_Kd0olbI0;fm_@020?nZZP07
0<bIV@3oZUD0c9VI0<bIV@3oZUD0c9VI0?o<V@020?nZE@80olbI0P3oZUD00`3oIVH0oomV0?ooIP02
0?nZE@050?nZZP3oZUD0c?mV0<coIP3<VFH02@3oool00`000000oooo0?ooo`0h0?ooo`006@3oool2
0:ZZo`030000IP3oool0oooo00L0oooo00H0ZZ[o0<coIP2Ic9T0VLbI0?ooZP2ZZUD20?ooZP0303=V
c00006H0001g0080IVJI0P0007L2001EZP070000M`00EJX0002I0000V@0c09T0002I06HcV@020000
V@0406HcV@0cI_l0TI6A096AT@80oonZ00D0002I001EE@00EED0<`2I0000IP0205EEZP0303=VIP00
07L0<fIV0080<`2I00L0IS>I03<0V@00EED005EE06HcV@000:X0<`2I0080<fJI00H0<`2I001Vo`1E
EJX0EEFZ03<0V@1V<iT203=VV@0306HcV@0cIYT0EEFZ0080EJ[o00L0002I03=VV@1V<iT0IS>I03=V
V@0c09T0002I0080IS>I00L0?clo06HcV@0cIVH0<fIV06HcV@0009T0IS>I0080LW9b00L0IS>I06IV
V@1V<iT0IS>I09TcV@1V<iT0VC>I0080IS>I00<0VC>I06IVV@1VIYT00`1VIYT209TcV@0305FZZP2I
<iT0EJZZ0080IVJI00L0SHf=06IVV@1EEJX0EEFZ096AT@1EEJX0TI6A0080VC?<00L0TI6A09Tcc02A
TI40TI6A09TcV@2ATI40VC>I0080TI6A00H0c02I096AT@3<09T0c02I096AT@3<VIT2096AT@030<bI
V@2a/K40c9VI0080c9VI00L0/K6a0<bIV@2ATI40TI6A0<bIV@2ATI40c9VI0080TI6A00L0c9VI0?nZ
ZP2k^k/0^k^k0?nZZP2k^k/0VIW<0080c9VI00L0VIW<0<bIV@2IVL`0VIW<0?nZZP2ZZZX0ojZZ0080
ZZZZ1@3<VIT01P3oc<`0VLbI09W<V@3<VIT0/K6a0<bIV@80/K6a00L0c9VI0<30`03<VIT0c9VI0<30
`03<VIT0`<300080c9VI00L0XJ6Q0<bIV@2QXJ40XJ6Q0<bIV@2QXJ40c9VI0080c9UV00H0c9VI0<bI
IP3<VIT0c9VI0?o<V@3oZZX20?o<V@030<bIV@3oc9T0olbI00@0c9VI0P3oZZX00`3<ofH0ojZZ0?nZ
ZP020?o<V@0709W<V@3oZZX0VLbI09W<V@3oZZX0VLbI0?o<V@020?nZZP070?o<V@3oZZX0olbI0?o<
V@3oZZX0olbI0<bIIP020?o<V@060;6a/@3oc9T0c9UV0<bIIP3oc9T0oiTc0P3oc9T00`3oZUD0olbI
0?mVV@020?ooIP040<bIIP3oc9T0c9UV0<bIIP<0olbI0P3oZZX00`3oojX0ojZZ0?o<V@030?o<V@05
0<bIIP3oc9T0olbI0<bI<`3oc9T00P3oZUD00`3oc9T0ojYE0?o<V@020?ooE@050?ooIP3<ofH0ojYE
0?nZE@3<VC<02@3oool3000003P0oooo000I0?ooo`80001E0P0007L70?ooo`030:[oo`3<VFH0VLbI
0080c?mV00L0olbI0<coIP0cI_l0<fKo03=Vc00006H0EEFZ0080001V0P0007L203<0IP070000V@0c
IYT0IS>I06HcV@0c06H0<fJI03<0IP0203=VV@070<bIIP3<VIT0oonZ0?ooZP2ZojX0002I0<coV@02
0000V@0703=VV@0007L0002Z0000ZP0c06H0001g03=VV@0203<0IP070000IP0k>c/0001g0000M`1V
<iT0CTi>05EEZP0204i>CP0603=VIP1EEJX0IS?<06Hcc00cI/`0IS?<0P1EEJX00`0c06H0EEFZ06Hc
c0020000IP0705EEZP0c06H0?clo03lo?`0009T0IS>I03=VIP02001EZP0706HcV@00EJX0IS>I06Hc
V@0007L0IS>I03=VIP0206HcV@0706HcIP1VIYT0IS=V06HcIP1bLW80EEFZ079bLP020861P@0306IV
V@2I<iT0VC>I00<0VC>I0P2ATI400`1VIYT0TI6A06IVV@040:YEZP80VC>I00<0VC?<09TcV@2I<l`0
0P2I<iT00`2ZEJX0VC>I0:YEZP0>0:YEZP030<bIc02ZEJX0c9W<0080VIW<00L0ZUFZ09VIc02ZEJX0
ZUFZ08f=S@2ZEJX0SHf=0080c?o<00L0ofK<0<bIV@3oI/`0ofK<0<bIV@3oI/`0c9VI0080ZUFZ00L0
c9VI0:YEZP3<VIT0c9VI0:[oo`2ZZZX0ZJVY0080ZZZZ00H0ZJVY0<bIV@2ZEJX0ZUFZ0?o<V@2e]KD2
0?o<V@030?nZZP3<VIT0ojZZ0080c9VI0P3oZZX20<bIV@030?nZZP3<VIT0ojZZ0080olbI00L0ojZZ
0?o<V@3oZZX0ojZZ0?o<V@3oZZX0olbI0080ojZZ00H0olbI0?nZZP3oc9T0olbI0=3@d03<ofH20?nZ
ZP030<bIIP3<VIT0c9VI00@0c9VI0P3<VFH00`3<VIT0c9UV0<bIV@020<bIV@050<bIIP3<VIT0c9UV
0<bIIP3oc9T00P3<VFH20<bIV@060<bIIP3<VIT0c9UV0<bIIP3<VIT0c9UV0`3oZZX20?nZE@80olbI
00L0ojYE0?o<V@3oIVH0ofIV0?ooIP3ooeD0ojYE0080c9UV00L0ojYE0<bIV@3oc9T0olbI0;fm_@3o
c9T0_Kfm0080ojZZ00@0c9VI0?nZZP3<VIT0c9VI0P3oZUD00`3oc9T0ojYE0?nZE@020?o<V@80oomV
00<0ofIV0?nZE@3oofH00P3oZUD00`3oZZX0oomV0<bIIP020<bIIP0309W<IP3oool0oooo00L0oooo
0P00000h0?ooo`006@3oool30000IP030000M`3oool0oooo00D0oooo00<0c?oo0<coIP3oofH00P2Z
ZUD01`3oojX0c9Tc0?ooZP3oojX0<fK<0000IP1EEJX00P0006H20000M`8005FZ00L0001g03<0IP00
0:X0002Z001EZP0009T005FZ0080002Z00L0c9UV0?ooZP2Ic9T0VLbI0?ooZP00EJX0002I008005EE
0P0006H205EEZP0303=VIP0007L0<fIV0080<`2I00L0IS>I03<0V@0c06H0<`1V06HcV@000:X0<`2I
0080002Z00H0<`2I03=VV@1EEJX0EEFZ001Vo`1EEJX2001Vo`0305EEZP0007L0<fK<0080001V00L0
EEFZ03=VV@0009T0002I03=VV@0c09T0002I0080<`2I00L0?clo06HcV@0cIVH0<fIV06HcV@0009T0
IS>I0080002I00L0IS>I06IVV@1V<iT0IS>I09TcV@1V<iT0VC>I0080IS>I00<0VC>I06HcV@1VIYT0
0`1VIYT209TcV@0305FZZP2I<iT0EJZZ0080IVJI00L0SHf=06IVV@1EEJX0EEFZ096AT@1EEJX0TI6A
0080VC?<00L0TI6A09Tcc02ATI40TI6A09TcV@2ATI40VC>I0080TI6A00H0c02I096AT@3<09T0c02I
0;fm_@3<VIT20;6a/@030<bIV@2a/K40c9VI0080c9VI00L0/K6a0<bIV@2a/K40/K6a0<bIV@2ATI40
gMgM0080l?3`00L0gMgM0?nZZP2k^k/0^k^k0?nZZP2k^k/0ojZZ0080c9VI00L0VIW<0<bIV@3<ol`0
c?o<0?ooc02ZZZX0ojZZ0080ZZZZ00H0ojZZ0<bIV@3oc<`0olc<09W<V@3oc<`209W<V@030<bIV@2a
/K40c9VI0080/K6a00L0ooo<09W<V@3<VIT0c9VI0<30`03<VIT0`<300080ooo<00L0XJ6Q0<bIV@2Q
XJ40XJ6Q0<bIV@3<oiT0olc<0080c9UV00H0c9VI0<bIIP3<VIT0c9VI0?o<V@3oZZX20?o<V@80c9VI
00D0olbI0<bIV@3<VIT0olbI0<coIP020?nZZP030<coIP3oZZX0ojZZ0080olbI0P3oZZX209W<V@03
0?nZZP2Ic9T0olbI0080ojZZ00L0olbI0<bIIP3oc9T0olbI0?nZZP3oc9T0c9UV0080olbI00H0/K6a
0?o<V@3<VFH0c9UV0?o<V@3oVC<20?o<V@030?nZE@3oc9T0ofJI0080oomV00<0ojZZ0<coIP3oc9T0
0`3oc9T01@3oojX0ojZZ0?nZZP3oojX0ojZZ0080olc<0P3oc9T01@3<VFH0olbI0?o<V@3<VC<0olbI
0080ojYE00<0olbI0?nZE@3oc9T00P3oIVH01P3oofH0c?mV0?ooE@3ooeD0c9UV0<coIP80c9UV2@3o
ool00`000000oooo0?ooo`0e0?ooo`006@3oool20000E@80001g1@3oool20<coc00309W<IP3oc9T0
VLbI0080c?mV00L0olbI0<coIP3<c<`0c<c<0000E@0006H0EEFZ0080001V0P0007L203<0IP070000
V@0007L0IS>I06HcV@0cIYT0IS>I03=VV@020?ooIP070<coIP2Ic9T0003<0000c000EOl0oonZ001E
ZP020000V@070000M`00EJX0001g0000M`0c06H0001g03<0V@0203<0IP070000IP0cIVH005FZ001E
ZP1V<iT0CTi>05EEZP0204i>CP0603=VIP1EEJX0<fIV03=VIP0cI/`0IS?<0P0cI/`00`1EEOl0<fK<
06Hcc0020000IP0705EEo`0c06H0?clo03lo?`0009T0IS>I03=VIP0205EEZP0706HcV@00EJX0IS>I
06HcV@0007L0IS>I03=VIP0206HcV@0705iNGP1VIYT0IS=V06HcIP1bLW80EEFZ079bLP020861P@03
06IVV@21PH40VC>I00<0VC>I0P2ATI400`1VIYT0TI6A06IVV@040:YEZP80VC>I00<0VC?<09TcV@2I
<l`00P2I<iT00`2ZEJX0VC>I0:YEZP070:YEZP050:ZZo`3<VL`0c9W<0:ZZo`3<VL`00P2ZEJX00`3<
VL`0ZUFZ0<bIc00209VIc0070:YEZP2IVL`0ZUFZ0:YEZP2=SHd0c?o<0?3`l0020<coc0070?3`l03<
VIT0ofK<0?mVc03<VIT0ofK<0<bIV@020:YEZP070<bIV@2Zool0c?o<0<coc02Zool0ZZZZ0:VYZ@02
0:ZZZP060:VYZ@3<VIT0]KFe0;Fe]@3oc9T0]KFe0P3oc9T00`2e]KD0c9VI0?nZZP020?o<c0070?o<
V@3oc<`0c9VI0<bIV@3oZZX0c9VI0?o<V@020<c<c0040?nZZP3oc9T0ojZZ0?nZZP80olbI00D0c?nI
0?nZZP3oZZX0olbI0?nZZP020<coIP050=3@d03<ofH0ojZZ0?nZZP3<VFH01P3<VIT20<bIIP030<bI
V@3<VFH0c9VI00<0c9VI00H0olbI0<bIIP3<VFH0olbI0<bIV@3<VFH20<bIV@060<bIIP3oZZX0c9UV
0<bIIP3oZZX0c9UV0`3oZZX20?nZE@80olbI00L0ojYE0?o<V@3oIVH0ofIV0?ooIP3ooeD0ojYE00@0
c9UV0P3oZUD00`2m_Kd0olbI0<bIV@020?nZZP070<bIV@3oojX0]KFe0;Fe]@3oojX0ojYE0?o<V@02
0?nZE@80olbI0P3oofH00`3oIVH0ojYE0?oo<`020?nZE@060?nZZP3oofH0c9UV0<bIIP3oZUD0VLaV
0P3<ol`:0?ooo`030000003oool0oooo03@0oooo000I0?ooo`80001E0P0007L50?ooo`80c?o<00<0
VLaV0?o<V@2Ic9T00P3<ofH01`3oc9T0c?mV0<c<c03<c<`0001E0000IP1EEJX00P0006H20000M`80
<`1V00L0002I0000M`1V<iT0IS>I03=VV@1V<iT0<fJI0080oomV00L0c?mV09W<V@000<`0003<001E
o`3oojX005FZ0080002I00L0001g001EZP0007L0001g03<0IP0007L0<`2I0080<`1V00L0001V03=V
IP00EJX005FZ06HcV@1>CTh0EEFZ0080CTi>00H0<fIV05EEZP0cIVH0<fIV03=Vc01V<l`203=Vc003
05EEo`0cI/`0IS?<0080001V00L0EEGo03<0IP0o?cl0?clo0000V@1V<iT0<fIV0080EEFZ00L0IS>I
001EZP1V<iT0IS>I0000M`1V<iT0<fIV0080IS>I00L0GUiN06IVV@1V<fH0IS=V079bLP1EEJX0LW9b
0080PH6100<0IVJI0861P@2I<iT00`2I<iT2096AT@0306IVV@2ATI40IVJI00@0ZUFZ0P2I<iT00`2I
<l`0VC>I09Tcc00209TcV@030:YEZP2I<iT0ZUFZ00L0ZUFZ00D0ZZ[o0<bIc03<VL`0ZZ[o0<bIc002
0:YEZP030<bIc02ZEJX0c9W<0080VIW<00L0ZUFZ09VIc02ZEJX0ZUFZ08f=S@3<ol`0l?3`0080c?o<
00L0l?3`0<bIV@3oI/`0ofK<0<bIV@3oI/`0c9VI0080ZUFZ00L0c9VI0:[oo`3<ol`0c?o<0:[oo`2Z
ZZX0ZJVY0080ZZZZ00H0ZJVY0<bIV@2e]KD0]KFe0?o<V@2e]KD20?o<V@030;Fe]@3<VIT0ojZZ0080
olc<00L0olbI0?o<c03<VIT0c9VI0?nZZP3<VIT0olbI0080c<c<00@0ojZZ0?o<V@3oZZX0ojZZ0P3o
c9T01@3<oiT0ojZZ0?nZZP3oc9T0ojZZ0080c?mV00D0d=3@0<coIP3oZZX0ojZZ0<bIIP060<bIV@80
c9UV00<0c9VI0<bIIP3<VIT00`3<VIT01P3oc9T0c9UV0<bIIP3oc9T0c9VI0<bIIP80c9VI00H0c9UV
0?nZZP3<VFH0c9UV0?nZZP3<VFH30?nZZP80ojYE0P3oc9T01`3oZUD0olbI0?mVIP3oIVH0oomV0?oo
E@3oZUD0103<VFH20?nZE@030;fm_@3oc9T0c9VI0080ojZZ00L0c9VI0?ooZP2e]KD0]KFe0?ooZP3o
ZUD0olbI0080ojYE0P3oc9T20?ooIP030?mVIP3oZUD0oolc0080ojYE00H0ojZZ0?ooIP3<VFH0c9UV
0?nZE@2Ic6H20<coc0X0oooo00<000000?ooo`3oool0=03oool001T0oooo0P0006H00`0009T0001V
0000V@030?ooo`060<coo`2ZZ_l0ZZ[o0<coIP2Ic9T0oonZ0P3<VC<01`2Zool0b<S80:[oo`2Zool0
001E03=Vc01EEJX00P0006H20000M`80002I00L0001g03<0IP000:X0002Z001EZP000:X000000080
c?mV00@0olbI0?ooIP3oc9T0olbI0P00EJX01@0009T005EE001EE@0006H0002I0080001g00<0<fIV
0000M`0007L00P0c09T01`1V<iT0<`2I03<0IP0c06H0<`2I0000ZP0c09T00P000:X01P0c09T0<fJI
03<0V@0c09T006Ko05EEZP80Z_oo00<0001V05FZo`0cI/`00P0006H01`0009T0<fJI0000V@0009T0
05FZ03<0V@0009T00P0c09T01`00EJX0IS>I03=VIP0cIVH0IS>I0000V@1V<iT00P0009T406HcV@03
09TcV@1V<iT0VC>I0080IS>I00<0VC>I06HcV@1VIYT00`1VIYT209TcV@0305FZZP2I<iT0EJZZ0080
IVJI00L0SHf=06IVV@1EEJX0EEFZ096AT@1EEJX0TI6A0080VC?<00L0TI6A09Tcc02ATI40TI6A09Tc
V@2ATI40VC>I0080e=CD00H0c<c<0;fm_@3<c<`0c<c<0;fm_@3<c<`20;6a/@030<bIV@2a/K40c9VI
00<0/K6a00H0c9VI09Tcc02I<l`0TI6A0<aVc03MgMd20?3`l0070=gMg@3oZZX0^k^k0;^k^`3oZZX0
^k^k0?nZZP020<bIV@070<coc03ool`0c?o<0<coc03ool`0c?o<0?nZZP020:ZZZP060<bIV@2IVL`0
olc<0?o<c02Ic9T0olc<0P2Ic9T00`3oc<`0/K6a0?ooc00209W<V@070?ooc02Ic9T0c9VI0<bIV@30
`<00c9VI0<c<c0020?ooc0070<c<c03<VIT0XJ6Q0:6QX@3<VIT0c?nI0?o<c0020<bIIP060<bIV@3<
VFH0ojZZ0?nZZP3oc9T0ojZZ0P3oc9T20<bIV@050?o<V@3<VIT0c9VI0?o<V@3<ofH00P3oZZX00`3<
ofH0olbI0?nZZP020?o<V@80ojZZ0P2Ic9T20?nZZP050?o<V@3oZZX0ojZZ0?o<V@3<VFH00P3oc9T0
0`3<VFH0olbI0<bIIP020?o<V@060;6a/@3oc9T0c9UV0<bIIP3oc9T0ojYE0P3oc9T00`3oofH0olbI
0?nZZP020?ooIP070<bIIP3<ofH0c?mV0<coIP3<oiT0olbI0?ooZP020?nZZP070?o<c03<oiT0olc<
0?o<c03<oiT0olbI0<bI<`020?o<V@070<bI<`3oc9T0ojYE0?nZE@3oc9T0ojYE0?o<V@020?mVIP06
0?ooIP3<ofH0c?mV0<coIP3<VFH0Z_nZ0P0cc<`00`2ZojX0oooo0?ooo`070?ooo`800000=@3oool0
01T0oooo0P0005D00`0007L0001V0000M`020?ooo`070<coc02Zool0c?o<0<coc034a<@0olbI0<bI
IP040?ooo`80c<c<00<0001E06Hcc00005D00P0006H40000M`070000V@0007L0002I0000V@0cIYT0
IS>I0<bIIP0209W<V@80olbI0P3<ofH00`3oc9T0003<001EZP020000IP070000M`00EJX0001g0000
M`0c06H0001g03<0V@0203<0IP070000IP0cIVH005FZ001EZP0k>c/0EEFZ03<0V@0204i>CP0603=V
IP1EEJX0<fIV03=VIP1EEJX0IS?<0`2ZZ_l00`0cI/`0001V0000IP020000IP0603<0IP0o?cl0?clo
03<0IP0cIYT0<fIV0P1EEJX01`1>CTh005FZ06HcV@1V<iT0001g06HcV@0cIVH00P1V<iT01`1NGUh0
EEFZ05iNGP1NGUh0LW9b05EEZP1bLW800P21PH400`1VIYT0PH6109TcV@0309TcV@80TI6A00<0IVJI
096AT@1VIYT0102ZEJX209TcV@0309Tcc02I<iT0VC?<0080VC>I00<0ZUFZ09TcV@2ZEJX00P2ZEJX0
102Zool0ZZ[o0:[oo`2Zool20:ZZo`80c9W<00L0ZZ[o0<bIc02ZEJX0ZUFZ0<bIc02ZEJX0c9W<00`0
ZUFZ00H0c?o<0?mVc03oI/`0c9VI0?mVV@3<I/`208f=S@070:YEZP2=SHd0ZUFZ0:YEZP2=SHd0c?o<
0:VYZ@020:YEZP060:ZZZP3<VIT0ZUFZ0:YEZP3oc9T0]KFe0P3<VIT00`3<VL`0c9VI0<bIc0020?o<
c0070?o<V@3oc<`0olbI0?o<V@3oZZX0c<c<0?o<V@020<c<c080olbI0P3oZZX00`3<oiT0olbI0<co
V@020?nZZP060?o<V@3@d=00c?mV0<coIP3@d=00c?mV0P3@d=000`3<VFH0c9VI0<bIV@020<bIV@04
0<30`03oc<`0c9UV0<bIIPH0c9VI00H0ojZZ0<bIIP3<VFH0olbI0<bIV@3<VFH20<bIV@060<bIIP3o
ZZX0c9UV0<bIIP3oZZX0c9UV0`3oZZX01P3oc9T0ojYE0?o<V@3oc9T0ojYE0?ooIP80ofIV00<0ojYE
0?nZZP3oZUD00P3<VFH01`3oZUD0c9UV0<coV@3<oiT0`<300?nZZP3<VIT00P3oZZX01`2e]KD0oonZ
0;Fe]@2e]KD0oonZ0<30`03oc9T00P3oZUD20?o<V@80oomV00<0ofIV0?nZE@3ooc<00P3oZUD01P3<
ofH0c9UV09W<IP2Ic6H0oolc001Eo`80002Z00<0I/c<0?ooo`3oool0203oool00`000000oooo0?oo
o`0c0?ooo`006@3oool20000IP030000V@0006H0002I0080001g00L0002I0<coc03^k^h0k^k^0?oo
IP3<VIT0oonZ00@0oooo0P2Zool00`1EEOl0<fK<0000E@030000IP050000M`0009T0002I03=Vc01V
IYT00P0cI/`00`00EJX0000009W<V@020?ooIP070?o<V@3oojX0olbI0?o<V@1Vc?l005FZ0000V@02
0000IP80002I0P0007L00`0cIVH0002I0000M`020000M`0706HcV@0c09T0<`1V03<0IP0c09T0<`1V
03=Vc0020000ZP0603<0V@0cIYT0<fK<03=Vc02Ic9T0ooo<0P3<ol`00`1Vc?l0001V0000M`02001E
ZP070000V@0cIYT0002I0000V@00EJX0IS>I0000V@0203<0V@07001EZP1V<iT0<fIV03=VIP1V<iT0
<fIV06HcV@020000V@@0IS>I00<0IVJI06HcV@2I<iT00P1V<iT00`2I<iT0IS>I06IVV@0306IVV@80
VC>I00<0EJZZ09TcV@1EZZX00P1VIYT01`2=SHd0IVJI08f=S@2=SHd0TI6A05EEZP2ATI400P1EEJX0
1@2ATI40VC?<0:[oo`2Zool0a<C40080Z_oo0P3De=@01P2Zool0_Kfm0<c<c03<c<`0_Kfm0<c<c080
_Kfm00<0c9VI0;6a/@2ZEJX00P2ATI401`2ZEJX0TI6A09Tcc02I<l`0TI6A0<aVc02ATI400P3<I/`0
1`2ATI40c6K<096AT@2ATI40MWIf09FEU@1fMWH00P3<VIT01P2ZEJX0c9VI0:YEZP2ZEJX0c9VI0:6Q
X@@0c9VI00D0VIW<0<bIV@3<VIT0c6K<0<bIV@020<aVc0L0c9VI0P3ool`00`30`<00ooo<0<c<c002
0?ooc0070<c<c03<VIT0XJ6Q0:6QX@3oc<`0c?nI0?o<c0020<coV@060<bIV@3oc9T0ojZZ0?nZZP3o
c9T0ojZZ0`3oc9T0103<VIT0olbI0<bIV@3<VIT20?o<V@80ojZZ00<0c?mV0?o<V@3oZZX00P3oc9T0
103oZZX0olbI09W<V@2Ic9T20?nZZP050?o<V@3oZZX0ojZZ0?o<V@3<VFH00P3oc9T00`3<VIT0olbI
0;6a/@020?o<V@060<bIIP3oc9T0c9UV0<bIIP3oc9T0ojYE0P3oc9T20?ooIP050?nZZP3oofH0oomV
0<coIP3<VC<00P00EJX00`1EZ_l005FZ0?ooZP020<coV@070?o<c03<oiT0olc<0?o<c030`<00olc<
0<bI<`020?o<V@070?ooIP3oc9T0ojYE0?nZE@3oc9T0ojYE0?o<V@020?mVIP030?nZE@3<VC<0c9Tc
0080c9Tc00@00000001EZP00EJX006K<2`3oool2000003<0oooo000I0?ooo`80001V00<0002I0000
IP0009T00P0007L01`0009T0c?o<0>k^kP3^k^h0oomV0<bIV@3oojX0103oool20:[oo`0305EEo`0c
I/`0001E00<0001V00D0001g0000V@0009T0<fK<06IVV@0203=Vc003001EZP000000VLbI0080oomV
00L0olbI0?ooZP3oc9T0olbI06K<o`00EJX0002I0080001V0P0009T20000M`0303=VIP0009T0001g
0080001g00L0IS>I03<0V@0c06H0<`1V03<0V@0c06H0<fK<0080002Z00H0<`2I03=VV@0cI/`0<fK<
09W<V@3ool`20<coc00306K<o`0006H0001g008005FZ00L0002I03=VV@0009T0002I001EZP1V<iT0
002I0080<`2I00L005FZ06HcV@0cIVH0<fIV06HcV@0cIVH0IS>I0080002I101V<iT00`1VIYT0IS>I
09TcV@0206HcV@0309TcV@1V<iT0IVJI00<0IVJI0P2I<iT00`1EZZX0VC>I05FZZP0206IVV@0708f=
S@1VIYT0SHf=08f=S@2ATI40EEFZ096AT@0205EEZP05096AT@2I<l`0Z_oo0:[oo`34a<@00P2Zool2
0=CDe0060:[oo`2m_Kd0c<c<0<c<c02m_Kd0c<c<0P2m_Kd00`3<VIT0/K6a0:YEZP02096AT@070:YE
ZP2ATI40VC?<09Tcc02ATI40c6K<096AT@020<aVc007096AT@3<I/`0TI6A096AT@1fMWH0UIFE07If
MP020<bIV@060:YEZP3<VIT0ZUFZ0:YEZP3<VIT0XJ6Q103<VIT01@2IVL`0c9VI0<bIV@3<I/`0c9VI
0080c6K<1`3<VIT20?ooc0030<30`03ool`0c<c<0080ooo<00L0c<c<0<bIV@2QXJ40XJ6Q0?o<c03<
oiT0olc<0080c?nI00H0c9VI0?o<V@3oZZX0ojZZ0?o<V@3oZZX30?o<V@040<bIV@3oc9T0c9VI0<bI
V@80olbI0P3oZZX00`3<ofH0olbI0?nZZP020?o<V@040?nZZP3oc9T0VLbI09W<V@80ojZZ00D0olbI
0?nZZP3oZZX0olbI0<bIIP020?o<V@030<bIV@3oc9T0/K6a0080olbI00H0c9UV0?o<V@3<VFH0c9UV
0?o<V@3oZUD20?o<V@80oomV00D0ojZZ0?ooIP3oofH0c?mV0<bI<`02001EZP0305FZo`00EJX0oonZ
0080c?nI00L0olc<0<coV@3oc<`0olc<0<30`03oc<`0c9Tc0080olbI00L0oomV0?o<V@3oZUD0ojYE
0?o<V@3oZUD0olbI0080ofIV00<0ojYE0<bI<`3<VC<00P3<VC<01000000005FZ001EZP00I/`;0?oo
o`800000<`3oool001T0oooo0P0005D50000M`80k^k^0P3<ool00`2Ic9T0oomV0?ooo`060?ooo`03
0<coo`1V<l`0001E0080001V1@0007L01P1EEOl0EJZZ05FZZP1EEOl0c?mV0?o<V@80VLbI00L0c?mV
0<bIIP3oofH0oomV0<bIIP000<`0001E0080001V00L005FZ0000IP0007L0001g0000V@0006H0<`2I
0080001g00L0001V03=VIP00EJX005FZ03/k>`00EJX0<`2I0080EEFZ00H0<`2I05EEZP3<VFH0c9UV
0<coc02Zool20<coc0030:ZZo`0006H0001V0080EEFZ00L0001V0000M`1EEJX0EEFZ03<0IP0o?cl0
<fIV0080EEFZ00L0CTi>05EEZP1V<iT0IS>I0000M`1V<iT0<fIV0080IS>I00@0GUiN05EEZP1NGUh0
GUiN0P1VIYT01@1bLW80PH610861P@1VIYT0PH6100H0VC>I00<0IVJI096AT@1VIYT00P2ATI440:YE
ZP0309Tcc02I<iT0VC?<0080VC>I00L0ZUFZ0:ZZo`2Zool0Z_oo0:ZZo`2Zool0ZZ[o0080Z_oo00D0
ZZ[o0:[oo`3<VL`0c9W<0:ZZo`040:YEZP0509Tcc02I<iT0VC?<09Tcc02I<iT0302ZEJX00`3<I/`0
ofJI0<aVc00208f=S@070:YEZP2=SHd0ZUFZ0:YEZP2=SHd0ZUFZ0:ZZZP020:YEZP060:ZZZP2ZEJX0
ZUFZ0:YEZP3<VIT0/K6a0P3<VIT00`2a/K40c9VI0:6QX@020?nZZP070:6QX@3oZZX0XJ6Q0:6QX@3o
ZZX0olbI0?nZZP0209W<V@070<bIV@3<c<`0ojZZ0?nZZP3<oiT0olbI0<coV@030?o<V@050=3@d03<
ofH0c?mV0=3@d03<ofH00P3@d=050<bIV@040<30`03oc<`0c9UV0<bIIPD0c9VI00L0_Kfm0?nZZP3<
VFH0c9UV0?o<V@3<VIT0c9UV0080c9VI00L0c9UV0?nZZP3<VFH0c9UV0?o<V@3<VFH0ojYE0080ojZZ
00H0olbI0?nZE@3oc9T0olbI0?nZE@3oofH20?mVIP030?nZE@3oZZX0ojYE0080ojYE00L0VL`c0?oo
<`000000000005EEo`0cc?l0001g0080oonZ00L0]KFe0?ooZP30`<00`<300<coc030`<00olc<00<0
ojYE00H0olbI0?ooIP3oofH0ofIV0?nZE@3ooc<20?nZE@060<coIP3ooc<0VL`c09W<<`3ooc<00000
0P000:X00`00EOl0002Z0?ooo`090?ooo`8000002@3oool4000000D0oooo0P00000O0?ooo`006`3o
ool00`0006H0001g0000V@020<coc0060>k^kP3<ol`0VLbI09W<V@3oojX0c9Tc1`3oool00`38b<P0
001E0000E@020000IP80001g0P0009T01`0007L0IVJI03=Vc00cI/`0ZZYE0?ooIP3oc9T00P3oofH0
1`3oc9T0oonZ0?o<V@3oc9T0oonZ09VIo`0004@00P0006H00`0009T0001g0000M`020000M`060000
V@0007L0001g0000M`0009T0<`2I0P1V<iT00`0c09T0<`1V03=Vc0020000ZP0603=Vc02Ic9T0oonZ
0?ooZP3oIVH0oonZ0P00I/`20000IP0503=Vc00007L0001g0000V@0006H00P0009T00`00EJX0002I
0000V@0203<0V@07001EZP0c09T0<fIV03=VIP1V<iT0<fIV06HcV@020000V@@0IS>I00<0IVJI06Hc
V@1VIYT00P1V<iT00`2I<iT0IS>I06IVV@0506IVV@0305FZZP2I<iT0EJZZ0080VC>I00L0SHf=06IV
V@2=SHd0SHf=096AT@1EEJX0Z_oo0080I/co00L0Z_oo06K<o`2Zool0Z_oo0<C4a01EEJX0ZUFZ0080
IVJI00H0ZUFZ06IVV@2=SHd0SHf=06IVV@3<VIT206IVV@030<bIV@2ATI40ZUFZ0080TI6A00L0ZUFZ
096AT@2I<l`0VC?<096AT@3<I/`0TI6A0080c6K<00L0TI6A0<aVc02EUID0UIFE07IfMP2EUID0MWIf
0080c9VI00@0ZUFZ0<bIV@2ZEJX0ZUFZ2@3<VIT0103<I/`0c9VI0<aVc03<I/`90<bIV@030:FUY@3<
VIT0YJFU0080ojZZ00L0olbI0?nZZP3<VIT0c9VI0?o<c03<oiT0olbI0080VLbI00H0ojZZ0?o<V@3o
ZZX0ojZZ0?o<V@3oZZX20?ooZP030<coc03<VIT0olbI00H0olbI00<0c?mV0?o<V@3oZZX01`3oc9T0
1P3oZZX0olbI0?nZZP3oZZX0olbI0<bIIP80olbI00<0c9VI0?o<V@2a/K400P3oc9T01P3<VFH0olbI
0?nI<`3oVC<0olbI0?nZE@80olbI0P3oofH01@3oZZX0c?mV0<coIP2ZZP00c9Tc0080000000<0EJ[o
001EZP0009T00P0006H01`3oc<`0`<300?o<c03oc<`0`<300?o<c038b<P00P3De=@01`3oofH0olbI
0?nZE@3oZUD0olbI0?nZE@3oc9T00P3oIVH0103oZUD0VL`c0<bI<`3<VC<400000003001Vc000EJX0
oooo00T0oooo0`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00000M
0?ooo`006`3oool00`0005D0001g0000M`030000M`040<C4a03oc9T0olbI0<bIIPP0oooo00<0c?oo
0000E@0005D00`0007L00`0009T0001g0000M`020000M`80EJZZ00<0d=3@09W<V@3oc9T00P3oc9T0
1`3oofH0c9UV0?ooIP3oofH0c9UV0:[oo`0005D00P0009T01`00EJX0001V0000M`0007L0002I0000
IP0c09T00P0007L01`00EJX0<fJI0000IP0006H0>c/k001EZP0k>c/00P1EEJX01P0c09T0oomV0<bI
IP3<VFH0oomV0?ooZP80olbI00<006K<0:ZZo`0007L00P0007L01`0006H0001g05EEZP1EEJX0<`1V
03lo?`0cIVH00P1V<iT01`1>CTh0EEFZ03<0V@0c09T0001g06HcV@0cIVH00P1V<iT0100cIVH0EEFZ
05iNGP1NGUh306IVV@80OWin00<0ZUFZ07inOP2I<iT01@2I<iT00`1VIYT0TI6A06IVV@02096AT@80
ZUFZ1@2Zool209VIo`0306HcV@00EJX0IS>I0080IS>I00H0VC>I05EEZP2Z0:X0ZP2Z05EEZP2ZEJX2
09TcV@D0ZUFZ00D0VC?<09TcV@2I<l`0VC?<09TcV@090:YEZP0609fMW@3oIYT0ofJI0<aVc03oIYT0
c6K<0P2=SHd01`2ZEJX0SHf=0:YEZP2ZEJX0XJ6Q0:YEZP2ZZZX00P2ZEJX01P2ZZZX0ZUFZ0;6a/@2a
/K40c9VI0;6a/@80c9VI00<0/K6a0?nZZP2QXJ400P3oZZX01`2QXJ40ojZZ0;Vi^@2i^KT0ojZZ0?o<
V@3<VIT00P2Ic9T01@3<VIT0VLbI0?nZZP3oZZX0WIfM0080olbI0P3oZZX01P3oc9T0d=3@0<coIP3<
ofH0d=3@0<coc080ooo<00<0c?o<0<bIV@3<VIT00P3oc<`01030`<00olc<0<30`030`<050<bIV@07
0;fm_@3oZZX0_Kfm0;fm_@3<VFH0c9VI0<bIIP020?nZZP070<bIIP3oZZX0c9VI0<bIV@3oc9T0c9VI
0?nZE@020?nZZP060?o<V@3oZUD0olbI0?o<V@3oZUD0oomV0P3ooeD00`3oZUD0ojZZ0?nZE@020?oo
<`0709W<<`00000000000000002Ic6H0<lco05EEo`020000V@070000M`3<ol`0`<300<30`03<ol`0
a<C40?o<c0020<C4a0030?nZE@3oIVH0oomV0080oomV00H0ojYE0?nZZP3oZUD0ojYE0<bIIP3ooc<2
09W<<`@0000000<005Go0000ZP3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P00000M0?ooo`006`3oool00`0006H0001g0000V@020000
M`050<30`03oofH0c9VI0<bIV@3oojX02@3oool20000E@@0001g0P0006H01`2IVOl0I/co0:[oo`2Z
ool0VLbI0?ooZP3oc9T00P3oojX01P3oc9T0oonZ0?o<V@3oc9T0ooo<0000E@<005FZ00<0001E0000
M`0007L00P0007L01P0009T0001g0000M`0007L0002I03<0V@80002I00<0<`2I03<0IP0c09T00P00
0:X01P3oojX0c9UV0?ooZP3oojX0c?nI0?ooZP80c?nI00<0002Z0000M`0006H00P0007L01@0009T0
001V0000V@0009T005FZ0080002I0P0c09T01`00EJX0<`2I001EZP00EJX0IS>I03=VIP1V<iT00P00
09T406HcV@0306IVV@1V<iT0IVJI0080EEFZ00H0EEGo05EEZP2=SHd0SHf=09VIc02=SHd206IVV@03
05FZZP2I<iT0VIW<00<0VIW<00H0VIWo06K<c01Vc<`0VIWo03<0IP0009T203<0IP@0IS>I00<0IS=V
05EEZP2ZEJX00P1VIYT01P2ZEJX0IVJI08f=S@2=SHd0IVJI0<bIV@80IVJI00<0c9VI096AT@2ZEJX0
0P2ATI401`2ZEJX0TI6A09Tcc02I<l`0TI6A09Tcc02ATI400P3<I/`01`2ZEJX0c9VI09FEU@2EUID0
MWIf09FEU@1fMWH00P3<VIT0102ZEJX0c9VI0:YEZP2ZEJX90<bIV@040<aVc03<VIT0c6K<0<aVc0T0
c9VI00<0olbI0<bIV@3oc9T00P3oZZX01P3oc9T0ojZZ0<bIV@3<VIT0olbI0;fm_@D0olbI0P3oZZX0
1P3oojX0c?o<0?ooZP3oojX0c?o<0<bIV@L0olbI00<0ojZZ0?o<V@3oZZX01`3oc9T01P3oZZX0olbI
0<bIIP3<VFH0olbI0<bIIP80olbI00<0c9VI0?o<V@3oc9T00P3oc9T01P3<VFH0olbI0?nI<`3oVC<0
olbI0?nZE@80olbI0P3oofH01@3oZZX0c9Tc0<bI<`2ZZP0000000080VLaV00<0c?nI001EZP1EZ_l0
0P0007L01`0009T0001V0?o<c03oc<`0b<S80=CDe038b<P00P3<c<`01`38b<P0olbI0?nZE@3oZUD0
olbI0?ooE@3oofH00P3<ofH0103oofH0c9Tc0<bI<`3<VC<4000000030000V@00EJX006K<00`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00800000
7@3oool001/0oooo00<0001V0000M`0009T00P0007L01@30`<00oomV0<bIV@3<VIT0oonZ00T0oooo
0P0005D40000M`80001V00L0VIWo06K<o`2Zool0Z_oo09W<V@3oojX0olbI0080oonZ00H0olbI0?oo
ZP3oc9T0olbI0?ooc00005D3001EZP030000E@0007L0001g0080001g00H0002I0000M`0007L0001g
0000V@0c09T20000V@0303<0V@0c06H0<`2I0080002Z00H0oonZ0<bIIP3oojX0oonZ0<coV@3oojX2
0<coV@030000ZP0007L0001V0080001g00D0002I0000IP0009T0002I001EZP020000V@80<`2I00L0
05FZ03<0V@00EJX005FZ06HcV@0cIVH0IS>I0080002I101V<iT00`1VIYT0IS>I06IVV@0205EEZP06
05EEo`1EEJX0SHf=08f=S@2IVL`0SHf=0P1VIYT00`1EZZX0VC>I09VIc00309VIc00609VIo`1Vc<`0
I/c<09VIo`0c06H0002I0P0c06H406HcV@0306HcIP1EEJX0ZUFZ0080IVJI00H0ZUFZ06IVV@2=SHd0
SHf=06IVV@3<VIT206IVV@030<bIV@2ATI40ZUFZ0080TI6A00L0ZUFZ096AT@2I<l`0VC?<096AT@2I
<l`0TI6A0080c6K<00L0ZUFZ0<bIV@2EUID0UIFE07IfMP2EUID0MWIf0080c9VI00@0ZUFZ0<bIV@2Z
EJX0ZUFZ2@3<VIT0103<I/`0c9VI0<aVc03<I/`90<bIV@030?o<V@3<VIT0olbI0080ojZZ00H0olbI
0?nZZP3<VIT0c9VI0?o<V@2m_Kd50?o<V@80ojZZ00H0oonZ0<coc03oojX0oonZ0<coc03<VIT70?o<
V@030?nZZP3oc9T0ojZZ00L0olbI00H0ojZZ0?o<V@3<VFH0c9UV0?o<V@3<VFH20?o<V@030<bIV@3o
c9T0olbI0080olbI00H0c9UV0?o<V@3oVC<0oiTc0?o<V@3oZUD20?o<V@80oomV00D0ojZZ0<bI<`3<
VC<0ZZX00000000209W<IP030<coV@00EJX0EJ[o0080001g00L0002I0000IP3oc<`0olc<0<S8b03D
e=@0b<S80080c<c<00L0b<S80?o<V@3oZUD0ojYE0?o<V@3ooeD0oomV0080c?mV00@0oomV0<bI<`3<
VC<0c9Tc100000000`0009T005FZ001Vc00<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`02000001d0oooo000K0?ooo`030000IP0007L0001g0080
a<C400@0c?oo0=CDe03oofH0oomV2P3oool20000E@<0001g00D0002I0000M`0007L0002I0:[oo`02
0<bIo`030?o<V@2Ic9T0oomV0080c9UV00L0oomV0<bIIP3oc9T0olbI0:[oZP3oojX005Go0080002I
0P0006H30000M`060000IP0c09T0001g0000M`0c09T0<fJI0P00EJX00`0cIYT005FZ0:ZZo`020?o<
V@80oomV0P3<VFH01P3oc9T0oonZ0<coc03<ol`0ooo<0000IPD0001g0P1EEJX00`0c06H0?clo0000
M`0206HcV@0704i>CP1EEJX0<`2I03<0V@00EED0IS>I03=VIP0206HcV@0403=VIP1EEJX0GUiN05iN
GPD0IVJI00H0ZUFZ07inOP2ZEJX0ZUFZ06Hcc01EEJX206Hcc00309VIo`1EZ_l0VIWo0080EJ[o00@0
VIWo05FZo`2Zool0Z_oo0P0007L01@00EJX0IS>I06HcV@1V<iT005FZ00@0IS>I00D0IVJI07inOP1n
OWh0EEFZ0:YEZP0209TcV@D0ZUFZ00H0VC?<09TcV@2I<l`0VC?<09TcV@2I<l`50:YEZPH0WIfM00<0
c6K<0?mVV@3<I/`00P3oIYT01`2ZEJX0SHf=0:YEZP2ZEJX0XJ6Q0:YEZP2ZZZX00P2ZEJX01P2ZZZX0
ZUFZ0;6a/@2a/K40c9VI0;6a/@80c9VI00<0/K6a0<bIV@2QXJ400P3oZZX01`2QXJ40ojZZ0;Vi^@2i
^KT0ojZZ0?o<V@3<VIT00P2Ic9T01`3<VIT0WIfM0?nZZP3oZZX0WIfM0?o<V@3<VIT00`3oc9T01@3o
ojX0oomV0?ooIP3oofH0c9Tc0080000000<0c<c<0?ooc030`<000P3oc<`01@30`<00olc<0<30`030
`<00c?o<0080c9VI0P3oZZX01`2m_Kd0ojZZ0;fm_@2m_Kd0c?nI0<bIV@3<VFH00P3oZZX01`3<VFH0
ojZZ0<bIV@3<VIT0olbI0<bIV@3oc9T00P3oZUD01P3oc9T0ojYE0?o<V@3oc9T0ojYE0?ooIP80oomE
00<0ojYE0<bIIP3oofH00P3ooc<01`2Ic3<0<fK<09VIc02IVL`0VLaV001EZP1EEOl00P0006H20000
M`80a<C400<0olc<0<C4a03oc<`00P38b<P01`3oc<`0_Kfm0?o<c03oc<`0oomV0?nZE@3oZZX00P3o
ofH01P3<VFH0oolc00000000000009W<03?<c08009W<00<000000000V@00EOl03@3oool2000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000001d0oooo000K0?ooo`80001g
00D0`<300?ooc03ool`0`<300?ooZP020<bIV@X0oooo00@0001E0000M`0006H0001V0P0007L20000
IP070:[oo`3@d=00e=CD0=CDe02Ic9T0oomV0?nZE@020?ooZP070?o<V@3oojX0oomE0?ooE@3oojX0
VLbI001EZP020000IP050000E@0007L0001g0000M`0006H01@0007L01P0c09T0002I0000V@0c09T0
EOnZ0?ooIP80VLaV00H0oonZ0?mVIP3oojX0oonZ0<coV@3<ool20?ooZP030<coo`00I/`0001V0080
001g0P0006H20000M`03001EZP0009T0<fJI0080<`2I00L005FZ03<0V@00EJX005FZ06HcV@00EJX0
IS>I0080002I1P1V<iT01@1VIYT0IS>I06HcV@1EEOl0EEFZ0080EEGo00D0VIW<08f=S@2IVL`0VIW<
08f=S@0509VIc0030?o<c00cc?l0<lco0080001V00<0002I03=VIP0cIVH0101V<iT00`1V<fH0EEFZ
05EEo`0206HcV@0605EEo`1VIYT0SHf=08f=S@1VIYT0SHf=0P1VIYT00`3<VIT0IVJI0:YEZP02096A
T@070:YEZP2ATI40VC?<09Tcc02ATI40c6K<0:YEZP020<bIV@070:YEZP3<VIT0ZUFZ0:YEZP1fMWH0
UIFE07IfMP0209FEU@060:YEZP3<VIT0XJ6Q0:6QX@3<VIT0XJ6Q103<VIT01@2i^KT0c9VI0<bIV@3<
I/`0c9VI0080c6K<00<0c9VI0?mVc03<VIT00`3<VIT01P3oc9T0c9VI0<bIV@3oc9T0ojZZ0?o<V@80
ojZZ0P3oc9T20<bIV@030?o<V@2m_Kd0olbI00<0olbI00<0ojYE0?o<V@3oc9T00P3<ofH20;6a/@03
07inOP1EZ_l0OWin00@0olbI0P3ool`00`30`<00olbI0?nZZP040?o<V@80/K6a00<0olc<0?nZZP3o
c9T00P3<VFH01@3oc9T0c9UV0?o<V@3oc9T0c9VI00@0olbI00H0c9UV0?o<V@3oVC<0oiTc0?o<V@3o
ZUD20?o<V@80oomV0`3<VC<2000000800:ZZ00<0<fKo002ZZP000:X00P00EJX01`0009T0001V0000
IP0006H0b<S80<c<c038b<P00P3<c<`01P38b<P0c<c<0?o<V@3oc9T0olc<0?ooE@<0olbI00<0ojYE
0<bI<`0000000P00000403=Vo`030000M`00I/`0oooo00/0oooo100000040?ooo`8000001P3oool0
0`000000oooo0?ooo`02000001d0oooo000L0?ooo`@0001V00<0h>3P0<bIIP3oool02`3oool01P00
05D0001g0000IP0006H0001g0000V@80d=3@00L0c9Wo0=3@d02Ic9T0VLbI0?ooIP3oZZX0oomV0080
c9UV00L0olbI0?nZE@3oc9T0olbI0?ooIP3oc9T000140080001E0P0006H20000V@030000M`0006H0
<`2I0080EEFZ00L0<`2I03=VV@00EJX005FZ05EEZP3<ofH0c9UV0080ojYE0P3oofH30?ooZP060?oo
IP3oc9T0olbI0000V@00EJX0001g0P0006H01`0007L0001V0000V@0009T0<`1V03lo?`0007L00P1V
<iT01`1>CTh0EEFZ03<0V@0c09T005EE03<0V@0cIVH00P1V<iT01@0cIVH0EEFZ05iNGP1NGUh0EEFZ
00@0IVJI00H0ZUFZ07inOP2ZEJX0ZUFZ06Hcc01EEJX206Hcc00305EEZP1V<l`0VIWo0080VLbI00L0
]KFe0?o<V@1Vc<`0I/c<0000IP0007L0<`2I0080IS>I00<0EEFZ001EZP1V<iT00`1V<iT01@1VIYT0
OWin07inOP1VIYT0PH6100<0ZUFZ00<0VC>I0:YEZP2ZEJX00P2ZEJX01@2I<iT0VC?<09Tcc02I<iT0
VC?<00@0ZUFZ1`2MWId00`3<I/`0ofJI0<aVc0020?mVV@070:YEZP2QXJ40ZUFZ0:YEZP2QXJ40ZUFZ
0:ZZZP020:YEZP060:ZZZP3<VIT0ZUFZ0:YEZP3<VIT0/K6a0P3<VIT00`2m_Kd0c9VI0:6QX@020?nZ
ZP070:6QX@3oZZX0^KVi0;Vi^@3oZZX0VLbI0<bIV@0209W<V@070<bIV@2MWId0ojZZ0?nZZP3<VIT0
olbI0<bIV@030?o<V@050?ooZP3oofH0oomV0<bIIP3<VC<00`2a/K401P2ZEOl0EEGo0:YEo`2ZEOl0
`<300<coc080c?oo00<0c?o<0<bIV@3<VIT00P3oZZX01`2m_Kd0ojZZ0?o<V@3oc9T0c?nI0<bIV@3<
VFH00P3oZZX01P3<VFH0olbI0<bIV@3<VIT0olbI0<bIV@@0olbI00D0ojYE0?o<V@3oc9T0ofIV0?oo
IP020?ooE@030?nZE@3<VFH0oomV0080oolc100000000`0cI/`0VIW<0000V@02001EZP070000M`00
09T0001g0000M`3oc<`0b<S80?o<c0020<S8b0070?o<c02m_Kd0olc<0?o<c03oc9T0olc<0?ooZP02
0?ooIP0309W<IP3ooc<000000080000000@0<lc<002Ic000VL`0<lc<0P0009T?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000001l0oooo000L0?ooo`@0001V00<0h>3P
0<bIIP3oool02`3oool01P0005D0001g0000IP0006H0001g0000V@80d=3@00L0c9Wo0=3@d02Ic9T0
VLbI0?ooIP3oZZX0oomV0080c9UV00L0olbI0?nZE@3oc9T0olbI0?ooIP3oc9T000140080001E0P00
06H20000V@030000M`0006H0<`2I0080EEFZ00L0<`2I03=VV@00EJX005FZ05EEZP3<ofH0c9UV0080
ojYE0P3oofH30?ooZP060?ooIP3oc9T0olbI0000V@00EJX0001g0P0006H01`0007L0001V0000V@00
09T0<`1V03lo?`0007L00P1V<iT01`1>CTh0EEFZ03<0V@0c09T005EE03<0V@0cIVH00P1V<iT01@0c
IVH0EEFZ05iNGP1NGUh0EEFZ00@0IVJI00H0ZUFZ07inOP2ZEJX0ZUFZ06Hcc01EEJX206Hcc00305EE
ZP1V<l`0VIWo0080VLbI00L0]KFe0?o<V@1Vc<`0I/c<0000IP0007L0<`2I0080IS>I00<0EEFZ001E
ZP1V<iT00`1V<iT01@1VIYT0OWin07inOP1VIYT0PH6100<0ZUFZ00<0VC>I0:YEZP2ZEJX00P2ZEJX0
1@2I<iT0VC?<09Tcc02I<iT0VC?<00@0ZUFZ1`2MWId00`3<I/`0ofJI0<aVc0020?mVV@070:YEZP2Q
XJ40ZUFZ0:YEZP2QXJ40ZUFZ0:ZZZP020:YEZP060:ZZZP3<VIT0ZUFZ0:YEZP3<VIT0/K6a0P3<VIT0
0`2m_Kd0c9VI0:6QX@020?nZZP070:6QX@3oZZX0^KVi0;Vi^@3oZZX0VLbI0<bIV@0209W<V@070<bI
V@2MWId0ojZZ0?nZZP3<VIT0olbI0<bIV@030?o<V@050?ooZP3oofH0oomV0<bIIP3<VC<00`2a/K40
1P2ZEOl0EEGo0:YEo`2ZEOl0`<300<coc080c?oo00<0c?o<0<bIV@3<VIT00P3oZZX01`2m_Kd0ojZZ
0?o<V@3oc9T0c?nI0<bIV@3<VFH00P3oZZX01P3<VFH0olbI0<bIV@3<VIT0olbI0<bIV@@0olbI00D0
ojYE0?o<V@3oc9T0ofIV0?ooIP020?ooE@030?nZE@3<VFH0oomV0080oolc100000000`0cI/`0VIW<
0000V@02001EZP070000M`0009T0001g0000M`3oc<`0b<S80?o<c0020<S8b0070?o<c02m_Kd0olc<
0?o<c03oc9T0olc<0?ooZP020?ooIP0309W<IP3ooc<000000080000000@0<lc<002Ic000VL`0<lc<
0P0009T?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000001l0oooo
000L0?ooo`80001g0P3Hf=P00`2Zool0oooo0?ooo`0;0?ooo`040000A00007L0001V0000IPD0001g
00H0d=3@0?ooIP3oofH0olbI0?ooZP3oZUD20?ooZP070?ooE@3oojX0c9VI0<bIV@3oojX0ooo<0000
<`020000IP050000E@0007L0001g0000M`0006H00P0007L203=Vc007001EZP0c09T005FZ001EZP0c
I/`0VL`c0?ooIP020<bIIP030?ooZP3<oiT0olbI00<0olbI0P3oZZX00`3oojX005EE0000A0040000
IP80001g00<005FZ0000V@0cIYT00P0c09T01`00EJX0<`2I001EZP00EJX0IS>I001EZP1EEJX00P00
09T606HcV@0506IVV@1V<iT0IS>I05EEo`1EEJX00P1EEOl01`1EEJX0SHf=09VIc02IVL`0SHf=0?o<
c02i^KT00P3oc<`01@2QXJ40olc<0?o<V@3oc9T0<fKo0080002I0P0cIVH01`0009T0<fJI06HcV@1V
<iT0IS=V05EEZP1V<fH00P1V<iT01P1EEOl0EEFZ0:YEZP2ZEJX0EEFZ0:YEZP80IVJI00<0c9VI06IV
V@2ZEJX00P2ATI401`2=SHd0ZUFZ0<aVc03<I/`0TI6A0<aVc02ZEJX00P3<VIT01`2ZEJX0c9VI0:YE
ZP2ZEJX0MWIf09FEU@1fMWH00P2EUID01P2QXJ40c9VI0:6QX@2QXJ40c9VI0:6QX@@0c9VI00D0^KVi
0<bIV@3<VIT0c6K<0<bIV@020<aVc0030<bIV@3oI/`0c9VI00<0c9VI00H0olbI0<bIV@3<VIT0olbI
0?nZZP3oc9T20?nZZP060<bIV@3oc9T0c9VI0<bIV@3oc9T0_Kfm103oc9T01@3<ofH0olbI0?o<V@3<
VFH0ZZ[o0080/K6a00<0ZZ[o05FZo`1nOWh00P1EZ_l01P1EEJX0`<300?ooc03ool`0`<300?ooc0D0
olbI0P2a/K400`3oc<`0/K6a0?o<V@020<bIIP050?o<V@3<VIT0olbI0?o<V@3<VIT0103oc9T01P3<
VIT0olbI0?nI<`3oVC<0olbI0?ooIP80olbI00<0ofJI0?ooIP3<VFH00P3<VC<01`000000Z_oo0=3@
d03@d=00<fKo002ZZP0009T00P00EJX01`0009T0001V0000M`0007L0001E0<c<c038b<P00P3<c<`0
1`3oc9T0c<c<09W<IP2Ic6H0olc<0;Vi^@3oc9T00P3oZZX00`3oZUD0c9Tc00000003000000@0<fKo
00<0002I001EZP00EJX03P3oool00`000000oooo0?ooo`0[0?ooo`00703oool01@0006H0h>3P0=CD
e03De=@0oomV00d0oooo00<000140000E@0007L01@0007L01`2ZZ_l0Z_oo0?o<V@3oc9T0oonZ0<bI
IP3oofH00P3oZUD01`3oc9T0ojYE0?o<V@3oc9T0c?oo0?ooc00004@00P0005D20000IP<0001g00H0
001V0000V@1EEJX0EEFZ03<0V@1EEJX203<0V@030;6a/@3oc9T0ojYE0080ojYE00D0c9UV0?ooZP3o
oeD0oomE0?ooZP040?o<V@03001EZP0007L0001V00<0001V0P0009T00`0c06H0?clo0000M`0203=V
IP0704i>CP1EEJX0CTi>04i>CP00EED0<`2I001EE@0206HcV@0503=VIP1EEJX0GUiN05iNGP1EEJX0
1@1VIYT01@1nOWh0ZUFZ0:YEZP1nOWh0EEFZ0080c?nI00<0olbI09W<V@3oc9T00P3oc9T01@2e]KD0
olc<0?nZZP3oZZX0olc<0080001V0P1V<iT01@00EJX0<fJI06HcV@1V<iT005FZ0080IS>I0P1nOWh0
1P1VIYT0PH610:YEZP2ZEJX0PH610:YEZP@0IVJI00D0SHf=06IVV@1VIYT0SHf=06IVV@050:YEZPH0
WIfM00<0c6K<0?mVV@3<I/`00P3oIYT01`2ZEJX0XJ6Q0:YEZP2ZEJX0XJ6Q0:YEZP2ZZZX00`2ZEJX0
1@3<VIT0ZUFZ0:YEZP3<VIT0/K6a0080c9VI00<0_Kfm0<bIV@2m_Kd00P3oZZX01`2i^KT0ojZZ0;Vi
^@2i^KT0ojZZ09W<V@3<VIT00P2Ic9T01@3oZZX0WIfM0?nZZP3oZZX0c9VI00@0olbI103oofH00`3<
VC<0c?oo0;6a/@020;6a/@060:YEo`1EEOl0ZUGo0:YEo`1EEOl0EEFZ0P1EEOl00`1EEJX0<`2I0;fm
_@020?nZZP070;fm_@3<oiT0olbI0?o<V@3<oiT0olbI0<bIIP020?nZZP060<bIIP3oc9T0c9VI0<bI
V@3oc9T0c9VI1`3oc9T01`3oIVH0ojYE0?ooE@3ooeD0ojYE0?nZZP3ooeD00P0000001`000140c<c<
0:[oo`2Zool0IS>I09VIc00cI/`00P00EJX01`0007L0001V0000M`0007L0001V0000M`3oc<`00P2m
_Kd01P3oc<`0olbI0<30`030`<00c?nI0?o<c0<0ojYE00<0VLaV0?oo<`0000000`000002001EZP03
03?<c000VL`0002I0080002I3P3oool00`000000oooo0?ooo`0[0?ooo`007P3oool20=SHf0h0oooo
00H000140000E@0006H0001V0000M`3De=@20?o<o`070=CDe02Ic9T0oonZ0?ooZP3<VIT0oonZ0?nZ
E@020?ooZP070?ooE@3oojX0ooo<0?ooc03oc9T0ooo<0000<`020000IP030000E@0007L0001V0080
001V0P0007L203=Vc007001EZP0cI/`0c9VI0<bIV@3oofH0VLaV0?ooZP020<bIIP030?o<V@3oZUD0
olbI0080olbI00D0oonZ0?nZZP3oZZX0oonZ0;fm_@030000IP070000M`0006H0001g0000M`1NGUh0
002I001EZP0203<0V@07001EZP0c09T005FZ001EZP1V<iT005FZ06HcV@020000ZP0305EEZP1V<iT0
IS>I00<0IS>I00D0IVJI06HcV@1V<iT0IVJI05EEZP0205EEo`@0olbI00<0^KVi0?o<c02QXJ400P3o
c<`01`2QXJ40_Kfm0?o<V@3oc9T0_Kfm0?nZZP0009T00P00EED01`0009T0<fJI03<0V@0c09T0IS>I
05EEZP1V<fH00P1V<iT01@1EEOl0IS>I0:YEZP2ZEJX0EEFZ00<0ZUFZ00<0TI6A0:YEZP2=SHd00P2Z
EJX01`2=SHd0ZUFZ0<aVc03<I/`0TI6A0<aVc02ATI400P3<VIT01`2ZEJX0c9VI0:YEZP2ZEJX0MWIf
09FEU@1fMWH00P3<VIT01`2QXJ40c9VI0:6QX@2QXJ40c9VI0:6QX@3<VIT00P2i^KT01P3<VIT0^KVi
0<bIV@3<VIT0c6K<0<bIV@80ofK<00<0c9VI0?mVc03<VIT00`3<VIT01P3oc9T0c9VI0<bIV@3oc9T0
ojZZ0?o<V@80ojZZ00H0c9VI0?o<V@2m_Kd0_Kfm0?o<V@2m_Kd40?o<V@050<coIP3oofH0oomV06IV
V@2IVL`00`1VIYT01P2a/K40OWin05FZo`1EZ_l0OWin09TcV@80EEFZ00<0IS?<05EEZP1V<l`00`3o
c9T01P3oc<`0/K6a0;6a/@3oc<`0/K6a0?o<c080c9UV00<0olbI0<bIV@3oc9T00`3oc9T01@3<VIT0
olbI0?o<V@3<VIT0olbI0080c9VI00<0olbI0?nZE@3oc9T00P3oc9T01P3oofH0c9UV00L71`071`L0
000A0:[oo`80d=3@00<0002Z002ZZP0cI_l00P00EJX01`000:X0001g0000V@0009T0001g0000V@3o
c9T00P3<c<`0103oc9T0olc<09W<IP2Ic6H30?o<V@80ojZZ00<0ojYE0<bI<`0cI/`00P0cI/`01P00
0000001V0000IP000:X0<fKo0000V@80001g3`3oool3000002X0oooo000N0?ooo`80f=SH3P3oool0
1P0004@0001E0000IP0006H0001g0=CDe080olco00L0e=CD09W<V@3oojX0oonZ0<bIV@3oojX0ojYE
0080oonZ00L0oomE0?ooZP3ool`0ooo<0?o<V@3ool`0000c0080001V00<0001E0000M`0006H00P00
06H20000M`80<fK<00L005FZ03=Vc03<VIT0c9VI0?ooIP2Ic6H0oonZ0080c9UV00<0olbI0?nZE@3o
c9T00P3oc9T01@3oojX0ojZZ0?nZZP3oojX0_Kfm00<0001V00L0001g0000IP0007L0001g05iNGP00
09T005FZ0080<`2I00L005FZ03<0V@00EJX005FZ06HcV@00EJX0IS>I0080002Z00<0EEFZ06HcV@1V
<iT00`1V<iT01@1VIYT0IS>I06HcV@1VIYT0EEFZ0080EEGo103oc9T00`2i^KT0olc<0:6QX@020?o<
c0070:6QX@2m_Kd0olbI0?o<V@2m_Kd0ojZZ0000V@02001EE@070000V@0cIYT0<`2I03<0V@1V<iT0
EEFZ06HcIP0206HcV@0505EEo`1V<iT0ZUFZ0:YEZP1EEJX00`2ZEJX00`2ATI40ZUFZ08f=S@020:YE
ZP0708f=S@2ZEJX0c6K<0<aVc02ATI40c6K<096AT@020<bIV@070:YEZP3<VIT0ZUFZ0:YEZP1fMWH0
UIFE07IfMP020<bIV@070:6QX@3<VIT0XJ6Q0:6QX@3<VIT0XJ6Q0<bIV@020;Vi^@060<bIV@2i^KT0
c9VI0<bIV@3<I/`0c9VI0P3oI/`00`3<VIT0ofK<0<bIV@030<bIV@060?o<V@3<VIT0c9VI0?o<V@3o
ZZX0olbI0P3oZZX01P3<VIT0olbI0;fm_@2m_Kd0olbI0;fm_@@0olbI00D0c?mV0?ooIP3oofH0IVJI
09VIc00306IVV@060;6a/@1nOWh0EJ[o05FZo`1nOWh0VC>I0P1EEJX00`1V<l`0EEFZ06Hcc0030?o<
V@060?o<c02a/K40/K6a0?o<c02a/K40olc<0P3<VFH00`3oc9T0c9VI0?o<V@030?o<V@050<bIV@3o
c9T0olbI0<bIV@3oc9T00P3<VIT00`3oc9T0ojYE0?o<V@020?o<V@060?ooIP3<VFH01`L700L71`00
0140Z_oo0P3@d=000`000:X00:ZZ03=Vo`02001EZP070000ZP0007L0002I0000V@0007L0002I0?o<
V@020<c<c0040?o<V@3oc<`0VLaV09W<IP<0olbI0P3oZZX00`3oZUD0c9Tc03=Vc00203=Vc0060000
000006H0001V0000ZP0cI_l0002I0P0007L?0?ooo`<00000:P3oool002l0oooo00<0001E0000M`00
07L00P0007L20:[oo`070:ZZo`30`<00VLbI09W<V@3oofH0c9UV0?o<V@020?nZE@030?o<V@3oojX0
oonZ0080oonZ00@0olbI0<coo`0005D0001E0P0006H30000M`060000IP0009T0001V0000IP0c09T0
EEFZ0P3<ofH00`2a/K40olbI0?ooIP020?ooIP040?ooE@3oojX0oomV0?ooIP@0olbI00<0c?nI0?o<
c02ZE@000`0006H01P0007L0002I0000V@0007L0?clo03<0IP80<fIV00L0<fJI05EEZP1>CTh0CTi>
001EE@0c09T005EE00<0IS>I00@0EEGo05FZo`1EZ_l0EEGo0P1VIYT203?<o`0606K<o`0cc?l0olbI
0?o<V@2m_Kd0olbI0P30`<000`3oZZX0VLbI0;Fe]@020?o<V@060?nZZP3oc<`0ojZZ0?nZZP3oc<`0
ojZZ0`0007L01@00EJX0<fJI05EEZP1EEJX0<fJI0080IS>I0P1nOWh01P1VIYT0OWin0:YEZP2ZEJX0
PH610:YEZP@0IVJI00D0SHf=06IVV@1VIYT0SHf=06IVV@050:YEZPL0WIfM00H0ofJI0<aVc02I<l`0
VC?<096AT@2QXJ420:YEZP030:6QX@2ZEJX0ZZZZ0080c9VI00H0ZUFZ0<bIV@2ZEJX0ZUFZ0<bIV@2a
/K420<bIV@030;fm_@3<VIT0_Kfm0080ojZZ00L0^KVi0?nZZP2i^KT0^KVi0<bIV@2Ic9T0c9VI0080
WIfM00D0ojZZ09fMW@3oc9T0olbI0<bIV@040?o<V@80oomV0P3<VC<01`2ZEJX0IVJI0<aVc03<I/`0
EEFZ0<aVc01EEOl00P2ZEOl01`1EEOl0EEFZ06HcV@1V<iT0EEFZ03<0V@1EEJX00P00EJX01@2m_Kd0
c?nI0?o<V@3oc9T0c?nI0080c?o<0P3oZZX01P3<VFH0olbI0<bIV@3<VIT0olbI0<bIV@T0olbI0`3o
ofH01P3<ofH0oomE00004@000140oonZ03<0V@80Z_oo00<0c<c<03=VV@0cI/`00`0009T00`0006H0
001g0000M`020000M`050000V@2m_Kd0_Kfm0<30`03oc9T00P30`<000`3<oiT0olbI0?nZE@020?nZ
E@0609W<<`0001401`L700L71`0cI/`005Go0P0cI/`00`0009T009W<0000M`020000VA00oooo0P00
000Z0?ooo`00;`3oool01@0007L0001V0000IP0007L0001V0080001g00L0e=CD09VIV@3oojX0oonZ
0?nZE@3oojX0oomE0080oonZ00L0c9VI0?o<V@3oZUD0ojYE0?ooZP3oc9T0oonZ00L0001V00H0EEGo
03=VV@1EEOl0EEGo001EZP1EEOl20;Vi^@030?ooIP3ooc<0oonZ00<0olbI00D0ojYE0?o<V@3oc9T0
ojZZ0?ooZP020;fm_@030?ooc02m_Kd0Z_oo0080001V00L0001E0000IP0007L0001g0000IP0009T0
05FZ0080<`2I00L0<fJI03<0V@00EJX005FZ06HcV@00EJX0IS>I0080002Z00L0EEFZ0000ZP1VIYT0
IVJI09VIc01VIYT0VIW<0080IVJI00@0I/c<0?o<V@3<oiT0c?nI1@3oc9T01P3oZZX0XJ6Q0?o<c03o
c<`0olbI0;fm_@80olbI00<0_Kfm0?nZZP0006H00P0006H01`0009T0<fJI03<0V@0c09T0<fJI05EE
ZP1V<fH00P1V<iT01@1EEOl0IS>I0:YEZP2ZEJX0EEFZ00<0ZUFZ00<0TI6A0:YEZP2ATI400P2ZEJX0
1`2=SHd0ZUFZ0<aVc03<I/`0TI6A0<aVc02ATI400P3<VIT01`2ZEJX0c9VI0:YEZP2ZEJX0c9VI09FE
U@3<I/`00P3<VIT01`3<I/`0c9VI0:6QX@2QXJ40c9VI0:6QX@3<VIT00P2i^KT01P3<VIT0^KVi0<bI
V@3<VIT0^KVi0<bIV@80ofK<00<0c9VI0?mVc03<VIT00P3oc9T01`3<VIT0olbI0<bIV@3<VIT0olbI
0?nZZP3oc9T00P3oZZX0103<VIT0olbI0;fm_@2m_Kd60?o<V@050<coIP3<VC<0c9Tc06IVV@2IVL`0
101VIYT01@1EEJX0EJ[o05FZo`1nOWh0VC>I0080EEFZ00<0<`2I05EEZP1V<l`00`0c09T01P3oc<`0
/K6a0;6a/@3oc<`0b<S80?o<c080b<S800<0olbI0<bIV@3oc9T00`3oc9T01@3<VIT0olbI0?o<V@3<
VIT0olbI0080c9VI00L0olbI0?nZE@3oc9T0olbI0<bIV@3oZUD0ZZX000<0Z_nZ00H0<fK<0000V@00
09T0Z_oo001EZP000:X2001EZP070000ZP0006H0002I0000V@0007L0001V0000c0020?o<c00409W<
IP3oc<`0^KVi0;Vi^@<0olbI0P3oZZX01@3<VC<0000A00<30`030`<0000A00<0<fK<00<0002Z0000
IP0cI_l00P0006H00`0009T0oooo0?ooo`0=0?ooo`800000:P3oool002l0oooo00@000140000M`00
07L0001g1030`<00103oofH0ojZZ0?nZZP3oofH20?o<V@80ojYE103oojX30?o<V@80000c0P0006H3
0000M`060000V@1EZZX0IVJI06IVV@1EZZX0/K6a0P3oc9T20?nZE@050?ooIP3oojX0oonZ0?ooE@3o
ojX00P3oofH50?o<V@060?ooZP2Zool000140000A00005D0001g0P0009T00`0007L0<`1V03<0IP02
03=VIP070000M`1EEJX0CTi>04i>CP00EED0<`2I001EE@0406HcV@80EJ[o00<0EEGo05FZo`1EEOl0
0P3oojX40?o<V@060;fm_@3oZZX0`<300<30`03oZZX0VLbI0`3oc9T01`3oZZX0olc<0?nZZP3oZZX0
c9VI0?nZZP3<VIT00P0007L01P0006H0IS>I05EEZP1EEJX0<fJI001EZP<0IS>I00H0IVJI07inOP2Z
EJX0ZUFZ0861P@2ZEJX706IVV@0308f=S@1VIYT0ZUFZ00@0ZUFZ1`2MWId01P3oIYT0TI6A09Tcc02I
<l`0TI6A0:6QX@80ZUFZ00<0XJ6Q0:YEZP2ZEJX00P3<VIT01P2ZEJX0c9VI0:YEZP2ZEJX0c9VI0;fm
_@80c9VI00<0_Kfm0<bIV@2m_Kd00P2UYJD01`2i^KT0ojZZ09W<V@2Ic9T0c9VI09W<V@3<VIT00P2I
c9T01@3oZZX0WIfM0?o<V@3oc9T0c9VI0080olbI0P3oojX20?ooIP80IVJI00L0ZUFZ06IVV@2ZEJX0
ZUFZ05EEZP3<I/`0ZUFZ0080IS>I00L0EEGo05EEZP1V<iT0IS>I001EZP0c09T0EEFZ008005FZ00@0
<fJI03=VIP3oc9T0olbI0`3<ol`20:[oo`040<bIV@3oc9T0c9VI0<bIV@T0olbI00<0oomV0?o<V@3o
ZUD00P3oZUD01P3<ofH0000R05EEo`1EEOl0oonZ0;fm_@80IS>I00<0c<c<03=VV@1V<iT00P2IVL`7
0000M`80IS?<00H0`<300?o<V@3oc<`0olc<0<coV@3oc9T30?nZE@060<bIIP000140I/c<06K<c02Z
ool005Go0P0cI/`00`0cIYT005FZ0000V@030000VA40oooo00<000000?ooo`3oool09`3oool002l0
oooo0`0005D01P1Vc<`0ZZ[o06K<c01Vc<`0oonZ0<bIV@80oonZ00<0ojYE0?ooZP3ooeD00P3oojX0
1`3oZUD0olbI0?nZE@3oZUD0oonZ0?o<V@3ool`00P0005D01`0004@0001V0000M`0007L0001V0000
M`0cIYT00P1EEOl01`1VIYT0oonZ09W<<`2Ic3<0oonZ0<bIIP3oojX00P3oZUD20?o<V@80oonZ00<0
oomV0?o<V@3oc9T00P3oc9T01P3<VIT0oonZ0000<`0003<0001E0000IP80001g00<0001V0000V@00
EJX00P0c09T01`0cIYT0<`2I03=VV@0cIYT0IS>I001EZP1V<iT00P00EJX01`1EEJX0002Z06IVV@1V
IYT0VIW<06IVV@3oZUD00P3oc9T00`3<oiT0olbI0?o<V@050?o<V@030<coV@3oZZX0c?nI0080ojZZ
00D0olbI0;fm_@3oZZX0ojZZ0;fm_@020?nZZP80001g00L0002I03=VIP0c09T0<`2I03=VV@1V<iT0
<`2I0080EEFZ00D0EEGo06HcV@2ZEJX0ZUFZ05EEZP030:YEZP03096AT@2ZEJX0TI6A0080ZUFZ00L0
SHf=0:YEZP2=SHd0SHf=096AT@3<I/`0TI6A0080c9VI00@0ZUFZ0<bIV@2ZEJX0ZUFZ0P3<VIT01@3<
I/`0c9VI0<bIV@3<I/`0c9VI0080XJ6Q00<0c9VI0<aVc03<VIT00P2i^KT01P3<VIT0^KVi0<bIV@3<
VIT0^KVi0<bIV@80ofK<00<0c9VI0?mVc03oZZX00P2IVIT01`3<VIT0olbI0?nZZP3oZZX0olbI0?nZ
ZP2a/K400P3oZZX0102a/K40olbI0;fm_@2m_Kd30?o<V@80ojYE00H0olbI0<bIIP2IVL`0VIW<06IV
V@2IVL`506IVV@80RHV900L0EEFZ05FZo`1EEJX0EEFZ09TcV@1V<iT0IS?<00<0<`2I00H005FZ06Hc
V@1V<iT0olc<0<coo`3Hf=P20<coo`030=SHf03<VIT0olbI00<0olbI00@0c9VI0?o<V@3oc9T0c9VI
103oc9T01P3oZUD0olbI0?o<V@3<VIT0ojYE09W<V@80EEFZ00L0IVJI0:[oZP0009T0002I03=Vc000
EJX0002Z008005FZ00@0002I0000IP0009T0002I0P0007L01@0006H005FZ001EZP000<`0olc<0080
^KVi0`3oc9T209W<<`060?ooIP30`<00Z_oo0:[oo`30`<00002I0`0cI/`01@0006H0002Z0000IP00
06H0002I0180oooo00<000000?ooo`3oool09P3oool002l0oooo0`0005D01P1Vc<`0ZZ[o06K<c01V
c<`0oonZ0<bIV@80oonZ00<0ojYE0?ooZP3ooeD00P3oojX01`3oZUD0olbI0?nZE@3oZUD0oonZ0?o<
V@3ool`00P0005D01`0004@0001V0000M`0007L0001V0000M`0cIYT00P1EEOl01`1VIYT0oonZ09W<
<`2Ic3<0oonZ0<bIIP3oojX00P3oZUD20?o<V@80oonZ00<0oomV0?o<V@3oc9T00P3oc9T01P3<VIT0
oonZ0000<`0003<0001E0000IP80001g00<0001V0000V@00EJX00P0c09T01`0cIYT0<`2I03=VV@0c
IYT0IS>I001EZP1V<iT00P00EJX01`1EEJX0002Z06IVV@1VIYT0VIW<06IVV@3oZUD00P3oc9T00`3<
oiT0olbI0?o<V@050?o<V@030<coV@3oZZX0c?nI0080ojZZ00D0olbI0;fm_@3oZZX0ojZZ0;fm_@02
0?nZZP80001g00L0002I03=VIP0c09T0<`2I03=VV@1V<iT0<`2I0080EEFZ00D0EEGo06HcV@2ZEJX0
ZUFZ05EEZP030:YEZP03096AT@2ZEJX0TI6A0080ZUFZ00L0SHf=0:YEZP2=SHd0SHf=096AT@3<I/`0
TI6A0080c9VI00@0ZUFZ0<bIV@2ZEJX0ZUFZ0P3<VIT01@3<I/`0c9VI0<bIV@3<I/`0c9VI0080XJ6Q
00<0c9VI0<aVc03<VIT00P2i^KT01P3<VIT0^KVi0<bIV@3<VIT0^KVi0<bIV@80ofK<00<0c9VI0?mV
c03oZZX00P2IVIT01`3<VIT0olbI0?nZZP3oZZX0olbI0?nZZP2a/K400P3oZZX0102a/K40olbI0;fm
_@2m_Kd30?o<V@80ojYE00H0olbI0<bIIP2IVL`0VIW<06IVV@2IVL`506IVV@80RHV900L0EEFZ05FZ
o`1EEJX0EEFZ09TcV@1V<iT0IS?<00<0<`2I00H005FZ06HcV@1V<iT0olc<0<coo`3Hf=P20<coo`03
0=SHf03<VIT0olbI00<0olbI00@0c9VI0?o<V@3oc9T0c9VI103oc9T01P3oZUD0olbI0?o<V@3<VIT0
ojYE09W<V@80EEFZ00L0IVJI0:[oZP0009T0002I03=Vc000EJX0002Z008005FZ00@0002I0000IP00
09T0002I0P0007L01@0006H005FZ001EZP000<`0olc<0080^KVi0`3oc9T209W<<`060?ooIP30`<00
Z_oo0:[oo`30`<00002I0`0cI/`01@0006H0002Z0000IP0006H0002I0180oooo00<000000?ooo`3o
ool09P3oool002l0oooo00@000140000IP0006H0001V0`30`<001P1V<l`0oonZ0<bIIP3<VFH0olbI
0?nZE@<0olbI0P3oojX40?o<V@050?ooZP0004@000140000E@0006H00P0007L00`0cI_l0<fK<03=V
o`0206IVV@040<coIP3oc9T0olbI0?o<V@80ojYE00@0oomV0?ooZP3oojX0oomE0`3oojX00`3oc9T0
oonZ0?o<V@020?o<V@050?ooZP3<VIT000140000A00005D0100007L203<0IP80<fIV00L0001g05EE
ZP0cIYT0<fJI0:YEo`1VIYT005EE0080<`2I101V<iT00`1EEOl0oomV0?o<V@020?ooZP@0olbI00L0
_Kfm0?nZZP30`<00`<300?o<V@2Ic9T0olbI0080VLbI00L0olbI0?o<c03oZZX0ojZZ0<bIV@3oZZX0
ZJVY00<0001V00H0002I05EEZP1EEJX0<fJI001EZP1EEJX2001EZP0606IVV@1nOWh0ZUFZ0:YEZP21
PH40ZUFZ0P21PH4506IVV@0408f=S@1VIYT0SHf=08f=S@D0ZUFZ102MWId00`2ZEJX0VC?<096AT@02
09Tcc007096AT@2QXJ40ZUFZ0:YEZP2QXJ40/K6a0:YEZP020<bIV@050:YEZP3<VIT0ZUFZ0:YEZP3<
VL`00`3<VIT00`2m_Kd0c9VI0<bIV@020:FUY@070;Vi^@3oZZX0VLbI09W<V@3<VIT0VLbI0?o<V@02
09W<V@050?o<V@30`<00olbI0?o<V@3<VIT00P3oc9T20?ooZP060?ooIP2Ic3<0IVJI06IVV@2ZEJX0
IVJI0P2ZEJX00`1EEJX0c6K<05EEZP0206HcV@070:YEZP1V<iT0IS>I06HcV@1EEJX0IS>I001EZP02
03<0V@0703=VV@00EJX0002I0000V@0cIVH0Z_oo0:ZZo`020:[oo`040:ZZo`2Zool0c9VI0<bIV@T0
olbI00<0oomV0?o<V@3oZUD00P3oZUD01P3<ofH0VLaV05EEo`1EEOl0EEFZ05EEo`80IS>I00<0<`2I
03=VV@1V<iT00P0cIYT01`0007L005FZ0000M`0007L0001V0000M`0006H00P1V<l`01`000:X0IS?<
0?o<c03oc<`0oonZ0?o<V@3<VFH00P3ooc<01P3<ofH0Z_oo06K<c01Vc<`0Z_oo06K<c080<fK<00<0
05Go001EZP0009T00P00EJX00`0007L0oooo0?ooo`0i0?ooo`00;`3oool01@0005D0VIW<09VIc01E
EOl0VIW<0080I/c<00L0oonZ0<bIV@3oc<`0olc<0?nZE@3oojX0oomE0080olbI00H0ojYE0?o<V@3o
c9T0olbI0?ooZP3oZZX30?ooo`030000A00006H0001g0080001g00H0VIW<06IVV@2IVL`0VIW<0<co
IP3oofH20?oo<`030?ooZP3<VFH0olbI0080ojYE00H0olbI0?ooIP3oc9T0olbI0?ooIP3oc9T20<bI
V@030?o<V@3oZZX0oonZ0080ZZX000L0001E0000IP0007L0001g0000IP0009T0GUiN0080<`2I00L0
<fJI03<0V@0cIYT0<fJI03<0V@1VIYT0<fK<0080IVJI00L0EEFZ0000ZP1Vc<`0I/c<0?mVIP3oc9T0
oomV0080olbI00<0c?nI0?o<V@3oc9T01@3oc9T00`3<oiT0ojZZ09VIV@020?nZZP0509VIV@2m_Kd0
ojZZ0?nZZP2m_Kd00P3oZZX20:VYZ@070000V@00EED0<`2I03<0V@0cIYT0IS>I03<0V@0206HcV@06
08V9R@1V<iT0EEGo05EEo`1EEJX0ZUFZ0P1EEJX00`2ATI40ZUFZ096AT@020:YEZP0708f=S@2ZEJX0
SHf=08f=S@2ATI40c6K<096AT@020<aVc0070:YEZP3<VIT0XJ6Q0:6QX@2ZEJX0c9VI0<aVc0020<bI
V@070<aVc03<VIT0XJ6Q0:6QX@3<VIT0c6K<0<bIV@020;Vi^@030<bIV@2i^KT0c9VI00<0c9VI0P3o
I/`00`3<VIT0ofK<0?nZZP0209VIV@070?nZZP3oc9T0ojZZ0?nZZP3oc9T0ojZZ0;6a/@020?nZZP03
0;6a/@3oc9T0olbI00@0olbI0P3<ofH00`3oojX0I/c<0:YEZP020:YEZP0405EEZP1VIYT0IVJI09VI
c080IVJI0P29RHT01`1EEJX0RHV905EEZP1EEJX0VC>I06HcV@0c09T00P1EEJX203<0V@80IS>I00<0
002I0000IP3Hf=P00P3<ool00`2IVOl0`<300?o<V@030?o<V@040<bIV@3oc9T0olbI0<bIV@@0olbI
00H0ojYE0?o<V@3oc9T0c9VI0<bI<`2Ic9T20<coV@0706IVV@1EEJX0002I0000V@0cI/`0<fIV0000
ZP02001EZP070000V@00EJX0002I0000V@0006H0002I0000M`020000V@040000c000EJX0003<0000
c080olbI00D0oomV0?nZZP3oZZX0c9Tc000000020:[oo`070<30`02Zool0002I0000V@0cI/`0<fJI
0000ZP020000IP030000V@0007L0oooo03T0oooo000_0?ooo`<0001400H0<fK<06Hcc00cI/`0<fK<
0?nZZP3oofH30?o<V@030?nZE@3oojX0oonZ00<0oonZ0`3oc9T40?ooo`070000E@0006H0001g0000
M`0006H0<fK<03=Vo`020;6a/@070?ooZP30`<00olbI0?o<V@3oofH0oonZ0?ooE@020?ooZP050?oo
IP3oc9T0oonZ0?ooZP3oc9T00`3oojX00`3oc9T0ojZZ0<bIV@020?nZZP070000E@0006H0001g0000
M`0009T0<`1V0000M`0203=VIP070000M`1EEJX0<fJI03=VV@1EEJX0IVJI0:YEo`0206IVV@060:YE
o`3oc9T0ojYE0?nZE@3oojX0oomV103oc9T01@2m_Kd0olbI0?o<V@30`<00ojZZ0080VLbI00<0olbI
09W<V@3oc9T00P2Ic9T01@3oc9T0VLbI0?nZZP3oZZX0c9VI00@0ZJVY00D0001g0000V@1V<iT0IS>I
03=VV@0205EEZP8005FZ00H0IS>I09TcV@1VIYT0IVJI0861P@2ZEJX20861P@D0IVJI00@0SHf=06IV
V@2=SHd0SHf=1@2ZEJX01`2MWId0ZUFZ0<aVc03<I/`0ZUFZ09Tcc02ATI400P2I<l`00`2ATI40VC?<
0:YEZP020:YEZP050;6a/@2ZEJX0c9VI0<bIV@2ZEJX00`3<VIT01`3<VL`0c9VI0<bIV@3<VIT0_Kfm
0:FUY@3<VIT00P2UYJD20<bIV@80VLbI00<0c9VI09W<V@3oc9T00P2Ic9T00`3oc9T0`<300?nZZP02
0?nZZP050?ooZP3oofH0ojYE0?nZE@3ooeD00`1VIYT01`2ZEJX0RHV90:YEZP2ZEJX0RHV90<aVc01E
EJX00P1V<iT01`2ZEJX0IS>I06HcV@1V<iT0EEFZ06HcV@00EJX00P1V<iT01`0cIYT005FZ06HcV@1V
<iT0<fIV0000M`0006H00P0007L0101Eool0Z_oo05Goo`1Eool90?o<V@070?ooIP3oc9T0ojZZ0?nZ
ZP3oZUD0oolc06IVV@0209W<V@0505EEZP1EEOl0<fJI03=VV@0c09T00P1V<iT203=VV@0303=VIP00
09T0001g00H0001g00L0EJ[o0:YEo`1EZ_l0EJ[o06Hcc03oofH0c9UV0080ojZZ00H0c?mV00000000
EJX005FZ0:[oo`1Vc<`205EEZP03001Eo`0009T0002I008005FZ00<0<`2I0000V@3oool0>@3oool0
02l0oooo0`0004@01P0cI/`0IS?<03=Vc00cI/`0ojZZ0?ooIP<0olbI00<0ojYE0?ooZP3oojX00`3o
ojX30?o<V@@0oooo00L0001E0000IP0007L0001g0000IP0cI/`0<fKo0080/K6a00L0oonZ0<30`03o
c9T0olbI0?ooIP3oojX0oomE0080oonZ00D0oomV0?o<V@3oojX0oonZ0?o<V@030?ooZP030?o<V@3o
ZZX0c9VI0080ojZZ00L0001E0000IP0007L0001g0000V@0c06H0001g0080<fIV00L0001g05EEZP0c
IYT0<fJI05EEZP1VIYT0ZUGo0080IVJI00H0ZUGo0?o<V@3oZUD0ojYE0?ooZP3oofH40?o<V@050;fm
_@3oc9T0olbI0<30`03oZZX00P2Ic9T00`3oc9T0VLbI0?o<V@0209W<V@050?o<V@2Ic9T0ojZZ0?nZ
ZP3<VIT0102YZJT01@0007L0002I06HcV@1V<iT0<fJI0080EEFZ0P00EJX01P1V<iT0VC>I06IVV@1V
IYT0PH610:YEZP80PH611@1VIYT0102=SHd0IVJI08f=S@2=SHd50:YEZP0709fMW@2ZEJX0c6K<0<aV
c02ZEJX0VC?<096AT@0209Tcc003096AT@2I<l`0ZUFZ0080ZUFZ00D0/K6a0:YEZP3<VIT0c9VI0:YE
ZP030<bIV@070<bIc03<VIT0c9VI0<bIV@2m_Kd0YJFU0<bIV@020:FUY@80c9VI0P2Ic9T00`3<VIT0
VLbI0?o<V@0209W<V@030?o<V@30`<00ojZZ0080ojZZ00D0oonZ0?ooIP3oZUD0ojYE0?ooE@0306IV
V@070:YEZP29RHT0ZUFZ0:YEZP29RHT0c6K<05EEZP0206HcV@070:YEZP1V<iT0IS>I06HcV@1EEJX0
IS>I001EZP0206HcV@0703=VV@00EJX0IS>I06HcV@0cIVH0001g0000IP020000M`0405Goo`2Zool0
EOoo05Goo`T0olbI00L0oomV0?o<V@3oZZX0ojZZ0?nZE@3ooc<0IVJI0080VLbI00D0EEFZ05EEo`0c
IYT0<fJI03<0V@0206HcV@80<fJI00<0<fIV0000V@0007L01P0007L01`1EZ_l0ZUGo05FZo`1EZ_l0
IS?<0?ooIP3<VFH00P3oZZX01P3<ofH00000001EZP00EJX0Z_oo06K<c080EEFZ00<005Go0000V@00
09T00P00EJX00`0c09T0002I0?ooo`0i0?ooo`00;`3oool01@0cIYT000140000A01EEOl0VIW<0080
EEGo00L0oonZ0:[oZP3oojX0oonZ0?ooE@3oc<`0oonZ0080olbI00@0ojYE0?ooZP3oc9T0olbI1@3o
ool01@0003<0001V06IVV@1VIYT0ZUGo00@0IVJI00D0^KVi0?ooZP3ooc<0oolc0?ooZP020?o<V@80
ojYE00<0olbI0?ooIP3oc9T00`3oc9T20<bIV@030?o<V@3oZZX0oonZ0080c9W<00@000140000M`00
06H0001V0P0007L01@1NGUh0EEFZ05EEZP0cIYT0<`2I0080<fJI00<0<`2I06IVV@0cI/`00P1VIYT0
1`2IVOl0c9VI0?o<V@3oc9T0ojYE0?o<V@3oofH00P3oc9T00`3<oiT0olbI0?o<V@030?o<V@80ojZZ
00<0c?nI0?nZZP2IVIT00P3oZZX01`2IVIT0ojZZ0?nZZP3oZZX0_Kfm0:VYZ@3oZZX00P2YZJT01@00
05D005EE0000V@0009T0<fJI0080<`2I0P1V<iT01P29RHT0EEFZ08V9R@29RHT0EEFZ0:YEZP80EEFZ
00<0TI6A0:YEZP2ATI400P2ZEJX01`2=SHd0ZUFZ08f=S@2=SHd0TI6A0<aVc02ATI400P2IVL`01`2Q
XJ40ZUFZ0:6QX@2QXJ40ZUFZ0<bIV@3<I/`00P3<VIT01`3<I/`0c9VI0:6QX@2QXJ40c9VI0<aVc03<
VIT00P2i^KT00`3<VIT0^KVi0<bIV@030<bIV@80ofK<00<0c9VI09VIV@3oZZX00P2IVIT01`3oZZX0
olbI0?nZZP3oZZX0olbI0?nZZP2a/K400P3oZZX50?o<V@060<bIV@3oc9T0c9UV0<bIIP3<VC<0I/c<
0`2ZEJX0101EEJX0ZUFZ0:YEZP1EEJX206IVV@80RHV900L0EEFZ08V9R@1EEJX0EEFZ09TcV@1V<iT0
<`2I0080IS>I0P0c09T203=VV@030000V@00EED0002I0080001V00L0EJ[o0=3@d01EZ_l0EJ[o0=3@
d03oc9T0c9VI0080olbI00@0c9VI0?o<V@3oZUD0ojYE0P3oc9T20?ooIP030<bIV@1EEJX0VIW<0080
EEFZ00D0IVJI05EEZP1VIYT0IVJI03=Vc0020000V@8005FZ00L0002Z001EZP0009T0002I0000IP00
09T0001g0080002Z00L0001V06IVV@1EEOl0EEGo06IVV@1EEOl0_Kfm0080ojYE00H0EEFZ0000001E
EJX0EEFZ03<0V@2Zool20000V@0303=Vc00cIYT0002I0080001V00<0002I0000IP3oool01`3oool0
0`000280oooo0?ooo`0_0?ooo`00;`3oool01@0006H0002I0000V@0cI/`0IS?<0080oonZ00<0002I
0?o<V@3oc9T00`3oc9T40?ooZP030?o<V@3oool0oooo00D0oooo00L0000R0000IP0006H0001V05FZ
o`1EEOl0EJ[o00<0olbI00H0ojYE0?o<V@3oc9T0olc<0?ooZP3ooeD30?ooZP030?o<V@3oojX0oonZ
0080olbI0P3oojX00`3<VIT0ojZZ0<bIV@020?nZZP040000A00006H0001g0000M`80002I00D0001g
03<0IP0c06H0002I03=VIP0203=VV@0305EEZP0cIYT0ZUGo0080I/co00@0c?mV0?ooIP3oofH0oomV
0P3oojX40?o<V@050;fm_@3oZZX0ojZZ0<30`03oZZX00P2Ic9T00`3oc9T0VLbI0?o<V@0209W<V@03
0<bIV@2Ic9T0c9VI0080c9VI0P2YZJT20:6QX@050000E@0007L0001V0000IP00EJX00P1EEJX2001E
ZP0605EEZP2I<iT0IS>I06HcV@29RHT0ZUFZ0P21PH4506IVV@0508f=S@1VIYT0SHf=08f=S@2ZEJX0
102QXJ401`3<I/`0ZUFZ0<aVc03<I/`0ZUFZ0<aVc02ATI400P2I<l`01`2ATI40VC?<0;6a/@2a/K40
ZUFZ0;6a/@2ZEJX00P2a/K401P2ZEJX0c9W<0<bIV@3<VIT0c9W<0<bIV@80c9W<00<0_Kfm0:FUY@3<
VIT00P2UYJD01`3<VIT0/K6a09W<V@2Ic9T0c9VI09W<V@3oc9T00P2Ic9T00`3oZZX0`<300?nZZP02
0?nZZP050?ooZP3oofH0ojYE0?nZE@2=SHd0101VIYT01P29RHT0ZUFZ0:YEZP29RHT0IS>I05EEZP80
c6K<00@0ZUFZ06HcV@2ZEJX0ZUFZ0P1V<iT01@00EJX0IS>I06HcV@0cIYT005FZ0080<fJI00<0<fIV
0000V@0006H00`0007L01@2ZZ_l0VIW<09VIc02ZZ_l0VIW<00L0olbI0P3oofH20?nZZP030?ooIP3<
oiT0IVJI0080ZUGo00L0EEFZ05EEo`1EEJX0EEFZ03=VV@1V<iT005FZ0080<fJI00<0IS>I0000V@00
07L01`0007L01P2ZEOl0EJ[o05FZo`2ZEOl0c9W<0;fm_@80olbI00H0IS?<03=Vc000000000000000
ZP00EJX20:[oo`03001EZP0cI/`0<fJI008005FZ00<0<`2I001EZP3oool01`3oool00`0003<0000R
00008P0_0?ooo`00<03oool20000ZP0603=VV@2IVL`0<fJI03=VV@3oc<`0ojYE0P3oojX00`2Ic6H0
olbI0?ooZP020?o<V@030?nZE@3oool0oooo00H0oooo00L0000c05EEZP0006H0001V0:YEo`1VIYT0
ZUGo0080oonZ00L0c?nI0?ooZP3<VFH0c9UV0?o<V@3oZUD0olbI0080oonZ00<0olbI0?ooIP3oc9T0
0`3oc9T20<bIV@030?ooZP3oZZX0oonZ0080c9W<00@0000c0000IP0006H0001V0P0007L01@1NGUh0
002I0000V@0cIYT0EEFZ0080<fJI00<0<`2I06K<c02IVOl00P3<ofH01`3oojX0ojYE0?o<V@3oc9T0
ojYE0?o<V@3<oiT01`3oc9T01P3<oiT0ojZZ0?nZZP3<oiT0ojZZ09VIV@80ojZZ00L0olbI0?nZZP3o
c9T0olbI0?nZZP2YZJT0ojZZ0080c9VI00D0000c0000M`0009T0002I001EE@0203<0V@80IS>I00H0
<`2I05EEZP29RHT0RHV905EEZP2ZEJX205EEZP03096AT@2ZEJX0TI6A0080ZUFZ00L0SHf=0:YEZP2I
VL`0VIW<0:YEZP2IVL`0ZUFZ0080VIW<0P2ZEJX20:6QX@030:YEZP2QXJ40c6K<0080c9VI00L0c6K<
0<bIV@3<I/`0c6K<0<bIV@3<I/`0c9VI0080c6K<203<VIT00`3oZZX0VIVI0?nZZP0209VIV@070?nZ
ZP3<oiT0ojZZ0?nZZP3oc9T0ojZZ0;6a/@020?nZZP80olbI0P3<VIT20?o<V@050?ooZP3<VFH0c9UV
096AT@1Vc<`00P2ZEJX01@1Vc<`0EEFZ0:YEZP2ZEJX0EEFZ00@0IVJI00L0EEFZ08V9R@1EEJX0EEFZ
03<0IP1EEJX0<`2I00<0IS>I0`0c09T00`0009T0IS>I0000V@020000IP070000M`1EZ_l0VIWo09VI
o`1EZ_l0VIWo05FZo`020?o<V@040<bIV@3oc9T0ojYE0?nZE@80olbI0P3oofH00`3<VC<0c?o<09VI
c00405EEZP80IVJI00<0<`2I0000V@0cI/`00P0cIVH01`000:X0IS>I0000V@0009T0001V0000V@00
07L00P0009T01`000:X0002I05EEo`1EEOl0_Kfm0<30`03oojX00P3oZUD405EEZP0703<0V@1EEJX0
<`2I03<0V@0009T0<fK<0000V@0203=VV@040000V@0c06H0002I0000V@D0oooo00@0000c09VIo`3<
ol`0c?o<;`3oool00300oooo0P0009T0100cIYT0002I0=3@d03@d=040?o<V@030?ooZP3oc9T0oonZ
0080oonZ2P3oool01P0005D0EEFZ05EEZP1EZ_l0EEGo0?ooZP80EEFZ00L0olbI0?nZE@3oc9T0olbI
0?ooIP3oojX0oomE0080olbI00@0oonZ0?o<V@3oojX0oonZ0P3oc9T20?ooZP030<bIV@3oZZX0c9W<
0080ojZZ00D0c9T00000IP0007L0001g0000V@020000M`80<`1V00L0002I0000ZP0009T0002I06K<
c01Vc?l0I/c<0080ojYE00@0olbI0?ooZP3oofH0oomV0P3oojX40?o<V@050;fm_@3oZZX0ojZZ0<30
`03oc9T00P2Ic9T00`3oc9T0VLbI0?o<V@0209W<V@040<bIV@2Ic9T0c9VI0<bIV@<0ZJVY0P2QXJ40
1`2MWId000140000IP0006H005FZ06HcV@1EEJX00P00EJX01P1EEJX0VC>I06HcV@1V<iT0VC>I0:YE
ZP80RHV900<0IVJI05FZZP1VIYT00P1EZZX0102ZEJX0VC?<0:YEZP2ZEJX60:6QX@060:YEZP3<I/`0
c6K<0:YEZP3<I/`0TI6A0P2I<l`01`2ATI40ZUFZ09VIc02IVL`0ZUFZ0;6a/@2ZEJX00P2a/K401P3<
VIT0c9W<0<bIV@3<VIT0c9W<0<bIV@80c9W<00<0c9VI0:FUY@3<VIT00P2UYJD01`3<VIT0/K6a0<bI
V@3<VIT0olbI09W<V@3oc9T00P30`<001`3oZZX0`<300?ooZP3oojX0ojZZ0?ooZP3ooeD00P2Ic3<0
0`2=SHd0IVJI06IVV@0206IVV@0608V9R@2ZEJX0ZUFZ08V9R@2ZEJX0VC?<0P1V<iT0102ZEJX0IS>I
0:YEZP2ZEJX206HcV@03001EZP1V<iT0IS>I008005FZ0P0cIYT00`0007L0002I0000V@030000M`06
0000IP2IVL`0VIW<06K<c02IVL`0I/c<0P2IVL`40?o<V@80oomV0P3oZZX00`3oojX0EEFZ06IVV@02
0:YEo`0706IVV@0c09T0EEFZ05EEZP1EEOl0<fJI03<0V@0306HcV@060000V@0007L0001g0000V@00
07L005FZ0P0007L01`0cIYT005FZ0<bIc03<VL`0ZZ[o0?nZZP2m_Kd00P3oc9T01P000000<fK<06Hc
c01V<l`0002Z001EZP80002Z00<005FZ05EEZP0cIYT00`0009T00`00EJX0001g0000M`030?ooo`<0
000c00<0VIWo05Goo`1Eool0;`3oool00300oooo0P0009T0100cIYT0002I0=3@d03@d=040?o<V@03
0?ooZP3oc9T0oonZ0080oonZ2P3oool01P0005D0EEFZ05EEZP1EZ_l0EEGo0?ooZP80EEFZ00L0olbI
0?nZE@3oc9T0olbI0?ooIP3oojX0oomE0080olbI00@0oonZ0?o<V@3oojX0oonZ0P3oc9T20?ooZP03
0<bIV@3oZZX0c9W<0080ojZZ00D0c9T00000IP0007L0001g0000V@020000M`80<`1V00L0002I0000
ZP0009T0002I06K<c01Vc?l0I/c<0080ojYE00@0olbI0?ooZP3oofH0oomV0P3oojX40?o<V@050;fm
_@3oZZX0ojZZ0<30`03oc9T00P2Ic9T00`3oc9T0VLbI0?o<V@0209W<V@040<bIV@2Ic9T0c9VI0<bI
V@<0ZJVY0P2QXJ401`2MWId000140000IP0006H005FZ06HcV@1EEJX00P00EJX01P1EEJX0VC>I06Hc
V@1V<iT0VC>I0:YEZP80RHV900<0IVJI05FZZP1VIYT00P1EZZX0102ZEJX0VC?<0:YEZP2ZEJX60:6Q
X@060:YEZP3<I/`0c6K<0:YEZP3<I/`0TI6A0P2I<l`01`2ATI40ZUFZ09VIc02IVL`0ZUFZ0;6a/@2Z
EJX00P2a/K401P3<VIT0c9W<0<bIV@3<VIT0c9W<0<bIV@80c9W<00<0c9VI0:FUY@3<VIT00P2UYJD0
1`3<VIT0/K6a0<bIV@3<VIT0olbI09W<V@3oc9T00P30`<001`3oZZX0`<300?ooZP3oojX0ojZZ0?oo
ZP3ooeD00P2Ic3<00`2=SHd0IVJI06IVV@0206IVV@0608V9R@2ZEJX0ZUFZ08V9R@2ZEJX0VC?<0P1V
<iT0102ZEJX0IS>I0:YEZP2ZEJX206HcV@03001EZP1V<iT0IS>I008005FZ0P0cIYT00`0007L0002I
0000V@030000M`060000IP2IVL`0VIW<06K<c02IVL`0I/c<0P2IVL`40?o<V@80oomV0P3oZZX00`3o
ojX0EEFZ06IVV@020:YEo`0706IVV@0c09T0EEFZ05EEZP1EEOl0<fJI03<0V@0306HcV@060000V@00
07L0001g0000V@0007L005FZ0P0007L01`0cIYT005FZ0<bIc03<VL`0ZZ[o0?nZZP2m_Kd00P3oc9T0
1P000000<fK<06Hcc01V<l`0002Z001EZP80002Z00<005FZ05EEZP0cIYT00`0009T00`00EJX0001g
0000M`030?ooo`<0000c00<0VIWo05Goo`1Eool0;`3oool00300oooo0P0005D01P0cIYT0002Z0:[o
ZP2ZojX0oonZ06Hcc080olc<00<0VLaV0?o<V@3oZUD00P3oc9T:0?ooo`060000M`0cI/`0<fK<05EE
ZP1VIYT0EEFZ0P3ool`01`3ooc<0oonZ0<bIV@3<VIT0olbI0?nZE@3oc9T00P3oojX01P3oc9T0oomV
0?o<V@3oc9T0c9VI0?o<V@80ojZZ00<0oonZ0?nZZP3oojX00P3<VL`00`3<V@00001V0000M`030000
M`0506Hcc00009T0002I03=VV@1EEJX00P0cIYT00`1EEJX0I/c<0?ooZP020<coIP070?ooZP3oZUD0
olbI0?o<V@3oofH0olbI0<coV@070?o<V@060<coV@3oZZX0ojZZ09VIV@3oZZX0VIVI0P3oZZX01`3o
c9T0ojZZ0?o<V@3oc9T0c9VI0:VYZ@3oZZX00P3<VIT01@3oZZX0001E0000V@0009T005EE0080<`2I
0P1V<iT01P0c09T0EEFZ08V9R@29RHT0EEFZ0:YEZP80EEFZ00<0OWin0:YEZP1nOWh00P2ZEJX01`2I
VL`0TI6A09VIc02IVL`0TI6A09VIc02ZEJX00P2IVL`20:YEZP80XJ6Q00<0ZUFZ0:6QX@3<I/`01`3<
VIT0103<I/`0c9VI0<aVc03<I/`80<bIV@030?nZZP2IVIT0ojZZ0080VIVI00L0ojZZ0<coV@3oZZX0
ojZZ0;6a/@3oZZX0/K6a00@0olbI0P3<VIT20?o<V@050?ooZP2ZEOl0ZUGo096AT@2ZEOl00P2ZEJX0
1P1Vc<`0EEFZ0:YEZP2ZEJX0EEFZ0:YEZP<0IVJI00L0EEFZ08V9R@1EEJX0EEFZ03<0IP1EEJX0<`2I
0080IS>I100c09T00`0009T0IS>I0000V@020000IP070000V@0006H0001g0000M`1EZ_l0VIWo05Go
o`0209VIo`0605Goo`3oc9T0ojYE0?nZE@3oc9T0c9VI0P3oofH00`3oc9T0EEFZ09VIc00205EEZP07
09VIc01V<iT0IVJI06IVV@1EEJX0002Z03=Vc00203=VIP070000ZP1V<iT0002I0000V@0c09T0002I
0000IP020000V@070000M`000:X0001V0000IP2m_Kd0ojZZ0?ooZP020<bI<`0306IVV@1EEJX0EEFZ
00<0EEFZ0`0c09T20000V@80<fJI00@0002Z03<0IP0009T0002I0`3oool200008P050000<`2IVOl0
c?o<0<coc02IVOl0;P3oool00300oooo0P0006H01P0cIYT0oonZ0=3@d03@d=00VIW<0?ooZP80olbI
00<0oonZ0?o<V@3oojX0303oool01P0009T0EEFZ05EEZP0c09T0EEFZ0?o<c080`<3000L0olbI0?o<
c03oojX0oonZ0?ooIP3oZZX0oonZ0080olbI00<0oonZ0?o<V@3oojX00P3oojX01P3oc9T0ojZZ0?nZ
ZP3<VIT0ojZZ0<bIc080ojZZ00L0c?mV0000A00007L0001g0000V@0007L0002I008005FZ00L0001g
0000ZP0009T0002I0:[oo`3<ool0c?mV0080ojYE00H0oomV0?ooZP3oofH0oomV0?o<V@3oojX40?o<
V@050<bIV@3oc9T0olbI09W<V@3oc9T00P2Ic9T00`3oc9T0VLbI0?o<V@0209W<V@070<bIV@2Ic9T0
ojZZ0?nZZP3oc9T0ZJVY09fMW@020:6QX@0709fMW@0004@0001V0000IP0009T0IS>I03<0V@02001E
ZP0605EEZP2I<iT0IS>I06HcV@2I<iT0ZUFZ0P29RHT00`2ZEJX0EJZZ06IVV@0205FZZP0506IVV@2I
<l`0ZUFZ0:YEZP2I<l`01@2QXJ401P2ZEJX0c6K<0<aVc02ZEJX0c6K<096AT@80ZUFZ00L0VIW<0:YE
ZP2IVL`0VIW<0:YEZP2a/K40ZUFZ0080c9W<00H0ZZZZ0<bIc03<VIT0c9VI0<bIc03<VIT40:FUY@05
0<bIV@2a/K40/K6a0<bIV@2a/K400P3<VIT00`30`<00VLbI0?o<V@020<30`080ojZZ0P3oojX00`3o
ofH0ojYE0?ooE@020:YEZP0308f=S@2I<l`0IVJI0080IVJI00H0RHV90:YEZP2ZEJX0RHV90:YEZP2I
<l`206HcV@0405EEZP1V<iT0ZUFZ0:YEZPD0IS>I00L005FZ03=VV@0cIYT0<fJI0000M`1V<iT0002I
00H0001g00<0/K6a0<30`02a/K400P30`<00102a/K40ZZ[o0;fm_@2m_Kd20?nZE@80olbI00<00000
05EEZP1EEJX00P2ZEOl01@1VIYT0<`2I001EZP00EJX0EEGo0080<fJI0P1V<iT01`00EJX0<fJI03=V
IP0cIVH0002I001EE@0007L00P1V<iT01`0007L005FZ03=VV@0cIYT0ZZ[o0?nZZP2m_Kd00P3ooc<0
1P2IVL`0<fK<06Hcc01V<l`0<fK<001EZP80002Z00<0<fJI05EEZP0cIYT00P0009T01@0cIYT005FZ
03<0V@0c09T0002I0080oooo0P0003<01@2Zool0EEFZ05Goo`1Eool0VIWo02h0oooo000`0?ooo`80
001E00H0001g09VIc01V<l`0IS?<09VIc02Ic6H20?o<c0030?ooZP3oc9T0oooo00`0oooo00H0000c
0000A00004@0EEFZ03=Vc03<oiT20?ooZP030<bIo`3oojX0olbI0080olbI00@0c9VI0?o<V@3oofH0
oomV103oc9T01`3<VIT0olbI0?nZZP3oZZX0olbI0;fm_@3oc9T00P3<oiT01@3oc9T0000c0000M`00
07L0IS>I0080001g0P1EEJX01`1V<l`0EEFZ0:ZZo`2ZZ_l0Z_oo0:ZZE@3oojX00P3<VIT01`3oc9T0
ojYE0?o<V@3oc9T0oomV0?o<V@2e]KD00P3oc9T01P2QXJ40olbI0<bIV@3<VIT0olbI0<coV@80ojZZ
00<0VIVI0?nZZP2IVIT00P3oZZX0103oc9T0ojZZ0<30`030`<020<bIV@050?nZZP3<VIT0c9VI0?nZ
ZP3<VIT00P0005D00`0006H0<`2I001EE@0205EEZP0603<0V@1V<iT0RHV908V9R@1EEJX0ZUFZ0P1E
EJX20:YEZP0507inOP2ZEJX0ZUFZ07inOP2ATI400P2IVL`00`2ATI40VIW<0:YEZP0209VIc080ZUFZ
0P2QXJ400`2ZEJX0XJ6Q0<bIV@070<bIV@030<aVc03<VIT0c9VI00L0c9VI0P2IVL`00`3oZZX0VIVI
0?nZZP020<coV@070?nZZP3<oiT0ojZZ0?nZZP2Ic9T0ojZZ0;6a/@040?o<V@80c9VI00<0olbI0<bI
IP3oojX00P2ATI401@1VIYT0TI6A0:YEZP2ZEJX0I/c<00<0ZUFZ00<0EEFZ0:YEZP1VIYT00P1VIYT0
1`1V<iT0EEFZ05EEZP1EEJX0<`1V05EEZP0c06H00P1V<iT203<0V@80IS>I00<0002I03=VV@0009T0
0P00EED00`0009T0001V0000V@020000V@0609VIo`1Eool0VIWo09VIo`3oc?l0_Kfm0P3oc?l01`3<
c<`0VLaV0?o<c03oc<`0VIW<05EEZP2IVL`00P1V<iT00`2IVL`0EEFZ05EEZP0205EEZP030000ZP0c
09T0002I0080002I00H005FZ0000V@0009T005FZ0000V@0006H20000V@0706HcV@1VIYT0EEFZ05EE
ZP000:X0ojZZ0?ooIP0203=Vc00306IVV@00EJX0EEFZ0080EEFZ0`0c09T00`1EEJX0IS>I0000V@02
03=VV@070000V@0c06H0002I0000V@0c06H0oooo0000<`0200008P0506K<c03<ol`0c?o<0<coc02I
VOl0;P3oool00300oooo0P0005D01P0007L0VIW<06Hcc01V<l`0VIW<09W<IP80olc<00<0oonZ0?o<
V@3oool0303oool01P0003<000140000A01EEJX0<fK<0<coV@80oonZ00<0c9Wo0?ooZP3oc9T00P3o
c9T0103<VIT0olbI0?ooIP3oofH40?o<V@070<bIV@3oc9T0ojZZ0?nZZP3oc9T0_Kfm0?o<V@020<co
V@050?o<V@0003<0001g0000M`1V<iT00P0007L205EEZP0706Hcc01EEJX0ZZ[o0:ZZo`2Zool0ZZYE
0?ooZP020<bIV@070?o<V@3oZUD0olbI0?o<V@3oofH0olbI0;Fe]@020?o<V@060:6QX@3oc9T0c9VI
0<bIV@3oc9T0c?nI0P3oZZX00`2IVIT0ojZZ09VIV@020?nZZP040?o<V@3oZZX0`<300<30`080c9VI
00D0ojZZ0<bIV@3<VIT0ojZZ0<bIV@020000E@030000IP0c09T005EE0080EEFZ00H0<`2I06HcV@29
RHT0RHV905EEZP2ZEJX205EEZP80ZUFZ00D0OWin0:YEZP2ZEJX0OWin096AT@0209VIc003096AT@2I
VL`0ZUFZ0080VIW<0P2ZEJX20:6QX@030:YEZP2QXJ40c9VI00L0c9VI00<0c6K<0<bIV@3<VIT01`3<
VIT209VIc0030?nZZP2IVIT0ojZZ0080c?nI00L0ojZZ0<coV@3oZZX0ojZZ09W<V@3oZZX0/K6a00@0
olbI0P3<VIT00`3oc9T0c9UV0?ooZP02096AT@0506IVV@2ATI40ZUFZ0:YEZP1Vc<`00`2ZEJX00`1E
EJX0ZUFZ06IVV@0206IVV@0706HcV@1EEJX0EEFZ05EEZP0c06H0EEFZ03<0IP0206HcV@80<`2I0P1V
<iT00`0009T0<fJI0000V@02001EE@030000V@0006H0002I0080002I00H0VIWo05Goo`2IVOl0VIWo
0?o<o`2m_Kd20?o<o`070<c<c02Ic6H0olc<0?o<c02IVL`0EEFZ09VIc00206HcV@0309VIc01EEJX0
EEFZ0080EEFZ00<0002Z03<0V@0009T00P0009T01P00EJX0002I0000V@00EJX0002I0000IP80002I
00L0IS>I06IVV@1EEJX0EEFZ0000ZP3oZZX0oomV0080<fK<00<0IVJI001EZP1EEJX00P1EEJX303<0
V@0305EEZP1V<iT0002I0080<fJI00L0002I03<0IP0009T0002I03<0IP3oool0000c0080000R00D0
I/c<0<coc03<ol`0c?o<09VIo`0^0?ooo`00<03oool609VIc0050?o<V@3oojX0olbI0?o<V@3oojX0
3P3oool01P0003<0001V0000IP0c09T0`<300;fm_@80ZZ[o00L0_Kfm0?o<c03oojX0oonZ0?nZZP3o
c9T0oonZ0080olbI00<0oonZ0?o<V@3oc9T00P3oc9T01P2m_Kd0olbI0?o<V@2m_Kd0olbI0<bIV@80
ojZZ00L0c9VI0000A00007L0001g05D0ZP1V<l`0002I008005FZ00L0002Z001EZP000:X0002Z0:[o
o`3oojX0c?mV0080olbI00@0oomV0?ooZP3oofH0oomV1P3oc9T01@3<VIT0olbI0?o<V@3oZZX0c9VI
0080VLbI00<0olbI09W<V@3<VIT00P2Ic9T01`3<VIT0VLbI0?nZZP3oZZX0olbI0?nZZP2MWId00P2Q
XJ401`2MWId0ojZZ0000E@0005D0001g06HcV@00EJX00P1EEJX01P0c09T005FZ06HcV@1V<iT0VC>I
0:YEZP80RHV900<0ZUFZ05FZZP1VIYT00P1EZZX01@1VIYT0VC?<0:YEZP2ZEJX0VC?<00H0XJ6Q0P3<
I/`20:YEZP0509VIc02ZEJX0ZUFZ09VIc02ZEJX00P2IVL`00`2ZEJX0/K6a0:ZZZP020<bIc0050:ZZ
ZP3<VL`0c9VI0<bIV@3<VL`01@2UYJD01@3<VIT0/K6a0;6a/@3<VIT0/K6a0080olbI00<0`<300?o<
V@3oZZX00P30`<020?nZZP80oonZ00<0oomV0?nZE@2ZEJX0102ZEJX205FZZP80IVJI0P2ZEJX00`29
RHT0ZUFZ09Tcc00206HcV@0405EEZP1VIYT0ZUFZ0:YEZP<0IS>I0`00EJX303=VV@03001EZP1V<iT0
<fIV00H0001g00<0002I0000IP2a/K400P2ZZ_l01P2m_Kd0ZZ[o0?o<c03oc<`0_Kfm0?ooZP80oomV
00<0c?oo05EEZP2ZEJX00P00EJX01P1VIYT0ZUGo001EZP00EJX0<`2I05EEZP<0<fJI00L005FZ06Hc
V@0cIVH0<fIV0000V@00EED0002I0080IS>I00L005FZ0000M`2IVOl0VIWo05EEo`2IVOl0c9UV0080
EEGo00H0VIW<001EZP1V<l`0IS?<03=Vc000EJX20000ZPD005FZ00L0<fJI0000ZP0c09T0<`2I001E
ZP0004@0000c0080000R00D0Z_oo0:[oZP000:X0002Z09VIo`0^0?ooo`00<P3oool01P1V<l`0VIW<
06Hcc01V<l`0olc<09W<IP80olbI00<0oonZ0?ooo`3oool0303oool01P2ZE@00002I0000V@0007L0
b<S80<bIo`80b<S800@0c9VI0?o<V@3oc9T0olbI0P3oojX00`3oc9T0oomV0?ooIP060?o<V@80ojZZ
00<0olbI0;fm_@3oc9T00P3<oiT00`3oc9T0001V0000M`020000M`06001EZP1V<iT0001g0000M`1V
<l`0EEFZ0P3<ol`00`3oojX0c?mV0?ooZP020?nZE@070?o<V@3oZUD0olbI0?o<V@2i^KT0olbI0:6Q
X@020?o<V@040<bIV@3oc9T0c9VI0<bIV@80olbI0P3oZZX00`2IVIT0ojZZ0?o<V@020?nZZP070?o<
V@3<VIT0`<300<30`03<VIT0YJFU0?nZZP040<bIV@80001E00<0001V0000V@00EED00P1EEJX01P00
EJX0EEFZ08V9R@29RHT0EEFZ08V9R@80EEFZ0P2ZEJX01@1nOWh0ZUFZ0:YEZP1nOWh0TI6A0080VIW<
00<0TI6A09VIc02ZEJX00P2IVL`01`2ZEJX0VIW<0:6QX@2QXJ40IVJI0<bIV@1VIYT01`3<VIT00`3<
I/`0c9VI0<bIV@050<bIV@0709VIc03oZZX0VIW<09VIc03oZZX0VIW<0?nZZP020<coV@060?nZZP3<
oiT0ojZZ0?nZZP2Ic9T0ojZZ203oc9T01P3<VFH0ZUFZ096AT@2ATI40IVJI096AT@80VC>I00H0VIW<
09TcV@2ZEJX0ZUFZ05EEZP2ZEJX406IVV@0605EEZP1V<iT0IS>I08V9R@1EEJX0<`1V0P1V<iT203<0
V@80IS>I00<0<`2I03=VV@0009T00P00EED00`0009T0001V0000M`020000M`060000V@3oc?l0_Kfm
0;fm_@3oc?l0c<c<0P3oc9T01`3oc<`0VLaV0?ooIP3oofH0IVJI05EEZP2IVL`00P1V<iT01`0c09T0
EEFZ05EEZP1EEJX0IS>I05EEZP0c09T00P000:X01`0009T0<fIV0000V@0009T0IS>I0000V@0c09T0
0P0009T01`1V<iT0002I05EEZP1EEJX0IVJI05EEZP1VIYT00P1E0:X0101VIYT0<fK<06HcV@1V<iT5
05EEZP0606HcV@0c09T0EEFZ05EEZP0c09T0<fJI0P1EEJX00`0c06H0002I0000<`0200008P0506K<
c03<ol`0IS>I06HcV@2IVOl0;P3oool00380oooo0P2IVL`20?ooZP040?o<V@3oojX0olbI0?o<V@l0
oooo00H000140000IP0006H0_Kfm0:ZZo`2m_Kd20:ZZo`030?o<V@3oofH0ojZZ0080ojZZ00H0olbI
0?ooZP3oc9T0olbI0?ooZP3oc9T20;fm_@070?o<V@2m_Kd0olbI0?o<V@3<VIT0olbI0<bIV@020?nZ
ZP070<bIV@0004@0<`2I03<0V@0006H0IS?<05D0ZP0206Hcc0070000ZP2Zool0c?oo0<coo`3oc9T0
ojYE0?o<V@020?ooZP040?ooIP3oojX0oonZ0?ooZPH0olbI0`3<VIT01`3oZZX0c9VI0?nZZP3oZZX0
olbI09W<V@3<VIT00P2Ic9T01`3<VIT0olbI0?nZZP3oZZX0olbI0?nZZP2MWId00P2QXJ401`2UYJD0
ojZZ0:FUY@2UYJD0001g0000IP00EJX00P1EEJX01P0c09T0EEFZ05EEZP1EEJX0VC>I06HcV@80RHV9
00<0ZUFZ05FZZP1VIYT00P1EZZX01P1VIYT0VC?<0:YEZP2ZEJX0VC?<0:YEZP@0XJ6Q00H0c9VI0:YE
ZP2ZEJX0VIW<0:YEZP2IVL`20:YEZP0709VIc02ZEJX0VIW<09VIc02ZEJX0c9W<0:ZZZP020<bIc004
0:ZZZP3<VL`0c9VI0<bIV@H0YJFU00D0c9VI0;6a/@2a/K40c9VI0<30`0020?o<V@030<30`03oc9T0
c<c<0080ojZZ00L0oonZ0?nZZP3oojX0oonZ0?ooE@3oofH0IVJI00@0ZUFZ0P1EZZX01`1VIYT0EJZZ
09TcV@2I<iT0RHV90:YEZP2I<l`00P1V<iT01@2I<l`0IVJI05EEZP1EEJX0IVJI0080IS>I0`00EJX4
03=VV@0506HcV@0007L0001g0000M`0009T00`0007L00`0009T0IS?<0000V@020:ZZo`060?o<c02m
_Kd0olc<0?o<c03oc9T0oonZ0P3<VFH00`2ZEJX0EEFZ0:YEZP02001EZP0605EEZP2ZEOl005FZ001E
ZP0c09T005FZ100cIYT01P1V<iT0<fJI03=VV@0009T005EE0000V@80001g00L005FZ06HcV@2IVOl0
VIWo05EEo`2IVOl00000008005FZ00H0VIW<05EEo`0c09T0<`2I001EZP1V<l`203=VV@8005FZ00D0
<fJI05EEZP1EEJX0<fJI0000V@0205EEZP030000ZP0c09T0000c0080000R00H0Z_oo0:[oZP000:X0
002Z05EEZP1Eool]0?ooo`00<`3oool01@2IVL`0VLaV09W<IP3oc<`0VLaV0180oooo0P0cI/`00`3<
VOl0b<S80<bIo`020?ooZP070<bIV@3<c<`0c9VI0<bIV@3oc9T0oonZ0?o<V@020?ooIP060?o<V@3o
ZZX0olbI0?o<V@3oZZX0olbI0P3oZZX00`3oc9T0_Kfm0?o<V@020<coV@070?o<V@2ZE@00001g0000
M`0cIYT005FZ06HcV@02001EZP0406HcV@3Hf=P0VIWo09VIo`<0oonZ0P3oZUD01`3oc9T0c9UV0?o<
V@3oc9T0]KFe0?o<V@2QXJ400P3oc9T00`3<VIT0olbI0?o<V@050?o<V@030<bIV@3oZZX0olbI0080
ojZZ00H0olbI0<bIV@30`<00`<300<bIV@2UYJD70<bIV@030000M`0009T0IS>I0080EEFZ00H005FZ
05EEZP1VIYT0IVJI05EEZP1VIYT205EEZP030:YEZP1EEJX0OWin0080ZUFZ00L0OWin0:YEZP2IVL`0
VIW<096AT@2IVL`0ZUFZ00<0VIW<00H0ZUFZ0<bIV@3<VIT0IVJI0<bIV@1VIYT=0<bIV@80ojZZ00L0
VIW<0?nZZP2IVL`0VIW<0?nZZP2IVL`0_Kfm0080c?nI00D0ojZZ09W<V@3oZZX0ojZZ09W<V@040?o<
V@070:f][@3oojX0olbI0?o<V@3oojX0IVJI0:YEZP02096AT@0606IVV@2ATI40IVJI06IVV@2IVL`0
VC>I0P2ZEJX00`1VIYT0ZUFZ05EEZP0306IVV@0305EEZP1V<iT0IS>I0080EEFZ00@0<`1V06HcV@1V
<iT005FZ0`1V<iT00`0c09T0<fJI0000V@02001EE@070000V@0006H0002I0000V@0006H0001g03=V
c0020<c<c0060?o<V@3<c<`0VLaV09W<IP3oc<`0ojYE0P3oojX00`1VIYT0EEFZ09VIc00205EEZP07
03<0V@1V<iT0VIW<09VIc01V<iT0EEFZ03<0V@020000ZP0703<0V@0cIVH0002I0000V@1V<iT0002I
03<0V@020000V@0706HcV@0009T0IS>I06HcV@1VIYT0ojZZ06IVV@020:YEZP0506HcV@0cI/`0IS>I
06HcV@00EJX0101EEJX01@1V<iT0<`2I0000V@0009T0<`2I00D0EEFZ00D0000c0;^k^`2k^k/0IS?<
0<coc00206HcV@0305EEZP3<ol`0oooo02`0oooo000c0?ooo`0509VIc02Ic6H0VLaV0?o<c02Ic6H0
4P3oool203=Vc0030<bIo`38b<P0c9Wo0080oonZ00L0c9VI0<c<c03<VIT0c9VI0?o<V@3oojX0olbI
0080oomV00H0olbI0?nZZP3oc9T0olbI0?nZZP3oc9T20?nZZP030?o<V@2m_Kd0olbI0080c?nI00L0
olbI0:YE000007L0001g03=VV@00EJX0IS>I008005FZ00@0IS>I0=SHf02IVOl0VIWo0`3oojX20?nZ
E@070?o<V@3<VFH0olbI0?o<V@2e]KD0olbI0:6QX@020?o<V@030<bIV@3oc9T0olbI00D0olbI00<0
c9VI0?nZZP3oc9T00P3oZZX01P3oc9T0c9VI0<30`030`<00c9VI0:FUY@L0c9VI00<0001g0000V@1V
<iT00P1EEJX01P00EJX0EEFZ06IVV@1VIYT0EEFZ06IVV@80EEFZ00<0ZUFZ05EEZP1nOWh00P2ZEJX0
1`1nOWh0ZUFZ09VIc02IVL`0TI6A09VIc02ZEJX00`2IVL`01P2ZEJX0c9VI0<bIV@1VIYT0c9VI06IV
V@d0c9VI0P3oZZX01`2IVL`0ojZZ09VIc02IVL`0ojZZ09VIc02m_Kd00P3<oiT01@3oZZX0VLbI0?nZ
ZP3oZZX0VLbI00@0olbI00L0[Jf]0?ooZP3oc9T0olbI0?ooZP1VIYT0ZUFZ0080TI6A00H0IVJI096A
T@1VIYT0IVJI09VIc02I<iT20:YEZP0306IVV@2ZEJX0EEFZ00<0IVJI00<0EEFZ06HcV@1V<iT00P1E
EJX0100c06H0IS>I06HcV@00EJX306HcV@0303<0V@0cIYT0002I008005EE00L0002I0000IP0009T0
002I0000IP0007L0<fK<0080c<c<00H0olbI0<c<c02Ic6H0VLaV0?o<c03oZUD20?ooZP0306IVV@1E
EJX0VIW<0080EEFZ00L0<`2I06HcV@2IVL`0VIW<06HcV@1EEJX0<`2I0080002Z00L0<`2I03=VIP00
09T0002I06HcV@0009T0<`2I0080002I00L0IS>I0000V@1V<iT0IS>I06IVV@3oZZX0IVJI0080ZUFZ
00D0IS>I03=Vc01V<iT0IS>I001EZP0405EEZP0506HcV@0c09T0002I0000V@0c09T01@1EEJX01@00
03<0^k^k0;^k^`1V<l`0c?o<0080IS>I00<0EEFZ0<coc03oool0;03oool004X0oooo0P1VIP000`1E
EJX0ZZ[o0;fm_@030?o<c0060;fm_@3oZZX0ojZZ0?ooZP3oc9T0oonZ0P3oc9T01P38b<P0olbI0;fm
_@2m_Kd0olbI0;fm_@80olbI00<0c9VI0?o<V@3<VIT00P3oZZX01`2a/K40ZUD00000IP0006H005FZ
0000M`1E0:X00P1V<l`01`3Hf=P0Z_oo0?ooZP3oojX0c?mV0?o<V@3oofH00P3oojX20?nZZP80oonZ
1P3oc9T30<bIV@070?nZZP3<VIT0ojZZ0?nZZP3<VIT0VLbI0<bIV@0209W<V@070?nZZP3oc9T0ojZZ
0?nZZP3oc9T0ojZZ0?o<V@020?nZZP070:FUY@3oZZX0YJFU0:FUY@0004@0001g001EZP0206HcV@06
03<0V@1EEJX0EEFZ05EEZP2I<iT0EEFZ0P0cI/`00`3<I/`0RHV906IVV@0205FZZP0706IVV@1EZZX0
ZUFZ0:YEZP2I<l`0ZUFZ0:6QX@020<bIV@0709TcV@3<VIT0VC>I09TcV@2IVL`0ZUFZ09VIc0020:YE
ZP0709VIc02ZEJX0VIW<09VIc03oIYT0c9W<0:ZZZP020<bIc0040:ZZZP3<VL`0c9VI0<bIV@D0YJFU
0P3oZZX20;6a/@070<bIV@30`<00olbI0?o<V@30`<00ojZZ0<c<c0030?nZZP<0olbI00<0c9UV07in
OP1VIYT01P2ZEJX01`1VIYT0EJZZ09TcV@2I<iT0EEFZ09TcV@29RHT00P1V<iT01P2I<l`0IVJI05EE
ZP1EEJX0IVJI06HcIPD0IS>I100cIYT01@0007L0IS>I06HcV@0009T005FZ00<0001g00H0001V06Hc
c01V<l`0IS?<0?o<c02m_Kd20?ooZP070?o<V@3oojX0c9Tc0<bI<`2ZEJX0IS>I0:YEZP0305EEZP06
001EZP1EEJX0EEFZ03<0V@00EJX0EEFZ0`0cIYT01P1V<iT005FZ001EZP00EJX0<fIV0000V@8005EE
00L0EEGo06IVV@00EJX005FZ0<S8b03oc<`0VIW<0080EEGo00H0EEFZ05EEo`0c09T0<`2I001EZP0c
09T203=VV@03001EZP000:X0<fJI008005FZ00L0<fJI001EZP0cIYT0<fJI0000ZP1EEJX0002Z0080
c9W<00H0EEFZ03<0V@2Zool0Z_oo05EEZP000:X]0?ooo`00BP3oool20000E@0305EEZP0cI/`0c9Wo
0080<fK<00H0olbI0?ooZP3<VIT0c9VI0?o<V@3oojX70?o<V@070?nZZP3oc9T0_Kfm0;fm_@3oc9T0
_Kfm0?o<V@020<coV@070?o<V@3<VIT0000c0000<`0cIYT0002I06HcV@020=SHf00709VIo`3Hf=P0
ZZYE0:ZZE@3ool`0ojYE0?o<V@020<bIIP070?ooZP2i^KT0olbI0?o<V@2e]KD0olbI0:6QX@020?o<
V@030<bIV@3oc9T0olbI0080olbI00@0c9VI0?o<V@3oc9T0c9VI0P3oc9T20?nZZP060<30`03<VIT0
`<300<30`03<VIT0YJFU1`3<VIT00`3oZZX0001g06HcV@020000V@05001EZP1EEJX0IVJI06IVV@1E
EJX00`1VIYT00`1EEJX0IVJI07inOP020:YEZP0707inOP2ZEJX0VIW<09VIc02ATI40VC>I09VIc002
0:YEZP0709VIc02ZEJX0VIW<09VIc01VIYT0c9VI06IVV@040<bIV@80TI6A00<0/K6a096AT@3<VIT0
0`3<VIT01@3<I/`0^KVi0;Vi^@2IVL`0ojZZ0080VIW<00<0ojZZ0<bIV@2m_Kd00P3<VIT0103oZZX0
VLbI0?nZZP3oZZX30?o<V@80oonZ00L0olbI0?ooZP3oZUD0ojYE0:YEZP1VIYT0ZUFZ0080TI6A00H0
IVJI096AT@1VIYT0IVJI09VIc02I<iT20:YEZP0306IVV@2ZEJX0IVJI00<0IVJI00<0EEFZ06HcV@1V
<iT00P1EEJX0100c06H0EEFZ05EEZP00EJX306HcV@0303<0V@0c06H0002I0080<fJI00L0002I001E
E@0009T0002I0000IP0009T0<fK<008005FZ00H0<fK<0<c<c02Ic6H0VLaV0?o<c03oZUD205EEZP03
06IVV@1EEJX0<`1V0080EEFZ00L0<`2I06HcV@0c09T0<`2I06HcV@1EEJX0IS>I0080002Z00L0<`2I
0000V@0009T0002I06HcV@0c09T0<fJI0080EEFZ00L0<`2I06IVV@1EEOl0EEGo06IVV@3<VFH0IVJI
0080ZUFZ00H0IS>I03=Vc01V<iT0IS>I001EZP1V<iT205EEZP<0<`2I0P1V<iT0100009T0EEFZ03<0
V@0c09T205EEZP0509VIc01EEJX0EEFZ06Hcc01EEJX00P1V<l`00`1EEJX0IS>I0?ooo`0/0?ooo`00
C03oool00`1EEJX0E@2Z05EEZP020;fm_@070?o<c03oZZX0olbI0?o<V@3oojX0olbI0?o<c0020?o<
V@060<S8b03oc9T0_Kfm0;fm_@3oc9T0_Kfm0P3oc9T00`3<VIT0ojZZ0<bIV@020?nZZP070;6a/@3o
ZZX0001E0000E@0009T0<`2I001EZP0203<0V@07001EZP2Zool0VIW<09VIc034a<@0olbI0?ooIP03
0?nZZPH0olbI0P3<VIT01P3oc9T0ojZZ0<bIV@3<VIT0ojZZ0<bIV@80ojZZ0`3<VIT209W<V@070?nZ
ZP3oc9T0ojZZ0?nZZP3oc9T0ojZZ0?o<V@020?nZZP050:FUY@3oZZX0_Kfm0;fm_@3<VIT00P0007L3
03<0V@0505EEZP0c09T0<`2I09TcV@1EEJX00P2I<iT00`3<I/`0<fK<09Tcc00209VIo`0709Tcc02I
VOl0TI6A096AT@2I<iT0TI6A09TcV@020<bIV@0709TcV@3<VIT0VC>I09TcV@2IVL`0ZUFZ09VIc002
0:YEZP0709VIc03oIYT0c9W<0<bIc03oIYT0c9W<0:ZZZP020<bIc0040:ZZZP3oZZX0c9VI0<bIV@@0
YJFU1@3oZZX01`3oc9T0`<300?o<V@3oc9T0c<c<0?nZZP3<c<`00P3oZZX20?o<V@80oomV00<0IVJI
07inOP1VIYT01P2ZEJX01`1VIYT0EJZZ06IVV@1VIYT0EEFZ09TcV@1EEJX00P1V<iT01P2I<l`0IVJI
05EEZP1EEJX0IVJI05EEZP@0IS>I00<005FZ03=VV@0cIYT00P0cIYT01@00EJX0IS>I06HcV@00EJX0
001g0080<`2I00<0001g0000ZP0009T01P1V<l`20?ooIP80EEFZ00<0ZUFZ05EEZP1V<iT00P1V<iT0
101EEJX005FZ05EEZP1EEJX2001EZP0303<0V@0cIYT0<fJI0080<fJI0`00EJX01P0cIYT0002I0000
ZP000:X0002I06IVV@80EEGo00<0IVJI05EEo`2IVL`00P1EEOl01P1EEJX005FZ09VIc02IVL`005FZ
03<0V@<005FZ0P0cIYT2001EZP0703=VV@00EJX0<fJI03=VV@2IVOl0c9W<09VIo`0209W<V@0305EE
ZP0c09T0EEFZ0080EEFZ00<0002Z0?ooo`3oool00`3oool20000EBH0oooo001<0?ooo`0305EEZP1E
0:X0EEFZ0080_Kfm00L0olc<0?nZZP3oc9T0olbI0?ooZP3oc9T0olc<0080olbI00H0b<S80?o<V@2m
_Kd0_Kfm0?o<V@2m_Kd20?o<V@030<bIV@3oZZX0c9VI0080ojZZ00L0/K6a0?nZZP0005D0001E0000
V@0c09T005FZ0080<`2I00L005FZ0:[oo`2IVL`0VIW<0<C4a03oc9T0oomV00<0ojZZ1P3oc9T20<bI
V@060?o<V@3oZZX0c9VI0<bIV@3oZZX0c9VI0P3oZZX30<bIV@80VLbI00L0ojZZ0?o<V@3oZZX0ojZZ
0?o<V@3oZZX0olbI0080ojZZ00D0YJFU0?nZZP2m_Kd0_Kfm0<bIV@020000M`<0<`2I00D0EEFZ03<0
V@0c09T0VC>I05EEZP0209TcV@030<aVc00cI/`0VC?<0080VIWo00L0VC?<09VIo`2ATI40TI6A09Tc
V@2ATI40VC>I0080c9VI00L0VC>I0<bIV@2I<iT0VC>I09VIc02ZEJX0VIW<0080ZUFZ00L0VIW<0?mV
V@3<VL`0c9W<0?mVV@3<VL`0ZZZZ0080c9W<00@0ZZZZ0?nZZP3<VIT0c9VI102UYJD50?nZZP070?o<
V@30`<00olbI0?o<V@3<c<`0ojZZ0<c<c0020?nZZP80olbI0P3oofH00`1VIYT0OWin06IVV@060:YE
ZP0706IVV@1EZZX0IVJI06IVV@1EEJX0VC>I05EEZP0206HcV@0609Tcc01VIYT0EEFZ05EEZP1VIYT0
EEFZ101V<iT00`00EJX0<fJI03=VV@0203=VV@05001EZP1V<iT0IS>I001EZP0007L00P0c09T00`00
07L0002Z0000V@0606Hcc080oomV0P1EEJX00`2ZEJX0EEFZ06HcV@0206HcV@0405EEZP00EJX0EEFZ
05EEZP8005FZ00<0<`2I03=VV@0cIYT00P0cIYT3001EZP0603=VV@0009T0002Z0000ZP0009T0IVJI
0P1EEOl00`1VIYT0EEGo09VIc00205EEo`0605EEZP00EJX0VIW<09VIc000EJX0<`2I0`00EJX203=V
V@8005FZ00L0<fJI001EZP0cIYT0<fJI09VIo`3<VL`0VIWo0080VLbI00<0EEFZ03<0V@1EEJX00P1E
EJX00`000:X0oooo0?ooo`030?ooo`80001E9P3oool003D0oooo00<0c/k>0?ooo`3oool0503oool0
0`2ZE@00<fK<0?o<V@020<c<c0050<bIV@3oojX0oonZ0?ooZP34a<@00P3oc9T20?nZZP@0olbI00L0
ojZZ0?o<V@2m_Kd0_Kfm0?o<V@3<oiT0olbI0080c9VI00L0olbI0<bIV@0004@000140000M`0009T0
<fJI0080ZZ[o00L0]KFe0:ZZo`3oojX0oonZ0?ooc03oZUD0olc<0080c9UV00L0oonZ0;Vi^@3oc9T0
olbI0;Fe]@3oc9T0XJ6Q0080olbI00<0c9VI0?o<V@3oc9T00P3oc9T01P3<VIT0olbI0?o<V@3<VL`0
olbI0<bIc080c9VI00L0`<300<bIV@2UYJD0YJFU0<bIV@2UYJD0c9VI0080olbI103<VIT00`3oZZX0
001g0000M`020000V@0606HcV@1EEJX005FZ001EZP1EEJX0IVJI0`1EEJX01P1VIYT0<fK<08f=S@2=
SHd0<fK<08f=S@80VC>I00<0VIW<09TcV@2IVL`00P2ZEJX01`2IVL`0ZUFZ09VIc02IVL`0IVJI0<bI
V@1VIYT00P3<VIT01`2ATI40/K6a096AT@2ATI40/K6a096AT@2a/K400P3<VIT01P2i^KT0c6K<0;Vi
^@2i^KT0c6K<0?nZZP80c9VI00<0_Kfm0<bIV@2m_Kd00P3<VIT00`3oc<`0VLbI0?o<V@030?o<V@05
0:f][@3oojX0oonZ0?o<V@3oojX00P3oZUD00`2ZEJX0IVJI0:YEZP02096AT@0606IVV@2ATI40IVJI
06IVV@2IVL`0VC>I0P2IVL`00`1VIYT0ZUFZ06IVV@0209Tcc00706IVV@1EEJX0IS>I06HcV@1EEJX0
IS>I03<0V@0205EEZP03001EZP1V<iT0<`2I0080<`2I00H0IS>I03<0V@0cIYT0<fJI0000V@00EED2
0000V@030000IP00EJX0EEFZ0080VIW<00H0IS?<09VIc01V<l`0IS?<09VIc03<VFH205EEZP0306IV
V@1EEJX0<`1V0080EEFZ00L0VIW<06HcV@0c09T0<`2I06HcV@1EEJX0IS>I0080EEFZ00L0<`2I0000
V@0c09T0<`2I06HcV@0c09T0IS>I0080EEFZ00L0<fJI06IVV@1EEOl0EEGo06IVV@1EEOl0EEFZ0080
ZUFZ00H0IS>I05D0ZP1VIYT0IVJI001EZP1V<iT2001EZP0303<0V@1EEJX0<`2I0080IS>I00<0<`2I
09VIo`1EEJX00P1EEJX01P2k^k/0VIW<05EEZP1EEJX0IS?<05EEZP80IS?<00<0EEFZ06HcV@1EEJX0
103oool20000A0030000E@3oool0oooo02<0oooo000e0?ooo`80c/k>5@3oool00`0cI/`0E@2Z0?o<
c0020;fm_@80ojZZ0P38b<P00`3oZZX0c<c<0?o<c0020?o<V@060;fm_@3oc9T0_Kfm0;fm_@3oc9T0
c9VI0P3oc9T00`3<VIT0ojZZ0<bIV@020?nZZP070;6a/@3oZZX0001E0000E@0009T0VLbI09VIc002
09W<V@0309VIc034a<@0olbI0080olbI00D0oonZ0?nZZP3oZZX0ojZZ0?ooZP060?o<V@80c9VI00H0
olbI0?nZZP3<VIT0c9VI0?nZZP3<VIT20?nZZP<0c9VI0P3oc9T01`3oZZX0olbI0?nZZP3oZZX0olbI
0?nZZP3<VIT00P3oZZX01`2UYJD0ojZZ0;fm_@2m_Kd0c9VI0;fm_@0007L00P0c09T01P00EJX0<fK<
03<0V@0c09T0VC>I05EEZP80VC>I00<0c6K<03=Vc03<I/`00P2IVOl01`2I<l`0VIWo09Tcc02I<l`0
VC>I096AT@2I<iT00P3<VIT01`2I<iT0c9VI09TcV@2I<iT0c9VI0:YEZP2IVL`00P2ZEJX01`3<VL`0
ofJI0<bIc03<VL`0ofJI0<bIc03oIYT00P3<VL`01P3<VIT0ojZZ0<bIV@3<VIT0ojZZ0:FUY@D0ojZZ
0P3<VIT01@2a/K40`<300?nZZP3oZZX0c<c<0080ojZZ0`3oc9T01P3<VFH0RHV908V9R@1VIYT0OWin
06IVV@80OWin102ZEJX01`1VIYT0EJZZ06IVV@1VIYT0EEFZ09TcV@1EEJX00P1VIYT01`2I<l`0IS>I
05EEZP1EEJX0IVJI05EEZP1V<iT00P1V<fH0101V<iT005FZ001EZP00EJX203=VV@05001EZP1V<iT0
IS>I001EZP1V<iT00P0c09T00`00EJX0001g05D0ZP020000IP0609VIc00cI_l0VIW<09VIc00cI_l0
oomV0P1EEJX00`2ZEJX0EEFZ06HcV@0306HcV@03001EZP1EEJX0EEFZ008005FZ00@0<`2I03=VV@0c
IYT0EEFZ0`0cIYT00`1V<iT0<fJI001EZP020000ZP070000V@000:X0EEGo05EEo`3<c<`0IVJI03<0
V@0205EEo`0605EEZP00EJX0EEFZ05EEZP00EJX0<`2I0P00EJX00`1EEJX0<fJI0000ZP02001EZP07
03=VV@1VIYT0EEGo05EEo`1VIYT0c9W<09W<<`0206HcV@0705EEZP0c09T0EEFZ05EEZP0cIYT0002Z
05EEZP0/0?ooo`00=03oool30<k>cQH0oooo00H0EEFZ0000o`3<c<`0c<c<0000o`34a<@20?mVc0<0
olbI0P3oZZX40?o<V@070?nZZP3oc9T0_Kfm0;fm_@3oc9T0c?nI0?o<V@020<bIV@070?o<V@3<VIT0
olbI0?o<V@2IVL`0<fK<0;Fe]@020:ZZo`030;Fe]@3ool`0oonZ0080oonZ00H0VLaV0?ooZP3<VFH0
c9UV0?o<V@2i^KT20?o<V@030:6QX@3oc9T0c9VI0080olbI00<0c9VI0?o<V@3oc9T00P3oc9T01P3<
VIT0olbI0?o<V@3<VL`0olbI0<bIc080ojZZ00L0`<300<bIV@2UYJD0YJFU0<bIV@2UYJD0c9VI0080
olbI103<VIT00`3oZZX0c9VI0000M`020000M`0606HcV@1EEJX0IS>I06HcV@1EEJX0IVJI0`1EEJX0
1P1VIYT0EEFZ08f=S@2=SHd0<fK<08f=S@80<fK<00<0VIW<09TcV@2IVL`00P2ZEJX01`2IVL`0ZUFZ
09VIc02IVL`0ZUFZ0<bIV@2ZEJX00P2a/K401`2ZEJX0/K6a096AT@2ATI40/K6a096AT@2a/K400P3<
I/`01P2i^KT0c6K<0;Vi^@2i^KT0c6K<0;fm_@80c9VI00<0_Kfm0<bIV@2m_Kd00P3<oiT00`3oc<`0
c?nI0?o<V@020?o<V@060?ooZP2][Jd0oonZ0?ooZP3oc9T0oonZ0P2=SHd00`2ZEJX0IVJI0:YEZP03
06IVV@05096AT@1VIYT0IVJI09VIc02I<iT00P2IVL`00`1VIYT0ZUFZ06IVV@0209Tcc00706HcV@1V
IYT0IS>I06HcV@1EEJX0IS>I03<0V@0205EEZP0403<0IP1V<iT005FZ001EZP80IS>I00D0<`2I03<0
IP0c06H0002I001EE@020000V@0306HcIP0009T0EEFZ008005FZ00H0IS?<09VIc01V<l`0IS?<0?oo
ZP3<VFH205EEZP0306IVV@1EEJX0<`1V0080EEFZ00L0<`1V06HcV@0c09T0<`2I06HcV@0009T0IS>I
0080EEFZ00L0<`2I0000ZP0c09T0<`2I03=VIP0c09T0IS>I0080<`2I00L0<fJI05EEZP3<ol`0c?o<
0?o<c01EEOl0EEFZ0080<fJI00H0IVJI05D0ZP1V<iT0IS>I001EZP1V<iT2001EZP0306HcV@1EEJX0
<`2I0080E@2Z00L0<`2I09VIo`1EEJX0EEFZ09VIo`1EEJX0IS?<0080EEFZ00L0<fJI05EEZP1V<l`0
IS?<05EEZP1V<iT0EEFZ0080oooo0P0004@X0?ooo`00=03oool40<k>cQD0oooo1@0cI/`01P3oZZX0
b<S80<S8b03oc<`0c<c<0<S8b080olbI00H0_Kfm0?o<V@2m_Kd0_Kfm0?o<V@3<VIT20?o<V@030<bI
V@3oZZX0/K6a0080ojZZ00L0/K6a0?nZZP2UYJD0YJFU0000A01V<l`0EEFZ0080VLbI00<0olbI0<C4
a03oc9T00P3oc9T01@3oojX0ojZZ0?nZZP3oZZX0oonZ00H0olbI0`3<VIT01@3oZZX0c9VI0<bIV@3o
ZZX0c9VI0080ojZZ0`3<VIT20?o<V@070?nZZP3oc9T0ojZZ0?nZZP3oc9T0ojZZ0<bIV@020?nZZP80
c9VI0P2m_Kd00`3<VIT0_Kfm0<bIV@020000M`060000ZP0cI/`0002Z0000ZP1EEOl0IVJI0P2I<iT0
0`1EEJX0<fK<0<aVc00209VIo`0709Tcc02IVOl0VC?<09Tcc02I<iT0TI6A09TcV@02096AT@0709Tc
V@3<VIT0VC>I09TcV@2a/K40ZUFZ0<bIc0020:YEZP050<bIc03oIYT0c9W<0<bIc03oIYT0103<VL`0
1P3<VIT0ojZZ0<bIV@3<VIT0ojZZ0<bIc0@0ojZZ00D0/K6a0<bIV@3<VIT0/K6a0<30`0020?o<V@03
0<c<c03oZZX0ojZZ00<0olbI00H0VLaV08V9R@29RHT0IVJI07inOP1VIYT207inOPD0ZUFZ00H0EJZZ
06IVV@1VIYT0EEFZ09TcV@1EEJX209TcV@0708f=S@1V<iT0EEFZ05EEZP1VIYT0EEFZ06HcV@0206Hc
IP0706HcV@00EJX0IS>I06HcV@0c09T0<fJI001EZP0203=VV@030000M`1V<iT005FZ008005FZ00H0
<`2I05D0ZP000:X0002Z05D0ZP0cI_l20?o<c0060?nZZP3<ofH0IS>I06HcV@2ZEJX0EEFZ101V<iT0
1P00EJX0EEFZ05EEZP00EJX0IS>I03<0V@80<fJI00<0EEFZ03=VV@0cIYT00`0cIYT01@00EJX0<fJI
03=VV@2IVL`0IS?<0080VIW<00<0ZUGo06IVV@0c09T00P1V<iT0102IVL`005FZ05EEZP1EEJX203<0
V@8005FZ0P0c09T01@00EJX0EEFZ05EEZP0cIYT005FZ0080EEGo00<0IVJI05EEZP1EEJX00P1V<iT0
101EEJX0<`2I05EEZP1EEJX203<0V@0503=VV@000:X0002Z0000E@0003<0:03oool003@0oooo1@3>
c/hD0?ooo`D0<fK<00H0ojZZ0<S8b038b<P0olc<0<c<c038b<P20?o<V@060;fm_@3oc9T0_Kfm0;fm
_@3oc9T0c9VI0P3oc9T00`3<VIT0ojZZ0;6a/@020?nZZP070;6a/@3oZZX0YJFU0:FUY@0004@0IS?<
05EEZP0209W<V@030?o<V@34a<@0olbI0080olbI00D0oonZ0?nZZP3oZZX0ojZZ0?ooZP060?o<V@<0
c9VI00D0ojZZ0<bIV@3<VIT0ojZZ0<bIV@020?nZZP<0c9VI0P3oc9T01`3oZZX0olbI0?nZZP3oZZX0
olbI0?nZZP3<VIT00P3oZZX20<bIV@80_Kfm00<0c9VI0;fm_@3<VIT00P0007L01P000:X0<fK<0000
ZP000:X0EEGo06IVV@80VC>I00<0EEFZ03=Vc03<I/`00P2IVOl01`2I<l`0VIWo09Tcc02I<l`0VC>I
096AT@2I<iT00P2ATI401`2I<iT0c9VI09TcV@2I<iT0/K6a0:YEZP3<VL`00P2ZEJX01@3<VL`0ofJI
0<bIc03<VL`0ofJI00@0c9W<00H0c9VI0?nZZP3<VIT0c9VI0?nZZP3<VL`40?nZZP050;6a/@3<VIT0
c9VI0;6a/@30`<000P3oc9T00`3<c<`0ojZZ0?nZZP030?o<V@0609W<IP29RHT0RHV906IVV@1nOWh0
IVJI0P1nOWh50:YEZP0605FZZP1VIYT0IVJI05EEZP2I<iT0EEFZ0P2I<iT01`2=SHd0IS>I05EEZP1E
EJX0IVJI05EEZP1V<iT00P1V<fH01`1V<iT005FZ06HcV@1V<iT0<`2I03=VV@00EJX00P0cIYT00`00
07L0IS>I001EZP02001EZP0603<0V@1E0:X0002Z0000ZP1E0:X0<fKo0P3oc<`01P3oZZX0c?mV06Hc
V@1V<iT0ZUFZ05EEZP@0IS>I00H005FZ05EEZP1EEJX005FZ06HcV@0c09T203=VV@0305EEZP0cIYT0
<fJI00<0<fJI00D005FZ03=VV@0cIYT0VIW<06Hcc00209VIc0030:YEo`1VIYT0<`2I0080IS>I00@0
VIW<001EZP1EEJX0EEFZ0P0c09T2001EZP80<`2I00D005FZ05EEZP1EEJX0<fJI001EZP0205EEo`03
06IVV@1EEJX0EEFZ0080IS>I00@0EEFZ03<0V@1EEJX0EEFZ0P0c09T01@0cIYT0002Z0000ZP0005D0
000c02P0oooo000c0?ooo`H0c/k>503oool01P1EEJX0003o05EEZP1EEJX0ofK<0<C4a0<0olbI00<0
ojZZ0?o<V@3oc9T00P3oc9T01@3oZZX0olbI0?o<V@2m_Kd0olbI0080_Kfm00<0olbI0<coV@3oc9T0
0P3<VIT01`3oc9T0c9VI0?o<V@3oc9T0001g03=Vc02IVL`00P0cI/`01`2IVL`0d=3@0=3@d03@d=00
olc<0<bIIP3oojX00P2i^KT01`3oc9T0]KFe0?o<V@3oc9T0XJ6Q0?o<V@3<VIT0103oc9T20<bIV@07
0?o<V@3<VIT0olbI0?o<V@3<VL`0olbI09W<IP020?nZZP070<30`03<VIT0YJFU0:FUY@3<VIT0olbI
0<bIV@020?o<V@070<bIV@3oZZX0c9VI0<bIV@3oZZX0c9VI0?nZZP020000E@06001EZP0009T0IS>I
06HcV@1EEJX0EEGo0P1EEJX00`1EEOl0IVJI05EEZP0206IVV@0703=Vc02=SHd0<fK<03=Vc02=SHd0
VC>I09VIc00209TcV@0709VIc03<VIT0VIW<09VIc03<VIT0VIW<0:YEZP020;6a/@070:YEZP2a/K40
TI6A096AT@2a/K40ojZZ0;Fe]@020?nZZP060;Vi^@3<I/`0^KVi0;Vi^@34a<@0_Kfm0P3<VIT00`2m
_Kd0c?nI0?o<c0020<coV@070?o<c03<oiT0olc<0?o<c03<oiT0olc<0?o<V@020?ooZP070?nZE@2A
TI40EEFZ05EEZP2ATI40c9VI06IVV@020<bIV@0606IVV@2ATI40IVJI06IVV@2ATI40VC>I0P2IVL`0
0`1VIYT0ZUFZ06IVV@020:YEZP0706HcV@2I<l`0IS>I06HcV@1EEJX0IS>I03<0V@0205EEZP0503<0
V@1V<iT005FZ001EZP1V<iT00P0c09T203<0IP0703<0V@00EED0002I0000V@1V<fH0002I06IVV@02
09VIc00605EEZP3<c<`0c<c<0<c<c03oojX0IVJI0P1EEJX00`1bLW80EEFZ03<0IP0205EEZP0703<0
IP1V<iT0<`2I03<0V@1V<iT0002I06HcV@0205EEZP0703<0V@1EEJX0<`2I03<0V@0009T0EEFZ06Hc
V@0203<0V@0703=Vc02IVL`0<fK<03=Vc01EEJX0EEGo05EEZP0203=VV@0605EEZP1E0:X0IS>I06Hc
V@1E0:X0EEFZ0P00EJX00`1V<iT005FZ03<0V@0205D0ZP0705EEZP1V<iT0EEFZ05EEZP2IVOl0EEFZ
06Hcc00205EEZP0706Hcc01EEJX0IS?<06Hcc01EEJX0IS>I05EEZP0206HcV@800014:03oool003<0
oooo1`3>c/hD0?ooo`0503=Vc03oZZX0ojZZ0<S8b03oZZX00P3<c<`00`3oc<`0olbI0<S8b0020?o<
V@060;fm_@3oc9T0_Kfm0;fm_@3oc9T0c9VI0P3oc9T00`3<VIT0ojZZ0;6a/@020?nZZP070:FUY@3o
ZZX0YJFU0:FUY@3<VIT0IS?<05EEZP0206Hcc0050=3@d03<VL`0oonZ0?ooZP3oc9T00P3oZZX20?o<
V@030?ooZP3oc9T0olbI00@0olbI0`3<VIT0103oZZX0c9VI0<bIV@3oZZX60<bIV@80olbI00L0c9VI
0?o<V@3oZZX0ojZZ0?o<V@3oZZX0c9VI0080ojZZ0P3<VIT20;fm_@D0c9VI00H0001g001EZP000:X0
002Z03=Vc01VIYT205EEo`0306IVV@2IVOl0EEGo0080VIWo00L0VC?<09VIo`2I<l`0VC?<09VIo`2A
TI40VC>I0080VIW<00L0c6K<0;6a/@3<I/`0c6K<0;6a/@3<I/`0c9W<0080ZUFZ00<0c9W<0:YEZP3<
VL`01`3<VL`01@3oZZX0c9W<0<bIc03oZZX0c9W<00<0ojZZ00H0c9VI0;6a/@3<VIT0c9VI0?o<V@30
`<020?o<V@030?ooZP2k^k/0olbI0080d=3@00D0c9UV09Tcc02I<iT0VC>I09Tcc0040:YEZP0305FZ
ZP29RHT0ZUFZ0080ZUFZ00H0EJZZ06IVV@1VIYT0EEFZ09TcV@1EEJX209TcV@0708f=S@1VIYT0EEFZ
05EEZP1VIYT0EEFZ06HcV@0206HcIP@0IS>I00<0<`2I001EZP0cIYT00P0cIYT01`00EJX0IS>I001E
ZP00EJX0IS?<03<0V@00EJX00P1V<l`01P0cI/`0IS?<0?ooIP3oofH0IS?<09TcV@80IVJI0P1V<iT0
0`2ZEJX0IS>I06HcV@0206HcV@80EEFZ00<005FZ06HcV@00EJX00P00EJX00`1EEJX0<fJI03=VV@03
03=VV@0506Hcc00cIYT0<fJI001EZP1V<l`00P2ZEJX00`1V<iT0IVJI03<0V@0206HcV@0603<0V@00
EJX0EEFZ05EEZP00EJX0EEFZ0P00EJX203<0V@<0EEFZ00@0002Z05EEZP1EEOl0EEGo0P1EEJX306Hc
V@0405EEZP0009T0IS>I06HcV@80<`2I00D0<fJI03<0V@0c09T0001E0000<`0X0?ooo`00<`3oool8
0<k>cQ<0oooo00D0ofK<0<C4a034a<@0ofK<0<C4a0030?o<V@030?nZZP3oc9T0olbI0080olbI00D0
ojZZ0?o<V@3oc9T0_Kfm0?o<V@020<coV@030?o<V@3<oiT0olbI0080c9VI00L0olbI0<bIV@3oc9T0
olbI0?nZZP0007L0VIW<00@0d=3@0P2Ic6H00`3oc<`0c9UV0?ooZP020;Vi^@070?o<V@2e]KD0olbI
0?o<V@2QXJ40olbI0<bIV@040?o<V@80c9VI00L0olbI0<bIV@3oc9T0olbI0<bIc03oc9T0VLaV0080
ojZZ00L0VLaV0<bIV@2UYJD0YJFU0<bIV@3oc9T0c9VI0080olbI00L0c9VI0?nZZP3<VIT0c9VI0?nZ
ZP3<VIT0ojZZ0080c9VI00H0001V0000V@1V<l`0IS?<05EEZP1EEOl205EEZP0305EEo`1EEJX0ZUGo
0080OWin1@2IVL`01P3<VIT0VIW<0<bIV@3<VIT0VIW<0<bIV@80VIW<00<0c9VI09VIc02ZEJX00P2a
/K401`2ZEJX0^KVi0?nZZP3oZZX0]KFe0?nZZP2e]KD00P3oZZX01P2e]KD0a<C40;fm_@2m_Kd0a<C4
0;fm_@80a<C400<0olc<0<coV@3oc<`00P3<oiT01`3oc<`0c?nI0?o<c03oc<`0c?nI0?o<c03oofH0
0P3ool`01`2Ic3<0TI6A05EEZP1EEJX0TI6A0<bIV@1VIYT00P3<VIT01P2I<iT0<fK<09TcV@2I<iT0
<fK<09TcV@80VIW<00<0VC>I0:YEZP1VIYT00P2ZEJX01P1V<iT0VC?<06HcV@1V<iT0EEFZ06HcV@<0
EEFZ00L0<`2I06HcV@00EJX005FZ06HcV@0c09T0IS>I0080<`1V00L0<`2I06HcV@0009T0002I001E
E@1EEJX0IS=V0080VIW<00H0IVJI09VIc01VIYT0IVJI0:YEZP1VIYT205EEZP03079bLP1EEJX0IVJI
0080EEFZ00L0<`1V05EEZP0c09T0<`2I06HcV@0009T0IS>I0080EEFZ00L0<`2I05EEZP1EEJX0EEFZ
0000V@0c09T0IVJI0080EEFZ00L0IS>I09VIc01VIYT0IVJI05EEZP1V<iT0IVJI0080<fJI00H0EEFZ
001EZP1V<iT0IS>I05D0ZP1EEJX203=VV@0306HcV@00EJX0EEFZ00<0EEFZ00H0E@2Z0=SHf03Hf=P0
ZP2Z05EEZP2Z0:X205EEZP0706Hcc01EEJX0<fJI03=VV@1EEJX0IS>I05EEZP0206HcV@0305EEZP00
04@0oooo02L0oooo000b0?ooo`T0c/k>4`3oool01@3oI/`0a<C40<C4a03oI/`0a<C400<0olbI00<0
ojZZ0?o<V@3oc9T00P3oc9T01@3oZZX0olbI0?o<V@2m_Kd0olbI0080c?nI00<0olbI0<coV@3oc9T0
0P3<VIT01`3oc9T0c9VI0?o<V@3oc9T0ojZZ0000M`2IVL`0103@d=0209W<IP030?o<c03<VFH0oonZ
0080^KVi00L0olbI0;Fe]@3oc9T0olbI0:6QX@3oc9T0c9VI00@0olbI0P3<VIT01`3oc9T0c9VI0?o<
V@3oc9T0c9W<0?o<V@2Ic6H00P3oZZX01`2Ic6H0c9VI0:FUY@2UYJD0c9VI0?o<V@3<VIT00P3oc9T0
1`3<VIT0ojZZ0<bIV@3<VIT0ojZZ0<bIV@3oZZX00P3<VIT01P0006H0002I06Hcc01V<l`0EEFZ05EE
o`80EEFZ00<0EEGo05EEZP2ZEOl00P1nOWh509VIc0060<bIV@2IVL`0c9VI0<bIV@2IVL`0c9VI0P2I
VL`00`3<VIT0VIW<0:YEZP020;6a/@070:YEZP2i^KT0ojZZ0?nZZP2e]KD0ojZZ0;Fe]@020?nZZP06
0;Fe]@34a<@0_Kfm0;fm_@34a<@0_Kfm0P34a<@00`3oc<`0c?nI0?o<c0020<coV@070?o<c03<oiT0
olc<0?o<c03<oiT0olc<0?ooIP020?ooc00709W<<`2ATI40EEFZ05EEZP2ATI40c9VI06IVV@020<bI
V@0609TcV@0cI/`0VC>I09TcV@0cI/`0VC>I0P2IVL`00`2I<iT0ZUFZ06IVV@020:YEZP0606HcV@2I
<l`0IS>I06HcV@1EEJX0IS>I0`1EEJX01`0c09T0IS>I001EZP00EJX0IS>I03<0V@1V<iT00P0c06H0
1`0c09T0IS>I0000V@0009T005EE05EEZP1V<fH00P2IVL`01P1VIYT0VIW<06IVV@1VIYT0ZUFZ06IV
V@80EEFZ00<0LW9b05EEZP1VIYT00P1EEJX01`0c06H0EEFZ03<0V@0c09T0IS>I0000V@1V<iT00P1E
EJX01`0c09T0EEFZ05EEZP1EEJX0002I03<0V@1VIYT00P1EEJX01`1V<iT0VIW<06IVV@1VIYT0EEFZ
06HcV@1VIYT00P0cIYT01P1EEJX005FZ06HcV@1V<iT0E@2Z05EEZP80<fJI00<0IS>I001EZP1EEJX0
0`1EEJX01P1E0:X0f=SH0=SHf02Z0:X0EEFZ0:X0ZP80EEFZ00L0IS?<05EEZP0cIYT0<fJI05EEZP1V
<iT0EEFZ0080IS>I00<0EEFZ0000A03oool09`3oool00380oooo2P3>c/hC0?ooo`80ojZZ00L0b<S8
0?o<c03<c<`0c<c<0<S8b03oc9T0b<S80080olbI00H0_Kfm0?o<V@3<VIT0c9VI0?o<V@3oZZX20=3@
d0030<coIP3oZZX0/K6a0080ojZZ00L0YJFU0?nZZP2m_Kd0_Kfm0<bIV@1EEOl0IVJI0080c9W<00L0
d=3@0?o<V@3oojX0oonZ0?o<V@3oZZX0oonZ0080`<3000L0olc<0<c<c03oZZX0ojZZ0;fm_@3oZZX0
_Kfm0080ojZZ00D0c9VI0?nZZP3<VIT0c9VI0?nZZP060<bIV@80olbI00L0c9VI0?o<V@3oZZX0ojZZ
0<bIV@3oZZX0c9VI0080ojZZ0P3<VIT20;fm_@H0c9VI00D005FZ0000ZP000:X0IS?<0000ZP0205EE
o`0306IVV@1EEOl0EEGo0080VIWo00D0EEGo03=Vc02ZEJX0ZUFZ03=Vc0020:YEZP80VIW<00L0ZUFZ
0;6a/@3<I/`0c6K<0;6a/@3<I/`0/K6a0080ZUFZ00<0c9W<09VIc03<VL`01P3<VL`01P3@d=00c9W<
0<bIc03<VL`0ojZZ0<bIc080ojZZ0P3<VIT01@2a/K40`<300<30`03oc9T0`<300080^k^k00<0oonZ
0=3@d03oc9T00P2Ic6H01@2I<iT0VC?<09TcV@2I<iT0VC?<00@0ZUFZ00H0EJZZ08V9R@1EZZX0EJZZ
08V9R@2ZEJX206IVV@0305FZZP2I<iT0EEFZ0080VC>I00L0SHf=06IVV@1EEJX0EEFZ06IVV@1EEJX0
IVJI0080IS=V00L0IS>I06HcIP1EEJX0EEFZ03<0V@00EJX0<`2I0080<fJI00H005FZ03=VV@1EEJX0
EEFZ06HcV@00EJX306Hcc00403=Vc01V<l`0ooo<0?ooc080VC>I0P1VIYT706HcV@80EEFZ00<005FZ
06HcV@00EJX00P1V<iT00`1EEJX0<fJI05EEZP0205EEZP0403=VV@1V<l`0EJZZ05FZZP80IS?<0P2Z
EJX00`1VIYT0IS>I0:YEo`0206HcV@0603<0V@1V<iT0<`2I03<0V@00EJX0EEFZ0`0c09T01P00EJX0
EEFZ03<0V@0c09T0002Z0<coo`80VC>I0`1EEJX203<0V@0705EEZP1V<iT0IS>I06HcV@0009T0EEFZ
03=VV@0203<0V@0303=VV@0003<0oooo02L0oooo000b0?ooo`/0c/k>4P3oool20000M`030?mVc03o
c9T0olbI0080olbI00H0ojZZ0?o<V@2m_Kd0_Kfm0?o<c02Ic9T20?o<V@030<bIc03oc9T0ojZZ0080
ojZZ00H0XJ6Q0?nZZP3<VIT0c9VI0?o<V@3<VIT20?o<V@030?nZZP3oc9T0EEGo0080<fK<00L0d=3@
0?o<c02Ic6H0VLaV0?ooZP2IVOl0olc<0080VLbI00H0olbI0<bIV@3oc9T0olbI0?o<c03oc9T30?nZ
ZP060<coV@3oc9T0c9VI0<bIV@3oc9T0c9W<0P3oc9T00`3<VL`0ojZZ09W<IP020?nZZP0709W<IP3<
VIT0YJFU0:FUY@3<VIT0olbI0<bIV@020?o<V@070<bIV@3oc9T0c9VI0<bIV@3oZZX0c9VI0?nZZP02
0<bIV@030?nZZP0009T005FZ008005FZ00H0IS?<05EEZP1EEJX0EEGo05EEZP2ZEOl207inOP030:YE
o`2IVL`0VIW<00@0VIW<0P3<VIT01`2IVL`0c9VI09VIc02IVL`0c9VI09VIc03<I/`00P2i^KT01`3<
VOl0^KVi0<bIo`3<VOl0]KFe0?nZZP2e]KD00P3<VL`01P30`<00c9W<0;fm_@2m_Kd0a<C40;fm_@80
/K6a00<0c<c<0;6a/@3oc<`00P3<oiT01`3oc<`0c?nI0?o<c03oc<`0c?nI0?ooc03oofH00P3<ofH0
1`2I<l`0TI6A05EEZP1EEJX0TI6A05EEZP1VIYT00P3<VIT01P1VIYT0<fK<09TcV@2I<iT0<fK<06IV
V@80OWin00<0VC>I0:YEZP1VIYT00P2ZEJX01P1V<iT0VC?<06HcV@1V<iT0IVJI06HcV@<0EEFZ00L0
<`2I05EEZP00EJX005FZ06HcV@0c09T0IS>I008005FZ00L0<`2I03<0IP1EEJX0EEFZ001EE@1EEJX0
05FZ0080EEFZ00@0IVJI0>3Ph03@d=00d=3@0P1VIYT205EEZP03079bLP1EEJX0LW9b0080EEFZ00L0
<`1V05EEZP0c09T0<`2I06HcV@0c09T0IS>I0080002I00L0<`2I05EEZP0c09T0<`2I03=Vc01EEJX0
002I0080EEFZ00L0IVJI05EEZP1VIYT0IVJI05EEZP1V<iT0EEFZ0080<fJI00H0EEFZ03=VV@1EEJX0
EEFZ05D0ZP1V<iT203=VV@0305EEZP00EJX0EEFZ008005FZ00L0EEFZ001EZP1EEJX0EEFZ0:X0ZP1E
EJX0ZP2Z0080EEFZ00L0<fJI05EEZP0cIYT0<fJI05EEZP1V<l`0EEFZ0080IS>I00<0EEFZ09VIo`3o
ool09`3oool00340oooo2@3>c/hE0?ooo`80EJZZ00L0EEGo05FZZP1EEOl0EEGo05FZZP1EEOl0olc<
0080c9W<00H0olbI0<bIV@3oZZX0ojZZ0;fm_@3<ofH20=3@d0030<coIP3oc9T0Z_nZ0080olbI00L0
YJFU0?nZZP2m_Kd0_Kfm0<bIV@3<VL`0IVJI0080EEGo00L0IVJI05EEo`2m_Kd0_Kfm0<bIo`2m_Kd0
olbI0080c<c<00L0olc<0;fm_@3oZZX0ojZZ0;fm_@3oZZX0_Kfm0080VLbI00D0olbI0?nZZP3<VIT0
c9VI0?nZZP040<bIV@060?o<V@3<VIT0olbI0?o<V@3<VIT0VLbI0P3oZZX00`3<VIT0ojZZ0<bIV@02
0?nZZP040<bIV@3oZZX0_Kfm0;fm_@H0c9VI00<0001V0000V@0009T00P1V<l`203=Vc0030<aVc01E
EOl0IVJI0080VIWo00D0EEGo03=Vc02ZEJX0ZUFZ03=Vc0020:YEZP80VIW<00L0ZUFZ09VIc03<I/`0
c6K<09VIo`2IVL`0VIWo0080VIW<00L0c9W<09VIc03<VL`0c9W<09VIc03<VL`0d=3@0080c9W<00H0
d=3@0<bIc03@d=00d=3@0?nZZP3<VIT20?o<c0030<bIV@3oc<`0c<c<0080`<3000L0olbI0?ooZP2k
^k/0^k^k0?o<V@3@d=00oonZ0080ZUFZ00H0VC>I0:YEZP2I<iT0VC>I09Tcc02I<iT40:YEZP0508V9
R@1EZZX0EJZZ08V9R@2ZEJX00P2I<iT00`2ZEJX0VC>I05EEZP0209TcV@0708f=S@1VIYT0SHf=08f=
S@1VIYT0EEFZ06IVV@0206HcIP0406HcV@1V<fH0EEFZ05EEZP8005FZ00D0<`2I001EZP00EJX0EEFZ
03=VV@0205EEZP030000ZP00EJX0IS?<008005FZ00D0IS?<001EZP1V<iT0IS>I09TcV@0306IVV@L0
IS>I0P1EEJX00`00EJX0EEFZ001EZP0206HcV@0303<0V@0cIYT0EEFZ0080EEFZ00H0<`2I05EEZP1E
ZZX0EJZZ09TcV@1V<iT20:YEZP0306IVV@1V<iT0IS>I0080IS>I00H0<`2I06HcV@0c09T0<`2I06Hc
V@1EEJX203<0V@0305EEZP0c09T0EEFZ0080<`2I00D0VIWo05EEZP2I<iT0VC>I06HcV@0405EEZP@0
IS>I00<0002I06HcV@0cIYT00P0c09T00`0cIYT0<`2I0?ooo`0W0?ooo`00=@3oool40<k>cQH0oooo
0P1EZZX01`1EEOl0EJZZ05EEo`1EEOl0EJZZ05EEo`3oc<`00P3<VL`01P3oc9T0c9VI0?nZZP3oZZX0
_Kfm0<coIP80d=3@00<0c?mV0?o<V@2ZojX00P3oc9T01`2UYJD0ojZZ0;fm_@2m_Kd0c9VI0<bIc01V
IYT00P1EEOl01`1VIYT0EEGo0;fm_@2m_Kd0c9Wo0;fm_@3oc9T00P3<c<`01`3oc<`0_Kfm0?nZZP3o
ZZX0_Kfm0?nZZP2m_Kd00P2Ic9T01@3oc9T0ojZZ0<bIV@3<VIT0ojZZ00@0c9VI00H0olbI0<bIV@3o
c9T0olbI0<bIV@2Ic9T20?nZZP030<bIV@3oZZX0c9VI0080ojZZ00@0c9VI0?nZZP2m_Kd0_Kfm1P3<
VIT00`0006H0002I0000V@0206Hcc080<fK<00<0c6K<05EEo`1VIYT00P2IVOl01@1EEOl0<fK<0:YE
ZP2ZEJX0<fK<0080ZUFZ0P2IVL`01`2ZEJX0VIW<0<aVc03<I/`0VIWo09VIc02IVOl00P2IVL`01`3<
VL`0VIW<0<bIc03<VL`0VIW<0<bIc03@d=000P3<VL`01P3@d=00c9W<0=3@d03@d=00ojZZ0<bIV@80
olc<00<0c9VI0?o<c03<c<`00P30`<001`3oc9T0oonZ0;^k^`2k^k/0olbI0=3@d03oojX00P2ZEJX0
1P2I<iT0ZUFZ09TcV@2I<iT0VC?<09TcV@@0ZUFZ00D0RHV905FZZP1EZZX0RHV90:YEZP0209TcV@03
0:YEZP2I<iT0EEFZ0080VC>I00L0SHf=06IVV@2=SHd0SHf=06IVV@1EEJX0IVJI0080IS=V00@0IS>I
06HcIP1EEJX0EEFZ0P00EJX01@0c09T005FZ001EZP1EEJX0<fJI0080EEFZ00<0002Z001EZP1V<l`0
0P00EJX01@1V<l`005FZ06HcV@1V<iT0VC>I00<0IVJI1`1V<iT205EEZP03001EZP1EEJX005FZ0080
IS>I00<0<`2I03=VV@1EEJX00P1EEJX01P0c09T0EEFZ05FZZP1EZZX0VC>I06HcV@80ZUFZ00<0IVJI
06HcV@1V<iT00P1V<iT01P0c09T0IS>I03<0V@0c09T0IS>I05EEZP80<`2I00<0EEFZ03<0V@1EEJX0
0P0c09T01@2IVOl0EEFZ09TcV@2I<iT0IS>I00@0EEFZ101V<iT00`0009T0IS>I03=VV@0203<0V@03
03=VV@0c09T0oooo02L0oooo000e0?ooo`@0c/k>603oool01`1EEJX0VIW<05EEZP1EEJX0VIW<0;fm
_@30`<000P2Ic9T01@3oc<`0c9W<0?o<V@3oc9T0c9W<00@0ojZZ00@0XJ6Q0?nZZP2e]KD0]KFe0P3o
ZZX20?o<V@030?nZZP3oc9T0EEGo0080<fK<00L0EEGo0<C4a02IVOl0VIWo0<C4a02Ic9T0olc<0080
c9VI00H0olbI0?o<c03oc9T0olbI0?nZZP3oc9T30?nZZP060<coV@3oZZX0c9VI0<bIV@3oc9T0c9W<
0P3oc9T00`3<VL`0ojZZ09W<IP020?nZZP070<bIIP3oZZX0YJFU0:FUY@3<VIT0olbI0<bIV@020?o<
V@070<bIV@3oc9T0c9VI0<bIV@3oZZX0c9VI0?nZZP020<bIV@060?nZZP3<VIT005FZ001EZP0009T0
IS?<0P00EJX00`1EZZX0<fK<05FZZP0207inOP030:YEo`1nOWh0VIW<00@0VIW<0P3<VIT209VIc080
^k^k00<0c6K<0;^k^`3<I/`00P2k^k/01`3<VOl0^KVi0<bIo`3<VOl0_Kfm0<bIc030`<000P3<VL`0
1P30`<00c9W<0<S8b038b<P0/K6a0<c<c080/K6a00<0c<c<0;6a/@3<c<`00P3<c<`01`3oc<`0c?nI
0?o<c03oc<`0oomV0?ooZP2ZEJX00P2ATI401`2I<l`0TI6A05EEZP1EEJX0TI6A05EEZP1VIYT00P3<
VIT01P1VIYT0<fK<09TcV@2I<iT0<fK<06IVV@80OWin00<0IVJI0:YEZP1VIYT00P2ZEJX01`1VIYT0
VC?<06HcV@1V<iT0IVJI06HcV@1VIYT00P1EEJX01`0c09T0EEFZ001EZP00EJX0IS>I03<0V@1V<iT0
0P0c09T01`1EEJX0<`1V05EEZP1EEJX0IS>I05EEZP00EJX00P1EEJX0101Vc?l0_Kfm05EEZP1EEJX2
06IVV@80EEFZ00<0LW9b05EEZP1bLW800P1EEJX01`0c06H0EEFZ03<0V@0c09T0IS>I03<0V@1V<iT0
0P0009T01`1V<iT0EEFZ03<0V@0c09T0<fK<05EEZP0cI/`00P1EEJX01`1VIYT0EEFZ06HcV@1V<iT0
EEFZ06HcV@1EEJX00P0c09T01P1EEJX0<fJI05EEZP1EEJX005FZ06HcV@80<fJI00<0EEFZ03=VV@2Z
Z_l00P2IVL`01`2m_Kd0VC>I05EEZP1EEJX0VC>I05EEZP2Z0:X00P1EEJX01`0cIYT0EEFZ06Hcc01V
<l`0EEFZ03=VV@2IVL`00P2IVOl00`2IVL`0IS>I0?ooo`0W0?ooo`00=@3oool40<k>cQP0oooo00L0
EEGo05FZZP1EEOl0EEGo0?o<c03<VL`0olc<0080c9VI00H0olbI0;fm_@3oZZX0ojZZ0;fm_@3<ofH2
0=3@d0030:[oZP3oc9T0Z_nZ0080olbI00L0VLbI0?o<V@2m_Kd0_Kfm0<bIV@3<VL`0c9VI0080EEGo
00L0_Kfm0<bIo`2m_Kd0_Kfm0?o<V@30`<00olc<0080c<c<00L0olc<0;fm_@3oZZX0ojZZ0;fm_@3o
ZZX0olbI0080VLbI00@0olbI09W<V@3oc9T0olbI1@3<VIT01P3oc9T0c9VI0?o<V@3oc9T0c9VI09W<
V@80ojZZ00<0c9VI0?nZZP3<VIT00P3oZZX00`3<VIT0ojZZ0<bIV@080<bIV@80001g00L0002I06Hc
c01V<l`0IS?<0<aVc00cI/`0c6K<0080EEGo00L0IVJI05EEo`2IVL`0VIW<09VIo`2IVL`0VIWo00H0
WIfM00<0VIWo09VIc02IVOl00P2IVL`01`2IVOl0VIW<0;fm_@2m_Kd0ZZ[o0;fm_@3@d=000P3<VL`0
1P3@d=00c<c<0<bIo`3<VOl0c<c<0<bIV@80olc<00<0c9VI0?o<c03<c<`00P3oc<`01P3<ol`0olc<
0;^k^`2k^k/0olbI0<coc0<0ZUFZ00H0VC>I0:YEZP2I<iT0VC>I09Tcc02I<iT40:YEZP0508V9R@1E
ZZX0EJZZ08V9R@1EZZX00P2I<iT00`2ZEJX0VC>I05EEZP0209TcV@0705EEZP1VIYT0SHf=08f=S@1V
IYT0EEFZ06IVV@0306HcV@0606HcIP1EEJX0EEFZ06HcV@00EJX0<`2I0P00EJX01P1EEJX0<`2I001E
ZP00EJX0002Z05EEZP@0VIWo00D0VC>I06HcV@1V<iT0VC>I06IVV@0205EEZP0309TcV@1V<iT0IS>I
00@0IS>I0P1EEJX00`00EJX0EEFZ001EZP0206HcV@07001EZP1EEJX0<`2I03<0V@0cIYT0<`2I05EE
ZP0207inOP0509TcV@1V<iT0IS>I06HcV@1VIYT0101V<iT01P1EEJX0IS>I03<0V@0c09T0IS>I03<0
V@8005FZ00<0EEFZ03<0V@1EEJX00P2IVL`01@3oool0EEFZ09TcV@2I<iT0EEFZ0080IS>I0P1EEJX0
1`1V<iT0<`2I06HcV@1V<iT0002I06HcV@0009T00P1VIYT00`1EEOl0oooo0?ooo`0W0?ooo`00=@3o
ool40<k>cQT0oooo00H0VIW<0;fm_@2m_Kd0`<300;fm_@3oc<`209W<V@040?o<c03<VL`0olbI0?o<
V@D0ojZZ00H0XJ6Q0?nZZP2e]KD0]KFe0?nZZP2a/K420?nZZP030<bIV@3oc9T0c9VI0080ojZZ00L0
VIWo0<C4a02IVOl0VIWo0?o<c02Ic9T0olbI0080c9VI00L0olbI0?o<c03oc9T0olbI0?nZZP3oc9T0
c?nI0080ojZZ00H0]KFe0?nZZP2e]KD0]KFe0?o<V@3<VL`20?o<V@0309W<IP3oZZX0VLaV0080ojZZ
00L0c9UV0?nZZP3oc9T0olbI0<bIV@3oc9T0c9VI0080olbI00L0c9VI0?o<V@3<VIT0c9VI0?nZZP3<
VIT0ojZZ00@0c9VI0P3<I/`01`0009T005FZ001Vc000I/`0EJZZ03=Vc01EZZX00P0cI/`0101EZ_l0
VIW<05FZo`1EZ_l509VIc0070:ZZo`2IVL`0ZZ[o0:ZZo`3<I/`0^k^k0<aVc0020;^k^`0709VIo`2m
_Kd0c9Wo0<bIo`2m_Kd0c9Wo0;fm_@020<bIc0060<S8b02m_Kd0b<S80<S8b02m_Kd0b<S80P2a/K43
0<c<c080c?o<00L0f=SH0<coc03ool`0ooo<0<coV@2ATI40ZUFZ0080TI6A00L0VC?<096AT@1EEJX0
EEFZ096AT@1EEJX0IVJI0080c9VI00H0IVJI03=Vc02I<iT0VC>I03=Vc02I<iT207inOP0306IVV@2Z
EJX0IVJI0080ZUFZ00L0IVJI09Tcc01V<iT0IS>I06IVV@1V<iT0IVJI0080EEFZ00@0IVJI05EEZP00
EJX005FZ0`1V<iT203<0V@0705EEZP00EJX0EEFZ05EEZP1V<iT0EEFZ06HcV@020;fm_@0606K<o`1V
IYT0EEFZ05EEZP1VIYT0EEFZ0P1V<iT00`1VIYT0EEFZ079bLP0205EEZP0706HcV@1EEJX0<`1V03<0
IP1V<iT0<`2I05EEZP020000V@0306HcV@1EEJX0EEFZ00<0EEFZ00D0NWYj05EEZP1EEJX0IVJI05EE
ZP0206HcV@0305EEZP1VIYT0EEFZ0080IS>I00H0EEFZ03<0V@1EEJX0EEFZ001EZP1EEJX2001EZP03
05EEZP0cIYT0EEFZ00<0oooo00H0VC>I05EEZP1EEJX0VC>I05EEZP00EJX205EEZP0503=VV@1EEJX0
<fJI03=VV@2IVL`00P1EEJX209VIo`0309VIc03oool0oooo02L0oooo000f0?ooo`@0c/k>6@3oool2
0<bIc0030?o<c03<VIT0olbI0080c9VI00H0ojZZ0;fm_@3oZZX0ojZZ0=3@d03<ofH20?o<V@030:[o
ZP3oc9T0VLbI0080olbI00L0VLbI0?o<V@2Ic9T0VLbI0<bIV@3<VL`0c9VI0080olbI00L006K<0<bI
o`30`<00`<300?o<V@30`<00olc<0080c<c<00L0ojZZ0;fm_@3oZZX0ojZZ0;fm_@3oZZX0olbI0080
VLbI00D0olbI09W<V@3oc9T0olbI09W<V@040<bIV@060?o<V@3<VIT0VLbI09W<V@3<VIT0VLbI0`3<
VIT01P3oZZX0c9VI0?nZZP3oZZX0c9VI0?nZZPP0c9VI00D0ojZZ0<bIV@3<VIT0c9VI0000M`02001E
ZP0306Hcc00cI/`0c6K<0080<fK<00L0IVJI05EEo`1VIYT0IVJI09VIo`2IVL`0VIWo0080VIW<1@2M
WId01P2IVL`0ZZ[o09VIo`2IVOl0ZZ[o09VIo`80_Kfm00<0ZZ[o0;fm_@2ZZ_l00P2ZZ_l01P3<VOl0
c<c<0<bIo`3<VOl0c<c<0?o<o`80olc<00<0c<c<0?o<c03<ol`00P3oc<`01P3<ol`0f=SH0<coc03<
ol`0c?nI09TcV@<0ZUFZ00H0VC>I0:YEZP2I<iT0VC>I09Tcc02I<iT50:YEZP80EJZZ00L0RHV905FZ
ZP2I<iT0VC>I0:YEZP2I<iT0EEFZ0080VC>I00L0EEFZ06IVV@2=SHd0SHf=06IVV@1EEJX0IVJI0080
EEFZ00<0IS>I06HcIP1V<iT00P1V<iT01P1EEJX0E@2Z001EZP00EJX0EEFZ03<0V@80EEFZ00<0EJ[o
09Tcc01EZ_l00P1EEJX01P2IVOl0VC>I06HcV@1V<iT0VC>I06HcV@80EEFZ00<0VC>I06HcV@1V<iT0
1P1V<iT00`00EJX0EEFZ001EZP0205EEZP07001EZP1EEJX0<`2I03<0V@1EEJX0<`2I09TcV@0207in
OP0309TcV@1nOWh0IS>I00H0IS>I00H0EEFZ06HcV@0c09T0<`2I06HcV@0c09T206HcV@0306K<c02I
VOl0oooo00@0oooo0P2I<iT00`1EEJX0VC>I06HcV@0206HcV@0705EEZP0c09T0IS>I06HcV@0c09T0
EEFZ05EEo`0/0?ooo`00=P3oool40<k>cQT0oooo0P3<VL`00`3oc<`0c9VI0?o<V@020<bIV@060?nZ
ZP2m_Kd0ojZZ0?nZZP3@d=00c?mV0P3oc9T00`2ZojX0olbI09W<V@020?o<V@0709W<V@3oc9T0VLbI
09W<V@3<VIT0c9W<0<bIV@020?o<V@07001Vc03<VOl0`<300<30`03oc9T0`<300?o<c0020<c<c007
0?nZZP2m_Kd0ojZZ0?nZZP2m_Kd0ojZZ0?o<V@0209W<V@050?o<V@2Ic9T0olbI0?o<V@2Ic9T0103<
VIT01P3oc9T0c9VI09W<V@2Ic9T0c9VI09W<V@<0c9VI00H0ojZZ0<bIV@3oZZX0ojZZ0<bIV@3oZZX8
0<bIV@050?nZZP3<VIT0c9VI0<bIV@0007L00P00EJX00`1V<l`0<fK<0<aVc00203=Vc00706IVV@1E
EOl0IVJI06IVV@2IVOl0VIW<09VIo`0209VIc0D0WIfM00H0VIW<0:ZZo`2IVOl0VIWo0:ZZo`2IVOl2
0;fm_@030:ZZo`2m_Kd0ZZ[o0080ZZ[o00H0c9Wo0<c<c03<VOl0c9Wo0<c<c03oc?l20?o<c0030<c<
c03oc<`0c?o<0080olc<00H0c?o<0=SHf03<ol`0c?o<0<coV@2I<iT30:YEZP0609TcV@2ZEJX0VC>I
09TcV@2I<l`0VC>I1@2ZEJX205FZZP0708V9R@1EZZX0VC>I09TcV@2ZEJX0VC>I05EEZP0209TcV@07
05EEZP1VIYT0SHf=08f=S@1VIYT0EEFZ06IVV@0205EEZP0306HcV@1V<fH0IS>I0080IS>I00H0EEFZ
05D0ZP00EJX005FZ05EEZP0c09T205EEZP0305FZo`2I<l`0EJ[o0080EEFZ00H0VIWo09TcV@1V<iT0
IS>I09TcV@1V<iT205EEZP0309TcV@1V<iT0IS>I00H0IS>I00<005FZ05EEZP00EJX00P1EEJX01000
EJX0EEFZ03<0V@0c09T20<k>cP0509TcV@1nOWh0OWin09TcV@1nOWh01`1V<iT01P1EEJX0IS>I03<0
V@0c09T0IS>I03<0V@80IS>I00<0I/c<09VIo`3oool0103oool209TcV@0305EEZP2I<iT0IS>I0080
IS>I00L0EEFZ03<0V@1V<iT0IS>I03<0V@1EEJX0EEGo02`0oooo000f0?ooo`@0c/k>6`3oool00`30
`<00VLbI0?o<c00209W<V@040?o<V@3<VL`0olbI0?o<V@80ojZZ0P2QXJ400`3oZZX0XJ6Q0?nZZP02
0;Fe]@070?nZZP2a/K40ojZZ0?nZZP2][Jd0olbI0<bIV@020?nZZP0709W<IP00I/`0VLbI09W<V@3o
c<`0c9VI0?o<V@020?o<c0070?o<V@3oc<`0olbI0?o<V@3oZZX0olbI0<coV@020?nZZP060;Fe]@3o
ZZX0]KFe0;Fe]@3oZZX0c9W<0P3oc9T00`2Ic6H0ojZZ09W<IP020?nZZP030<bIIP3oZZX0c9VI0080
c9VI00H0olbI0<bIV@3oc9T0olbI0<bIV@3oc9T20<bIV@030?nZZP3<VIT0ojZZ00@0c9VI0P3<I/`0
1`3<VIT0c6K<0000V@0009T0002Z05EEo`2IVL`00P1EEOl0101EZZX0VIW<05FZo`1EZ_l709VIc080
ZZ[o00<0_Kfm0:ZZo`2IVOl00P2m_Kd01`2IVOl0_Kfm09VIo`2IVOl0_Kfm0<30`03<c<`00P30`<00
1P3<c<`0_Kfm0<c<c03<c<`0I/co0<c<c080I/co00<0c<c<0<coc03Hf=P00P3<ol`01`3ool`0b<S8
0?ooc03ool`0ZUFZ096AT@2ZEJX00P2ATI401`2I<l`0TI6A05EEZP1EEJX0TI6A05EEZP1VIYT00P3<
VIT01P1VIYT0c9VI09TcV@2I<iT0<fK<09TcV@80OWin00<0IVJI07inOP1VIYT00P2ZEJX01`1VIYT0
VC?<06HcV@1V<iT0IVJI06HcV@1VIYT00P1V<iT01`1VIYT0EEFZ03<0V@0c09T0IS>I001EZP1EEJX0
0`1V<iT01P00EJX0EEFZ05EEZP00EJX0VIW<08f=S@80VIW<00H0ZUFZ05EEZP1EEJX0EEFZ06IVV@1E
EJX206HcV@0306IVV@1EEJX0LW9b0080EEFZ00H0IS>I05EEZP0c06H0<`1V06HcV@0c09T306HcV@04
05EEZP0009T0EEFZ05EEZPD0c/k>00L0IVJI05EEZP1V<iT0IS>I05EEZP1V<iT0EEFZ0080IS>I00H0
EEFZ03<0V@1EEJX0EEFZ03=VV@1EEJX2001EZP0305EEZP2IVOl0oooo00H0oooo00<0VC>I05EEZP00
EJX00P1EEJX01000EJX0EEFZ03=VV@0cIYT205EEZP0309VIc03oool0oooo02X0oooo000f0?ooo`@0
c/k>7@3oool01@3oc9T0c9VI0<bIV@3oZZX0_Kfm0080c?mV00L0d=3@0<coIP3oc9T0olbI0:[oZP3o
c9T0VLbI0080olbI00L0VLbI0?o<V@2Ic9T0VLbI0?o<V@2Ic9T0c9VI0080olbI00L0c9VI03<0V@00
I/`006K<0?o<V@3<c<`0olc<0080_Kfm00L0ojZZ0;fm_@3oZZX0ojZZ0;fm_@2Ic9T0olbI0080VLbI
00D0olbI09W<V@3oc9T0olbI09W<V@030?o<V@030<bIV@3oc9T0c9VI0080VLbI00<0c9VI09W<V@3<
VIT00P3<VIT01P3oZZX0c9VI0?nZZP3oZZX0c9VI0?nZZP80]KFe0`3<VIT20?nZZP030<bIV@3oZZX0
c9VI00D0c9VI0P00EJX505FZZP80VIW<00<0EJZZ09VIc02Ic9T00P2IVL`01`2Ic9T0/K6a06K<c01V
c<`0/K6a06K<c02a/K400P2IVOl0102ZZ_l0Z_oo0<C4a034a<@50:ZZo`060:[oo`2ZZ_l0olco0?o<
o`3<c<`0olco0P3Hf=P00`2Zool0f=SH0<coc0020=SHf0060<coc03<oiT0c?o<0<coc02ZEJX0VC>I
0`2ZEJX01P2I<iT0ZUFZ09TcV@2I<iT0VC?<09TcV@D0ZUFZ0P1EZZX01`29RHT0EJZZ09TcV@2I<iT0
ZUFZ09TcV@1EEJX00P2I<iT01`1EEJX0VC>I08f=S@2=SHd0IVJI05EEZP1VIYT00P1EEJX506HcV@06
05EEZP1E0:X0EEFZ05EEZP1E0:X0<`2I0P1EEJX00`0c09T0VC?<05FZo`0209Tcc0060:YEZP21PH40
IS>I06HcV@2I<iT0IS>I0P1EEJX00`1VIYT0IS>I06HcV@0606HcV@03001EZP1EEJX005FZ0080EEFZ
00@0IS?<05EEZP0c09T0<`2I203>c/h806HcV@80EEFZ00D0IS>I03<0V@1V<iT0IS>I03<0V@090?oo
o`0309TcV@1V<iT0IS>I0080IS>I00H0IVJI03=Vc00cI/`0<`2I05EEZP1EEOl/0?ooo`00=P3oool4
0<k>cQh0oooo0P3<VL`00`3oc9T0c9W<0?nZZP030?nZZP80XJ6Q00<0ojZZ0;Fe]@3oZZX00P2e]KD0
1`3oZZX0/K6a0?nZZP3oZZX0[Jf]0?nZZP2Ic6H00P3oZZX01`2Ic6H0ojZZ05D0o`1E0?l006K<05D0
o`3oc9T00P3oc<`0103oc9T0olc<0?o<V@3oc9T20?nZZP050<coV@3oZZX0ojZZ0;Fe]@3oZZX00P2Z
ZZX01`3oZZX0ZZZZ0?nZZP3oZZX0VLaV0?nZZP3<VFH00P3oZZX01`3<VFH0ojZZ0<bIV@3<VIT0ojZZ
0?o<V@3<VIT00P3oc9T01`3<VIT0olbI0<bIV@3<VIT0ojZZ0<bIV@3oZZX0103<VIT20<aVc0070<bI
V@3<I/`0c9VI0<bIV@3<I/`005Go09VIc00205EEo`0709VIc01EEOl0<fK<03=Vc02IVOl0<fK<09VI
o`020:[oo`0709VIo`2Zool0ZZ[o0:ZZo`2m_Kd0ZZ[o0:[oo`020:ZZo`0709W<V@2ZZ_l0VLbI09W<
V@2ZZ_l0`<300<c<c00209VIo`060<c<c02IVOl0c<c<0<c<c01Vc?l0f=SH0P2ZZ_l00`3Hf=P0ZZ[o
0>3Ph0020=3@d0070<coc02ZEJX0TI6A096AT@2ZEJX0TI6A0:YEZP02096AT@0709Tcc02ATI40VC?<
09Tcc02ATI40EEFZ096AT@020<bIV@0606IVV@3<VIT0VC>I09TcV@0cI/`0VC>I0P1nOWh00`1VIYT0
OWin06IVV@020:YEZP80IVJI0P1EEJX00`2I<l`0IS>I06IVV@0206HcV@0706IVV@1EEJX0IVJI06IV
V@1V<iT005FZ05EEZP0206HcV@0305EEZP2IVL`0VIW<0080VIW<00<0EEFZ08f=S@1VIYT00P1VIYT3
05EEZP0706IVV@1EEJX0IS>I06HcV@1VIYT0EEFZ079bLP0205EEZP0606HcV@1EEJX0IS>I06HcV@1E
EJX0I/c<0`1V<iT0101EEJX0IS>I05EEZP1EEJX:0<k>cP0606HcV@1EEJX0IS?<06Hcc01EEJX0<`2I
0P1EEJX0100c09T0VIWo0<C4a034a<@:0?ooo`0605EEZP00EJX0EEFZ05EEZP00EJX0VIW<0P2ZEOl_
0?ooo`00=P3oool40<k>cQ`0oooo00H0c/k>0?ooo`3<VL`0c9W<0?o<V@3<VL`40?nZZP80XJ6Q00<0
ojZZ0;Fe]@3oZZX00P2e]KD01`3oZZX0/K6a0?nZZP3oZZX0[Jf]0?nZZP2Ic6H00P3oZZX01`2Ic6H0
ojZZ05D0o`1E0?l006K<05D0o`3oc9T00P3oc<`0103oc9T0olc<0?o<V@3oc9T20?nZZP050<coV@3o
ZZX0ojZZ0;Fe]@3oZZX00P2ZZZX01`3oZZX0ZZZZ0?nZZP3oZZX0VLaV0?nZZP3<VFH00P3oZZX01`3<
VFH0ojZZ0<bIV@3<VIT0ojZZ0?o<V@3<VIT00P3oc9T01`3<VIT0olbI0<bIV@3<VIT0ojZZ0<bIV@3o
ZZX0103<VIT20<aVc0070<bIV@3<I/`0c9VI0<bIV@3<I/`005Go09VIc00205EEo`0709VIc01EEOl0
<fK<03=Vc02IVOl0<fK<09VIo`020:[oo`0709VIo`2Zool0ZZ[o0:ZZo`2m_Kd0ZZ[o0:[oo`020:ZZ
o`0709W<V@2ZZ_l0VLbI09W<V@2ZZ_l0`<300<c<c00209VIo`060<c<c02IVOl0c<c<0<c<c01Vc?l0
f=SH0P2ZZ_l00`3Hf=P0ZZ[o0>3Ph0020=3@d0070<coc02ZEJX0TI6A096AT@2ZEJX0TI6A0:YEZP02
096AT@0709Tcc02ATI40VC?<09Tcc02ATI40EEFZ096AT@020<bIV@0606IVV@3<VIT0VC>I09TcV@0c
I/`0VC>I0P1nOWh00`1VIYT0OWin06IVV@020:YEZP80IVJI0P1EEJX00`2I<l`0IS>I06IVV@0206Hc
V@0706IVV@1EEJX0IVJI06IVV@1V<iT005FZ05EEZP0206HcV@0305EEZP2IVL`0VIW<0080VIW<00<0
EEFZ08f=S@1VIYT00P1VIYT305EEZP0706IVV@1EEJX0IS>I06HcV@1VIYT0EEFZ079bLP0205EEZP06
06HcV@1EEJX0IS>I06HcV@1EEJX0I/c<0`1V<iT0101EEJX0IS>I05EEZP1EEJX=0<k>cP0306Hcc01E
EJX0<`2I0080EEFZ00@0<`2I09VIo`34a<@0a<C42P3oool01P1EEJX005FZ05EEZP1EEJX005FZ09VI
c080ZUGo;`3oool003H0oooo103>c/hK0?ooo`80c/k>0`3oool01P3oZZX0_Kfm0<coIP3<ofH0d=3@
0:[oZP80olbI00<0Z_nZ0?o<V@2Ic9T00P3oc9T01`2Ic9T0olbI09W<V@2Ic9T0olbI09W<V@30`<00
0P3oc9T01`3<VIT0VLbI0<bIV@3<VIT0IVJI06K<c01VIYT00P1Vc<`01`1VIYT0_Kfm0?nZZP3oZZX0
_Kfm09W<V@3oc9T00P2Ic9T01@3oc9T0VLbI0?o<V@3oc9T0VLbI00<0olbI00<0c9VI0?o<V@3<VIT0
0P2Ic9T01`3<VIT0VLbI0<bIV@3<VIT0VLbI0?nZZP3<VIT00P3oZZX0103<VIT0ojZZ0;Fe]@2e]KD3
0<bIV@80ojZZ00<0c9VI0?nZZP3<VIT01P3<VIT00`2ZEJX005FZ05FZZP0605FZZP0609VIc01EZZX0
VIW<09VIc02Ic9T0d=3@0P1Vc<`00`30`<00I/co0<30`00206K<o`050<30`02Zool0a<C40<C4a02i
^KT00P2Zool20:ZZo`060:[oo`2ZZ_l0Z_oo0:[oo`2IVOl0Z_oo0P3Hf=P00`2Zool0c?oo0<coc002
0<coo`0709W<V@2ZEJX0VC>I09TcV@2ZEJX0VC>I0:YEZP0309TcV@060:YEZP2I<iT0VC>I09Tcc02I
<iT0VC?<102ZEJX205FZZP0708V9R@1EZZX0VC>I09TcV@2ZEJX0VC>I05EEZP0209TcV@0705EEZP2I
<iT0OWin07inOP2I<iT0EEFZ06IVV@0205EEZP@0IS>I00<0IS?<05EEZP1E0:X00P1EEJX01`1E0:X0
EEFZ06Hcc01V<l`0EJ[o05EEZP2I<iT00P2I<l`01P1V<iT0VC?<06HcV@1V<iT0VC>I06HcV@80EEFZ
00<0IVJI05EEZP1EEJX01`1V<iT01P1V<l`0IVJI05EEZP1EEJX0IS?<05EEZP80c6K<3@3>c/h00`1E
EJX0IS>I06HcV@0205EEZP0306HcV@1EEJX0oooo00`0oooo00<0EEFZ06HcV@1V<iT00P1V<iT203=V
c2l0oooo000g0?ooo`@0c/k>6@3oool30<k>cP@0oooo1@3oZZX20:6QX@030?nZZP2e]KD0ojZZ0080
/K6a00L0ojZZ0;6a/@3oZZX0ojZZ0:f][@3oZZX0c?mV0080ojZZ00L0VLaV0?nZZP3oc9T0olbI0?nZ
ZP1EZ_l0VIWo0080Z_oo00@0_Kfm0:[oo`3oc9T0olbI0P3oZZX01@3<oiT0ojZZ0?nZZP2e]KD0ojZZ
0080ZZZZ00L0ojZZ0:ZZZP3oZZX0ojZZ09W<IP3oZZX0c9UV0080ojZZ00L0c9UV0?nZZP3<VIT0c9VI
0?nZZP3oc9T0c9VI0080olbI00D0c9VI0?o<V@3<VIT0c9VI0?nZZP060<bIV@80c6K<00D0c9VI0<aV
c03<VIT0c9VI0<aVc0020<bIV@8006K<00L0ZUGo05FZo`2ZEOl0ZUGo09VIo`1Vc<`0VIWo0080I/c<
00L0VIWo05Goo`2IVOl0VIWo05Goo`2ZZ_l0Z_oo0080ZZ[o00L0I/c<0:ZZo`2Ic9T0VLbI0:ZZo`2I
c9T0ZZ[o0080VIWo00H0e=CD0:[oo`3De=@0e=CD0:[oo`3De=@20:ZZo`030>3Ph03@d=00h>3P0080
000000L0TI6A0:YEZP2ATI40TI6A0:YEZP2ATI40ZUFZ0080TI6A00L0VC?<096AT@2I<l`0VC?<096A
T@1EEJX0TI6A0080c9VI00H0IVJI0<bIV@1VIYT0IVJI03=Vc02I<iT203=Vc00306IVV@1nOWh0IVJI
0080ZUFZ00L0IVJI0:YEZP1EEJX0EEFZ06IVV@1EEJX0IVJI0080IS>I00H0IVJI05EEZP1VIYT0IVJI
05EEZP2=SHd306HcV@0705EEZP1V<iT0EEFZ05EEZP2IVL`0IVJI0:YEZP0406IVV@80EEFZ00L0IVJI
05EEZP1V<iT0IS>I06IVV@1V<iT0VC>I0080EEFZ00L0LW9b05EEZP1V<iT0IS>I05EEZP1Vc<`0EEFZ
0080I/c<00@0EEFZ06IVV@1EEJX0EEFZ303>c/h206Hcc00505EEZP1V<l`0EEFZ05EEZP0c09T03`3o
ool205EEZP04001EZP1EEJX0ZUGo0:YEobl0oooo000g0?ooo`@0c/k>603oool50<k>cP@0oooo0P00
EJX01`3oc9T0Z_nZ0?o<V@3oc9T0VLbI0?o<V@2Ic9T00P3oc9T0102Ic9T0olbI09W<V@2Ic9T20?o<
V@050<30`03oc9T0olbI0<bIV@2Ic9T00P3<VIT00`2Ic9T0ZZ[o09VIo`020:ZZo`0709VIo`2ZZ_l0
VIWo09VIo`3oc9T0VLbI0?o<V@0209W<V@060?o<V@2Ic9T0olbI0?o<V@2Ic9T0`<300P3oc9T00`30
`<00VLbI0<bIV@0209W<V@070<bIV@2Ic9T0c9VI0<bIV@2Ic9T0ojZZ0<bIV@020?nZZP050;Fe]@3o
ZZX0]KFe0;Fe]@3oZZX00P3<VIT20?nZZP030<bIV@3oZZX0c9VI00H0c9VI00H0ZUFZ0<bIV@2ZEJX0
ZUFZ001Vc01EZ_l206IVV@0305FZo`1Vc<`0VIWo0080I/c<00L0VIWo0=3@d01Vc<`0I/c<0:[oo`30
`<00d=3@0080EOoo00L0d=3@05Goo`3@d=00d=3@0;Vi^@2Zool0a<C400<0Z_oo00D0VIWo0:[oo`2Z
ool0VIWo0?o<o`020<c<c0030?o<o`3<ool0000000L0ZUFZ00<0VC>I0:YEZP2I<iT00P2I<iT01P2Z
EJX0VC>I09TcV@2I<l`0VC>I09Tcc0H0ZUFZ00L0RHV905FZZP29RHT0RHV90:YEZP2I<iT0EEFZ0080
VC>I00H0EEFZ09TcV@1nOWh0OWin09TcV@2ZEJX305EEZP0306IVV@1V<iT0IS>I0080IS>I00H0EEFZ
06Hcc01EEJX0EEFZ05D0ZP1Vc?l205FZZP0306IVV@1EEJX0VC>I0080EEFZ00H0IS>I09Tcc01V<iT0
IS>I09TcV@1V<iT209TcV@0306IVV@1EEJX0EEFZ00L0IS>I00H0IS?<06IVV@1V<l`0IS?<096AT@2I
<iT206IVV@0309TcV@3>c/h0c/k>00P0c/k>00D0IS>I05EEZP1EEJX0IS>I05EEZP0206HcVDD0oooo
000g0?ooo`@0c/k>5`3oool60<k>cPH0oooo00L006K<0?nZZP2QXJ40XJ6Q0?nZZP2e]KD0ojZZ0080
/K6a00L0ojZZ0:f][@3oZZX0ojZZ0:f][@3oZZX0c?mV0080ojZZ00L0olbI0?nZZP3<VFH0c9UV0?nZ
ZP3<VFH0_Kfm0080Z_oo00L0_Kfm0:[oo`3<c<`0c<c<09VIo`3<c<`0]KFe0080ojZZ00H0]KFe0?nZ
ZP2ZZZX0ZZZZ0?nZZP2Ic6H20?nZZP0309W<IP3oZZX0c9UV0080ojZZ00L0c9VI0?nZZP3<VIT0c9VI
0?nZZP3<oiT0c9VI0080olbI00D0c9VI0?o<V@3<VIT0c9VI0?o<V@060<bIV@80WIfM00D0c9VI0<aV
c03<VIT0c9VI0?mVc0060<bIV@80EEFZ00<0EJ[o06K<c02IVOl00P1Vc9T01`2IVOl0I/bI09VIo`2I
VOl0I/c<09VIo`1Vc<`00P2ZZ_l01`1Vc<`0ZZ[o06K<c01Vc<`0ZZ[o0<coc02ZZ_l00P3<ol`01P2Z
Z_l0Z_oo0:[oo`2Zool0ZZ[o0:[oo`80ZZ[o00<0Z_oo0000002ATI400P2ZEJX01`2ATI40ZUFZ096A
T@2ATI40ZUFZ096AT@2ZEJX00P2ATI401`2I<l`0TI6A06IVV@1VIYT0ZUFZ06IVV@2ZEJX00P1EZZX0
1P2ZEJX0EJZZ06IVV@1VIYT0<fK<09TcV@80<fK<00<0IVJI07inOP1VIYT00P2ZEJX01`1VIYT0ZUFZ
05EEZP1EEJX0IVJI05EEZP2ZEJX00P1EEJX01`1VIYT0EEFZ06IVV@1VIYT0EEFZ08f=S@1EEJX00P2=
SHd01`1EEJX0I/c<09TcV@2I<iT0VIW<06IVV@2ZEJX0101VIYT207inOP80EEFZ0`1VIYT01P1V<iT0
IVJI05EEZP1EEJX0VC>I05EEZP80IS>I00<0EEFZ06HcV@1EEJX00P2ATI401@1EEJX0IVJI05EEZP1E
EJX0IVJI00T0c/k>00H0VIWo05EEZP1V<l`0IS?<05EEZP1V<l`205EEZTD0oooo000g0?ooo`@0c/k>
5P3oool70<k>cPH0oooo00L006K<0?nZZP2QXJ40XJ6Q0?nZZP2e]KD0ojZZ0080/K6a00L0ojZZ0:f]
[@3oZZX0ojZZ0:f][@3oZZX0c?mV0080ojZZ00L0olbI0?nZZP3<VFH0c9UV0?nZZP3<VFH0_Kfm0080
Z_oo00L0_Kfm0:[oo`3<c<`0c<c<09VIo`3<c<`0]KFe0080ojZZ00H0]KFe0?nZZP2ZZZX0ZZZZ0?nZ
ZP2Ic6H20?nZZP0309W<IP3oZZX0c9UV0080ojZZ00L0c9VI0?nZZP3<VIT0c9VI0?nZZP3<oiT0c9VI
0080olbI00D0c9VI0?o<V@3<VIT0c9VI0?o<V@060<bIV@80WIfM00D0c9VI0<aVc03<VIT0c9VI0?mV
c0060<bIV@80EEFZ00<0EJ[o06K<c02IVOl00P1Vc9T01`2IVOl0I/bI09VIo`2IVOl0I/c<09VIo`1V
c<`00P2ZZ_l01`1Vc<`0ZZ[o06K<c01Vc<`0ZZ[o0<coc02ZZ_l00P3<ol`01P2ZZ_l0Z_oo0:[oo`2Z
ool0ZZ[o0:[oo`80ZZ[o00<0Z_oo0000002ATI400P2ZEJX01`2ATI40ZUFZ096AT@2ATI40ZUFZ096A
T@2ZEJX00P2ATI401`2I<l`0TI6A06IVV@1VIYT0ZUFZ06IVV@2ZEJX00P1EZZX01P2ZEJX0EJZZ06IV
V@1VIYT0<fK<09TcV@80<fK<00<0IVJI07inOP1VIYT00P2ZEJX01`1VIYT0ZUFZ05EEZP1EEJX0IVJI
05EEZP2ZEJX00P1EEJX01`1VIYT0EEFZ06IVV@1VIYT0EEFZ08f=S@1EEJX00P2=SHd01`1EEJX0I/c<
09TcV@2I<iT0VIW<06IVV@2ZEJX0101VIYT207inOP80EEFZ0`1VIYT01P1V<iT0IVJI05EEZP1EEJX0
VC>I05EEZP80IS>I00<0EEFZ06HcV@1EEJX00P2ATI401@1EEJX0IVJI05EEZP1EEJX0IVJI00P0c/k>
00<0EEFZ09VIo`1EEJX00P1V<l`0101EEJX0IS?<05EEZP1EEJY50?ooo`00=`3oool40<k>cQH0oooo
203>c/h60?ooo`060000c03oc9T0olbI09W<V@3oc9T0VLbI0P3oc9T01`2Ic9T0olbI09W<V@2Ic9T0
`<300?o<V@30`<000P3oc9T01`3<VIT0VLbI0<bIV@3<VIT0VLbI0<bIV@2Ic9T00`2ZZ_l01P3<c<`0
ZZ[o0:ZZo`3<c<`0c9Wo0?o<V@80VLbI00H0olbI09W<V@3oc9T0olbI09W<V@30`<020?o<V@030<30
`03<oiT0c9VI0080VLbI00D0c9VI09W<V@3<VIT0c9VI0;fm_@020<bIV@80ojZZ00@0]KFe0?nZZP2e
]KD0]KFe0P3oZZX00`3<VIT0ojZZ0?nZZP020<bIV@80WIfM1@3<VIT01P2m_Kd0c9VI0:YEZP2ZEJX0
c9VI0<bIc080c9VI0P1EZ_l01@2Zool0I/co06K<o`2Zool0I/co00<0Z_oo00<0`<300:[oo`2Zool0
0P2Zool01P30`<00Z_oo0:[oo`30`<00Z_oo0<C4a080Z_oo00H0_Kfm0:ZZo`2m_Kd0_Kfm0<c<c02Z
ool20<coc0X0ZUFZ00@0VC>I0:YEZP2ZEJX0ZUFZ102=SHd00`1VIYT0RHV906IVV@0206IVV@0608V9
R@1VIYT0RHV908V9R@1VIYT0EJZZ0P1VIYT00`2ZEJX0VC>I0:YEZP0209TcV@0705EEZP2I<iT0OWin
07inOP2I<iT0OWin05EEZP020:YEZP0305EEZP1V<iT0IS>I00<0IS>I00D0IS?<05EEZP1EEJX0EJZZ
09TcV@0209VIV@0306IVV@1EEJX0VC>I0080EEFZ00H0IS>I09Tcc01V<iT0IS>I0:YEZP1V<iT209Tc
V@0306IVV@1EEJX0IVJI0080IS>I00L0EEFZ03=Vc00cI_l0<fKo03=Vc01V<iT0IVJI0080VC>I00D0
TI6A09TcV@1VIYT0IVJI09TcV@090<k>cP0306IVV@1EEOl0IS>I0080IS>I00<0EEFZ0?ooo`3oool0
A@3oool003L0oooo103>c/hE0?ooo`T0c/k>2@3oool00`3oZZX0]KFe0?nZZP020;6a/@070?nZZP2]
[Jd0ojZZ0?nZZP3<ofH0ojZZ0<coIP020?nZZP070?mVc03oZZX0c9UV0<bIIP3oZZX0c9UV0?nZZP02
0?o<V@030?nZZP2IVOl0c<c<00@0c<c<0P3oZZX01P2e]KD0ojZZ0:ZZZP2ZZZX0ojZZ09W<IP80ojZZ
00<0olbI0?nZZP3<VFH00P3oZZX01`3<VIT0ojZZ0<bIV@3<VIT0ojZZ0<coV@3<VIT00P3oc9T01@3<
VIT0olbI0<bIV@3<VIT0olbI00D0c9VI00D0ojZZ09fMW@2MWId0c9VI0<aVc0020<bIV@030?mVc03<
VIT0c9VI00L0c9VI00@0VLbI03?<o`1Vc9T0I/bI0P2IVOl206K<o`80VIWo00D0I/c<09VIo`2IVOl0
I/c<0:ZZo`0206K<c0030:[oo`2m_Kd0Z_oo0080_Kfm00<0Z_oo0:ZZo`2Zool00P2Zool01P2ATI40
c9UV0<bIIP2ATI40ofJI096AT@80ofJI00L0TI6A0:YEZP2ATI40TI6A0:YEZP2ATI40ZUGo0080TI6A
00L0IVJI0:YEZP1VIYT0IVJI0:YEZP1VIYT0ZUFZ0080EJZZ00H0ZUFZ05FZZP2ZEJX0ZUFZ05EEZP2Z
EJX205EEZP0306IVV@1V<l`0IVJI0080ZUFZ00L0IVJI0:YEZP1EEJX0EEFZ06IVV@1EEJX0ZUFZ0080
EEFZ00@0ZUFZ06IVV@1EZ_l0EJ[o0P1VIYT01@1EEJX0EJZZ05FZZP2I<iT0EJZZ0080EEFZ00<0UIFE
06IVV@2ZEJX01P1VIYT01`1EEJX0OWin05EEZP1EEJX0IVJI06HcV@1VIYT00P1EEJX01@2I<iT0EEFZ
05EEZP1EEJX0VIW<0080oooo0P2ATI401@1EEJX0TI6A05EEZP1EEJX0IVJI00X0c/k>00@0EEFZ09VI
o`2IVOl0EEFZB03oool003L0oooo103>c/hD0?ooo`X0c/k>2P3oool01P3oc9T0VLbI0?o<V@3oc9T0
VLbI0?o<V@80VLbI00<0`<300?o<V@30`<000P2i^KT01`3<oiT0VLbI0<bIV@3<VIT0VLbI0<bIV@2I
c9T00P3<VIT01`2Ic9T0c9VI0<bIo`3<VOl0Z_oo0<bIo`2Zool00P3<VOl00`3oc9T0VLbI0?o<V@02
0?o<V@060<30`03oc9T0olbI0<30`03<oiT0c9VI0P2Ic9T01`3<VIT0VLbI0<bIV@3<VIT0_Kfm0<bI
V@2m_Kd00P3oZZX01@2e]KD0ojZZ0;Fe]@2e]KD0ojZZ0080c9VI0P3oZZX20<bIV@80WIfM0P3<VIT2
0;fm_@030<bIV@2m_Kd0c9VI0080ZUFZ00<0c9VI0<bIc03<VIT00P3<VIT01P2ZEJX0c9VI0<bIV@3<
VIT04@0009VIo`80Z_oo00<0VIWo0:[oo`2Zool00`2Zool01P2ZZ_l0Z_oo0:[oo`1Vc?l0VIWo0=3@
d080ZZ[o00H0d=3@06K<o`2=SHd0SHf=0<aVc02ZEJX20<aVc0h0ZUFZ1@2=SHd00`29RHT0IVJI08V9
R@0208V9R@0506IVV@29RHT0RHV906IVV@1EZZX00P1VIYT00`2IVL`0ZUFZ09VIc00209TcV@0705EE
ZP2I<iT0EEFZ05EEZP2I<iT0OWin05EEZP020:YEZP0705EEZP2ZEJX0VIWo09VIo`0cI_l0VIWo03=V
o`0206IVV@0705FZZP1VIYT0VIVI09VIV@2I<iT0IVJI09TcV@0205EEZP0606HcV@2I<l`0IS>I06Hc
V@2ZEJX0IS>I0P2ZEJX00`1V<l`0EJ[o06IVV@0305EEZP0406HcV@1EEJX0EEFZ03=Vc080oooo0P2I
<iT01@2ATI40VC>I06IVV@1VIYT0VC>I00<0c/k>0P2I<iT00`1VIYT0c/k>0<k>cP030<k>cT/0oooo
000h0?ooo`@0c/k>4P3oool<0<k>cPT0oooo00H0olbI09W<V@3oc9T0olbI09W<V@3oc9T209W<V@03
0<30`03oc9T0`<300080^KVi00L0c?nI09W<V@3<VIT0c9VI09W<V@3<VIT0VLbI0080c9VI00L0VLbI
0<bIV@3<VOl0c9Wo0:[oo`3<VOl0Z_oo0080c9Wo00<0olbI09W<V@3oc9T00P3oc9T01P30`<00olbI
0?o<V@30`<00c?nI0<bIV@80VLbI00L0c9VI09W<V@3<VIT0c9VI0;fm_@3<VIT0_Kfm0080ojZZ00D0
]KFe0?nZZP2e]KD0]KFe0?nZZP020<bIV@80ojZZ0P3<VIT209fMW@80c9VI0P2m_Kd00`3<VIT0_Kfm
0<bIV@020:YEZP030<bIV@3<VL`0c9VI0080c9VI00H0ZUFZ0<bIV@3<VIT0c9VI0140002IVOl20:[o
o`0309VIo`2Zool0Z_oo00<0Z_oo00H0ZZ[o0:[oo`2Zool0I/co09VIo`3@d=020:ZZo`060=3@d01V
c?l0SHf=08f=S@3<I/`0ZUFZ0P3<I/`>0:YEZPD0SHf=00<0RHV906IVV@29RHT00P29RHT01@1VIYT0
RHV908V9R@1VIYT0EJZZ0080IVJI00<0VIW<0:YEZP2IVL`00P2I<iT01`1EEJX0VC>I05EEZP1EEJX0
VC>I07inOP1EEJX00P2ZEJX01`1EEJX0ZUFZ09VIo`2IVOl0<fKo09VIo`0cI_l00P1VIYT01`1EZZX0
IVJI09VIV@2IVIT0VC>I06IVV@2I<iT00P1EEJX01P1V<iT0VC?<06HcV@1V<iT0ZUFZ06HcV@80ZUFZ
00<0IS?<05FZo`1VIYT00`1EEJX0101V<iT0EEFZ05EEZP0cI/`20?ooo`80VC>I00D0TI6A09TcV@1V
IYT0IVJI09TcV@020<k>cP<0VC>I00<0IVJI06HcV@3>c/h0103>c/i:0?ooo`00>03oool40<k>cQ40
oooo3@3>c/h:0?ooo`050?nZZP2a/K40/K6a0?nZZP2][Jd00P3oZZX00`3<ofH0ojZZ0<coIP020?nZ
ZP070?mVc03oZZX0c9UV0<bIIP3oZZX0olbI0?nZZP020?o<V@040?nZZP2a/K40ojZZ0?nZZP80c<c<
00D0ZZ[o0:[oo`2Zool0ZZ[o0?nZZP020:ZZZP070?nZZP2Ic6H0ojZZ0?nZZP3oc9T0ojZZ0?o<V@02
0?nZZP070<bIV@3oZZX0c?nI0<coV@3oZZX0c?nI0?nZZP020?o<V@060<bIV@3oc9T0c9VI0<bIV@3o
c9T0ojZZ0`3<VIT01P2MWId0ojZZ09fMW@2MWId0c9VI0<aVc080c9VI00<0ofK<0<bIV@3<VIT01`3<
VIT01P2Ic9T0c9VI0<aVc03<I/`0c9VI0:6QX@80c9VI00<0EJZZ06K<o`1EZZX00P1Vc?l01`3oc?l0
I/co03?<o`0cc?l0<lc<03?<o`1Eool00P1Vc<`01P3<VIT0VIW<0<bIV@3<VIT0c9UV096AT@80c9UV
00<0TI6A0?mVV@2ATI400P3oIYT01`2ATI40ZUFZ0:YEZP2ZEJX0ZUGo096AT@2ZEOl00P2ATI401`2Z
EOl0ZUFZ06IVV@1VIYT0ZUFZ06IVV@2ZEJX00P1VIYT01P2ZEJX0EJZZ0:YEZP2ZEJX0EEFZ0:YEZP80
EEFZ00<0ZUFZ06Hcc01VIYT00P1EZ_l00`1VIYT0ZUFZ06IVV@0206IVV@0605EEZP2ZEJX0EEFZ05EE
ZP2ZEJX0EEFZ0P1EZ_l00`1VIYT0EJ[o09TcV@0205FZZP0709TcV@1EZZX0EEFZ05EEZP2EUID0EEFZ
08f=S@0206IVV@060:YEZP1VIYT0IVJI06IVV@1EEJX0OWin0P1EEJX00`1nOWh0IVJI05EEo`0206IV
V@0309TcV@1EEJX0oooo00H0oooo00L0EEFZ096AT@1EEJX0EEFZ06IVV@3>c/h0ZUFZ0080EEFZ00@0
ZUFZ05EEZP2I<iT0VC>I103>c/i:0?ooo`00>03oool40<k>cQD0oooo2@3>c/h;0?ooo`80olbI00L0
VLbI0?o<V@3oc9T0olbI0<30`03oc9T0c?nI0080^KVi00L0c?nI09W<V@3<VIT0c9VI09W<V@3<VIT0
VLbI0080c9VI00L0VLbI0<bIV@3<oiT0c?nI0?nZZP3<VIT0_Kfm0080ZZ[o00H0_Kfm0:ZZo`30`<00
`<300?o<V@30`<020<coV@030<30`03<oiT0`<300080VLbI00L0c9VI09W<V@3<VIT0c9VI0;fm_@3<
VIT0_Kfm0080ojZZ00D0]KFe0?nZZP2e]KD0]KFe0:f][@020<bIV@80ojZZ00@0WIfM0<bIV@2MWId0
WIfM0P3<VIT20;fm_@030<bIV@2m_Kd0c9VI0080ZUFZ00<0c9VI0<bIc03<VIT00P3<VIT01P2ZEJX0
c9VI0<bIV@3<VIT0/K6a0:YEZP80c9VI00@0ZUFZ0<bIV@2ZEJX0XJ6Q0P0000001P2QXJ40ZUFZ0:YE
ZP29RHT0ZUFZ08V9R@80ZUFZ00H0SHf=0:YEZP2=SHd0SHf=0<aVc02ZEJX20<aVc0H0ZUFZ00<0WIfM
0:6QX@2QXJ401P2ZEJX408f=S@0308V9R@1VIYT0RHV90080RHV900D0IVJI08V9R@29RHT0IVJI05FZ
ZP0206IVV@0305FZZP2ZEJX0VIW<0080c6K<00L0<fK<0<aVc00cI/`0<fK<09TcV@1nOWh0VC>I0080
ZUFZ00L0EEFZ0:YEZP1EEJX0EEFZ03=Vo`29RHT0EJZZ0080IVJI00L0EJZZ06IVV@2IVIT0VIVI09Tc
V@2IVIT0ZUFZ0080IVJI00H0VC>I09Tcc01V<iT0IS>I0:YEZP1V<iT20:YEZP0306HcV@1EZ_l0IS?<
0080EJ[o00<0IS?<0?ooo`3oool01`3oool01P2I<iT0IVJI06IVV@2I<iT0IVJI05EEZP80VC>I00D0
EEFZ09TcV@1EZ_l0EJ[o0?ooo`040<k>cTT0oooo000h0?ooo`@0c/k>5@3oool30<k>cP80oooo1@3>
c/h<0?ooo`070?nZZP2][Jd0ojZZ0?nZZP3<ofH0ojZZ0?mVc0020?nZZP070?mVc03oc<`0c9UV0<bI
IP3oZZX0olbI0?nZZP020?o<V@030?nZZP2a/K40ojZZ0080c/k>00<0c9VI0=3@d03<VIT00P3<VIT0
1@3oZZX0VLaV09W<IP3oZZX0VLaV0080ojZZ00<0olbI0?nZZP3oc9T00P3oc<`01`3<VIT0ojZZ0<co
V@3<oiT0ojZZ0<coV@3oZZX00`3<VIT01@3oc9T0c9VI0<bIV@3oc9T0ojZZ00<0c9VI00H0WIfM0?nZ
ZP2MWId0WIfM0?nZZP3<I/`20<bIV@030?mVc03<VIT0ofK<00L0c9VI00H0VLbI0<bIV@3<I/`0c6K<
0<bIV@2QXJ420<bIV@040:6QX@3<VIT0XJ6Q0<bIV@@0000000@0ZUFZ0<bIV@2ZEJX0c9VI0P2IVL`0
1P3<VIT0VIW<0<bIV@3<VIT0c9UV096AT@80c9UV00<0TI6A0?mVV@2ATI400P3oIYT01`2ZEJX0WIfM
0:YEZP2ZEJX0WIfM096AT@2ZEOl00P2ATI401`2ZEOl0ZUFZ06IVV@1VIYT0ZUFZ06IVV@2ZEJX00P1V
IYT01P2ZEJX0EJZZ0:YEZP2ZEJX0EJZZ0:YEZP80EEFZ00<0ZUFZ06Hcc01VIYT00P1V<l`01`1VIYT0
EJ[o06IVV@1VIYT0<fK<09VIc00cI/`00P1EEJX01`2ZEJX0IVJI0<bIV@3<VIT0VC>I06IVV@2I<iT0
0P1EZZX01`2I<iT0EJZZ05EEZP1EEJX0UIFE05EEZP2=SHd00P1EEJX00`2=SHd0IVJI06IVV@0206IV
V@0607inOP1EEJX0EEFZ07inOP1VIYT0EEGo0P1VIYT;0?ooo`80EEFZ00<0IVJI05EEZP2ZEJX00P1E
EJX00`2ZEJX0EEFZ0?ooo`020?ooo`D0c/k>B03oool003P0oooo103>c/hE0?ooo`<0c/k>1P3oool0
0`3>c/h0oooo0?ooo`0;0?ooo`060<30`03oc9T0olbI0<30`02i^KT0c?nI0P2i^KT01`3oc9T0VLbI
0<bIV@3<VIT0VLbI0<bIV@2Ic9T00P3<VIT50<k>cP030<bIV@3oZZX0c9VI0080c9VI00D0VLbI0<bI
V@3<VIT0olbI0<30`0020<coV@030<30`03<oiT0d=3@0080olbI00L0c9VI09W<V@3<VIT0c9VI0;fm
_@3<VIT0c?nI0080c9VI00L0]KFe0?nZZP3<VIT0c9VI0:f][@3<VIT0[Jf]0080ojZZ00@0WIfM0<bI
V@2MWId0WIfM0P3<VIT20;fm_@030<bIV@2m_Kd0c9VI0080c9W<00L0c9VI0<bIc03<VIT0c9VI0<bI
c02ZEJX0/K6a0080c9VI00P0/K6a0:YEZP3<VIT0c9VI0:YEZP3<VIT0ZUFZ0:6QX@H00000102ZEJX0
1P2=SHd0ZUFZ08f=S@2=SHd0c6K<0:YEZP80c6K<1@2ZEJX01@2QXJ40WIfM0:6QX@2QXJ40WIfM00D0
ZUFZ102=SHd00`29RHT0IVJI08V9R@0208V9R@0506IVV@29RHT0RHV906IVV@1EZZX00P1VIYT00`1E
ZZX0ZUFZ09VIc0020:YEZP0703=Vc03<I/`0<fK<03=Vc03<I/`0VIW<03=Vo`0209VIc0@0ZUFZ00<0
EJZZ08V9R@1EZZX00P1VIYT01`1EZZX0IVJI09VIV@2IVIT0VC>I09VIV@2ZEJX00P1VIYT01P2ZEJX0
VIW<05EEo`1EEOl0VC?<06HcV@80ZUFZ00<0IS>I0:YEZP1V<l`03`3oool00`2I<iT0IVJI09TcV@02
09TcV@0305EEZP3oool0oooo00<0oooo1@3>c/i70?ooo`00>03oool40<k>cQD0oooo0`3>c/hD0?oo
o`060<30`03oc9T0olbI0<30`02i^KT0c?nI0P2i^KT01@3oc9T0VLbI0<bIV@3<VIT0VLbI00T0c/k>
00<0c9VI0?nZZP3<VIT00P3<VIT01@2Ic9T0c9VI0<bIV@3oc9T0`<300080c?nI00<0`<300<coV@3@
d=000P3oc9T01`3<VIT0VLbI0<bIV@3<VIT0_Kfm0<bIV@3<oiT00P3<VIT01`2e]KD0ojZZ0<bIV@3<
VIT0[Jf]0<bIV@2][Jd00P3oZZX0102MWId0c9VI09fMW@2MWId20<bIV@80_Kfm00<0c9VI0;fm_@3<
VIT00P3<VL`01`3<VIT0c9W<0<bIV@3<VIT0c9W<0:YEZP2a/K400P3<VIT0202a/K40ZUFZ0<bIV@3<
VIT0ZUFZ0<bIV@2ZEJX0XJ6Q1`0000030:YEZP0608f=S@2ZEJX0SHf=08f=S@3<I/`0ZUFZ0P3<I/`5
0:YEZP050:6QX@2MWId0XJ6Q0:6QX@2MWId01@2ZEJX408f=S@0308V9R@1VIYT0RHV90080RHV900D0
IVJI08V9R@29RHT0IVJI05FZZP0206IVV@0305FZZP2ZEJX0VIW<0080ZUFZ00L0<fK<0<aVc00cI/`0
<fK<0<aVc02IVL`0<fKo0080VIW<102ZEJX01`1EZZX0RHV90<k>cP3>c/h0IVJI05FZZP1VIYT00P2I
VIT00`2I<iT0VIVI0:YEZP0206IVV@060:YEZP2IVL`0EEGo05EEo`2I<l`0IS>I0P2ZEJX00`1V<iT0
ZUFZ06Hcc00?0?ooo`0309TcV@1VIYT0VC>I0080VC>I00<0EEFZ0?ooo`3oool0103oool50<k>cTH0
oooo000h0?ooo`@0c/k>503oool30<k>cQH0oooo0P3oZZX00`3<ofH0ojZZ0?mVc0020?nZZP030;6a
/@3oc<`0c/k>00X0c/k>00<0`<300<bIV@3@d=000`3<VIT01@3oZZX0c9VI0<bIV@3<VIT0olbI0080
ojZZ00<0olbI0?o<c02Ic6H00P3oc<`01`2Ic6H0ojZZ0<coV@3<oiT0ojZZ0<coV@3oc<`00`3<VIT0
1P3oc9T0ojZZ0?nZZP3oc9T0ojZZ0?o<V@80ojZZ00H0WIfM0?nZZP2MWId0WIfM0?nZZP3oI/`20<bI
V@030?mVc03<VIT0ofK<00L0c9VI00H0VLbI0<bIV@3<I/`0c6K<0<bIV@2QXJ420<bIV@040:6QX@3<
VIT0UIFE0<bIV@T000000P3<VIT01@2IVL`0c9VI0<bIV@3<VFH0TI6A0080c9UV00<0TI6A0?mVV@2Q
XJ400P3<VIT01`2ZEJX0WIfM0:YEZP2ZEJX0WIfM096AT@2ZEOl00P2ATI401`2ZEOl0ZUFZ06IVV@1V
IYT0ZUFZ06IVV@2ZEJX00P1VIYT01P2ZEJX0EJZZ0:YEZP2ZEJX0EJZZ0:YEZP80EEFZ00<0ZUFZ06Hc
c01VIYT00P1V<l`01`1VIYT0EJ[o06IVV@1VIYT0EJ[o06IVV@0cI/`00P2ZEJX00`1Vc<`0c/k>0<k>
cP050<k>cP0305FZZP2I<iT0EJZZ0080EEFZ00<0UIFE05EEZP2=SHd00P1EEJX01P2=SHd0IVJI05FZ
o`1EZ_l0IVJI07inOP80EEFZ5@3oool205EEZPP0oooo1@3>c/i50?ooo`00>@3oool40<k>cQ<0oooo
0`3>c/hH0?ooo`030<30`02i^KT0c?nI0080VLbI00<0olbI0<k>cP3>c/h02P3>c/h00`38b<P0c9VI
0?nZZP0209W<V@060<bIV@2Ic9T0c9VI0<bIV@3oc9T0`<300P3<oiT00`30`<00olbI0=3@d0020?o<
V@070:[oo`2m_Kd0c9VI0<bIV@2m_Kd0c9VI0<coV@020<bIV@070<coV@3oZZX0c9VI0<bIV@2][Jd0
c9VI0:f][@020<bIV@0409fMW@3<VIT0WIfM09fMW@80c9VI0P2m_Kd00`3<VIT0_Kfm0<bIV@020<bI
c0070<bIV@3<VL`0c9VI0<bIV@3<VL`0c9VI0;6a/@020<bIV@080;6a/@3<VIT0c9VI0<bIV@3<VL`0
c9VI0<bIc02QXJ4;000000030:YEZP2=SHd0SHf=0080ZUFZ0P3<I/`20:YEZP050<aVc02ZEJX0ZUFZ
0<aVc02MWId00P2QXJ400`2MWId0ZUFZ0:YEZP030:YEZP@0SHf=00@0RHV906IVV@29RHT0RHV90P1V
IYT208V9R@0706IVV@1EZZX0IVJI06IVV@1EZZX0IVJI09VIc0020:YEZP0509VIc03<I/`0<fK<03=V
c03<I/`02`3>c/h206IVV@0705FZZP1VIYT0EJZZ05FZZP2I<iT0VIVI0:YEZP0206IVV@050:YEZP1V
IYT0EEGo05EEo`2IVL`08`3oool40<k>cTD0oooo000i0?ooo`@0c/k>4`3oool30<k>cQX0oooo00D0
ofK<0?o<c03oc<`0/K6a0?o<c00;0<k>cP030<30`03<VIT0d=3@0080ojZZ00H0c9VI0?nZZP3<ofH0
c?mV0?nZZP2QXJ420?nZZP0309W<IP3oc<`0VLaV0080c?o<00L0I/c<0?nZZP3<oiT0c?nI0?nZZP3<
VIT0olc<0080c9VI00L0olc<0?o<V@3oZZX0ojZZ0?o<V@3oZZX0olbI0080ojZZ00H0WIfM0?nZZP2M
WId0WIfM0?nZZP3oI/`20<bIV@030?mVc03<VIT0ojYE00L0c9VI00H0c6K<0<bIV@3<I/`0c6K<0<bI
V@3<I/`20<bIV@0409FEU@3<VIT0UIFE0<bIV@/0000000D0VIW<0<bIV@3<VIT0VIW<096AT@020<bI
IP03096AT@3<VIT0XJ6Q0080c9VI00L0XJ6Q09fMW@2ZEJX0ZUFZ09fMW@2ATI40ZUGo0080TI6A00L0
ZUGo0:YEZP1VIYT0IVJI0:YEZP1VIYT0ZUFZ0080IVJI00H0ZUFZ05FZZP2ZEJX0ZUFZ05FZZP2ZEJX2
05EEZP030:YEZP1EEJX0IVJI0080IS?<00<0IVJI05FZo`2ZEJX03@3>c/h205FZZP0709TcV@1EZZX0
VC>I09TcV@2EUID0EEFZ09FEU@0205EEZP0408f=S@1EEJX0EJ[o05FZobD0oooo103>c/i40?ooo`00
>@3oool40<k>cQ<0oooo0`3>c/hJ0?ooo`060?mVc03oc<`0olc<0;6a/@3oc<`0a<C42P3>c/h00`30
`<00c9VI0=3@d0020?nZZP060<bIV@3oZZX0c?mV0<coIP3oZZX0XJ6Q0P3oZZX00`2Ic6H0olc<09W<
IP020<coc00706K<c03oZZX0c?nI0<coV@3oZZX0c9VI0?o<c0020<bIV@070?o<c03oc9T0ojZZ0?nZ
ZP3oc9T0ojZZ0?o<V@020?nZZP0609fMW@3oZZX0WIfM09fMW@3oZZX0ofK<0P3<VIT00`3oI/`0c9VI
0?nZE@070<bIV@060<aVc03<VIT0c6K<0<aVc03<VIT0c6K<0P3<VIT0102EUID0c9VI09FEU@3<VIT:
000000060<bIV@2IVL`0c9VI0<bIV@2IVL`0TI6A0P3<VFH00`2ATI40c9VI0:6QX@020<bIV@070:6Q
X@2MWId0ZUFZ0:YEZP2MWId0TI6A0:YEo`02096AT@070:YEo`2ZEJX0IVJI06IVV@2ZEJX0IVJI0:YE
ZP0206IVV@060:YEZP1EZZX0ZUFZ0:YEZP1EZZX0ZUFZ0P1EEJX00`2ZEJX0EEFZ06IVV@0206Hcc004
06IVV@1EZ_l0ZUFZ0:YEZP/0c/k>00D0ZUFZ05FZZP1EZZX0VC>I05FZZP0209TcV@0309FEU@1EEJX0
UIFE0080EEFZ00@0SHf=05EEZP1EZ_l0EJ[o9@3oool50<k>cT<0oooo000i0?ooo`@0c/k>4`3oool3
0<k>cQd0oooo00@0olbI0<C4a03<ool0c?oo2@3>c/h00`38b<P0ojZZ0?nZZP0209W<V@060<bIV@2I
c9T0`<300<30`03oc9T0ojZZ0`3<VIT01P3oc9T0c9VI09fMW@2MWId0ojZZ0:[oo`80c9VI00<0c?nI
0<bIV@3<oiT00P3<VIT01`3<oiT0[Jf]0<bIV@3<VIT0[Jf]0<bIV@3@d=000P3<VIT01P2MWId0c9VI
09fMW@2MWId0c?nI0<bIV@80_Kfm00<0c9VI0;fm_@3oZZX00P3<VL`01`3<VIT0c9W<0<bIV@3<VIT0
c9W<0<bIV@2a/K400P3<VIT0202a/K40c9VI0<bIV@3<VIT0c9W<0<bIV@3<VL`0XJ6Q2@0000000`2I
VL`0SHf=0:YEZP0208f=S@80ZUFZ0P3<I/`00`2ZEJX0VIW<0<aVc0020:YEZP050<aVc02MWId0XJ6Q
0:6QX@2MWId01P2ZEJX408f=S@0306IVV@29RHT0RHV90080IVJI0P29RHT01`1VIYT0EJZZ06IVV@1V
IYT0EJZZ06IVV@2IVL`00P2ZEJX207inOP80SHf=00<0OWin0<k>cP3>c/h0203>c/h01@1EZZX0EEFZ
05EEZP1EEOl0IVJI0080EJZZ00<0VC>I09VIV@2I<iT00P1VIYT00`2ZEJX0oooo0?ooo`0W0?ooo`D0
c/k>@P3oool003T0oooo103>c/hB0?ooo`<0c/k>8@3oool90<k>cP040?o<V@30`<00olbI0<bIV@80
ojZZ00H0c9VI0?nZZP3<ofH0c?mV0?nZZP2QXJ420<bIV@0309W<V@3oZZX0VLbI0080ojZZ0P3<VIT2
0<coV@030?o<c03<VIT0olc<0080c9VI00L0c?o<0?o<V@3oZZX0ojZZ0?o<V@3oZZX0olbI0080olc<
00H0WIfM0?nZZP2e]KD0]KFe0?nZZP2e]KD20<bIV@030?mVc02m_Kd0ojYE0080_Kfm103<VIT00`2m
_Kd0c6K<0<bIV@020<aVc0080<bIV@3<I/`0c9VI0<bIV@2EUID0c9VI09FEU@3<VIT8000000<0c9VI
00D0VIW<0<bIV@3<VIT0VIW<096AT@0209VIc0030<bIV@2IVL`0XJ6Q0080c9VI00L0XJ6Q09fMW@2Z
EJX0ZUFZ09fMW@2ZEJX0ZUGo0080TI6A00L0ZUGo096AT@1VIYT0IVJI0:YEZP1VIYT0ZUFZ0080IVJI
00H0VIW<09VIo`2IVOl0VIWo0<30`02IVOl207inOP030:YEZP1nOWh0ZUFZ0080IVJI00H0ZUFZ05EE
o`2ZEJX0ZUFZ05EEo`2ZEJX;0<k>cP0306K<c02IVL`0EEFZ0080VIW<00<0UIFE05EEZP2EUID00P1E
EJX[0?ooo`D0c/k>@@3oool003T0oooo103>c/hB0?ooo`<0c/k>803oool:0<k>cP040?nZZP38b<P0
ojZZ0<bIV@80VLbI00H0c9VI0?o<V@30`<00`<300?o<V@30`<030<bIV@0609fMW@3<VIT0olc<0?o<
c02m_Kd0WIfM0P3oZZX00`3<oiT0c9VI0<coV@040<coc080c9VI00<0[Jf]0<coIP3@d=000P3<ofH0
1P2MWId0c9VI0<30`030`<00c?nI0<30`080_Kfm00<0c9VI0?nZZP3oZZX00P3oZZX00`3<VIT0c9W<
0?nZZP020?nZZP050<bIV@2a/K40c9VI0<bIV@2a/K400`3<VIT0103<VL`0c9VI0<bIc03<VIT70000
00030:YEZP2IVL`0VIW<0080ZUFZ0P2=SHd20:YEZP80VIW<00<0ZUFZ09VIc03<I/`00P2ZEJX01P3<
I/`0WIfM0:6QX@2QXJ40WIfM0:6QX@D0ZUFZ0`2=SHd01P2YZJT0^KVi09VIo`2IVOl0^KVi09VIo`80
^KVi00<0I/c<0:YEZP2=SHd00`2=SHd00`1nOWh0SHf=08f=S@0207inOP80SHf=00<0OWin096AT@3>
c/h03@3>c/h205EEo`0305EEZP3oool0oooo02h0oooo103>c/i10?ooo`00>@3oool40<k>cQ80oooo
0`3>c/hO0?ooo`/0c/k>00@0olbI0<30`03oc9T0c?nI0P3oZZX01P3<VIT0ojZZ0<coIP3<ofH0ojZZ
0<coIP80ojZZ00<0VLbI0?nZZP2Ic9T00P3oc9T01`3oZZX0c9VI0<bIV@3<VIT0ojZZ0<bIV@3oZZX0
0P3<I/`01`3<VIT0Z_nZ0?nZZP3oZZX0olbI0?o<c03oc9T00P3oc<`01P2MWId0ojZZ0;Fe]@2e]KD0
ojZZ0;Fe]@80c9VI00<0ojYE0;fm_@3oZUD00P2m_Kd20<bIV@80ojZZ00<0_Kfm0?nZZP3<VIT00P3<
I/`0203<VIT0VLbI0<bIV@3<VIT0UIFE0<bIV@2EUID0c9VI200000030<bIV@0509VIc03<VIT0c9VI
0?nZZP30`<000P2IVL`00`3<VIT0VIW<0:6QX@020<bIV@070:6QX@3<VIT0ZUFZ0:YEZP2MWId0ZUFZ
0:YEo`02096AT@070:[oo`2m_Kd0WIfM09fMW@2ZZ_l0WIfM0:ZZo`0209VIo`0609VIc02ZEJX0TI6A
096AT@2ZEJX0TI6A0P1nOWh00`2ZEJX0OWin0:YEZP0206IVV@070:YEZP1EEOl0ZUFZ0:YEZP1EEOl0
ZUFZ05FZZP0@0<k>cS40oooo103>c/i00?ooo`00>P3oool40<k>cQ40oooo0`3>c/hN0?ooo`L0c/k>
00<0/K6a0<k>cP3>c/h00P3>c/h0103oc9T0`<300?o<V@3<oiT20?nZZP060<bIV@3oZZX0c?mV0<co
IP3oZZX0c?mV0P3oZZX00`2Ic9T0ojZZ09W<V@020?o<V@070?nZZP3<VIT0c9VI0<bIV@3oZZX0c9VI
0?nZZP020<aVc0070<bIV@2ZojX0ojZZ0?nZZP3oc9T0olc<0?o<V@020?o<c00609fMW@3oZZX0]KFe
0;Fe]@3oZZX0]KFe0P3<VIT00`3oZUD0_Kfm0?nZE@020;fm_@80c9VI0P3oZZX00`2m_Kd0ojZZ0<bI
V@020<aVc0080<bIV@2Ic9T0c9VI0<bIV@2EUID0c9VI09FEU@3<VIT3000000030<aVc00000000000
008000000`3<VIT01@2IVL`0c9VI0<bIV@3oZZX0`<300080VIW<00<0c9VI09VIc02QXJ400P3<VIT0
1`2QXJ40c9VI0:YEZP2ZEJX0WIfM0:YEZP2ZEOl00P2ATI401`2Zool0_Kfm09fMW@2MWId0ZZ[o09fM
W@2ZZ_l00P2IVOl01P2IVL`0ZUFZ096AT@2ATI40ZUFZ096AT@80OWin00<0ZUFZ07inOP2ZEJX00P1V
IYT0202ZEJX0EEGo0:YEZP2ZEJX0EEGo0:YEZP1EZZX0ZUFZ1@3>c/h00`2ZEJX0c/k>0<k>cP0:0<k>
cRh0oooo1@3>c/ho0?ooo`00>P3oool40<k>cQ40oooo0`3>c/hM0?ooo`L0c/k>00<0oooo0?nZZP3o
ZZX00`3>c/h0103oZZX0b<S80<coV@3ool`209W<V@060<bIV@3oc9T0`<300<30`03oc9T0`<300P2M
WId00`3<VIT0WIfM0<bIV@020?o<c0070;fm_@2MWId0ojZZ0?nZZP3<VIT0/K6a0<bIV@020;6a/@07
0<bIV@2MWId0c9VI0<bIV@3@d=00c?mV0=3@d0020<coIP0609fMW@3<oiT0`<300<30`03<oiT0`<30
0P2m_Kd50?nZZP030<bIV@3oZZX0ojZZ00<0ojZZ00D0/K6a0<bIV@3<VIT0olbI0<30`0020?o<V@07
0<bIc03<VIT0c9W<0<bIV@000000ZUFZ0<bIV@020?nZZP@0000000<0VIW<0:YEZP2ZEJX00P2m_Kd0
1`3<VL`0_Kfm09VIc02IVL`0ZUFZ09VIc03<I/`00P2ZEJX01`3<I/`0ZUFZ0:6QX@2QXJ40WIfM0:[o
o`3Hf=P01P2ZZ_l00`2IVL`0ZJVY09fMW@0209VIV@0309fMW@2ZEJX0ZUFZ00<0ZUFZ102=SHd00`1n
OWh0SHf=08f=S@0207inOP80SHf=00<0OWin096AT@1VIYT00P2ATI440<k>cP80IVJI00<0EJZZ0<k>
cP3>c/h02P3>c/h]0?ooo`D0c/k>?P3oool003X0oooo103>c/h@0?ooo`<0c/k>7@3oool70<k>cP@0
oooo00L0c9VI0<k>cP3oc9T0olbI0<bIV@3oZZX0c9VI0080ojZZ00H0c9VI0?nZZP3<ofH0c?mV0?nZ
ZP3<ofH20?ooc00309W<V@3oZZX0ojZZ0080olbI00L0ojZZ0<bIV@3<VIT0c9VI0?nZZP3<ofH0ojZZ
0080c?mV00D0c9VI09fMW@3oZZX0ojZZ09fMW@050<bIV@050?nZZP2e]KD0]KFe0?nZZP3<VIT00P2m
_Kd00`3oZUD0_Kfm0?nZE@020;fm_@070?nZZP2m_Kd0ojZZ0?nZZP2m_Kd0ojZZ0<bIV@020<aVc007
0?o<c02Ic9T0olc<0?o<c02EUID0c9VI09FEU@020<coc0040<aVc02k^k/0c6K<0<aVc0@0000000<0
c9VI0:[oZP3oZZX00P30`<001P3oZZX0`<3009VIc02IVL`0c9VI09VIc0<0c9VI00L0XJ6Q0<bIV@2Z
EJX0ZUFZ0:ZZo`2Zool0ZZ[o00<0Z_oo00H0_Kfm0:6QX@2QXJ40ZUFZ0:6QX@2ZEJX209VIV@80ZUFZ
0P2ATI401`2ZEJX0TI6A07inOP1nOWh0ZUFZ07inOP2ZEJX00P1VIYT01`2ZEJX0IVJI0:YEZP2ZEJX0
EEGo0:YEZP1EZZX00P2ZEJX40<k>cP030:YEZP1Vc<`0ZUFZ0080I/c<00<0oooo0<k>cP3>c/h02P3>
c/h[0?ooo`D0c/k>?@3oool003X0oooo103>c/h@0?ooo`<0c/k>703oool70<k>cPD0oooo00L0[Jf]
0?nZZP2Ic9T0VLbI0<bIV@2Ic9T0c9VI0080YJFU00D0`<300?o<V@30`<00`<300?o<V@030<coV@03
0<bIV@2MWId0_Kfm0080olc<00L0_Kfm0?o<c03oZZX0ojZZ0<bIV@2a/K40c9VI0080/K6a00L0c9VI
09fMW@3<VIT0c9VI09fMW@2QXJ40ojZZ0080XJ6Q00H0ojZZ0:6QX@30`<00`<300<bIc03<VIT20<bI
c0<0ojZZ0P3<VL`00`3<VIT0ojZZ0?nZZP030?nZZP050;6a/@30`<00`<300?o<V@30`<000P3oc9T0
0`3<VL`0c9VI0:[oZP0209W<V@050?nZZP3<VIT0ojZZ0?nZZP3<VIT0100000001P2Zool0c9W<0;fm
_@2m_Kd0c9W<0;fm_@80c9W<00<0ZUFZ09VIc02ZEJX00P2ZEJX01P3<I/`0c9VI0<aVc03<I/`0ZUFZ
0<aVc0<0ZUFZ00L0VIW<0:YEZP2UYJD0YJFU0:6QX@2UYJD0WIfM0080VIVI00<0WIfM0:YEZP2ZEJX0
0`2ZEJX708f=S@0707inOP2=SHd0SHf=08f=S@1nOWh0SHf=06IVV@02096AT@0406IVV@3>c/h0c/k>
0<k>cPT0oooo303>c/hY0?ooo`D0c/k>?03oool003X0oooo103>c/h@0?ooo`<0c/k>6`3oool70<k>
cPH0oooo00L0[Jf]0?nZZP2Ic9T0VLbI0<bIV@2Ic9T0c9VI0080YJFU00D0`<300?o<V@30`<00`<30
0?o<V@030<coV@030<bIV@2MWId0_Kfm0080olc<00L0_Kfm0?o<c03oZZX0ojZZ0<bIV@2a/K40c9VI
0080/K6a00L0c9VI09fMW@3<VIT0c9VI09fMW@2QXJ40ojZZ0080XJ6Q00H0ojZZ0:6QX@30`<00`<30
0<bIc03<VIT20<bIc0<0ojZZ0P3<VL`00`3<VIT0ojZZ0?nZZP030?nZZP050;6a/@30`<00`<300?o<
V@30`<000P3oc9T00`3<VL`0c9VI0:[oZP0209W<V@050?nZZP3<VIT0ojZZ0?nZZP3<VIT01@000000
1@3<VL`0_Kfm0;fm_@3<VL`0_Kfm0080c9W<00<0ZUFZ09VIc02ZEJX00P2ZEJX01P3<I/`0c9VI0<aV
c03<I/`0ZUFZ0<aVc0<0ZUFZ00L0VIW<0:YEZP2UYJD0YJFU0:6QX@2UYJD0WIfM0080VIVI00<0WIfM
0:YEZP2ZEJX00`2ZEJX708f=S@0707inOP2=SHd0SHf=08f=S@1nOWh0SHf=06IVV@02096AT@80IVJI
0P3>c/h;0?ooo``0c/k>:03oool40<k>cS`0oooo000j0?ooo`@0c/k>403oool30<k>cQX0oooo1`3>
c/h70?ooo`80c9VI0P3oZZX00`3<VIT0ojZZ0<bIV@030<bIV@050?nZZP3<ofH0c?mV0?ooc02Ic9T0
0P3<VIT00`2Ic9T0ojZZ0?nZZP020?o<V@070?nZZP3oc9T0c?mV0<coIP3oZZX0c?mV0?nZZP020<co
IP050?nZZP2MWId0ojZZ0?nZZP2MWId03@3<VIT00`2m_Kd0c9VI0<bIV@030<bIV@80ojZZ00<0_Kfm
0?mVV@3<VIT00P2Ic9T01`3oc<`0VLbI0?o<c03oc<`0UIFE0<bIV@2IVL`00P3<VIT01P3<oiT0^k^k
0<aVc03<I/`0^k^k0<bIV@@0000000D0I/c<0<30`030`<00ojZZ0<30`0020?nZZP030<bIV@2IVL`0
ZUFZ0080SHf=00L0ZUFZ08f=S@2ATI40TI6A0?mVV@2ATI40EEFZ0080c9VI00L0EEFZ0<bIV@2QXJ40
XJ6Q0:YEZP2QXJ40ZUFZ0080VIVI0P2ZEJX2096AT@030:YEZP2ATI40ZUFZ0080ZUFZ00H0OWin0:YE
ZP1VIYT0IVJI0:YEZP1VIYT20:YEZP0305EEo`2ZEJX0EJZZ0080ZUFZ4P3oool<0<k>cRH0oooo103>
c/hk0?ooo`00>P3oool40<k>cQ00oooo0`3>c/hI0?ooo`L0c/k>2@3oool01P3oZZX0VLbI09W<V@3<
VIT0VLbI0?nZZP80YJFU00D0ojZZ0:FUY@30`<00`<300?o<V@030;6a/@0309fMW@3oc<`0_Kfm0080
olc<00L0_Kfm0<bIc02a/K40/K6a0<bIV@2a/K40c9VI0080/K6a00@0c9VI09fMW@3<VIT0c9VI0P3o
c9T01@3oZZX0XJ6Q0:6QX@3oZZX0olbI0080oonZ00L0c9W<0<bIV@3<VL`0c9W<0<bIV@3<VL`0c9VI
0080c9W<00L0c9VI0<bIc02ZEJX0ZUFZ0?nZZP2k^k/0ojZZ0080ZUFZ00L0olbI0<30`03oZZX0ojZZ
0<bIV@2ZEJX0c9VI00<0ZUFZ00H0c9VI0?nZZP3oZZX0c9W<0:YEZP2QXJ4400000080_Kfm00L0c9W<
0?mVc02ZEJX0ZUFZ09VIc02ZEJX0VLbI0080c9VI00L0VLbI0<bIV@3<I/`0c6K<0:YEZP3<VL`0VIW<
0080ZUFZ00L0VIW<0:YEZP2UYJD0YJFU0:6QX@2UYJD0WIfM0080VIVI00<0WIfM09VIV@2ZEJX01@2Z
EJX508f=S@0307inOP3oool0oooo01/0oooo303>c/hS0?ooo`D0c/k>>P3oool003/0oooo103>c/h>
0?ooo`<0c/k>6@3oool70<k>cPX0oooo00H0c9VI0?nZZP3oZZX0c9VI0?nZZP3<VL`20?ooZP80c9VI
0P2Ic9T01@3oZZX0VLbI0<bIV@3<VIT0WIfM00D0ojZZ00H0c9VI0<coIP3<ofH0ojZZ0<coIP3oZZX2
0;fm_@060?nZZP2MWId0ojZZ0?nZZP3<VIT0ooo<103<VIT00`3oc<`0VLaV09W<IP040<bIV@030?nZ
ZP3ool`0c9VI00@0c9VI0P3oIYT00`3<VIT0ofJI0<bIV@040<bIV@80_Kfm00<0VIW<0<bIV@2IVL`0
0P3<VIT01`2=SHd0c9VI0?mVc03oI/`0c9VI09VIc03<VIT0100000020;Fe]@070?nZZP2e]KD0VIVI
09VIV@3<VIT0VIVI0:YEZP0208f=S@070:YEZP2=SHd0TI6A096AT@3oIYT0/K6a0?mVV@020<bIV@07
05EEZP3<VIT0XJ6Q0:6QX@2ZEJX0XJ6Q0:YEZP0209VIV@060:YEZP2IVIT0TI6A096AT@2ZEJX0TI6A
0`2ZEJX00`1nOWh0oooo0?ooo`0Q0?ooo`d0c/k>8@3oool50<k>cST0oooo000k0?ooo`@0c/k>3P3o
ool30<k>cQP0oooo1`3>c/h;0?ooo`060<bIV@2Ic9T0VLbI0<bIV@2m_Kd0ojZZ0P2m_Kd01P3oZZX0
olbI0;6a/@2a/K40olbI0;6a/@80c9VI00<0WIfM0<bIV@2MWId00`3<VIT0103<VL`0<`0003<0003<
VIT20;6a/@<0c?nI00<0WIfM0?o<V@3oc9T00P3oc9T01@3oZZX0XJ6Q0:6QX@3oojX0olbI0080oonZ
00L0c9W<0<bIV@3<VL`0c9W<0?o<V@2m_Kd0c9VI0080c9W<00L0c9VI0<bIc02k^k/0^k^k0?nZZP2k
^k/0ojZZ0080ZUFZ00<0ZJVY0?nZZP3oZZX00P3oZZX00`2ZEJX0c9VI0:YEZP020:YEZP070<bIc02i
^KT0^KVi0<bIc02ZEJX0XJ6Q0:YEZP04000000030?mVc03<VIT0ofK<0080ZUFZ00<0VIW<0:YEZP2I
VL`00P3<VIT00`2Ic9T0c9VI0<bIc0040<bIc080ZUFZ00L0VIW<0:YEZP2IVL`0VIW<0:6QX@2UYJD0
XJ6Q0080VIVI00<0WIfM09VIV@2ZEJX00P2ZEJX[0?ooo``0c/k>803oool50<k>cSP0oooo000k0?oo
o`@0c/k>3P3oool30<k>cQL0oooo1`3>c/h<0?ooo`060<bIV@2Ic9T0VLbI0<bIV@2m_Kd0ojZZ0P2m
_Kd01P3oZZX0olbI0;6a/@2a/K40olbI0;6a/@80c9VI00<0WIfM0<bIV@2MWId00`3<VIT0103<VL`0
<`0003<0003<VIT20;6a/@<0c?nI00<0WIfM0?o<V@3oc9T00P3oc9T01@3oZZX0XJ6Q0:6QX@3oojX0
olbI0080oonZ00L0c9W<0<bIV@3<VL`0c9W<0?o<V@2m_Kd0c9VI0080c9W<00L0c9VI0<bIc02k^k/0
^k^k0?nZZP2k^k/0ojZZ0080ZUFZ00<0ZJVY0?nZZP3oZZX00P3oZZX00`2ZEJX0c9VI0:YEZP020:YE
ZP060<bIc02i^KT0^KVi0<bIc02ZEJX0XJ6Q0P2ZEJX4000000070<bIV@3oI/`0ZUFZ0:YEZP2IVL`0
ZUFZ09VIc0020<bIV@0309W<V@3<VIT0c9W<00@0c9W<0P2ZEJX01`2IVL`0ZUFZ09VIc02IVL`0XJ6Q
0:FUY@2QXJ400P2IVIT00`2MWId0VIVI0:YEZP020:YEZRh0oooo303>c/hN0?ooo`D0c/k>=`3oool0
03/0oooo103>c/h>0?ooo`<0c/k>5P3oool70<k>cPd0oooo00H0c9VI0?nZZP3oZZX0c9VI0?ooZP3<
VL`20?ooZP060<bIV@3oZZX0VLbI09W<V@3oZZX0VLbI0P3oZZX00`2MWId0ojZZ09fMW@020?ooZP03
0?nZZP3<VIT0ojZZ0080ojZZ0P3<VIT20<aVc0060?ooZP2MWId0ooo<0?ooc03<VIT0ooo<0`3<VIT0
102Ic6H0olc<09W<IP2Ic6H20<bIV@80ooo<00<0ojZZ0?ooc03<VIT0103<VIT20?mVV@030<bIV@3o
IYT0c9VI0080c9VI00L0_Kfm0?nZZP2m_Kd0_Kfm0?nZZP3<VIT0VIW<0080c9VI00L0ofK<0<bIV@3o
I/`0ofK<0<bIV@2IVL`0c9VI0080VIW<100000001`3oZZX0]KFe09VIV@2IVIT0c9VI09VIV@3<VIT0
0P2=SHd01`2ZEJX0olco0<coc03<ol`0ofJI0;6a/@3oIYT00P3<VIT01`1EEJX0c9VI05EEZP1EEJX0
ZUFZ0:6QX@2ZEJX00P2IVIT00`2ZEJX0oooo0?ooo`0b0?ooo`d0c/k>703oool50<k>cSH0oooo000k
0?ooo`@0c/k>3@3oool30<k>cQH0oooo1`3>c/h?0?ooo`80VLbI00<0ojZZ0;fm_@3oZZX00P2m_Kd0
1P3oZZX0olbI0;6a/@2a/K40olbI0;6a/@80VLbI00<0WIfM0<bIV@2MWId00P3<VIT01`3oc<`0c9W<
0<bIV@3<VIT0c9W<0;fm_@3oc<`00P3<VIT01`2a/K40WIfM0?o<V@3oc9T0c9VI0:YEZP3<VIT00P2Q
XJ401P3oojX0olbI0?ooZP3oojX0olbI0<bIV@80_Kfm00<0olbI0;fm_@3<VIT00P3<VL`01`3<VIT0
c?nI0;^k^`2k^k/0ojZZ0;^k^`3oZZX00P2ZEJX50?nZZP060:YEZP3<VIT0ZUFZ0:YEZP2ZojX0c9W<
0P2i^KT00`3<VL`0^KVi0:6QX@020:YEZP030:6QX@00000000000080000000H0ofK<0:YEZP2ZEJX0
VIW<0:YEZP2IVL`20<bIV@@0k>c/1@3<VL`01P2IVL`0ZUFZ09VIc02IVL`0XJ6Q0:FUYC/0oooo303>
c/hK0?ooo`D0c/k>=@3oool003/0oooo103>c/h=0?ooo`<0c/k>5@3oool70<k>cQ00oooo0P3oZZX0
0`3<VL`0oonZ0<bIc0020?ooo`0609W<V@3oZZX0VLbI09W<V@3oZZX0ZZYE0P3<ofH00`2MWId0ojZZ
09fMW@020?ooZP070?nZZP3<VIT0ojZZ0?nZZP3oc9T0c9VI0?o<V@020<aVc0070<bIV@2Ic6H0ojZZ
0?nZZP2Ic6H0c9VI09VIc0020?nZZP040<coV@3<VIT0VIW<09VIc080c9VI0P3ool`00`3oZZX0ooo<
0?nZZP020<bIV@070<aVc03oojX0VLbI09W<V@3<VIT0ofJI0<bIV@020?nZZP070;fm_@3oZZX0_Kfm
0;fm_@3oZZX0c9VI09VIc0020?ooZP0709W<IP3<VIT0ofK<0?mVc03<VIT0ofK<0<bIV@0209VIc003
0:[oZP00000000000080000000D0]KFe0?nZZP3oZZX0c9VI09VIV@080?ooo`060;6a/@3oIYT0/K6a
0;6a/@1EEJX0c9VI@P3oool<0<k>cQP0oooo103>c/hf0?ooo`00>`3oool40<k>cPd0oooo0`3>c/hD
0?ooo`L0c/k>4@3oool20?nZZP030<bIc03oojX0c9W<0080oooo00H0VLbI0?nZZP2Ic9T0VLbI0?nZ
ZP2ZZUD20<coIP0309fMW@3oZZX0WIfM0080oonZ00L0ojZZ0<bIV@3oZZX0ojZZ0?o<V@3<VIT0olbI
0080c6K<00L0c9VI09W<IP3oZZX0ojZZ09W<IP3<VIT0VIW<0080ojZZ00@0c?nI0<bIV@2IVL`0VIW<
0P3<VIT20?ooc0030?nZZP3ool`0ojZZ0080c9VI00L0c6K<0?ooZP2Ic9T0VLbI0<bIV@3oIYT0c9VI
0080ojZZ00L0_Kfm0?nZZP2m_Kd0_Kfm0?nZZP3<VIT0VIW<0080oonZ00L0VLaV0<bIV@3oI/`0ofK<
0<bIV@3oI/`0c9VI0080VIW<00<0Z_nZ0;Vi^@0000000`0000020?nZZP030<bIV@2IVIT0oooo00L0
oooo00H0/K6a0?mVV@2a/K40/K6a05EEZP3<VIU40?ooo`d0c/k>5P3oool00`3>c/h0oooo0?ooo`0f
0?ooo`00?03oool40<k>cP`0oooo0`3>c/hC0?ooo`L0c/k>6P3oool01@3oc9T0/K6a0;6a/@2Ic9T0
oooo0080VLbI00<0WIfM0<bIV@3oc<`00P3<VIT01`3oc<`0c9W<0<bIV@3<VIT0olc<0;fm_@3oc<`0
0P3<VIT01`2a/K40`<300?o<V@3oc9T0`<300:YEZP30`<000P3<VIT01P30`<00ZUFZ0<bIV@3<VIT0
ZUFZ0<30`080ZUFZ00<0c9VI0:YEZP3<VIT00P3<VL`01`3<VIT0/K6a0<coV@3<oiT0ojZZ0;^k^`3o
ZZX00P2k^k/50?nZZP060:YEZP3<VIT0VIW<09VIc03<VIT0c9W<0P2i^KT00`3<VL`0^KVi0:6QX@04
0?ooo`030?mVc000000000000080000000<0c9VI09VIc03oool0E@3oool=0<k>cT`0oooo000l0?oo
o`@0c/k>303oool30<k>cQ80oooo1`3>c/hL0?ooo`80VLbI103oool00`2ZZUD0ojZZ0?nZZP020?oo
ZP070?nZZP3oojX0ojZZ0?nZZP3oc9T0c9VI0?o<V@020<aVc0070?nZZP2Ic6H0ojZZ0?nZZP2Ic6H0
c9VI0<coV@020?nZZP060<coV@3<VIT0VIW<09VIc03oZZX0Z_nZ0P3oZZX00`2IVL`0c9VI09VIc002
0?o<c0070<aVc03<VIT0c6K<0<aVc03<VIT0SHf=0<bIV@020<aVc0070<bIV@3oZZX0_Kfm0;fm_@2Q
XJ40c9VI0:YEZP020<bIV@050:YEZP3<VIT0ofK<0?mVc03<VIT01`3oool4000005/0oooo303>c/i:
0?ooo`00?03oool40<k>cP/0oooo0`3>c/hB0?ooo`L0c/k>903oool20<bIV@80ZUFZ00L0]KFe0?o<
V@2m_Kd0_Kfm0?o<c02m_Kd0olc<0080c9VI00L0olbI0<30`03oc9T0olbI0<30`02ZEJX0`<300080
c9VI00H0`<300<bIV@3<VIT0c9VI0?o<V@30`<020?o<V@030<bIV@2ZEJX0c9VI0080olbI00L0c9VI
0;6a/@3<VIT0c9VI0;6a/@2k^k/0ojZZ0080^k^k00L0ojZZ0:YEZP2MWId0WIfM0:YEZP2Ic9T0c9VI
0080VIW<00D0c9VI09VIc02ZEJX0ZUFZ08f=S@080?ooo`@00000G03oool=0<k>cTL0oooo000l0?oo
o`@0c/k>2`3oool30<k>cQ40oooo1`3>c/hU0?ooo`80c9VI0P2ZEJX01`2e]KD0olbI0;fm_@2m_Kd0
olc<0;fm_@3oc<`00P3<VIT01`3oc9T0`<300?o<V@3oc9T0`<300:YEZP30`<000P3<VIT01P30`<00
c9VI0<bIV@3<VIT0olbI0<30`080olbI00<0c9VI0:YEZP3<VIT00P3oc9T01`3<VIT0/K6a0<bIV@3<
VIT0/K6a0;^k^`3oZZX00P2k^k/01`3oZZX0ZUFZ09fMW@2MWId0ZUFZ09W<V@3<VIT00P2IVL`01@3<
VIT0VIW<0:YEZP2ZEJX0SHf=00P0oooo1000001O0?ooo`d0c/k>A03oool003`0oooo103>c/h;0?oo
o`<0c/k>403oool70<k>cRL0oooo00D0ZZ[o0<bIV@3<VIT0VLbI0?nZZP0209W<V@030?o<V@3<VIT0
ojZZ0080VLbI00L0ojZZ09W<IP3oZZX0ojZZ09W<IP3oZZX0c?nI0080ojZZ00H0c?nI0?nZZP2IVL`0
VIW<0?nZZP2ZojX20?nZZP0309VIc03<VIT0VLaV0080olc<00L0VLaV0<bIV@3<I/`0c6K<0<bIV@00
0000c9VI0080c6K<00L0c9VI0<aVc03<VIT0c9VI0:6QX@3oc<`0ZUFZ0080c9VI00@0ZUFZ0<bIV@1V
IYT0IVJI2P3oool400000640oooo303>c/i20?ooo`00?03oool40<k>cP/0oooo0`3>c/h?0?ooo`L0
c/k>:03oool01@3<VIT0olbI0?o<V@2e]KD0olbI0080]KFe0P2][Jd01@3<VIT0[Jf]0:f][@2UYJD0
`<300080olbI00<0ZZZZ0<bIV@30`<000P3<VIT01P30`<00c9VI0<30`030`<00olbI0<30`080olbI
00<0c9VI0?o<V@3oojX00P3oc9T0103oojX0/K6a0<bIV@3<VIT2000000050?nZZP2k^k/0^k^k0?nZ
ZP2k^k/00P2MWId00`3oc9T0VLbI0?o<V@0209VIc0040<bIV@2IVL`0ZUFZ0:YEZP/0oooo1000001R
0?ooo`X0c/k>@P3oool003`0oooo103>c/h;0?ooo`<0c/k>3P3oool70<k>cRT0oooo00D0ZZ[o0?nZ
ZP3oZZX0VLbI0?nZZP0209W<V@030<bIV@2Ic9T0ojZZ0080VLbI00L0ojZZ09VIc03oZZX0ojZZ09W<
V@3oZZX0VIW<0080ojZZ00H0c?nI0?nZZP2IVL`0VIW<0<bIV@2ZojX20?nZZP0309VIc03oc<`0VLaV
0080olc<00L0VLaV0<bIV@00000000000?ooo`000000c9VI0080c6K<00L0c9VI0<aVc03<VIT0c9VI
0;Vi^@3oc<`0^KVi0080c9VI00<0ZUFZ0<bIV@3oool0303oool4000006D0oooo1P3>c/i30?ooo`00
?@3oool40<k>cPT0oooo0`3>c/h>0?ooo`L0c/k>:P3oool01@3<VIT0olbI0?o<V@2e]KD0olbI0080
]KFe00<0c9VI0:f][@3<VIT00P2][Jd01`3<VIT0ZUFZ0<bIV@3<VIT0ZZZZ0<bIV@2ZEJX0102a/K42
0:YEZP030:FUY@2ZEJX0oooo00L0oooo00<0/K6a0?ooo`3oool00P3oool010000000^k^k0;^k^`3o
ZZX30?ooo`030?o<V@2Ic9T0olbI0080VIW<00<0c9VI0?ooo`3oool03@3oool4000006L0oooo0`3>
c/i30?ooo`00?@3oool40<k>cPT0oooo0`3>c/h=0?ooo`L0c/k>:`3oool01@3<VIT0olbI0?o<V@2e
]KD0olbI0080]KFe00<0c9VI0:f][@3<VIT00P2][Jd01`3<VIT0ZUFZ0<bIV@3<VIT0ZZZZ0<bIV@2Z
EJX0102a/K420:YEZP030:FUY@2ZEJX0oooo00L0oooo00<0/K6a0?ooo`3oool00P3oool010000000
^k^k0;^k^`3oZZX30?ooo`030?o<V@2Ic9T0olbI0080VIW<00<0c9VI0?ooo`3oool03P3oool40000
0:`0oooo000m0?ooo`@0c/k>2@3oool30<k>cP`0oooo1`3>c/h/0?ooo`0509W<V@3oZZX0ojZZ09W<
V@3oZZX00P2Ic9T00`3oZZX0VLbI0?nZZP0209W<V@070?nZZP2Ic9T0ojZZ0?nZZP2Ic9T0ojZZ09VI
c0020?nZZP030<bIV@3oZZX0c9VI0080c9VI3`3oool20<aVc0L0oooo0P3<VITA0?ooo`@00000[03o
ool003d0oooo103>c/h90?ooo`<0c/k>2`3oool70<k>cRh0oooo0P3oc9T00`2e]KD0olbI0?ooo`02
0?ooo`060:f][@3<VIT0[Jf]0:f][@3<VIT0ZZZZ0P3<VIT00`2ZZZX0c9VI0;6a/@060;6a/@030:FU
Y@3oool0oooo02X0oooo1000002[0?ooo`00?@3oool40<k>cPT0oooo0`3>c/h:0?ooo`L0c/k><@3o
ool00`2Ic9T0oooo0?ooo`020?ooo`0609W<V@3oZZX0VLbI09W<V@3oool0VLbI0P3oZZX00`2Ic9T0
ojZZ0<bIV@020?nZZP030<bIV@3oZZX0c9VI0080c9VI;03oool4000005@0oooo10000000100c<c<0
oooo0?ooo`1gMgL20000000507MgM`3oool0oooo0?ooo`1gMgL00P0000001`2IVIT0oooo09VIV@0A
4A40000008R8R00000000P3oool00`000000^k^k0?ooo`040?ooo`090000002k^k/0oooo0;^k^`00
0000^k^k0?ooo`2k^k/000000080oooo01D0VIVI014A4@000000R8R80000003oool0EEEE04A4A03o
ool0k^k^014A4@28R8P0oooo0000002k^k/0oooo0000002k^k/0oooo0;^k^`0000000P3oool02@2k
^k/0<c<c0?ooo`3oool0VIVI014A4@000000R8R80000000;0?ooo`00?@3oool40<k>cPP0oooo0`3>
c/h;0?ooo`H0c/k><P3oool00`2Ic9T0oooo0?ooo`020?ooo`0609W<V@3oZZX0VLbI09W<V@3oool0
VLbI0P3oZZX00`2Ic9T0ojZZ0<bIV@020?nZZP030<bIV@3oZZX0c9VI0080c9VI;@3oool4000005<0
oooo00P0000008R8R02k^k/0^k^k0<c<c03oool0IVIV03<c<`80k^k^00h0<c<c06IVIP3oool0IVIV
028R8P3MgMd0oooo0=gMg@3oool0000008R8R03oool0IVIV00000080oooo00<000000;^k^`3oool0
103oool02@000000^k^k0?ooo`1EEED04A4A05EEE@3oool0^k^k000000020?ooo`0;00000028R8P0
oooo06IVIP000000oooo0>k^kP0A4A40ZZZZ06IVIP0c<c<00P3oool020000000^k^k0?ooo`000000
^k^k0?ooo`2k^k/000000P3oool02@2k^k/0<c<c0?ooo`3oool0000008R8R03oool0IVIV0000000;
0?ooo`00B@3oool30<k>cPd0oooo0`3>c/hi0?ooo`030<bIV@3oool0oooo0080oooo0P3<VIT00`2Z
ZZX0oooo0?ooo`040;6a/C40oooo1000001B0?ooo`030000002k^k/0oooo00<0oooo00T000000;^k
^`3oool0oooo0;^k^`000000oooo0000002k^k/0103oool01@000000R8R80?ooo`2k^k/000000080
oooo00<000000;^k^`3oool0103oool02@000000^k^k0?ooo`000000VIVI0000003oool0^k^k0000
00020?ooo`0500000028R8P0oooo0;^k^`0000000P3oool0103<c<`000000000003MgMd20?ooo`08
0000002k^k/0oooo0000002k^k/0oooo0;^k^`0000020?ooo`090;^k^`0c<c<0oooo0?ooo`000000
R8R80?ooo`2k^k/0000000/0oooo002J0?ooo`80ojZZ1@3oool00`3<VIT0oooo0?ooo`0`0?ooo`@0
0000DP3oool00`000000^k^k0?ooo`030?ooo`090000002k^k/0oooo0?ooo`2k^k/000000?ooo`00
0000ZZZZ00@0oooo00D0c<c<04A4A00R8R808R8R000000020?ooo`030000002k^k/0oooo00@0oooo
00T000000;^k^`2ZZZX04A4A0?ooo`14A4@0ZZZZ0;^k^`0000000P3oool01@3<c<`0A4A4028R8P0R
8R8000000080oooo00@0k^k^0000000A4A40k^k^0P3oool030000000^k^k0?ooo`000000^k^k0?oo
o`2k^k/000000>k^kP3oool0^k^k03<c<`80oooo00D0c<c<04A4A00R8R808R8R0000000;0?ooo`00
e@3oool400000540oooo00<000000;^k^`3oool00`3oool0301VIVH08R8R0>k^kP3^k^h08R8R06IV
IP3oool0IVIV028R8P3^k^h0oooo0>k^kP@0oooo00H0ZZZZ014A4@3oool0oooo0000002k^k/50?oo
o`090000002k^k/0EEEE06IVIP3oool0VIVI05EEE@2k^k/0000000D0oooo00D0ZZZZ014A4@3oool0
oooo04A4A00306IVIP80oooo00`000000;^k^`3oool0000004A4A03oool0R8R80000001EEED0oooo
06IVIP14A4@50?ooo`030:ZZZP0A4A40oooo00X0oooo003F0?ooo`<00000D@3oool00`000000^k^k
0?ooo`030?ooo`0B0>k^kP1VIVH04A4A014A4@1VIVH0k^k^0?ooo`3^k^h0MgMg028R8P000000VIVI
0?ooo`3MgMd0A4A40000000R8R80c<c<0P3oool00`000000^k^k0?ooo`040?ooo`090000002ZZZX0
00000<c<c03oool0k^k^0000002ZZZX000000080oooo00P0gMgM04A4A00000008R8R0<c<c03oool0
R8R800000080k^k^00l000000;^k^`3oool000000;^k^`3oool0000009VIV@0000004A4A0:ZZZP1V
IVH00000028R8P3<c<`00P3oool01@3MgMd0A4A40000000R8R80c<c<00/0oooo000M0?ooo`@00000
00@0<c<c0?ooo`3oool0MgMg0P0000001@1gMgL0oooo0?ooo`3oool0MgMg0080000000L0VIVI0?oo
o`2IVIT04A4A00000028R8P000000080oooo00<000000;^k^`3oool0103oool02@000000^k^k0?oo
o`2k^k/000000;^k^`3oool0^k^k000000020?ooo`0E09VIV@0A4A40000008R8R0000000oooo05EE
E@14A4@0oooo0>k^kP0A4A40R8R80?ooo`000000^k^k0?ooo`000000^k^k0?ooo`2k^k/000000080
oooo00T0^k^k03<c<`3oool0oooo09VIV@0A4A40000008R8R0000000K@3oool400000500oooo00<0
00000;^k^`3oool05`3oool00`000000^k^k0?ooo`040?ooo`030000001EEED04A4A00<0oooo00<0
A4A405EEE@000000;@3oool001d0oooo00P0000008R8R02k^k/0^k^k0<c<c03oool0IVIV03<c<`80
k^k^00h0<c<c06IVIP3oool0IVIV028R8P3MgMd0oooo0=gMg@3oool0000008R8R03oool0IVIV0000
0080oooo00<000000;^k^`3oool0103oool02@000000^k^k0?ooo`1EEED04A4A05EEE@3oool0^k^k
000000020?ooo`0;00000028R8P0oooo06IVIP000000oooo0>k^kP0A4A40ZZZZ06IVIP0c<c<00P3o
ool020000000^k^k0?ooo`000000^k^k0?ooo`2k^k/000000P3oool02@2k^k/0<c<c0?ooo`3oool0
000008R8R03oool0IVIV0000001^0?ooo`@00000C`3oool00`000000^k^k0?ooo`0G0?ooo`030000
002k^k/0oooo00@0oooo0P0000001@28R8P0oooo0?ooo`3oool0R8R8008000003`3oool00`2k^k/0
k^k^0?ooo`0K0?ooo`007@3oool00`000000^k^k0?ooo`030?ooo`090000002k^k/0oooo0?ooo`2k
^k/000000?ooo`000000^k^k00@0oooo00D0000008R8R03oool0^k^k000000020?ooo`030000002k
^k/0oooo00@0oooo00T000000;^k^`3oool0000009VIV@000000oooo0;^k^`0000000P3oool01@00
0000R8R80?ooo`2k^k/000000080oooo00@0c<c<000000000000gMgM0P3oool020000000^k^k0?oo
o`000000^k^k0?ooo`2k^k/000000P3oool02@2k^k/0<c<c0?ooo`3oool0000008R8R03oool0^k^k
0000001^0?ooo`@00000C`3oool00`000000^k^k0?ooo`0G0?ooo`030000002k^k/0oooo00@0oooo
0P0000001@3MgMd0oooo0?ooo`3oool0gMgM008000003`3oool00`000000^k^k0?ooo`0K0?ooo`00
7@3oool00`000000^k^k0?ooo`030?ooo`090000002k^k/0oooo0?ooo`2k^k/000000?ooo`000000
ZZZZ00@0oooo00D0c<c<04A4A00R8R808R8R000000020?ooo`030000002k^k/0oooo00@0oooo00T0
00000;^k^`2ZZZX04A4A0?ooo`14A4@0ZZZZ0;^k^`0000000P3oool01@3<c<`0A4A4028R8P0R8R80
00000080oooo00@0k^k^0000000A4A40k^k^0P3oool030000000^k^k0?ooo`000000^k^k0?ooo`2k
^k/000000>k^kP3oool0^k^k03<c<`80oooo00D0c<c<04A4A00R8R808R8R0000001_0?ooo`@00000
Y@3oool001d0oooo00<000000;^k^`3oool00`3oool0301VIVH08R8R0>k^kP3^k^h08R8R06IVIP3o
ool0IVIV028R8P3^k^h0oooo0>k^kP@0oooo00H0ZZZZ014A4@3oool0oooo0000002k^k/50?ooo`09
0000002k^k/0EEEE06IVIP3oool0VIVI05EEE@2k^k/0000000D0oooo00D0ZZZZ014A4@3oool0oooo
04A4A00306IVIP80oooo00`000000;^k^`3oool0000004A4A03oool0R8R80000001EEED0oooo06IV
IP14A4@50?ooo`030:ZZZP0A4A40oooo06l0oooo0`00002U0?ooo`007@3oool00`000000^k^k0?oo
o`030?ooo`0B0>k^kP1VIVH04A4A014A4@1VIVH0k^k^0?ooo`3^k^h0MgMg028R8P000000VIVI0?oo
o`3MgMd0A4A40000000R8R80c<c<0P3oool00`000000^k^k0?ooo`040?ooo`090000002ZZZX00000
0<c<c03oool0k^k^0000002ZZZX000000080oooo00P0gMgM04A4A00000008R8R0<c<c03oool0R8R8
00000080k^k^00l000000;^k^`3oool000000;^k^`3oool0000009VIV@0000004A4A0:ZZZP1VIVH0
0000028R8P3<c<`00P3oool01@3MgMd0A4A40000000R8R80c<c<0700oooo1000002T0?ooo`007@3o
ool00`000000^k^k0?ooo`0G0?ooo`030000002k^k/0oooo00@0oooo00<0000005EEE@0A4A400`3o
ool00`14A4@0EEEE0000002C0?ooo`@00000X`3oool001d0oooo00<000000;^k^`3oool05`3oool0
0`000000^k^k0?ooo`040?ooo`80000000D0R8R80?ooo`3oool0oooo08R8R002000000l0oooo00<0
^k^k0>k^kP3oool0P@3oool400000:<0oooo000M0?ooo`030000002k^k/0oooo01L0oooo00<00000
0;^k^`3oool0103oool2000000050=gMg@3oool0oooo0?ooo`3MgMd00P00000?0?ooo`030000002k
^k/0oooo0880oooo1000002R0?ooo`00g03oool300000:80oooo003L0?ooo`@00000X@3oool00=d0
oooo1000002P0?ooo`00gP3oool300000:00oooo003N0?ooo`@00000W`3oool00=l0oooo0`00002O
0?ooo`00g`3oool4000009h0oooo003P0?ooo`@00000W@3oool00>40oooo1@00002K0?ooo`00h@3o
ool4000009`0oooo003R0?ooo`030000003oool0oooo09`0oooo003o0?oooh80oooo003o0?oooh80
oooo003o0?oooh80oooo00370?ooo`030=gMg@1EEED04A4A0080000000D04A4A04A4A03oool00000
03<c<`020?ooo`0507MgM`0A4A400000014A4@1gMgL00P3oool00`0000008R8R05EEE@020000000;
05EEE@3^k^h0ZZZZ014A4@000000EEEE06IVIP000000oooo0000000c<c<01@3oool010000000<c<c
0?ooo`3^k^h20000000E0>k^kP3oool0<c<c0000003oool0ZZZZ014A4@000000EEEE06IVIP000000
oooo04A4A0000000gMgM0?ooo`0R8R8000000<c<c0000000<c<c0080oooo00H0000003<c<`3oool0
oooo0000000c<c<20?ooo`080000000c<c<0^k^k014A4@000000EEEE06IVIP0000020?ooo`060000
000c<c<0oooo0?ooo`000000<c<c0P3oool00`000000<c<c0?ooo`1H0?ooo`00aP3oool0103<c<`0
00000000001EEED20;^k^`0>028R8P000000oooo0000000c<c<0oooo06IVIP000000MgMg0;^k^`1g
MgL0000006IVIP3oool20000000906IVIP2k^k/0MgMg0000001EEED04A4A03<c<`2k^k/0VIVI0080
000000<0oooo0000000c<c<01@3oool010000000<c<c0?ooo`2IVIT20000000909VIV@3oool0<c<c
0000003oool04A4A03<c<`2k^k/0VIVI0080000000X0oooo0>k^kP0A4A40EEEE07MgM`000000R8R8
0?ooo`000000<c<c0P3oool01P000000<c<c0?ooo`3oool0000003<c<`80oooo00H0000003<c<`0A
4A4000000:ZZZP1gMgL200000080oooo00H0000003<c<`3oool0oooo0000000c<c<20?ooo`030000
000c<c<0oooo05P0oooo00360?ooo`0304A4A0000000ZZZZ00<0oooo00P0<c<c0000003oool00000
03<c<`3oool00000028R8P<0oooo00D08R8R0000003oool00000028R8P030?ooo`0;028R8P000000
4A4A028R8P3^k^h0oooo06IVIP000000oooo0000000c<c<01@3oool010000000<c<c0?ooo`1EEED2
014A4@0;05EEE@3oool0<c<c0000003oool04A4A028R8P3^k^h0oooo06IVIP0000000P3oool0102k
^k/000000000000c<c<20?ooo`060000000c<c<0oooo0?ooo`000000<c<c0P3oool020000000<c<c
0?ooo`3oool0000003<c<`000000<c<c0P3oool01P0R8R8000000?ooo`3oool0000003<c<`80oooo
00H0000003<c<`3oool0oooo0000000c<c=I0?ooo`00aP3oool03P0000004A4A0?ooo`3oool0c<c<
0;^k^`0R8R8000000?ooo`000000<c<c0?ooo`0000008R8R0`3oool01@0R8R8000000?ooo`000000
8R8R00<0oooo00@08R8R0000003<c<`0<c<c100000000`3oool0000003<c<`050?ooo`040000000c
<c<0oooo00000080IVIV00L000000?ooo`0c<c<000000?ooo`3<c<`0<c<c00@000000P3oool0103<
c<`000000000001gMgL20?ooo`060000000c<c<0oooo0?ooo`000000<c<c0P3oool020000000<c<c
0?ooo`3oool0000003<c<`000000<c<c0P3oool01P0c<c<000000?ooo`3oool0000003<c<`80oooo
00H0000003<c<`3oool0oooo0000000c<c=I0?ooo`00aP3oool01@000000<c<c0?ooo`3oool0<c<c
00<0000000`0oooo0000000c<c<0oooo07MgM`000000MgMg0;^k^`1gMgL0000007MgM`3oool20000
000706IVIP2k^k/0MgMg0000001EEED0gMgM09VIV@020;^k^`0503<c<`0R8R80oooo0000000c<c<0
1@3oool010000000<c<c0:ZZZP0000020:ZZZP070000002ZZZX0<c<c0000003oool0gMgM09VIV@02
0;^k^`0<03<c<`0R8R80oooo0?ooo`0R8R804A4A06IVIP000000c<c<0?ooo`000000<c<c0P3oool2
00000080R8R80P00000208R8R0040000001VIVH0000003<c<`80oooo00@0<c<c0000003oool0oooo
0P00000208R8R08000000P28R8P00`000000IVIV0?ooo`1H0?ooo`00aP3oool00`0A4A4000000?oo
o`060?ooo`090000000c<c<0oooo0?ooo`1gMgL08R8R0000000R8R80MgMg0080oooo00<00000028R
8P1VIVH00P0000001014A4@0k^k^0=gMg@0c<c<20000000504A4A03<c<`0oooo0000000c<c<01@3o
ool010000000<c<c05EEE@0000020?ooo`070000001EEED0<c<c0000003oool0gMgM03<c<`020000
000<04A4A03<c<`0oooo05EEE@000000ZZZZ0?ooo`0A4A408R8R0>k^kP000000<c<c0P3oool03000
0000IVIV04A4A00000008R8R0;^k^`0c<c<0000003<c<`3MgMd0000003<c<`80oooo00h0<c<c0000
003oool0oooo0000001VIVH0A4A40000000R8R80^k^k03<c<`000000<c<c0=gMgET0oooo00360?oo
o`0305EEE@000000R8R800H0oooo00<0000003<c<`3oool0203oool00`000000<c<c0?ooo`0;0?oo
o`030000000c<c<0oooo00@0oooo00@0000003<c<`000000EEEE0P3oool0101EEED0000003<c<`00
00280?ooo`00aP3oool02`3^k^h0000000000014A4@0ZZZZ0;^k^`2IVIT0MgMg0?ooo`000000<c<c
00T0oooo00<0000003<c<`3oool02`3oool00`000000<c<c0?ooo`040?ooo`<0000000@0ZZZZ0?oo
o`3oool0ZZZZ0`00000?0?ooo`0307MgM`2IVIT0oooo07H0oooo00370?ooo`030>k^kP1VIVH08R8R
00<0000000@0IVIV0?ooo`000000<c<c2@3oool00`000000<c<c0?ooo`0;0?ooo`030000000c<c<0
oooo00@0oooo0`000000103^k^h0oooo0?ooo`3^k^h3000000l0oooo00<0000003<c<`3oool0MP3o
ool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3o
ool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3oool00?l0ooooPP3o
ool00?l0ooooPP3oool00?l0ooooPP3oool00001\
\>"], "Graphics",
  CellMargins->{{Inherited, 322}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageSize->{385, 302.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A Multimodal Function in Two Dimensions: The problem of local \
maxima\
\>", "NumberedFigure"],

Cell["", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000600000a2000`400?l00000o`00003oo`3ooon1
0?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon1
0?ooo`00o`3ooon10?ooo`00b@3oool300000;@0oooo00380?ooo`040000003oool0oooo0?ooo`80
0000/P3oool00<P0oooo00@000000?ooo`3oool0oooo0P00002b0?ooo`00b03oool010000000oooo
0?ooo`3oool200000;80oooo00380?ooo`040000003oool0oooo0?ooo`800000/P3oool00<P0oooo
00@000000?ooo`3oool0oooo0P00002b0?ooo`00b03oool010000000oooo0?ooo`3oool200000;80
oooo00380?ooo`040000003oool0oooo0?ooo`800000/P3oool00<T0oooo0`00000?0?ooo`@00000
1P3oool2000009T0oooo003L0?ooo`8000001@3oool200000080oooo0P00002G0?ooo`00g03oool2
000000D0oooo0P0000020?ooo`800000U`3oool00=80oooo1P0000040?ooo`8000001@3oool20000
0080oooo0P00002G0?ooo`00g03oool2000000D0oooo0P0000020?ooo`800000U`3oool00=`0oooo
0P0000050?ooo`8000000P3oool2000009L0oooo003L0?ooo`8000001@3oool200000080oooo0P00
002G0?ooo`00b@3oool5000000d0oooo0`0000050?ooo`8000000P3oool2000009L0oooo001M0?oo
o`<0000000@0oooo0000000000000000H@3oool400000080oooo00<000000?ooo`3oool00P00000<
0?ooo`8000001`3oool2000003`0oooo1000001I0?ooo`00G@3oool3000000040?ooo`0000000000
00000640oooo100000020?ooo`030000003oool0oooo00800000303oool2000000L0oooo0P00000l
0?ooo`@00000F@3oool005h0oooo0P0000000`3oool000000000000^0?ooo`H00000103oool20000
00D0oooo1000000K0?ooo`@000001P3oool00`000000oooo0?ooo`020?ooo`@00000D03oool20000
05X0oooo001P0?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo0P00000E0?ooo`@000004`3oool3000004l0oooo00<000000?oo
o`3oool0E`3oool005h0oooo0P0000000`3oool000000000000U0?ooo`L00000103oool200000140
oooo0P00000C0?ooo`8000000`3oool00`000000oooo0?ooo`0A0?ooo`80000000@0oooo00000000
00000000C03oool00`000000oooo0?ooo`1G0?ooo`00GP3oool2000000030?ooo`000000000002D0
oooo1`0000040?ooo`8000004@3oool2000001<0oooo0P0000030?ooo`030000003oool0oooo0140
oooo0P000000103oool0000000000000001<0?ooo`030000003oool0oooo05L0oooo001M0?ooo`<0
000000@0oooo0000000000000000<@3oool00`000000oooo0?ooo`0>0?ooo`8000003`3oool40000
01l0oooo100000160?ooo`80000000<0oooo0000003oool0E`3oool00940oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`D00000303oool5000002L0oooo0`0000130?ooo`80
000000<0oooo0000003oool0E`3oool00940oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo100000030?ooo`8000009`3oool00`000000oooo
0?ooo`0200000400oooo0`000000103oool0000000000000001F0?ooo`00T@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool4000000<0oooo
0P00000W0?ooo`030000003oool0oooo00800000@03oool3000000040?ooo`0000000000000005H0
oooo002B0?ooo`@000002`3oool700000080oooo1000000`0?ooo`030000003oool0oooo0080oooo
1000000Q0?ooo`@00000M03oool00:P0oooo0P0000020?ooo`030000003oool0oooo03P0oooo0`00
000L0?ooo`800000103oool00`000000oooo0?ooo`1a0?ooo`00Y03oool4000003l0oooo0P000000
103oool0000000000000000A0?ooo`L000001`3oool00`000000oooo0?ooo`1a0?ooo`00Y03oool4
000003l0oooo0P000000103oool0000000000000000A0?ooo`L000001`3oool00`000000oooo0?oo
o`1a0?ooo`00W`3oool5000004T0oooo1000000K0?ooo`030000003oool0oooo0740oooo002K0?oo
o`@000000`3oool2000004/0oooo1000000C0?ooo`H00000M03oool00700oooo1000000U0?ooo`80
0000E03oool200000080oooo0`00000@0?ooo`800000N03oool00700oooo1000000U0?ooo`800000
E03oool200000080oooo0`00000@0?ooo`800000N03oool006l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0N0?ooo`D00000G03oool3000000d0oooo1`00001c0?ooo`00I`3oool6
000000L0oooo00<000000?ooo`3oool06P3oool4000000@0oooo00<000000?ooo`3oool0G03oool5
000008<0oooo001d0?ooo`030000003oool0oooo01H0oooo1000001/0?ooo`<00000P03oool007@0
oooo00<000000?ooo`3oool05P3oool4000006`0oooo0`0000200?ooo`00K`3oool5000001H0oooo
0`0000020?ooo`800000C03oool6000001d0oooo0P00001n0?ooo`00K`3oool00`000000oooo0?oo
o`0D0?ooo`@00000D@3oool:000001/0oooo00<000000?ooo`0000000`00001j0?ooo`00K`3oool0
0`000000oooo0?ooo`0D0?ooo`@00000C`3oool4000000H0oooo1000000I0?ooo`030000003oool0
000000<00000NP3oool006l0oooo1P00000=0?ooo`@0000000<0oooo0000003oool0C`3oool30000
0080oooo100000040?ooo`<000007P3oool3000001h0oooo0`00001F0?ooo`00OP3oool4000005H0
oooo0P0000040?ooo`8000001P3oool2000001h0oooo0P000000103oool0000000000000000J0?oo
o`050000003oool0oooo0?ooo`000000E@3oool007/0oooo0`0000000`3oool000000?ooo`1F0?oo
o`8000001@3oool2000000L0oooo0P00000G0?ooo`0303<000000280oooo00<0oooo0P0000040?oo
o`@000005P3oool01@000000oooo0?ooo`3oool0000005D0oooo001k0?ooo`<0000000<0oooo0000
003oool0EP3oool2000000D0oooo0P0000070?ooo`8000005`3oool00`0c0000000R0?ooo`030?oo
o`800000103oool4000001H0oooo00D000000?ooo`3oool0oooo0000001E0?ooo`00M`3oool40000
05/0oooo0P0000060?ooo`800000203oool200000100oooo0P0C4a<01P0S8b<04a<C03<0<`0c03<0
4a<C03<0<`80EJ[o2`3oool4000001<0oooo00D000000?ooo`3oool0oooo0000001E0?ooo`00A`3o
ool2000000L0oooo00<000000?ooo`3oool00`3oool4000001T0oooo1@00001N0?ooo`8000001P3o
ool2000000P0oooo0P00000<0?ooo`80000R00H08b<S00008P0S8b<08b<S00008P0c000200008P05
03<0001EZ_l0IVJI06IVV@1EZ_l02P3oool010000000oooo0?ooo`3oool200000140oooo00D00000
0?ooo`3oool0oooo0000001E0?ooo`00A`3oool2000000`0oooo00<000000?ooo`3oool00P3oool2
000001<0oooo1000001S0?ooo`8000001@3oool3000000P0oooo0P00000;0?ooo`0500004@1E05D0
E@1E01<C4`0S8b<00P0C4a<01P0S8b<04a<C03<0<`0c03<04a<C09VIo`80EJ[o00<0VIWo05FZo`3o
ool03P3oool4000000d0oooo00D000000?ooo`3oool0oooo0000001E0?ooo`00A`3oool2000000`0
oooo00<000000?ooo`3oool00P3oool2000001<0oooo1000001S0?ooo`8000001P3oool2000000P0
oooo0P00000;0?ooo`0500004@1E05D0E@1E01<C4`0S8b<00P0C4a<01P0S8b<04a<C03<0<`0c03<0
4a<C09VIo`80EJ[o00<0VIWo0000000000001000000:0?ooo`@000003@3oool01@000000oooo0?oo
o`3oool0000005D0oooo000m0?ooo`H000001P3oool00`000000oooo0?ooo`0>0?ooo`8000003`3o
ool5000006H0oooo0P00000@0?ooo`8000001`3oool01@0002808b<S00008P000280<`0c0080000R
00H08b<S00008P0S8b<08b<S00008P0c000200008P0309VIc01EZ_l0IVJI00X00000203oool20000
0080oooo0`00000;0?ooo`<00000EP3oool004T0oooo00<000000?ooo`3oool03P3oool2000000`0
oooo0`0000040?ooo`030000003oool0oooo06@0oooo0P00000@0?ooo`80000000D0oooo0000<`00
03<0000R03<0<`0200008P0503<0<`000280E@1E05D0E@0001400P0S8b<01P0C4a<08b<S01<C4`0C
4a<0<`0c01<C4`80<`0c00<0<fK<06IVV@0000000P0000060?ooo`<000003P3oool300000640oooo
001:0?ooo`8000002@3oool5000000X0oooo1@00001]0?ooo`<000003P3oool2000000060000<`0c
03<0000c0000<`0c03<0000R0P0S8b<01@000280<`0c00008P000280<`0c0080000R00H08b<S0000
8P0S8b<08b<S00008P0c000200008P0306Hcc0000000000000X0oooo0P00000=0?ooo`030000003o
ool0oooo00<00000GP3oool004X0oooo0P0000090?ooo`D000002P3oool5000006d0oooo0`00000>
0?ooo`80000000H0000c03<0<`0003<0000c03<0<`00028202<S8`0500008P0c03<0000R00008P0c
03<00P0002801P0S8b<0000R02<S8`0S8b<0000R03<00080000R0P0000040?ooo`<000001@3oool2
000000`0oooo00<000000?ooo`3oool00`00001N0?ooo`00A@3oool00`000000oooo0?ooo`020?oo
o`8000002@3oool00`000000oooo0?ooo`080?ooo`@00000K03oool:000000`0oooo0P0000020000
<`0500008P0003<0000c00008P0c03<00P0002801@0c03<0000A05D0E@1E05D0000A00808b<S00L0
4a<C02<S8`0C4a<04a<C03<0<`0005D0ZUFZ00<00000103oool010000000oooo0000000000040?oo
o`<000004@3oool4000001/0oooo1000000k0?ooo`00A@3oool7000000T0oooo2`0000000`3oool0
00000000001T0?ooo`0500004@0000000`<300<30`0000000P030`<=000000X0oooo0`0000000`00
0280000c03<0<`020000<`0602<S8`0002808b<S02<S8`000280<`0c0P0002800`0S8b<0000R0000
8P0605D0E@0305EEZP000000000000P0oooo0P0000040?ooo`8000004@3oool010000000oooo0?oo
o`3oool2000001L0oooo0P0000040?ooo`030000003oool0oooo03P0oooo000^0?ooo`@000001@3o
ool3000001l0oooo0`00001U0?ooo`80000A00<0000R00004@0001400P00014010030`<000000000
00030`<;000000030000E@1E05D0000000<000001P3oool400000080000R00H0000c00008P0003<0
000c00008P0c03<200008P0505D0E@000140E@1E05D0E@0005D00P1E05D01P0005D0E@1E0000E@00
05D0E@2Z0000E@<000001`3oool2000000D0oooo0`00000F0?ooo`<000006P3oool00`000000oooo
0?ooo`0h0?ooo`00;P3oool4000000D0oooo0`00000O0?ooo`<00000I@3oool200004@0300008P00
0140000A0080000A00@00`<30000000000000`<32`000000100005D0E@1E05D0E@0005D:00000006
0000<`0c03<0000R00008P0003<0000R0P0003<01P000280<`0c00008P000280E@1E00004@80E@1E
00D0001E05D0E@1E05D0001E05D0E@020000E@0405D0ZP0005D00000000000H0oooo0`0000070?oo
o`8000005P3oool3000001X0oooo00<000000?ooo`3oool0>03oool002l0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000001X0oooo100000000`3oool000000000001Q0?oo
o`80000R00H0000c00008P0003<0000c00008P00014200L71`0400<30`0000000`<300<30`T00000
0P0c03<01`0c06H0<`0c03<0IP0c06H0E@1E03<0IP1E05D01P00000206HcV@0600008P0003<0<`0c
03<0<`0003<0<`0c0P0002801P0S8b<0000R02<S8`0S8b<0E@1E03<0IP/0E@1E0P0000080?ooo`80
00001P3oool2000001H0oooo0P0000000`3oool0000000000002000001H0oooo00<000000?ooo`3o
ool0>03oool002@0oooo1`0000040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000F0?ooo`@00000I`3oool01@00028000140000A0000140000R00H0000A00D0000000<3
0`000000000000<30`0400000080<`1V00H0001E05D0E@0005D0001E05D0E@0005D205D0E@030000
E@1E05D0c/k>0080c/k>0P0cI/`01P00EJX0<fK<001EZP00EJX0000c03<0<`80000R00H0000c0000
8P0c03<0<`0c00008P0c06H20000E@0505D0E@0005D0E@1E05D0E@0005D00P1E05D01P0005D0E@1E
0000E@0005D0E@2Z0000E@8000001P3oool00`000000oooo0?ooo`02000000D0oooo0P00000F0?oo
o`800000103oool4000000d0oooo1P00000k0?ooo`00;`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000004P3oool4000000<0oooo00<000000?ooo`3oool0H@3oool01@00
0280000c0000<`000280000c0080000R00H0000c00008P0003<0000c00L71`00014200L71`0500<3
0`0000000`<300<30`0000000P1E05D01P0c06H0<`0c03<0IP0c06H0<`0c03<0IP80<`0c00H0<`1V
03<0<`0c06H0<`1V05D0E@0c06H30<k>cP80<`2I00H0IS>I03<0V@1V<iT0IS>I00008P0003<203<0
<`060000<`0c03<0E@1E05D0E@0c06H0E@1E0P0c06H00`1E05D0<`1V05D0E@0905D0E@0306Hcc000
0000000000H0oooo100000060?ooo`800000703oool010000000oooo0?ooo`3oool2000000/0oooo
0P00000o0?ooo`00;`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
4P3oool4000000<0oooo00<000000?ooo`3oool0H@3oool01@000280000c0000<`000280000c0080
000R00H0000c00008P0003<0000c00L71`00014200L71`0500<30`0000000`<300<30`0000000P1E
05D01P0c06H0<`0c03<0IP0c06H0<`0c03<0IP80<`0c00H0<`1V03<0<`0c06H0<`1V05D0E@0c06H3
0<k>cP80<`2I00H0IS>I03<0V@1V<iT0IS>I00008P0003<203<0<`060000<`0c03<0E@1E05D0E@0c
06H0E@1E0P0c06H00`1E05D0<`1V05D0E@0905D0E@0306Hcc000000000000100oooo0P00000L0?oo
o`040000003oool0oooo0?ooo`8000002`3oool2000003l0oooo000_0?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`@00000IP3oool01@0003<000140000A000
03<000140080000c00H0001400008P000280000R00004@00028400004@800`<300D0000000<30`00
0000000005D0E@020000E@0603<0IP0005D0<`1V03<0IP0005D0E@1E0P0005D01P1E05D0001E05D0
E@1E05D0001E05D0E@<0c/k>0P0cI/`01P00EJX0<fK<001EZP00EJX0000c03<0<`80000R00H0<`0c
0000E@0c06H0<`1V0000E@0c06H20000E@0505D0E@0005D0E@1E05D0E@0005D00P1E05D01P0005D0
E@2Z0000E@0005D0E@2Z03=Vc0<000003P3oool300000280oooo1@0000060?ooo`L00000>P3oool0
02h0oooo0P0000060?ooo`050000003oool0oooo0?ooo`0000002`3oool4000000<0oooo00<00000
0?ooo`3oool0HP3oool20000<`050000A0000280000R0000<`0002800P0003<01P000280000c0000
8P000280000c00008P80000A00H01`L700004@000000000000<30`0005D205D0E@050000E@1E05D0
E@1E03<0IP0c03<00P0c06H01P0c03<0<`1V03<0<`0c03<0<`1V05D0E@80<`1V00<0E@1E03<0IP3>
c/h00P3>c/h203<0V@0606HcV@0c09T0IS>I06HcV@000280000c0P1E05D203<0IP80E@1E00H0<`1V
05D0E@0c06H0<`1V05D0E@0c06H:05D0E@0406Hcc01EEJX00000000000h0oooo0P00000S0?ooo`80
00000`3oool2000001T0oooo100000050?ooo`<00000803oool002l0oooo00<000000?ooo`3oool0
1@3oool3000000P0oooo1@00001Y0?ooo`050000A00003<000140000A00003<00P0004@01@0003<0
001400008P000280001400<0000R00<0000A00008P0001400`00014205D0E@050000E@1E05D0001E
0000E@1E05D00P0005D01P0c06H0001E03<0IP0c06H0001E05D0E@80001E00L0E@1E0000E@1E05D0
E@1E0000E@1E05D0<fK<00<0c/k>00<0<fK<001EZP0cI/`00P00EJX01P0cI/`0<`0c0000E@0005D0
<`0c0000E@80<`1V00H0001E05D0E@0005D0001E05D0E@0005D205D0E@050000E@1E05D0E@1E0000
E@1E0:X00P0005D00`1E0:X0<fK<0:YEZP03000000`0oooo0`00000Y0?ooo`@000005`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000007`3oool002l0oooo00<000000?oo
o`3oool01@3oool3000000P0oooo1@00001Y0?ooo`050000A00003<000140000A00003<00P0004@0
1@0003<0001400008P000280001400<0000R00<0000A00008P0001400`00014205D0E@050000E@1E
05D0001E0000E@1E05D00P0005D01P0c06H0001E03<0IP0c06H0001E05D0E@80001E00L0E@1E0000
E@1E05D0E@1E0000E@1E05D0<fK<00<0c/k>00<0<fK<001EZP0cI/`00P00EJX01P0cI/`0<`0c0000
E@0005D0<`0c0000E@80<`1V00H0001E05D0E@0005D0001E05D0E@0005D205D0E@050000E@1E05D0
E@1E0000E@1E0:X00P0005D0101E0:X0<fK<0:YEZP2ZEJX2000000`0oooo0P00000Z0?ooo`@00000
5`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000007`3oool003h0oooo
1000001/0?ooo`@000140`0003<200008P060000<`000280000c0000<`000280000c0P0002801P00
03<01`L700004@000140001E05D0E@80001E00D0E@1E0000E@1E05D0E@1E0000E@0205D0E@0603<0
IP0c03<0<`1V03<0IP0c03<0<`1V0P0c03<01`0c06H0E@1E03<0IP0c06H0E@1E03<0IP0c09T00`3>
c/h00`0c09T0IS>I03<0V@0206HcV@0403<0V@0c06H0E@1E05D0E@80<`1V0P1E05D01P0c06H0E@1E
03<0IP0c06H0E@1E03<0IPX0E@1E00@0IS?<05EEZP1EEJX0IS?<0P00000:0?ooo`800000:`3oool0
10000000oooo0?ooo`3oool3000001@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000001l0oooo000k0?ooo`<000000`3oool00`000000oooo0?ooo`1R0?ooo`H0000000H0
000c0000A00003<0000c0000A00003<20000A0050000<`0004@000140000<`0004@00P0002801P00
04@0000A00008P000280000A03<0<`80001E00H0<`0c0000E@1E05D0E@1E0000E@1E05D20000E@05
05D0E@0005D0001E03<0IP0005D00P0c06H01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E00<0
001E05D0E@0cI/`00`3>c/h00`0cI/`005FZ03=Vc002001EZP0603=Vc00c03<0001E0000E@0c03<0
001E0P0c06H01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E00D0001E05D0E@1E05D0001E05D0
ZP020000E@0605D0ZP0cI/`0IVJI06IVV@0cI/`0ZUFZ0`0000060?ooo`<00000<@3oool600000100
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000001l0oooo000k0?ooo`<0
00000`3oool00`000000oooo0?ooo`1R0?ooo`H0000000H0000c0000A00003<0000c0000A00003<2
0000A0050000<`0004@000140000<`0004@00P0002801P0004@0000A00008P000280000A03<0<`80
001E00H0<`0c0000E@1E05D0E@1E0000E@1E05D20000E@0505D0E@0005D0001E03<0IP0005D00P0c
06H01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E00<0001E05D0E@0cI/`00`3>c/h00`0cI/`0
05FZ03=Vc002001EZP0603=Vc00c03<0001E0000E@0c03<0001E0P0c06H01P0005D0E@1E0000E@00
05D0E@1E0000E@80E@1E00D0001E05D0E@1E05D0001E05D0ZP020000E@0705D0ZP0cI/`0IVJI06IV
V@0cI/`0ZUFZ05EEZP0:00000380oooo1P00000@0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`00=`3oool6000004T0oooo00D005FZ05D0ZP1V<l`0IS?<05D0
ZP0206Hcc00605D0ZP0c09T0E@2Z05D0ZP1EEJX0<fJI0P1EEJX0100cIYT0IS>I03=VV@0cIYT90?oo
o`80000A1@000000100005D000140000A00005D30000A0030000<`0004@0000c0080000c0P000280
1P0003<0000R0000<`0003<0000R0000<`80000R00H0E@1E0000E@1E05D0E@1E0000E@1E05D20000
E@0505D0E@0005D0E@1E05D0E@0005D00P0c03<01P0c06H0<`0c03<0IP0c06H0<`0c03<0IP80<`0c
00L0<`1V05D0E@0c06H0<`1V05D0E@0c06H0<`2I00<0c/k>00<0<`2I06HcV@0c09T00P1V<iT00`0c
09T0<`1V05D0E@0205D0E@0503<0IP1E05D0E@1E03<0IP1E05D00P0c06H<05D0E@0503<0V@0cI/`0
<fK<05D0ZP0cI/`00P1E0:X00`0cI/`0000000000004000003P0oooo1000000>0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`00<`3oool4000004/0oooo0P0c
I/`2001EZP80<fK<0P00EJX01@0cI/`005FZ001EZP1V<l`005FZ0080IS?<00H0002Z06HcV@000:X0
002Z001EZP000:X2001EZP060000V@0c09T0002I0000V@0c09T0002I0P0c09T00`0009T0000R0000
8P04000000060000E@0003<0001E0000E@0003<000140P0003<01@0004@0000c0000A00004@0000c
0080001400H0000c0000A0000280000R0000A000014203<0IP060000E@0c03<0001E0000E@0c03<0
001E0P1E05D01@0005D0<fIV0000ZP000:X0E@1E0080001E00H0<`1V0000E@0c06H0<`1V0000E@1E
05D20000E@0705D0E@0005D0E@1E05D0E@0005D0E@1E03=Vc0030<k>cP0303=Vc000EJX0<fK<0080
05FZ00H0<fK<001EZP0005D0001E03<0IP0005D203<0IP060000E@1E05D0001E0000E@1E05D0001E
0P1E05D01@0005D0E@1E05D0E@0005D0E@2Z0080001E00H0E@2Z05EEZP1V<l`0IS?<05EEZP0cI/`2
05EEZP0303=Vc01EEJX0c/k>0080c/k>0P00EOlh0?ooo`8000000P3oool3000000X0oooo0P000006
0?ooo`050000003oool0oooo0?ooo`0000007`3oool002l0oooo100000000`3oool000000000001:
0?ooo`80c6K<00D0EJ[o0<aVc01V<l`0IS?<001EZP0306Hcc00505D0ZP1V<l`0IS?<05D0ZP0c09T0
0P1E0:X01P1EEJX0<fJI05EEZP1EEJX0<fJI06HcV@80<fJI00H005FZ05EEZP00EJX005FZ05EEZP00
EJX205EEZP05001EZP1EEJX0EEFZ001EZP1EEJX00P00EJX0101EEJX0<fJI05EEZP1EEJX40000A003
0000<`0004@0000c0080000c0P0002801P0003<0000R0000<`0003<0000R03<0<`80001E00H0E@1E
0000E@1E05D0E@1E05EEZP0cIYT205EEZP0506IVV@1EEJX0IVJI06IVV@0005D00P0c03<01P0c06H0
<`0c03<0IP0c06H0<`0c03<0IP80<`0c00H0<`1V05D0E@0c06H0<`1V05D0E@1V<iT203<0V@<0c/k>
00H0IS>I03<0V@1V<iT0IS>I03<0V@1V<iT305D0E@0503<0IP1E05D0E@1E03<0IP1E05D00P0c06H<
05D0E@0503<0V@0cI/`0<fK<03<0V@0cI/`00P1E0:X00`0cI/`0E@2Z0<k>cP020<k>cP80EEFZ00<0
IS?<0?ooo`3oool0=@3oool2000000@0oooo1@0000070?ooo`030000003oool0oooo00D0oooo0`00
000P0?ooo`00;`3oool4000000030?ooo`000000000004X0oooo0P3<I/`01@1EZ_l0c6K<06Hcc01V
<l`005FZ00<0IS?<00D0E@2Z06Hcc01V<l`0E@2Z03<0V@0205D0ZP0605EEZP0cIYT0EEFZ05EEZP0c
IYT0IS>I0P0cIYT01P00EJX0EEFZ001EZP00EJX0EEFZ001EZP80EEFZ00D005FZ05EEZP1EEJX005FZ
05EEZP02001EZP0405EEZP0cIYT0EEFZ05EEZP@0001400<0000c0000A00003<00P0003<200008P06
0000<`000280000c0000<`000280<`0c0P0005D01P1E05D0001E05D0E@1E05D0EEFZ03=VV@80EEFZ
00D0IVJI05EEZP1VIYT0IVJI0000E@0203<0<`0603<0IP0c03<0<`1V03<0IP0c03<0<`1V0P0c03<0
1P0c06H0E@1E03<0IP0c06H0E@1E06HcV@80<`2I0`3>c/h01P1V<iT0<`2I06HcV@1V<iT0<`2I06Hc
V@<0E@1E00D0<`1V05D0E@1E05D0<`1V05D0E@0203<0IP`0E@1E00D0<`2I03=Vc00cI/`0<`2I03=V
c00205D0ZP0303=Vc01E0:X0c/k>0080c/k>0P1EEJX00`1V<l`0oooo0?ooo`0e0?ooo`800000103o
ool5000000L0oooo00<000000?ooo`3oool01@3oool300000200oooo000[0?ooo`D00000CP3oool0
0`1Vc?l0<fK<03=Vc00303=Vc08005FZ00D0<fK<001EZP00EJX005FZ03=Vc002001EZP0603=Vc000
EJX0IS?<06Hcc000EJX0IS>I0P000:X01P1V<iT0002Z001EZP00EJX0002I03<0V@80002I00D0<`2I
0000V@0c09T0<`2I0000V@0203<0V@030000V@0c09T0002I00D0002I00H0<`2I06HcV@0c09T0<`2I
06HcV@0c09T2001EZP0503<0V@1EEJX0EEFZ03<0V@1EEJX00P0c09T01P1BDU80002Z059BDP1BDU80
002Z06IVIP80002Z00H0IVIV0000ZP0cIVH0<fIV0000ZP0cIVH20000ZP0505D0E@0005D0001E03<0
IP0005D00P0c06H01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E00@0001E05EEZP0cI/`0<fK<
0`3>c/h01P00EJX0<fK<001EZP00EJX0EEFZ0000V@80001E00H0<`1V0000E@0c06H0<`1V0000E@1E
05D20000E@0505D0E@0005D0E@1E05D0E@0005D00P1E05D01P0005D0E@2Z0000E@0005D0IS?<05EE
ZP80IS?<00H0EEFZ03=Vc01EEJX0EEFZ03=Vc01EEJX30<k>cP8005Go00<0EEFZ0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`020?ooo`<00000;`3oool002P0oooo100000030?ooo`030000003oool0
oooo04X0oooo102IVOl20<aVc00505FZo`3<I/`0IS?<06Hcc000EJX00`1V<l`01@1E0:X0IS?<06Hc
c01E0:X0<`2I0080E@2Z00H0<`2I03=VV@1EEJX0EEFZ03=VV@1V<iT203=VV@0606HcV@1EEJX005FZ
001EZP1EEJX005FZ0P1EEJX01@00EJX0EEFZ05EEZP00EJX0EEFZ008005FZ00@0EEFZ03=VV@1EEJX0
EEFZ1@00EJX0100cIYT005FZ001EZP0cIYT6001EZPH0EEFZ0P0cIYT01P1EEJX0<fJI05EEZP1EEJX0
IVJI05EEZP80IVJI00D0EEFZ03<0<`0c03<0<`1V03<0<`0203<0IP0603<0<`0c06H0<`0c03<0<`0c
06H0E@1E0P0c06H0101E05D0002I0000ZP000:X30<k>cP060000V@1EEJX0002I0000V@1EEJX0002I
0`1E05D01@0c06H0E@1E05D0E@0c06H0E@1E0080<`1V2`1E05D01P0cI/`0<`2I03=Vc00cI/`0<`2I
03=Vc080E@2Z00<0<fK<05D0ZP3>c/h00P3>c/h205EEZP0306Hcc03oool0oooo03L0oooo00<04@00
03<0003oool01P3oool2000000040?ooo`0000000000000002`0oooo000T0?ooo`@000000P3oool0
0`000000oooo0?ooo`1>0?ooo`050:[oo`1Vc<`0I/c<06K<o`2Zool01`0cI/`01000EJX0<fK<03=V
c00cI/`2001EZP0603=Vc000EJX0IS?<06Hcc000EJX0IS>I0P000:X01P1V<iT0002Z001EZP00EJX0
002Z03<0V@80002I00D0<`2I0000V@0c09T0<`2I0000V@0203<0V@030000V@0c09T0002I00D0002I
00H0<`2I06HcV@0c09T0<`2I06HcV@0c09T2001EZP0503<0V@1EEJX0EEFZ03<0V@1EEJX00P0c09T0
1P1BDU80002Z059BDP1BDU80002Z06IVIP80002Z00H0IVIV0000ZP1VIVH0IVIV0000ZP0cIVH20000
ZP0503=VIP0005D0001E03<0IP0005D00P1E05D01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E
00@0001E001EZP1EEJX0EEFZ0`3>c/h205EEZP80002I00H0EEFZ0000V@0005D0001E03<0IP0005D2
03<0IP060000E@1E05D0001E0000E@1E05D0001E0P1E05D01@0005D0E@2Z05D0ZP0005D0E@2Z0080
001E00H0IS?<05EEZP1V<l`0IS?<05EEZP0cI/`205EEZP0303=Vc01EEJX0c/k>0080c/k>0P00EOl0
0`1EEJX0oooo0?ooo`0]0?ooo`801`L72@0A00000`1VIYT0oooo0?ooo`090?ooo`H00000:03oool0
02@0oooo100000020?ooo`030000003oool0oooo04h0oooo00D0Z_oo06K<c01Vc<`0I/co0:[oo`07
03=Vc004001EZP0cI/`0<fK<03=Vc08005FZ00H0<fK<001EZP1V<l`0IS?<001EZP1V<iT20000ZP06
06HcV@000:X005FZ001EZP000:X0<`2I0P0009T01@0c09T0002I03<0V@0c09T0002I0080<`2I00<0
002I03<0V@0009T01@0009T01P0c09T0IS>I03<0V@0c09T0IS>I03<0V@8005FZ00D0<`2I05EEZP1E
EJX0<`2I05EEZP0203<0V@06059BDP000:X0DU9B059BDP000:X0IVIV0P000:X01P1VIVH0002Z06IV
IP1VIVH0002Z03=VIP80002Z00D0<fIV0000E@0005D0<`1V0000E@0205D0E@060000E@1E05D0001E
0000E@1E05D0001E0P1E05D0100005D005FZ05EEZP1EEJX30<k>cP80EEFZ0P0009T01P1EEJX0002I
0000E@0005D0<`1V0000E@80<`1V00H0001E05D0E@0005D0001E05D0E@0005D205D0E@050000E@1E
0:X0E@2Z0000E@1E0:X00P0005D01P1V<l`0EEFZ06Hcc01V<l`0EEFZ03=Vc080EEFZ00<0<fK<05EE
ZP00EOl00`3>c/h00`00EOl0EEFZ0?ooo`0^0?ooo`801`L72@0A00000`1VIYT0oooo0?ooo`090?oo
o`H00000:03oool00200oooo100000020?ooo`030000003oool0oooo04/0oooo00<00`<300000000
000010000000102Ic9T0Z_nZ0:[oZP2Ic9T309VIo`0605FZo`3<I/`0EJ[o05FZo`00EJX0IS?<0P00
EJX01@1E0:X0IS?<06Hcc01E0:X0<`2I0080E@2Z00H0<`2I03=VV@1EEJX0EEFZ03=VV@1V<iT203=V
V@0606HcV@1EEJX005FZ001EZP1EEJX005FZ0P1EEJX01@00EJX0EEFZ05EEZP00EJX0EEFZ008005FZ
00D0EEFZ03=VV@1EEJX0EEFZ03=VV@04001EZP0403=VV@00EJX005FZ03=VV@L005FZ1@1EEJX203=V
V@0605EEZP0cIYT0EEFZ05EEZP1VIYT0EEFZ0P1VIYT01@1EEJX0<`0c03<0<`0c06H0<`0c0080<`1V
00H0<`0c03<0IP0c03<0<`0c03<0IP1E05D203<0IP0405D0E@0009T0002Z0000ZP<0c/k>00H0002I
05EEZP0009T0002I05EEZP0009T305D0E@0503<0IP1E05D0E@1E03<0IP1E05D00P0c06H805D0E@<0
<`1V00H0<fK<03<0V@0cI/`0<fK<03<0V@0cI/`205D0ZP0303=Vc01E0:X0EEFZ00<0c/k>00<0EEFZ
06Hcc03oool0:P3oool2000000D04@000`1V<fH01P0c06H0IS=V03<0IP0c06H0VIWo03=Vo`80VIWo
2@3oool200000080oooo1000000V0?ooo`00703oool6000000X0oooo1P00000o0?ooo`@00`<31@00
00000`1Vc<`0002Z0000V@030000V@80I/co00<0Z_oo03=Vc00cI/`00P0cI/`01000EJX0<fK<03=V
c00cI/`2001EZP0603=Vc000EJX0IS?<06Hcc000EJX0IS>I0P000:X01P1V<iT0002Z001EZP00EJX0
002Z03<0V@80002I00D0<`2I0000V@0c09T0<`2I0000V@0203<0V@050000V@0c09T0002I0000V@0c
09T0100009T01@1V<iT0<`2I03<0V@1V<iT0<`2I008005FZ00D0<`2I001EZP00EJX0<`2I05EEZP02
03<0V@0605EEZP000:X0DU9B059BDP000:X0DU9B0P000:X01P1VIVH0002Z06IVIP1VIVH0002Z03=V
IP80002Z00D0<fIV0000E@0005D0<`1V0000E@0205D0E@060000E@1E05D0001E0000E@1E05D0001E
0P1E05D00`0005D005FZ05EEZP0205EEZP<0c/k>00D0EEFZ0000V@0009T0EEFZ0000V@0205EEZP06
03<0IP0005D0<`1V03<0IP0005D0E@1E0P0005D00`1E05D0001E03<0IP0203<0IP80001E00H0<`1V
0000E@0c06H0<`1V05D0ZP1EEJX206Hcc00705EEZP1V<l`0EEFZ05EEZP0cI/`0EEFZ03=Vc0030<k>
cP03001Eo`1EEJX005Go01l0oooo0P2I<c<01P1E05D0VC=V05D0E@1E05D0LW9b05D0E@80LW9b00D0
E@1E06HcV@1V<iT0E@1E06HcV@0205D0E@0603<0V@1E05D0<`2I03<0V@1E05D0EEFZ0P1E05D0101E
Z_l0IVJI05FZo`1EZ_l=0?ooo`8000000P3oool3000002<0oooo000K0?ooo`030000003oool0oooo
00`0oooo2P00000l0?ooo`0400008P030`<00`<300<30`@000000P1V<l`01P1EEJX005FZ001EZP00
EJX0IS>I001EZP80<`2I00H005FZ0<aVc01EZ_l0EJ[o0<aVc01V<l`2001EZP0505D0ZP1V<l`0IS?<
05D0ZP1V<l`00P1E0:X01P0c09T0<fJI05EEZP1EEJX0<fJI06HcV@80<fJI00H0IS>I05EEZP00EJX0
05FZ05EEZP00EJX205EEZP05001EZP1EEJX0EEFZ001EZP1EEJX00P00EJX01@1EEJX0<fJI05EEZP1E
EJX0<fJI00L005FZ00<0<fJI001EZP00EJX01@00EJX505EEZP80<fJI00H0EEFZ03=VV@1EEJX0EEFZ
06IVV@1EEJX206IVV@0505EEZP0c03<0<`0c03<0IP0c03<00P0c06H01P0c03<0<`1V03<0<`0c03<0
<`1V05D0E@80<`1V00D0E@1E0000V@0c09T0<`2I0000V@030<k>cP050000ZP0009T0002I05EEZP00
09T00P1EEJX01P1E05D0<`1V05D0E@1E05D0<`1V05D0E@<0<`1V00@0001E03<0IP0c06H0001E1P0c
06H01P00EJX0<`2I03=Vc00cI/`0<`2I03=Vc080E@2Z00<0<fK<05D0ZP0cI/`00`3>c/h00`1EEJX0
IS?<05EEZP0B0?ooo`0505D0002Z05D0ZP1E05D0E@2Z05D00P2I<c<01P1E05D0VC<c05D0E@1E05D0
IS=V09Tc<aD0IS=V00H0<`1V06HcIP0c06H0<`1V09VIo`0cI_l209VIoa<0oooo1@00000O0?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`@000001P3oool4000003X0oooo00@0000R00<30`030`<0
0`<31000000206Hcc00605EEZP00EJX005FZ001EZP1V<iT005FZ0P0c09T01P00EJX0c6K<05FZo`1E
Z_l0c6K<06Hcc08005FZ00D0E@2Z06Hcc01V<l`0E@2Z06Hcc00205D0ZP0603<0V@0cIYT0EEFZ05EE
ZP0cIYT0IS>I0P0cIYT01P1V<iT0EEFZ001EZP00EJX0EEFZ001EZP80EEFZ00D005FZ05EEZP1EEJX0
05FZ05EEZP02001EZP0505EEZP0cIYT0EEFZ05EEZP0cIYT01`00EJX00`0cIYT005FZ001EZP05001E
ZPD0EEFZ0P0cIYT01P1EEJX0<fJI05EEZP1EEJX0IVJI05EEZP80IVJI00D0EEFZ03<0<`0c03<0<`1V
03<0<`0203<0IP0603<0<`0c06H0<`0c03<0<`0c06H0E@1E0P0c06H01@1E05D0002I03<0V@0c09T0
002I00<0c/k>00D0002Z0000V@0009T0EEFZ0000V@0205EEZP0605D0E@0c06H0E@1E05D0E@0c06H0
E@1E0`0c06H0100005D0<`1V03<0IP0005D603<0IP06001EZP0c09T0<fK<03=Vc00c09T0<fK<0P1E
0:X00`0cI/`0E@2Z03=Vc0030<k>cP0305EEZP1V<l`0EEFZ0180oooo00D0E@000:X0E@2Z05D0E@1E
0:X0E@0209Tc<`0605D0E@2I<c<0E@1E05D0E@1V<fH0VC<c5@1V<fH01P0c06H0IS=V03<0IP0c06H0
VIWo03=Vo`80VIWo4`3oool5000001l0oooo000W0?ooo`<000002P3oool3000003P0oooo00<0000R
00004@030`<00P030`<3000000<005FZ00<0<fJI0000ZP0009T01@0009T00`0c06H0002I03=Vc002
03=Vc003001EZP0cI/`0<fK<00<005FZ00H0<fK<001EZP1V<l`0IS?<001EZP1V<l`20000ZP0606Hc
V@000:X005FZ001EZP000:X005FZ0P0009T01@0c09T0002I03<0V@0c09T0002I0080<`2I00D0002I
03<0V@0009T0002I03<0V@040000V@0506HcV@0c09T0<`2I06HcV@0c09T00P00EJX01@0c09T005FZ
001EZP0c09T0EEFZ0080<`2I00H0EEFZ0000ZP1BDU80DU9B0000ZP1BDU820000ZP0606IVIP000:X0
IVIV06IVIP000:X0<fIV0P000:X01@0cIVH0001E0000E@0c06H0001E0080E@1E00H0001E05D0E@00
05D0001E05D0E@0005D205D0E@030000E@00EJX0EEFZ0080EEFZ0`3>c/h01@1EEJX0002I0000V@1E
EJX0002I0080EEFZ00H0<`1V0000E@1E05D0E@1E03<0IP1E05D703<0IP80001E00H0<`1V0000E@0c
06H0<`1V05D0ZP1EEJX206Hcc00705EEZP1V<l`0EEFZ05EEZP0cI/`0EEFZ03=Vc0030<k>cP03001E
o`1EEJX005Go00h0oooo00<0<`0005D0001E0000101E00001P2Z05D0E@0009Tc002I<`00E@1E09Tc
0080E@1E00H0VC<c05D0E@2I<c<0VC<c05D0E@2I<fH205D0E@05079bLP1E05D0LW9b079bLP1E05D0
0P1V<iT01P1E05D0IS>I05D0E@1E05D0<`2I05D0E@80EEFZ00H0E@1E05EEZP1E05D0E@1E05FZo`1V
IYT205FZo`0306IVV@3oool0oooo0100oooo00@000000?ooo`3oool0oooo1000000L0?ooo`009`3o
ool2000000D0oooo0P0000050?ooo`800000<P3oool400000080000R00@0000A00<30`030`<00`<3
0P00000206IVV@<0IS?<00H0EEFZ001EZP1EEJX0EEFZ06HcV@00EJX203<0V@06001EZP0c09T0002I
0000V@0cIYT0IS?<0P00EJX306Hcc00605D0ZP1V<l`0E@2Z05D0ZP0c09T0E@2Z0P1EEJX01P0cIYT0
EEFZ03=VV@0cIYT0IS>I03=VV@8005FZ00D0EEFZ001EZP1EEJX0EEFZ001EZP0205EEZP06001EZP1E
EJX005FZ001EZP1EEJX0<fJI0P1EEJX00`0cIYT005FZ001EZP05001EZP0303=VV@00EJX005FZ00D0
05FZ1@1EEJX203=VV@0605EEZP0cIYT0EEFZ05EEZP1VIYT0EEFZ0P1VIYT01@1EEJX0<`0c03<0<`0c
06H0<`0c0080<`1V00H0<`0c03<0IP0c03<0<`0c03<0IP1E05D203<0IP0503<0V@0009T0<`2I03<0
V@0009T00`3>c/h01@000:X0002I0000V@1EEJX0002I0080EEFZ00H0E@1E03<0IP0005D0001E03<0
IP0005D303<0IP040000E@0c06H0<`1V0000E@H0<`1V00H005FZ03<0V@0cI/`0<fK<03<0V@0cI/`2
05D0ZP0303=Vc01E0:X0<fK<00<0c/k>00<0EEFZ06Hcc01EEJX0101E000206HcIP0605D0E@1V<fH0
VC<c09Tc<`2I<fH0VC<c0P0c00001@2Z0000E@000:X0002Z0000E@1E0080ZP1E00D0E@1E0:X0E@2I
<c<0VC<c05D0E@0309Tc<`0306HcIP2I<c<0IS=V01@0IS=V00H0<`1V06HcIP0c06H0<`1V09VIo`0c
I_l209VIo`0303=Vo`3oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`009P3o
ool2000000H0oooo0P0000060?ooo`800000<03oool4000000040000<`000140000A00008P<00`<3
00D000000:YEo`0cI/`0<fK<0:YEo`02001EZP0403=VV@000:X0<fJI03=VV@@0002I00H0<`1V0000
V@00EED005EE0000V@00EED203=Vc0<005FZ00H0<fK<001EZP1V<l`0IS?<001EZP1V<l`20000ZP06
06HcV@000:X005FZ001EZP000:X005FZ0P0009T01@0c09T0002I03<0V@0c09T0002I0080<`2I00D0
002I03<0V@0009T0002I03<0V@040000V@0506HcV@0c09T0<`2I06HcV@0c09T00P00EJX01@0c09T0
05FZ001EZP0c09T0EEFZ0080<`2I00H0EEFZ0000ZP1BDU80DU9B0000ZP1BDU820000ZP0606IVIP00
0:X0IVIV06IVIP000:X0<fIV0P000:X01@0cIVH0002Z0000ZP0c06H0001E0080E@1E00H0001E05D0
E@0005D0001E05D0E@0005D205D0E@0305EEZP00EJX0EEFZ0080EEFZ0`3>c/h01@1EEJX0002I0000
V@1EEJX0002I0080EEFZ0P0c06H205D0E@0303<0IP1E05D0<`1V00H0<`1V0P0005D01P0c06H0001E
05EEZP1EEJX0E@2Z05EEZP80IS?<00L0EEFZ06Hcc01EEJX0EEFZ03=Vc01EEJX0<fK<00<0c/k>00<0
05Go05EEZP00EOl00P2I<c<01P2Z05D0VC<c0:X0E@2Z05D0VC<c0:X0E@80IS=V00H0VC=V06HcIP1V
<iT0IS>I06HcIP1V<iT205D000050:X0E@1E0000E@000:X0E@1E05D00P2I<`001P1E05D0VC<005D0
E@1E05D0VC<c05D0E@80VC=V00H0E@1E09TcIP1E05D0E@1E079bLP1E05D2079bLP0505D0E@1V<iT0
IS>I05D0E@1V<iT00P1E05D01P0c09T0E@1E05EEZP1EEJX0E@1E05EEZP80IVJI00D0EJ[o06IVV@0c
I_l0<fKo06IVV@0f0?ooo`009P3oool2000000H0oooo0P0000060?ooo`800000<03oool400000004
0000<`000140000A00008P<00`<300D000000:YEo`0cI/`0<fK<0:YEo`02001EZP0403=VV@000:X0
<fJI03=VV@@0002I00H0<`1V0000V@00EED005EE0000V@00EED203=Vc0<005FZ00H0<fK<001EZP1V
<l`0IS?<001EZP1V<l`20000ZP0606HcV@000:X005FZ001EZP000:X005FZ0P0009T01@0c09T0002I
03<0V@0c09T0002I0080<`2I00D0002I03<0V@0009T0002I03<0V@040000V@0506HcV@0c09T0<`2I
06HcV@0c09T00P00EJX01@0c09T005FZ001EZP0c09T0EEFZ0080<`2I00H0EEFZ0000ZP1BDU80DU9B
0000ZP1BDU820000ZP0606IVIP000:X0IVIV06IVIP000:X0<fIV0P000:X01@0cIVH0002Z0000ZP0c
06H0001E0080E@1E00H0001E05D0E@0005D0001E05D0E@0005D205D0E@0305EEZP00EJX0EEFZ0080
EEFZ0`3>c/h01@1EEJX0002I0000V@1EEJX0002I0080EEFZ0P0c06H205D0E@0303<0IP1E05D0<`1V
00H0<`1V0P0005D01P0c06H0001E05EEZP1EEJX0E@2Z05EEZP80IS?<00L0EEFZ06Hcc01EEJX0EEFZ
03=Vc01EEJX0<fK<00<0c/k>00<005Go05EEZP00EOl00P2I<c<01P2Z05D0VC<c0:X0E@2Z05D0VC<c
0:X0E@80IS=V00H0VC=V06HcIP1V<iT0IS>I06HcIP1V<iT205D000050:X0E@1E0000E@000:X0E@1E
05D00P2I<`001P1E05D0VC<005D0E@1E05D0VC<c05D0E@80VC=V00H0E@1E09TcIP1E05D0E@1E079b
LP1E05D2079bLP0505D0E@1V<iT0IS>I05D0E@1V<iT00P1E05D01P0c09T0E@1E05EEZP1EEJX0E@1E
05EEZP80IVJI00D0EJ[o06IVV@0cI_l0<fKo06IVV@0f0?ooo`009@3oool2000000@0oooo1P000006
0?ooo`800000;P3oool01P071`L00000000000000000000R00004@80000R00H0000A00<30`030`<0
0`<30000001EZ_l206IVV@0505FZo`1V<l`0IS?<06Hcc000EJX00P1EEJX01P1V<iT005FZ06HcV@1V
<iT005FZ03<0V@80002I00D0<fJI0000V@00EJX005FZ0000V@02001EZP0605D0ZP1V<l`0E@2Z05D0
ZP0c09T0E@2Z0P1EEJX01P0cIYT0EEFZ03=VV@0cIYT0IS>I03=VV@8005FZ00D0EEFZ001EZP1EEJX0
EEFZ001EZP0205EEZP06001EZP1EEJX005FZ001EZP1EEJX0<fJI0P1EEJX00`0cIYT0EEFZ001EZP05
001EZP0303=VV@00EJX005FZ00D005FZ201EEJX01@0cIYT0EEFZ05EEZP0cIYT0EEFZ0080IVJI00D0
EEFZ06IVV@1VIYT0<`1V03<0<`0203<0IP0603<0<`0c06H0E@1E05D0E@0c06H0E@1E0P0c06H01P0c
09T0002I03<0V@0c09T0002I0000ZP<0c/k>0P0009T01P1EEJX0002I05EEZP1EEJX0001E03<0IP80
001E00<0<`1V0000E@0c06H00P0c06H00`0005D0<`1V03<0IP0503<0IP80IS?<00H005FZ06Hcc00c
I/`0<fK<03<0V@0cI/`203<0V@0403=Vc01E0:X0<fK<03=Vc0<0c/k>00H0IS?<05EEZP1V<l`0IS?<
05D0001E05D206HcIP0605D0E@2I<fH0VC<c09Tc<`2I<fH0VC<c102I<fH206HcV@0509TcIP1V<iT0
IS>I09TcIP2I<iT00P1V<fH01P2I<iT0VC<c09Tc<`2I<c<0IS=V09Tc<aD0IS=V00H0<`1V06HcIP2I
VL`0VIW<06Hcc02IVL`206Hcc00309VIc03oool0oooo03@0oooo000U0?ooo`800000103oool20000
00030?ooo`000000000000L0oooo0P00000[0?ooo`03000000030`<00`<3008000000P0003<20000
8P80000A0P030`<2000000050000V@00EED0<fK<03=Vc02ZEOl00`00EJX00`000:X0<fJI03=VV@04
0000V@0603<0IP0009T0<`1V03<0IP0009T005EE0P0009T01@0cIVH0002I0000V@0cI/`005FZ0080
IS?<00H005FZ06Hcc0000:X0002Z06HcV@000:X2001EZP060000ZP00EJX0002I0000V@0c09T0002I
0P0c09T01@0009T0<`2I03<0V@0009T0<`2I0080002I00<0<`2I0000V@0009T00`0009T203<0V@05
06HcV@0c09T005FZ001EZP0c09T00P00EJX01P0c09T0EEFZ03<0V@0c09T0EEFZ03<0V@80DU9B00H0
002Z059BDP000:X0002Z06IVIP000:X206IVIP050000ZP0cIVH0002Z0000ZP0cIVH00P000:X01P0c
06H0001E05D0E@1E05D0001E05D0E@80001E00H0E@1E0000A00c03<0<`0c05EEZP00EJX405EEZP<0
c/k>0P0009T0101EEJX0002I05EEZP1EEJX203<0IP80E@1E00<0<`1V05D0E@0c06H01P0c06H20000
E@0603<0IP0005D0EEFZ05EEZP1E0:X0EEFZ0P1V<l`01P1EEJX0IS?<05EEZP1EEJX0<fK<05EEZP80
<fK<0`3>c/h01P1EEJX005Go05EEZP1EEJX0ZP1E09Tc<`80ZP1E00H0VC<c09TcIP1V<fH0IS=V09Tc
IP1V<fH206HcV@0306HcIP1V<iT0IS=V00H0IS=V0P2I<iT506HcIP0505D0E@2I<fH0VC=V05D0E@2I
<fH00P1E05D01@1bLW80E@1E079bLP1bLW80E@1E0080IS>I00H0E@1E03<0V@1E05D0E@1E03<0V@1E
05D205EEZP0605D0E@1EEJX0IVJI06IVV@0cI_l0IVJI0P0cI_l00`1VIYT0oooo0?ooo`0d0?ooo`00
9@3oool2000000D0oooo00@000000?ooo`00000000001`3oool2000002P0oooo0`0000000`071`L0
000A00004@0200000080000A00@0000R00004@000280000R0P030`<3001EZP040000V@0007L0001g
05FZo`<0IS?<00D005FZ05EEZP1EEJX0IS>I001EZP0206HcV@06001EZP0c09T005FZ001EZP0cIYT0
002I0P00EJX01@0009T005FZ001EZP0009T0IS?<0080E@2Z00H0<`2I05D0ZP1EEJX0EEFZ03=VV@1E
EJX203=VV@0606HcV@0cIYT005FZ001EZP1EEJX005FZ0P1EEJX01@00EJX0EEFZ05EEZP00EJX0EEFZ
008005FZ00H0EEFZ001EZP1EEJX0EEFZ03=VV@1EEJX6001EZP0403=VV@00EJX005FZ03=VV@D005FZ
1`1EEJX01@0cIYT0EEFZ05EEZP0cIYT0EEFZ0080IVJI00D0EEFZ06IVV@1VIYT0<`1V03<0<`0203<0
IP0603<0<`0c06H0E@1E05D0E@0c06H0E@1E0P0c06H01P0c09T0002I03<0V@0c09T0002I0000ZP<0
c/k>0P0009T01P1EEJX0c/k>05EEZP1EEJX0001E03<0IP80001E00H0<`1V0000E@0005D0001E03<0
IP0005D703<0IP80<`2I00H0IS>I06Hcc00cI/`0<fK<03<0V@0cI/`203<0V@0403=Vc01E0:X0<fK<
03=Vc0<0c/k>00H0IS?<05EEZP1V<l`0IS?<079bLP1V<iT206HcIP0405D0E@2I<fH0VC<c09Tc<`H0
VC=V0P1V<iT01@2I<fH0IS>I06HcV@2I<fH0VC>I0080IS=V00H0VC>I06HcV@2I<fH0VC=V06HcV@1V
<fH206HcV@0606HcIP1V<iT0E@1E05D0E@1V<iT0E@1E2P1V<fH01@0c06H0IS=V06HcIP1V<fH0<`2I
0080VIW<00D0IS?<09VIc01V<l`0IS?<09VIc00f0?ooo`009@3oool2000000D0oooo100000070?oo
o`800000:03oool30000000300L71`000140000A008000000P00014010000280000A00008P000282
00<30`<005FZ00@0002I0000M`0007L0EJ[o0`1V<l`01@00EJX0EEFZ05EEZP1V<iT005FZ0080IS>I
00H005FZ03<0V@00EJX005FZ03=VV@0009T2001EZP050000V@00EJX005FZ0000V@1V<l`00P1E0:X0
1P0c09T0E@2Z05EEZP1EEJX0<fJI05EEZP80<fJI00H0IS>I03=VV@00EJX005FZ05EEZP00EJX205EE
ZP05001EZP1EEJX0EEFZ001EZP1EEJX00P00EJX01P1EEJX005FZ05EEZP1EEJX0<fJI05EEZPH005FZ
00@0<fJI001EZP00EJX0<fJI1@00EJX705EEZP0503=VV@1EEJX0EEFZ03=VV@1EEJX00P1VIYT01@1E
EJX0IVJI06IVV@0c06H0<`0c0080<`1V00H0<`0c03<0IP1E05D0E@1E03<0IP1E05D203<0IP0603<0
V@0009T0<`2I03<0V@0009T0002Z1`3>c/h205EEZP050000E@0c06H0001E0000E@0c06H00`0005D0
0`0c06H0001E03<0IP0603<0IP80<`2I00H0IS>I06Hcc00cI/`0<fK<03<0V@0cI/`203<0V@0403=V
c01E0:X0<fK<03=Vc0<0c/k>00H0IS?<05EEZP1V<l`0IS?<079bLP1V<iT206HcIP0405D0E@2I<fH0
VC<c09Tc<`H0VC=V0P1V<iT01@2I<fH0IS>I06HcV@2I<fH0VC>I0080IS=V00H0VC>I06HcV@2I<fH0
VC=V06HcV@1V<fH206HcV@0606HcIP1V<iT0E@1E05D0E@1V<iT0E@1E2P1V<fH01@0c06H0IS=V06Hc
IP1V<fH0<`2I0080VIW<00D0IS?<09VIc01V<l`0IS?<09VIc00f0?ooo`009@3oool2000000L0oooo
0P0000070?ooo`8000009`3oool40000000500004@030`<00`<30000000002800P0003<200008P80
000A00H00`<30000ZP00EED005EE0000ZP00EED20000V@03001EE@0cI/`0<fK<008005FZ0P0cIYT4
0000V@0603<0IP0009T0<`1V03<0IP0009T005EE0P0009T01@0cIVH0002I0000V@0cIVH0002I0080
<fK<00H005FZ06Hcc0000:X0002Z06HcV@000:X2001EZP060000ZP00EJX0002Z0000ZP0c09T0002I
0P0c09T01@0009T0<`2I03<0V@0009T0<`2I0080002I00<0<`2I0000V@0009T00`0009T203<0V@05
06HcV@0c09T0IS>I06HcV@0c09T00P00EJX01P0c09T0EEFZ03<0V@0c09T0EEFZ03<0V@80DU9B00H0
002Z059BDP000:X0002Z06IVIP000:X206IVIP050000ZP0cIVH0002Z0000ZP0cIVH00P000:X01P1E
05D0001405D0E@1E05D0001405D0E@80001400D0<`0c0000A00c03<0<`0c05EEZP0;0<k>cP030000
V@1EEJX0EEFZ0080<`1V0P1E05D00`0c06H0E@1E03<0IP0603<0IP80001E00H0<`1V0000E@0cI/`0
<fK<0000V@0cI/`206Hco`0605EEZP1V<ol0EEFZ05EEZP1V<l`0EEFZ0P1V<l`30<k>cP0605EEZP00
EOl0EEFZ05EEZP1V<fH0VC=V0`1V<fH01@2I<fH0IS=V06HcIP2I<fH0IS=V0080IS>I00<0IS=V06Hc
V@1V<fH0101V<fH0102I<iT0IS=V09TcV@2I<iT<06HcIP0306HcV@1V<fH0IS=V00X0IS=V0P1E05D0
1P1V<fH0E@1E06IVV@1VIYT0EEGo06IVV@80<fKo00<0IVJI03=Vo`0cI_l0=03oool002D0oooo0P00
000@0?ooo`8000009@3oool50000000300004@071`L000000080000000D0000R00004@000140000R
00004@0300<30`0503<0V@00EJX005FZ03<0V@0009T00P0007L00`0009T0001g0000M`0206Hcc080
EEFZ0P00EJX206HcV@06001EZP0c09T005FZ001EZP0cIYT0002I0P0cIYT01@0009T005FZ001EZP00
09T005FZ0080002I00H0<`2I05D0ZP0c09T0<`2I03=VV@1EEJX203=VV@0606HcV@0cIYT0IS>I06Hc
V@1EEJX005FZ0P1EEJX01@00EJX0EEFZ05EEZP00EJX0EEFZ008005FZ00H0EEFZ001EZP1EEJX0EEFZ
03=VV@1EEJX6001EZP0403=VV@00EJX005FZ03=VV@D005FZ1`1EEJX01@0cIYT0EEFZ05EEZP0cIYT0
EEFZ0080IVJI00D0EEFZ06IVV@1VIYT0<`1V03<0<`0203<0IP0603<0<`0c06H0E@1E05D0E@0c06H0
E@1E0P0c06H00`0c09T0002I0<k>cP090<k>cP050000V@1EEJX0EEFZ0000V@0c06H00P0005D01P0c
06H0001E0000E@0005D0<`1V0000E@L0<`1V0P0c09T01P1V<iT0<`2I001EZP00EJX0E@2Z001EZP80
E@2Z00@0<fK<03<0V@0cI/`0<fK<0`3>c/h01P1V<l`0EEFZ06Hcc01V<l`0LW9b06HcV@80LW9b00@0
KVi^06HcV@2I<c<0VC<c1P2I<fH206HcV@0509TcIP1V<iT0IS>I06HcIP2I<iT00P1V<fH01P2I<fH0
IS>I09TcIP2I<fH0IS>I06HcIP80IS>I00H0IS=V06HcV@1E05D0E@1E06HcV@1E05D206HcV@0503<0
IP1V<iT0IS>I03<0IP1E0:X00P1:BTX01P1E0:X0IS=V03<0V@0c09T0IS=V03<0V@80VIW<00D0IS?<
09VIc01V<l`0IS?<09VIc00206Hcc3@0oooo000V0?ooo`8000003P3oool2000002D0oooo1P000000
0`030`<0000A000000020000000500008P0003<0000c00004@0002800P030`<01P1V<l`005FZ001E
E@00EED0002Z001EE@80002I00<005EE0000V@0009T00P00EJX203=VV@060000ZP0009T0002I0000
V@0c06H0002I0P0c06H01@0009T005EE0000V@0009T0<fIV0080002I00H0<fIV0000V@0cIVH0<fIV
0000V@0cIVH2001EZP0606HcV@000:X0IS>I06HcV@000:X005FZ0P000:X01@0c09T0002I03<0V@0c
09T0002I0080<`2I00D0002I03<0V@0009T0002I03<0V@050000V@80<`2I00D0IS>I03<0V@1V<iT0
IS>I03<0V@02001EZP0603<0V@1EEJX0<`2I03<0V@1EEJX0<`2I0P1BDU801P000:X0DU9B0000ZP00
0:X0IVIV0000ZP80IVIV00D0002Z03=VIP000:X0002Z03=VIP020000ZP0603=VIP0004@0E@1E05D0
E@0004@0E@1E0P0004@01`0c03<0001403=VV@0cIYT0EEFZ001EZP1EEJX02@3>c/h01@0009T0EEFZ
05EEZP0009T0<`1V0080E@1E00<0<`1V05D0E@0c06H01P0c06H20000E@0603<0IP0005D0<fK<03=V
c00009T0<fK<0P1V<ol01P1EEJX0IS?o05EEZP1EEJX0IS?<05EEZP80IS?<0`3>c/h01P1EEJX005Go
05EEZP1EEJX0IS=V09TcIP80IS=V00H0VC=V06i^KP2I<fH0VC=V06HcV@1V<fH206HcV@L0IS=V00@0
VC>I06HcIP2I<iT0VC>I301V<fH00`1V<iT0IS=V06HcIP0:06HcIP80E@1E00H0IS=V05D0E@1VIYT0
IVJI05EEo`1VIYT203=Vo`0306IVV@0cI_l0<fKo03@0oooo000V0?ooo`8000003P3oool2000002D0
oooo1P0000000`030`<0000A000000020000000500008P0003<0000c00004@0002800P030`<01P1V
<l`005FZ001EE@00EED0002Z001EE@80002I00<005EE0000V@0009T00P00EJX203=VV@060000ZP00
09T0002I0000V@0c06H0002I0P0c06H01@0009T005EE0000V@0009T0<fIV0080002I00H0<fIV0000
V@0cIVH0<fIV0000V@0cIVH2001EZP0606HcV@000:X0IS>I06HcV@000:X005FZ0P000:X01@0c09T0
002I03<0V@0c09T0002I0080<`2I00D0002I03<0V@0009T0002I03<0V@050000V@80<`2I00D0IS>I
03<0V@1V<iT0IS>I03<0V@02001EZP0603<0V@1EEJX0<`2I03<0V@1EEJX0<`2I0P1BDU801P000:X0
DU9B0000ZP000:X0IVIV0000ZP80IVIV00D0002Z03=VIP000:X0002Z03=VIP020000ZP0603=VIP00
04@0E@1E05D0E@0004@0E@1E0P0004@01P0c03<0001403=VV@0cIYT0EEFZ001EZP80EEFZ1`3>c/h0
1P1EEJX0002I05EEZP1EEJX0002I03<0IP80E@1E00<0<`1V05D0E@0c06H01P0c06H20000E@0603<0
IP0005D0<fK<03=Vc00009T0<fK<0P1V<ol01P1EEJX0IS?o05EEZP1EEJX0IS?<05EEZP80IS?<0`3>
c/h01P1EEJX005Go05EEZP1EEJX0IS=V09TcIP80IS=V00H0VC=V06i^KP2I<fH0VC=V06HcV@1V<fH2
06HcV@L0IS=V00@0VC>I06HcIP2I<iT0VC>I301V<fH00`1V<iT0IS=V06HcIP0:06HcIP80E@1E00H0
IS=V05D0E@1VIYT0IVJI05EEo`1VIYT203=Vo`0306IVV@0cI_l0<fKo03@0oooo000W0?ooo`800000
303oool2000002D0oooo00<0000000<30`0000000P00000300004@0300L71`00000000000080000R
0P0001401P000280000A05FZo`1EZ_l0IS?<0000ZP8005FZ00D0<`2I0000V@00EJX005FZ0000V@02
0000M`040000V@1V<l`0EEFZ05EEZP8005FZ0P1V<iT01P00EJX0<`2I001EZP00EJX0<fJI0000V@80
<fJI00D0002I001EZP00EJX0002I001EZP020000V@06001EZP0009T005FZ001EZP0cIYT0EEFZ0P0c
IYT01P1V<iT0<fJI06HcV@1V<iT0EEFZ001EZP80EEFZ00D005FZ05EEZP1EEJX005FZ05EEZP02001E
ZP0605EEZP00EJX0EEFZ05EEZP0cIYT0EEFZ1P00EJX0100cIYT005FZ001EZP0cIYT5001EZPL0EEFZ
00D0<fJI05EEZP1EEJX0<fJI05EEZP0206IVV@0505EEZP1VIYT0IVJI05EEZP0c03<00P0c06H01P0c
03<0<`1V05D0E@1E05D0<`1V05D0E@80002I00D0<`2I0000V@0c09T0<`2I0000V@060<k>cP0605EE
ZP0009T0EEFZ05EEZP0009T0<`1V0P0005D01P0c06H0001E0000E@0005D0<`1V0000E@H0<`1V00D0
002Z03<0V@0c09T0IS>I03<0V@0206HcV@0605D0ZP00EJX0E@2Z05D0ZP00EJX0<`2I0P0cI/`30<k>
cP0606Hcc01EEJX0IS?<06Hcc01EEJX0IS>I0P1bLW801P1^KVh0IS>I06i^KP1^KVh0VC>I07IfMP@0
VC=V0P1V<iT01@2I<fH0IS>I06HcV@1V<fH0VC>I0080IS=V00H0VC=V06HcV@2I<fH0VC=V06HcV@1V
<fH206HcV@0606HcIP1V<iT0E@1E05D0E@1V<iT0E@1E0P1V<iT01@0c06H0IS>I06HcV@0c06H0E@2Z
0080BTY:00H0E@2Z06HcIP0c09T0<`2I06HcIP1V<l`209VIc00506Hcc02IVL`0IS?<06Hcc02IVL`0
0P1V<l`d0?ooo`009`3oool3000000X0oooo0`00000S0?ooo`L000000P0002801P030`<000000000
00000000000c00008P80000c00H0000A00<30`0009T0002I06Hcc000EJX2001EE@050000ZP00EED0
002I0000V@00EED00P0009T01@00EED0002I001EZP00EJX0002Z00D0002I0P0c06H01@0009T005EE
0000V@0009T0<fIV0080002I00H0<fIV0000V@0cIVH0<fIV0000V@0cIVH20000V@060000M`0009T0
IS>I06HcV@000:X005FZ0P000:X01@0c09T0002I03<0V@0c09T0002I0080<`2I00D0002I03<0V@00
09T0002I03<0V@070000V@0506HcV@0c09T0IS>I06HcV@0c09T00P00EJX01P0c09T005FZ03<0V@0c
09T0EEFZ03<0V@80EEFZ00H0002Z059BDP000:X0002Z059BDP000:X206IVIP050000ZP1VIVH0002Z
0000ZP0cIVH00P000:X01P0cIVH0001405D0E@1E05D0001403<0<`80001400H0<`0c0000A00cIYT0
<fJI05EEZP00EJX205EEZP03001EZP1EEJX0c/k>00@0c/k>00H0EEFZ0000V@1EEJX0EEFZ0000V@0c
06H205D0E@0303<0IP1E05D0<`1V00<0<`1V0P0005D01@0c06H0001E0000E@0c06H005FZ0080<fK<
00H0002I03=Vc00009T0002I05EEZP1V<ol205EEZP0506Hco`1EEJX0IS?<06Hcc01EEJX00`3>c/h0
1@00EOl0EEFZ05EEZP00EOl0VC=V0080KVi^00H0VC=V06i^KP2I<fH0VC=V09TcV@1V<fH209TcV@L0
IS=V00@0VC>I06HcIP2I<iT0VC>I2@1V<fH0101V<iT0IS=V06HcIP1V<iT<06HcIP80E@1E00H0IS=V
05EEo`1VIYT0IVJI05EEo`1VIYT203=Vo`0306IVV@0cI_l0<fKo00`0oooo00<0DU9B06HcIP3oool0
9@3oool002P0oooo100000060?ooo`@00000903oool700000080000R00H00`<30000000000000000
0000<`0002820000<`0600004@030`<0002I0000V@1V<l`005FZ0P00EED01@000:X005EE0000V@00
09T005EE0080002I00D005EE0000V@00EJX005FZ0000ZP050000V@80<`1V00D0002I001EE@0009T0
002I03=VIP020000V@0603=VIP0009T0<fIV03=VIP0009T0<fIV0P0009T01P0007L0002I06HcV@1V
<iT0002Z001EZP80002Z00D0<`2I0000V@0c09T0<`2I0000V@0203<0V@050000V@0c09T0002I0000
V@0c09T01`0009T01@1V<iT0<`2I06HcV@1V<iT0<`2I008005FZ00H0<`2I001EZP0c09T0<`2I05EE
ZP0c09T205EEZP060000ZP1BDU80002Z0000ZP1BDU80002Z0P1VIVH01@000:X0IVIV0000ZP000:X0
<fIV0080002Z00H0<fIV0000A01E05D0E@1E0000A00c03<20000A00603<0<`0004@0<fJI03=VV@1E
EJX005FZ0P1EEJX00`00EJX0EEFZ05EEZP030<k>cP80EEFZ00D0002I05EEZP1EEJX0002I03<0IP02
05D0E@0303<0IP1E05D0<`1V00<0<`1V0P0005D01@0c06H0001E0000E@0c06H005FZ0080<fK<00H0
002I03=Vc00009T0002I05EEZP1V<ol205EEZP0506Hco`1EEJX0IS?<06Hcc01EEJX00`3>c/h01@00
EOl0EEFZ05EEZP00EOl0VC=V0080KVi^00H0VC=V06i^KP2I<fH0VC=V09TcV@1V<fH209TcV@L0IS=V
00@0VC>I06HcIP2I<iT0VC>I2@1V<fH0101V<iT0IS=V06HcIP1V<iT<06HcIP80E@1E00H0IS=V05EE
o`1VIYT0IVJI05EEo`1VIYT203=Vo`0306IVV@0cI_l0<fKo00`0oooo00<0DU9B06HcIP3oool09@3o
ool002X0oooo2P0000070?ooo`80<fKo00@0EJ[o0000ZP00EJX005FZ603oool30000000500<30`00
000000000000000002800P071`L01P00014000000000<`0003<0000A00008P80000A00H0000R0000
V@0009T0002I0000M`000:X2001EZP0503<0V@00EJX005FZ001EZP0009T00P0007L0100009T0001V
0000V@0009T2001EZP80IS>I00H005FZ03<0V@00EJX005FZ03<0V@0009T203=VV@050000V@00EJX0
05FZ0000V@00EJX00P0009T00`00EJX0002I001EZP02001EZP0503<0V@00EJX005FZ06HcV@0cIYT0
0P1V<iT01@0cIYT005FZ05EEZP1EEJX005FZ0080EEFZ00H005FZ05EEZP00EJX005FZ05EEZP00EJX2
05EEZP0403=VV@1EEJX0<fJI03=VV@@005FZ00@0<fJI001EZP00EJX0<fJI1`00EJX505EEZP0503=V
V@1EEJX0EEFZ03=VV@1EEJX00P1VIYT01@1EEJX0IVJI06IVV@1EEJX0<`0c0080<`1V00H0<`0c03<0
IP1E05D0E@1E03<0IP1E05D20000V@0503<0V@0009T0<`2I03<0V@0009T00P000:X01P0009T0c/k>
0<k>cP0009T0EEFZ0000V@80EEFZ00D0002I03<0IP0005D0001E03<0IP030000E@0303<0IP0005D0
<`1V00D0<`1V00D0002Z03<0V@0c09T0IS>I03<0V@0206HcV@0605D0ZP00EJX0E@2Z05D0ZP00EJX0
<`2I0P0cI/`01@0c09T0c/k>0<k>cP3>c/h0EEFZ0080IS?<00H0EEFZ06HcV@1V<iT0IS>I06i^KP1V
<iT206i^KP0609TcV@1fMWH0VC>I09TcV@1fMWH0VC>I0P1bLW801@2I<fH0VC>I09TcV@1V<fH0VC>I
0080IS=V00H0VC=V06HcV@2I<fH0VC=V06HcV@1V<fH206HcV@0606HcIP1V<iT0E@1E05D0E@1V<iT0
E@1E0P1V<iT01@0c06H0IS>I06HcV@1:BTX0E@2Z0080BTY:00H0E@2Z06HcIP0c09T0<`2I06HcIP1V
<l`209VIc00506Hcc02IVL`0IS?<06Hcc02IVL`00P1V<l`40?ooo`H0IS>I0P1E0:X0101V<iT0E@2Z
03=Vo`0cI_lT0?ooo`00;03oool6000000T0oooo0P30`<00100cI/`005FZ0000V@0009TE0?ooo`80
VLaV00H0VL`c000000000000000000L71`00000200008P<0000A00D00`<30000<`000280000R0000
<`0300008P0600004@0006H0002I0000V@0006H005FZ0P00EED01@000:X005EE0000V@0009T005EE
0080002I00D005EE0000V@00EED005EE0000ZP050000V@80<`1V00D0002I001EE@0009T0002I03=V
IP020000V@0603=VIP0009T0<fIV03=VIP0009T0<fIV0P0009T01P0007L0002I0000M`0007L0002I
001EZP80002Z00D005FZ0000V@0c09T0<`2I0000V@0203<0V@050000V@0c09T0002I0000V@0c09T0
1`0009T01@1V<iT0<`2I06HcV@1V<iT0<`2I008005FZ00H0<`2I001EZP0c09T0<`2I05EEZP0c09T2
05EEZP060000ZP1BDU80002Z0000ZP1BDU80002Z0P1VIVH01@000:X0IVIV0000ZP000:X0<fIV0080
002Z00H0<fIV0000A01E05D0E@1E0000A00c03<20000A00603<0<`0004@0<fJI03=VV@1EEJX005FZ
0P1EEJX00`00EJX0EEFZ05EEZP0205EEZP040<k>cP1EEJX0EEFZ0000V@80EEFZ00H0002I03<0IP1E
05D0E@1E03<0IP1E05D403<0IP80001E00D0<`1V0000E@0005D0<`1V001EZP0203=Vc0060000V@0c
I/`0002I0000V@1EEJX0IS?o0P1EEJX01@1V<ol0EEFZ06Hcc01V<l`0EEFZ00<0c/k>00D005Go05EE
ZP1EEJX005Go09TcIP0206i^KP0609TcIP1^KVh0VC=V09TcIP2I<iT0IS=V0P2I<iT01@1V<fH0IS>I
06HcIP1V<fH0IS>I0080IS=V00<0VC>I06HcIP1V<fH02P1V<fH0101V<iT0IS=V06HcIP1V<iT<06Hc
IP80E@1E00H0IS=V05EEo`1VIYT0IVJI05EEo`1VIYT203=Vo`0506IVV@0cI_l0<fKo06HcIP1V<iT0
0P1V<fH01P1V<iT0IS=V05D0E@1E05D0IS=V059BDP80IS=V00@0DU9B06HcIP1EEJX0EEFZ903oool0
03X0oooo00D0Z_oo0<coc03<ol`0Z_oo03=Vo`02001EZP030000IP3oool0oooo0180oooo0P3<VFH2
00000080000A00D00`<3000000000280000R00004@0200L71`06000000000280000R00008P000140
000R0P0001401P00EJX0002I0000V@0009T0001g0000IP80IS?<00D0<`2I001EZP00EJX005FZ0000
V@020000M`060000V@0006H0002I0000V@0006H0EEFZ0P1V<iT01P00EJX0<`2I001EZP00EJX0<`2I
0000V@80<fJI00D0002I001EZP00EJX0002I001EZP020000V@06001EZP0009T005FZ001EZP0009T0
<`2I0P00EJX0100c09T005FZ03<0V@0c09T2001EZP80EEFZ00D005FZ05EEZP1EEJX005FZ05EEZP02
001EZP0605EEZP00EJX0EEFZ05EEZP0cIYT0EEFZ0P0cIYT4001EZP0403=VV@00EJX005FZ03=VV@L0
05FZ1@1EEJX01@0cIYT0EEFZ05EEZP0cIYT0EEFZ0080IVJI00D0EEFZ06IVV@1VIYT0EEFZ03<0<`02
03<0IP0603<0<`0c06H0E@1E05D0E@0c06H0E@1E0P0009T01@0c09T0002I03<0V@0c09T0002I0080
002Z00H0002I0000ZP0009T0002I05EEZP0009T205EEZP050000V@0c06H0001E0000E@0c06H00`00
05D00`0c06H0001E03<0IP0503<0IP050000ZP0cI/`0<fK<06HcV@0c09T00P1V<iT01P1E0:X005FZ
05D0ZP1E0:X005FZ03<0V@80<fK<2@3>c/h206HcV@0606i^KP1V<iT0KVi^06i^KP2I<iT0MWIf0P2I
<iT0101fMWH0VC>I079bLP1bLW8309TcV@0606HcV@2I<iT0IS>I06HcV@2I<fH0IS>I0P2I<fH01P1V
<iT0IS=V06HcV@1V<iT0IS=V06HcV@80E@1E00D0IS>I03<0IP1V<iT0IS>I03<0IP0206HcV@0604Y:
BP1E0:X0BTY:04Y:BP0c09T0IS=V0P0c09T01P1V<fH0IS?<09VIc02IVL`0IS?<09VIc080IS?<00D0
VIW<06Hcc01V<l`0VIW<06HcV@0206HcIPH0IS>I0P1E0:X0101V<iT0E@2Z03=Vo`0cI_lT0?ooo`00
>P3oool01@2Zool0c?o<0<coc02Zool0<fKo008005FZ00<0001V0?ooo`3oool04P3oool20<bIIP80
00000P0001401@030`<0000000008P000280000A00801`L700H0000000008P000280000R00004@00
028200004@06001EZP0009T0002I0000V@0007L0001V0P1V<l`01@0c09T005FZ001EZP00EJX0002I
0080001g00H0002I0000IP0009T0002I0000IP1EEJX206HcV@06001EZP0c09T005FZ001EZP0c09T0
002I0P0cIYT01@0009T005FZ001EZP0009T005FZ0080002I00H005FZ0000V@00EJX005FZ0000V@0c
09T2001EZP0403<0V@00EJX0<`2I03<0V@8005FZ0P1EEJX01@00EJX0EEFZ05EEZP00EJX0EEFZ0080
05FZ00H0EEFZ001EZP1EEJX0EEFZ03=VV@1EEJX203=VV@@005FZ00@0<fJI001EZP00EJX0<fJI1`00
EJX505EEZP0503=VV@1EEJX0EEFZ03=VV@1EEJX00P1VIYT01@1EEJX0IVJI06IVV@1EEJX0<`0c0080
<`1V00H0<`0c03<0IP1E05D0E@1E03<0IP1E05D20000V@0503<0V@0009T0<`2I03<0V@0009T00P00
0:X01P0009T0002Z0000V@0009T0EEFZ0000V@80EEFZ00D0002I03<0IP0005D0001E03<0IP030000
E@0303<0IP0005D0<`1V00D0<`1V00D0002Z03=Vc00cI/`0IS>I03<0V@0206HcV@0505D0ZP00EJX0
E@2Z05D0ZP00EJX0303>c/h206HcV@0606i^KP1V<iT0KVi^06i^KP2I<iT0MWIf0P2I<iT0101fMWH0
VC>I079bLP1bLW8309TcV@0606HcV@2I<iT0IS>I06HcV@2I<fH0IS>I0P2I<fH01P1V<iT0IS=V06Hc
V@1V<iT0IS=V06HcV@80E@1E00D0IS>I03<0IP1V<iT0IS>I03<0IP0206HcV@0604Y:BP1E0:X0BTY:
04Y:BP0c09T0IS=V0P0c09T01P1V<fH0IS?<09VIc02IVL`0IS?<09VIc080IS?<00D0VIW<06Hcc01V
<l`0VIW<06HcV@0206HcIPH0IS>I0P1E0:X0101V<iT0E@2Z03=Vo`0cI_lT0?ooo`00=`3oool20000
00060<bIIP3<ofH0`<300<30`0000:X0IVJI0P0009T00`00EJX0oooo0?ooo`0A0?ooo`0509W<<`00
000000000000000001400P030`<010000000000A00008P00028300004@0600008P0003<0000R0000
8P0003<0000R0P1EEJX01P000:X0001V0000V@0009T0001V0000V@80IS?<00D0002Z001EE@0009T0
002I001EE@020000V@06001EE@0009T005EE001EE@0009T0<fJI100009T203<0IP050000V@00EED0
002I0000V@00EED00P0009T01P0cIVH0002I03=VIP0cIVH0002I03=VIP80002I00H0<fIV0000V@00
07L0001g0000V@00EJX20000V@05001EZP000:X0001g0000M`0009T00P0c09T01P0009T0<`2I0000
V@0009T0<`2I0000V@80<`2I100009T01@1V<iT0<`2I06HcV@1V<iT0<`2I008005FZ00H0<`2I001E
ZP0c09T0<`2I05EEZP0c09T205EEZP060000ZP1BDU80002Z0000ZP1BDU80002Z0P1VIVH01@000:X0
IVIV0000ZP000:X0<fIV0080002Z00H0<fIV0000A01E05D0E@1E0000A00c03<20000A00603<0<`00
04@0<fJI03=VV@1EEJX005FZ0P1EEJX00`00EJX0EEFZ05EEZP0505EEZP050000V@1EEJX0EEFZ0000
V@0c06H00P1E05D00`0c06H0E@1E03<0IP0303<0IP80001E00D0<`1V0000E@0005D0<`1V001EZP02
05EEZP060000V@0cI/`0002I0000V@0cI/`0IS?o0P1EEJX00`1V<ol0EEFZ0<k>cP090<k>cP0505EE
ZP1^KVh0KVi^09TcIP1^KVh00P2I<fH01P2I<iT0IS=V09TcV@2I<iT0IS=V06HcV@80IS=V00@0IS>I
06HcIP1V<fH0VIUV301V<fH0101V<iT0IS=V06HcIP1V<iT:06HcIP0605D0E@1V<fH0E@1E05D0E@1V
<fH0EEGo0P1VIYT01@1EEOl0IVJI03=Vo`0cI_l0IVJI0080<fKo00H0IVJI06HcV@1V<fH0IS=V06Hc
V@1V<fH205D0E@0606HcIP1BDU80IS=V06HcIP1BDU80IS=V0P1EEJX00`2IVL`0oooo0?ooo`0Q0?oo
o`00=`3oool20000000609W<V@0009T0EOoo05Goo`00I/`0001V0P00EJX00`000:X0001g0?ooo`0A
0?ooo`@0000000@0000A00<30`030`<000000`000280100001401`L700L71`0003<300008P030000
4@00028005FZ008005FZ0`0009T01@0007L0002I0000M`0007L0<`2I00<005FZ00D0002I0000M`00
07L0002I0000IP020000V@060000IP0009T0IS>I06HcV@00EJX0<`2I0P00EJX01@0c09T0002I03=V
V@0cIYT0002I008005FZ00H0002I001EZP0009T0002I001EZP0009T2001EZP060000V@0c09T005FZ
001EZP0c09T005FZ0P0c09T01@00EJX0IS>I001EZP00EJX0IS>I0080EEFZ00H005FZ05EEZP00EJX0
05FZ05EEZP00EJX205EEZP0403=VV@1EEJX0<fJI03=VV@L005FZ00<0<fJI001EZP00EJX01@00EJX5
05EEZP0503=VV@1EEJX0EEFZ03=VV@1EEJX00P1VIYT01@1EEJX0IVJI06IVV@1EEJX0IVJI0080<`1V
00D0E@1E03<0IP1E05D0E@1E03<0IP030000V@0503<0V@0009T0<`2I03<0V@0009T00P000:X01P00
09T0002Z0000V@0009T0EEFZ0000V@80EEFZ00D0002I03<0IP0005D0001E03<0IP030000E@0303<0
IP0005D0<`1V00D0<`1V00D0002Z03=Vc00cI/`0IS>I03<0V@0206HcV@0703<0V@00EJX0E@2Z05D0
ZP00EJX0E@2Z03=Vc0090<k>cP0506Hcc01V<iT0IS>I06i^KP1V<iT00P1fMWH01P2I<iT0MWIf09Tc
V@2I<iT0LW9b09TcV@80LW9b0`2I<iT01P1V<iT0VC>I06HcV@1V<iT0VC>I06HcV@80VC>I00H0IS>I
06HcIP1V<iT0IS>I05D0E@1V<iT205D0E@0506HcV@0c06H0IS>I06HcV@0c06H00P1V<iT01P1:BTX0
E@2Z04Y:BP1:BTX0<`2I06HcIP80<`2I00H0IS=V06Hcc02IVL`0VIW<06Hcc02IVL`206Hcc00509VI
c01V<l`0IS?<09VIc01V<iT00P1V<fH606HcV@80E@2Z00D0IS>I05D0ZP1V<l`0IS?<09VIc00S0?oo
o`00=P3oool01@000000c?mV0<coIP2IVL`0<fKo008005FZ00H0002Z0000M`0009T0002I001EZP00
09TA0?ooo`@0000000H01`L700004@030`<00`<300008P00014200008P0500<30`000280000R0000
8P0003<00P0002801P0003<0002I05EEZP1EEJX0002Z0000IP80002I00H0001V0000V@0007L0001g
0000ZP00EED20000V@05001EE@0009T0002I001EE@0009T00P00EED00`0009T005EE0000V@030000
V@80<`1V00D0002I001EE@0009T0002I001EE@020000V@0603=VIP0009T0<fIV03=VIP0009T0<fIV
0P0009T01P0cIVH0002I0000M`0007L0002I001EZP80002I00D005FZ0000ZP0007L0001g0000ZP02
001EZP060000ZP00EJX0002I0000V@0c09T0002I0P0c09T50000V@0403<0V@1V<iT0IS>I03<0V@80
05FZ00H0<`2I001EZP0c09T0<`2I05EEZP0c09T205EEZP060000ZP1BDU80002Z0000ZP1BDU80002Z
0P1VIVH01@000:X0IVIV0000ZP000:X0<fIV0080002Z00H0<fIV0000ZP1E05D0E@1E0000A00c03<2
0000A00603<0<`1EEJX0<fJI03=VV@1EEJX005FZ0P1EEJX00`00EJX0EEFZ05EEZP0505EEZP050000
V@1EEJX0EEFZ0000V@1EEJX00P1E05D603<0IP80001E00D0<`1V0000E@0005D0EEFZ001EZP0205EE
ZP060000V@0cI/`0002I0000V@0cI/`0IS?o0P1EEJX00`1V<ol0EEFZ06Hcc0080<k>cP06001Eo`1E
EJX0LW9b079bLP2I<fH0KVi^0P1V<fH01P2I<iT0IS=V09TcV@2I<iT0IS=V06HcV@80IS=V00@0IS>I
06HcIP1V<fH0VIUV1`1V<fH01P2I<fH0IS=V09TcIP2I<fH0IS=V06HcV@80IS=V00<0IS>I06HcIP1V
<fH0201V<fH01P1E05D0IS=V05D0E@1E05D0IVJI05EEo`80IVJI00D0EEGo06IVV@1EEOl0EEGo06IV
V@0203=Vo`0606IVV@1V<iT0IS=V06HcIP1V<iT0IS=V0P1E05D01@1V<fH0DU9B06HcIP1V<fH0DU9B
00@0IVJI8`3oool003H0oooo00D000000<coIP3<ofH0VIW<03=Vo`02001EZP060000ZP0007L0002I
0000V@00EJX0002I4@3oool40000000600L71`0001400`<300<30`000280000A0P0002801@030`<0
000R00008P000280000c0080000R00H0000c0000V@1EEJX0EEFZ0000ZP0006H20000V@060000IP00
09T0001g0000M`000:X005EE0P0009T01@00EED0002I0000V@00EED0002I008005EE00<0002I001E
E@0009T00`0009T203<0IP050000V@00EED0002I0000V@00EED00P0009T01P0cIVH0002I03=VIP0c
IVH0002I03=VIP80002I00H0<fIV0000V@0007L0001g0000V@00EJX20000V@05001EZP000:X0001g
0000M`000:X00P00EJX01P000:X005FZ0000V@0009T0<`2I0000V@80<`2I1@0009T0100c09T0IS>I
06HcV@0c09T2001EZP0603<0V@00EJX0<`2I03<0V@1EEJX0<`2I0P1EEJX01P000:X0DU9B0000ZP00
0:X0DU9B0000ZP80IVIV00D0002Z06IVIP000:X0002Z03=VIP020000ZP0603=VIP000:X0E@1E05D0
E@0004@0<`0c0P0004@01P0c03<0EEFZ03=VV@0cIYT0EEFZ001EZP80EEFZ00<005FZ05EEZP1EEJX0
1@1EEJX01@0009T0EEFZ05EEZP0009T0EEFZ0080E@1E1P0c06H20000E@0503<0IP0005D0001E05EE
ZP00EJX00P1EEJX01P0009T0<fK<0000V@0009T0<fK<06Hco`80EEFZ00@0IS?o05EEZP1V<l`0IS?<
1`3>c/h01P00EOl0EEFZ079bLP1bLW80VC=V06i^KP80IS=V00H0VC>I06HcIP2I<iT0VC>I06HcIP1V
<iT206HcIP0406HcV@1V<fH0IS=V09VIIPL0IS=V00H0VC=V06HcIP2I<fH0VC=V06HcIP1V<iT206Hc
IP0306HcV@1V<fH0IS=V00P0IS=V00H0E@1E06HcIP1E05D0E@1E06IVV@1EEOl206IVV@0505EEo`1V
IYT0EEGo05EEo`1VIYT00P0cI_l01P1VIYT0IS>I06HcIP1V<fH0IS>I06HcIP80E@1E00D0IS=V059B
DP1V<fH0IS=V059BDP0406IVVB<0oooo000f0?ooo`050000003oc9T0olbI0000M`1EZ_l00P0009T0
1@1Vc?l005FZ0000M`0007L0002Z00<0001g3`3oool400000080000A0P030`<200008P80000A0`00
02801P0003<0000R00008P000280000A0000M`80002I00H005FZ0000V@00EJX005FZ0000M`0009T2
0000M`050000IP00EJX0<`2I03<0V@0009T00P0007L01P0009T0001V0000V@0009T0001V0000V@80
001g00H0002I06HcV@00EJX005FZ03<0V@0009T203=VV@050000V@00EJX005FZ0000V@00EJX00P00
09T01P00EJX0002I001EZP00EJX0002I03<0V@8005FZ00H0<`2I001EZP0c09T0<`2I001EZP0c09T2
001EZP0506HcV@00EJX005FZ05EEZP00EJX00P1E0:X01P000:X0E@2Z05EEZP1EEJX0<fJI05EEZP80
<fJI00<0EEFZ001EZP00EJX01000EJX0100cIYT005FZ03=VV@0cIYT5001EZPL0EEFZ00D0<fJI05EE
ZP0cIYT0<fJI05EEZP0206IVV@0605EEZP1VIYT0<`1V03<0IP1E05D0<`1V0P1E05D00`0c06H0002I
0000V@030000V@80<`2I00D0002I03<0V@0c09T0002I0000ZP020000V@060000ZP0009T0EEFZ05EE
ZP0009T0EEFZ0P0005D203<0IP80001E1`0c06H01P00EJX0002Z03=Vc00cI/`0IS>I03<0V@80IS>I
00H0<`2I001EZP1E0:X0E@2Z001EZP1E0:X203=Vc00303<0V@3>c/h0c/k>00<0c/k>00<0IS?<05EE
ZP1V<l`00P1VIYT206HcV@80MWIf00H0VC>I07IfMP2I<iT0VC>I079bLP2I<iT2079bLP0506HcV@2I
<iT0VC>I06HcV@2I<iT00P1V<iT0102I<iT0IS>I09TcV@2I<iT406HcV@0606HcIP1V<iT0IS=V06Hc
IP1V<iT0<`1V0P1V<iT01@0c06H0E@2Z05D0ZP1:BTX0E@2Z0080BTY:00H0<`2I06HcIP0c09T0<`2I
09VIc01V<l`209VIc00506Hcc02IVL`0IS?<06Hcc02IVL`00P1V<l`0103<I/`0IS>I06HcIP1V<fH4
06HcV@0605D0ZP1V<iT0E@2Z05D0ZP1V<iT0VIW<0P1V<l`00`2IVL`0oooo0?ooo`0Q0?ooo`00=03o
ool300000080<fKo00H0EEGo0000V@00EJX005FZ0000M`00I/`20000V@04001EZP0009T0001V0000
IPd0oooo1P00000200L71`800`<300D0000R00004@000140000A00008P020000<`0600008P0003<0
000R00008P0006H0002I0`0007L01@1EEJX0002I0000V@0006H0002I0080001g00D0002I0000M`00
0:X0002Z001EE@020000V@06001EE@0009T005EE001EE@0009T005EE0P0009T01P00EED0002I03<0
IP0c06H0002I03<0IP80002I00D005EE0000V@0009T0<fIV0000V@0203=VIP060000V@0cIVH0002I
0000V@0cIVH0002I0P0007L01P0009T005FZ0000V@0009T005FZ0000V@80001g00@0002Z0000M`00
07L0002Z0`00EJX01P1V<l`005FZ06Hcc01V<l`005FZ05EEZP8005FZ00D0002I03<0V@1V<iT0IS>I
03<0V@02001EZP0603<0V@00EJX0<`2I03<0V@1EEJX0<`2I0P1EEJX01P0c09T0DU9B0000ZP000:X0
DU9B0000ZP80IVIV00D0002Z06IVIP000:X0002Z03=VIP020000ZP80<fKo0P1E05D01P0004@0<`0c
0000A00004@0<`0c05EEZP80<fJI00D0EEFZ001EZP1EEJX0EEFZ001EZP0705EEZP050000V@1EEJX0
EEFZ0000V@1EEJX00P1E05D603<0IP80001E00<0<`1V0000E@0005D00P00EJX205EEZP06001EZP0c
I/`0002I0000V@0cI/`0IS?o0P1EEJX01P1V<ol0EEFZ06Hcc01V<l`0EEFZ06Hcc0@0c/k>00<0EEFZ
001Eo`1EEJX00P1bLW801P2I<fH0LW9b06HcIP1V<fH0VC>I06HcIP80VC>I00D0IS=V06HcV@1V<fH0
IS=V09VIIP0206HcIP0309VIIP1V<fH0IS=V00D0IS=V00H0VC=V06HcIP2I<fH0VC=V06HcIP1V<iT2
06HcIP0506HcV@1V<fH0IS>I06HcV@1V<fH00P0cIVH00`1V<fH0<fIV06HcIP0506HcIP0606IVV@1E
EOl0IVJI06IVV@1EEOl0EEFZ0P1EEOl01@1EEJX0EEGo05EEo`1EEJX0IS>I0080IS=V00H0E@1E06Hc
IP1E05D0E@1E06HcIP1BDU8206HcIP03059BDP1VIYT0IVJI0080IVJI8`3oool001`0oooo00<0002Z
0?ooo`3oool05@3oool2000000050?ooZP0007L0001g03?<c00007L00P1Vc<`00`0009T005FZ0000
M`020000M`04001EZP0006H0001V0000IP`0oooo1000000300004@0300<30`000280000R00T0000R
0P0007L00`0009T0001g0000IP020000IP<005FZ00H0001g0000V@0007L0001g0000IP0007L20000
IP050000V@0007L0001g0000V@0007L00P0009T01P0006H0002I0000IP0006H0002I0000M`80002I
00D0<`2I001EZP0cIYT0<fJI0000V@02001EZP060000V@00EJX0002I0000V@00EJX0002I0P00EJX0
1P0009T0<`2I001EZP00EJX0<`2I001EZP80<`2I00D005FZ03<0V@00EJX005FZ06HcV@02001EZP06
05EEZP00EJX0EEFZ05EEZP000:X0E@2Z0P000:X01P1E0:X0003<06Hcc01V<l`0003<03=Vc080<`2I
00D0<fK<06Hcc01V<l`006K<06Hcc00203=VV@D005FZ0`1EEJX01P00I_l0<fK<03=Vc00cI/`0<lc<
03=Vc0<0<lc<0P0cI/`01P0cc<`0<fK<03?<c00cc<`0E@1E03<0IP80E@1E00<0<`1V0000V@0009T0
0`0009T203<0V@050000V@0c09T0<`2I0000V@000:X00P0009T01P000:X0002I05EEZP1EEJX0002I
05EEZP80001E0P0c06H20000E@@0<`1V0`1E05D01P1V<l`005FZ001EE@00EED0002Z03<0V@80IS>I
00H0<`2I06HcV@1E0:X0E@2Z001EZP1E0:X203=Vc00303<0V@0cI/`0c/k>00<0c/k>00<0IS?<05EE
ZP1V<l`00P1VIYT01P1V<iT0IVJI05D0E@1E05D0ZP2Z07IfMP80VC>I00D0LW9b09TcV@1bLW80LW9b
06HcV@0209TcV@0606HcV@2I<iT0IS>I06HcV@2I<iT0IS>I0P2I<iT406HcV@0606HcIP1V<iT0IS=V
06HcIP1V<iT0E@1E0P1V<iT01@1E05D0E@2Z05D0ZP1V<fH0E@2Z0080IS=V00H0<`2I06HcIP0c09T0
<`2I09VIc02ZEJX20<aVc00506IVV@3<I/`0IVJI06IVV@3<I/`00P1VIYT0103<I/`0IS>I06HcIP1V
<fH406HcV@0605D0ZP1V<iT0E@2Z05D0ZP1V<iT0VIW<0P1V<l`00`2IVL`0IS?<0?ooo`0Q0?ooo`00
703oool00`000:X0oooo0?ooo`0E0?ooo`80000000D0oonZ0000M`0007L0<lc<0000M`0206K<c003
0000V@00EJX0001g0080001g00@005FZ0000IP0006H0001V303oool4000000<0000A00<00`<30000
8P0002802@0002820000M`030000V@0007L0001V0080001V0`00EJX01P0007L0002I0000M`0007L0
001V0000M`80001V00D0002I0000M`0007L0002I0000M`020000V@060000IP0009T0001V0000IP00
09T0001g0P0009T01@0c09T005FZ03=VV@0cIYT0002I008005FZ00H0002I001EZP0009T0002I001E
ZP0009T2001EZP060000V@0c09T005FZ001EZP0c09T005FZ0P0c09T01@00EJX0<`2I001EZP00EJX0
IS>I008005FZ00H0EEFZ001EZP1EEJX0EEFZ0000ZP1E0:X20000ZP0605D0ZP000<`0IS?<06Hcc000
0<`0<fK<0P0c09T01@0cI/`0IS?<06Hcc000I/`0IS?<0080<fJI1@00EJX305EEZP06001Vo`0cI/`0
<fK<03=Vc00cc<`0<fK<0`0cc<`203=Vc00603?<c00cI/`0<lc<03?<c01E05D0<`1V0P1E05D00`0c
06H0002I0000V@030000V@80<`2I00D0002I03<0V@0c09T0002I0000ZP020000V@060000ZP0009T0
EEFZ05EEZP0009T0EEFZ0P0005D203<0IP80001E100c06H305D0E@0606Hcc000EJX005EE001EE@00
0:X0<`2I0P1V<iT01P0c09T0IS>I05D0ZP1E0:X005FZ05D0ZP80<fK<00<0<`2I03=Vc00cI/`00P3>
c/h206Hcc00605EEZP1V<l`0IVJI06IVV@1V<iT0IVJI0P1E05D01P2Z0:X0MWIf09TcV@2I<iT0LW9b
09TcV@80LW9b00D0IS>I09TcV@2I<iT0IS>I09TcV@0206HcV@0409TcV@1V<iT0VC>I09TcV@@0IS>I
00H0IS=V06HcV@1V<fH0IS=V06HcV@1E05D206HcV@0505D0E@1E0:X0E@2Z06HcIP1E0:X00P1V<fH0
1P0c09T0IS=V03<0V@0c09T0VIW<0:YEZP80c6K<00D0IVJI0<aVc01VIYT0IVJI0<aVc00206IVV@04
0<aVc01V<iT0IS=V06HcIP@0IS>I00H0E@2Z06HcV@1E0:X0E@2Z06HcV@2IVL`206Hcc00309VIc01V
<l`0oooo0240oooo000K0?ooo`040<30`02Zool005FZ001EZQ@0oooo0`0000000`2Zool0I/co06K<
o`020000V@80001V00H0002I0000M`0009T0002I0000M`0009T20000IP030000M`3oool0oooo00T0
oooo1@00000200004@801`L70P0001400`000280000A00008P0200008P80000c00H0000R0000<`00
07L0001g001EZP0009T40000M`80002I00H0001V0000V@0007L0001g0000V@0007L20000V@05001E
E@0009T0002I001EE@0009T00P00EED01P0009T005EE0000V@0009T005EE0000V@8005EE00D0002I
03<0IP0009T0002I001EE@020000V@0603=VIP0009T0<fIV03=VIP0009T0<fIV0P0009T01P0cIVH0
002I0000M`0007L0002I0000M`80002I00D005FZ0000V@0007L0001g0000ZP020000M`060000ZP00
EJX0002Z0000ZP1V<l`005FZ0P1V<l`01P00EJX0EEFZ001EZP00EJX0EEFZ001Vc080003<00D006K<
0000c0000<`006K<0000c002001Vc0D0<fK<00D0<lco03=Vc00cI/`0<lco03=Vc00203?<o`0503=V
o`00VL`0<fKo03=Vo`00VL`01`0cI_l01@0c03<000140000A00c03<005FZ0080IS?<0P00EJX205EE
ZP03001EZP1EEJX0EEFZ00D0EEFZ00D0002I05EEZP1EEJX0<`2I03=Vc00205D0E@@0<`1V00D0E@1E
0000E@1E05D0E@1E0000E@0205D0E@06001EZP000:X0IS?<06Hcc0000:X0<fK<0P0009T01P0cI/`0
002I05EEZP1EEJX0IS?o05EEZP80IS?o00D0EEFZ06Hcc01V<l`0EEFZ0<k>cP0205EEZP05001Eo`1E
EJX005Go001Eo`2I<fH00`1bLW801P1V<fH0LW9b06HcV@1V<iT0IS=V06HcV@80IS=V00@0VIUV06Hc
IP1V<fH0VIUV1`1V<fH01P2I<fH0IS=V09TcIP2I<fH0IS=V06HcV@80IS=V00D0IS>I06HcIP1V<iT0
IS>I06HcIP0203=VIP0306HcIP0cIVH0IS=V00D0IS=V00H0EEFZ09VIc01EEJX0EEFZ05EEo`1EEJX2
05EEo`0505EEZP1EEOl0EEGo05EEZP1EEOl00P1V<fH01P1E05D0IS=V05D0E@1E05D0IS=V059BDP80
IS=V00<0DU9B06IVV@1VIYT00`1VIYTR0?ooo`007@3oool2001EZQ@0oooo00@000000?o<V@3oc9T0
oonZ0P000<`01P0009T0<fK<0000M`0007L0002I0000IP80001g00<0001V001EZP0006H00P0006H0
0`0007L0oooo0?ooo`080?ooo`D000000P00014200<30`H0000R00D0000c00008P000280000R0000
V@040000M`<0001V00D0002I001EZP00EJX0001g0000V@020000M`040000IP0007L0001V0000IP<0
001g00H0002I0000M`0009T0002I0000IP0009T20000IP030000V@0007L0002I00<0002I0P0cIYT0
1@0009T0<fJI03=VV@0009T005FZ0080002I00D005FZ0000V@00EJX005FZ0000V@03001EZP0603<0
V@00EJX0<`2I03<0V@00EJX0<`2I0P00EJX01@1V<iT005FZ001EZP1EEJX005FZ0080EEFZ00H0002Z
05D0ZP000:X0002Z05D0ZP000<`206Hcc0050000c01V<l`0<`2I03<0V@0cI/`00P0c09T01P00I/`0
IS?<001Vc000I/`0IS?<001EZP8005Go00H005FZ001Eo`0cI/`0<fK<001Vo`0cI/`2001Vo`80<fK<
0P0cc<`01@0cI/`0<lc<03?<c00cc<`0<fK<0080<lc<00H0<fK<03<0IP1E05D0E@1E03<0IP1V<iT2
05D0ZP0506HcV@000:X005FZ001EZP000:X00P00EJX0100c09T0IS>I03<0V@0c09T206HcV@80002I
00@0IS>I0000V@0005D0001E2`1E05D01P1V<l`0E@2Z001EE@00EED005FZ05EEZP80<`2I00H0EEFZ
06HcV@1E0:X0E@2Z001EZP1E0:X2001EZP0503<0V@0cI/`0<fK<03<0V@0cI/`00P1V<l`01P1EEJX0
IS?<05EEZP1EEJX0IS>I06IVV@80E@1E00H0ZP2Z05D0E@2I<iT0VC>I079bLP2I<iT2079bLP0506Hc
V@2I<iT0VC>I06HcV@2I<iT00P1V<iT00`2I<iT0IS>I06HcV@0506HcV@0606HcIP1V<iT0IS=V06Hc
IP1V<iT0E@1E0P1V<iT01@1E05D0E@2Z05D0ZP1V<fH0E@2Z0080IS=V00H0<`2I06HcIP0c09T0<`2I
03=Vc02ZEJX20<aVc00506IVV@3<I/`0IVJI06IVV@3<I/`00P1VIYT0103<I/`0IVJI06HcIP1V<fH4
06HcV@0605D0ZP1V<iT0EEFZ05EEZP1V<fH0VIW<0P1V<l`00`2IVL`0IS?<0?ooo`0Q0?ooo`00<P3o
ool01@2Ic3<000000<coV@3<oiT0c?o<0080oooo00H0Z_oo0000E@0009T0002I03=Vo`0007L20000
V@040000M`0006H0001V0000IP80001g0P0006H80?ooo`@0000000D01`L700004@0001400`<30000
8P0200004@D0000R0P0003<01P000280001g0000M`0007L0001V0000V@H0001g00H0001V0000V@00
06H0001V0000V@0007L20000V@050000M`0009T0002I001EE@0009T00P00EED01P0009T005EE0000
V@0009T005EE0000V@8005EE00D0002I001EE@0009T0002I001EE@020000V@0603=VIP0009T0<fIV
03=VIP0009T0<fIV0P0009T01P0cIVH0002I0000M`0007L0002I0000M`80002I00D005FZ0000V@00
EJX005FZ0000ZP020000M`040000ZP00EJX0002Z0000ZP8005FZ0P1V<l`01P00EJX0IS?<001EZP00
EJX0EEFZ001EZP80003<00D006K<0000c0000<`006K<0000c002001Vc0030000c00cI/`0<fK<00D0
<fK<00H0<lco03=Vc00cc?l0<lco03=Vc000VL`203=Vo`04002Ic00cI_l0<fKo002Ic0D0<fKo0P00
04@01P1EEJX005FZ06Hcc01V<l`005FZ03=Vc080EEFZ00D0<fK<05EEZP1EEJX005FZ03=Vc002001E
ZP0603=Vc00c09T0<fK<03=Vc00c09T0<fK<0P0c09T01P0005D0E@1E0000E@0005D0E@1E0000E@80
E@1E00D0001E05D0E@1E05D005FZ05EEZP0206Hcc0060000ZP0cI/`0IS>I06HcV@0cI/`0IS>I0P0c
I/`01@00EJX0<fK<06Hco`1V<ol0EEFZ0080IS?<00H0EEFZ06Hcc01EEJX0EEFZ001Eo`1EEJX2001E
o`0609TcIP1V<fH0LW9b079bLP1V<fH0LW9b0P2I<iT01@1V<fH0IS>I06HcIP1V<fH0VIUV0080IS=V
00<0VIUV06HcIP1V<fH01@1V<fH01P2I<fH0IS=V09TcIP2I<fH0IS=V06HcV@80IS=V00D0IS>I06Hc
IP1V<iT0IS>I06HcIP0203=VIP0306HcIP0cIVH0IS=V00D0IS=V00H0EEFZ09VIc01EEJX0EEFZ05EE
o`1EEJX205EEo`0505EEZP1EEOl0EEGo05EEZP1EEOl00P1V<iT01P1V<fH0IS>I06HcIP1V<fH0IS>I
059BDP80IS>I00<0DU9B06IVV@1VIYT00`1VIYTR0?ooo`00<P3oool01@2Ic3<000000<coV@3<oiT0
c?o<0080oooo00H0Z_oo0000E@0009T0002I03=Vo`0007L20000V@040000M`0006H0001V0000IP80
001g0P0006H80?ooo`@0000000D01`L700004@0001400`<300008P0200004@D0000R0P0003<01P00
0280001g0000M`0007L0001V0000V@H0001g00H0001V0000V@0006H0001V0000V@0007L20000V@05
0000M`0009T0002I001EE@0009T00P00EED01P0009T005EE0000V@0009T005EE0000V@8005EE00D0
002I001EE@0009T0002I001EE@020000V@0603=VIP0009T0<fIV03=VIP0009T0<fIV0P0009T01P0c
IVH0002I0000M`0007L0002I0000M`80002I00D005FZ0000V@00EJX005FZ0000ZP020000M`040000
ZP00EJX0002Z0000ZP8005FZ0P1V<l`01P00EJX0IS?<001EZP00EJX0EEFZ001EZP80003<00D006K<
0000c0000<`006K<0000c002001Vc0030000c00cI/`0<fK<00D0<fK<00H0<lco03=Vc00cc?l0<lco
03=Vc000VL`203=Vo`04002Ic00cI_l0<fKo002Ic0D0<fKo0P0004@01P1EEJX005FZ06Hcc01V<l`0
05FZ03=Vc080EEFZ00D0<fK<05EEZP1EEJX005FZ03=Vc002001EZP0603=Vc00c09T0<fK<03=Vc00c
09T0<fK<0P0c09T01P0005D0E@1E0000E@0005D0E@1E0000E@80E@1E00D0001E05D0E@1E05D005FZ
05EEZP0206Hcc0060000ZP0cI/`0IS>I06HcV@0cI/`0IS>I0P0cI/`01@00EJX0<fK<06Hco`1V<ol0
EEFZ0080IS?<00H0EEFZ06Hcc01EEJX0EEFZ001Eo`1EEJX2001Eo`0609TcIP1V<fH0LW9b079bLP1V
<fH0LW9b0P2I<iT01@1V<fH0IS>I06HcIP1V<fH0VIUV0080IS=V00<0VIUV06HcIP1V<fH01@1V<fH0
1P2I<fH0IS=V09TcIP2I<fH0IS=V06HcV@80IS=V00D0IS>I06HcIP1V<iT0IS>I06HcIP0203=VIP03
06HcIP0cIVH0IS=V00D0IS=V00H0EEFZ09VIc01EEJX0EEFZ05EEo`1EEJX205EEo`0505EEZP1EEOl0
EEGo05EEZP1EEOl00P1V<iT01P1V<fH0IS>I06HcIP1V<fH0IS>I059BDP80IS>I00<0DU9B06IVV@1V
IYT00`1VIYTR0?ooo`007`3oool00`000:X0oooo0?ooo`0@0?ooo`030000003oojX0oooo00D0oooo
0`0007L00`0006H0002I0000IP020000IP030000M`0006H0001V00@0001g1`3oool5000000<0000A
00<00`<300008P0002801@0002801@0003<0000R00008P0007L0002I00@0001g0`0006H00`0009T0
001V0000IP020000V@80001g00D0001V0000M`0006H0001V0000M`02001EZP060000V@0007L0002I
0000V@0006H0002I0P0006H00`0009T0001g0000V@030000V@8005FZ00D0002I03=VV@0cIYT0002I
001EZP020000V@05001EZP0009T005FZ001EZP0009T00`00EJX01P0c09T005FZ03<0V@0c09T005FZ
03<0V@8005FZ00D0IS>I001EZP00EJX0IS>I001EZP0205EEZP06001EZP1E0:X0002Z0000ZP1E0:X0
002Z0P1V<l`01@000<`0IS?<03<0V@0c09T0<fK<0080<`2I00H0<fK<06Hcc000I/`006K<06Hcc000
I/`2001Eo`06001EZP00EOl005FZ001EZP00I_l0<fK<0P00I_l01@0cI/`006Ko03?<c00cc<`0<fK<
0080<lc<00H0<fK<03?<c00cc<`0<lc<03=Vc00cc<`203=Vc0@0E@2Z00D0IS>I05D0ZP00EJX005FZ
0000ZP02001EZP060000ZP1V<iT0<`2I03<0V@1V<iT0<`2I0P0009T0101V<iT0002I06HcV@1V<iT;
05D0E@0606Hcc01E0:X005EE001EE@00EJX005EE0P0c09T01P1EEJX0<`2I03<0V@0c09T0IS>I03<0
V@80IS>I00D0<`2I03=Vc00cI/`0<`2I03=Vc00206Hcc00603=Vc01V<l`0<fK<03=Vc01V<iT0ZP2Z
0P1E05D01@2Z0:X0E@1E09TcV@2I<iT0LW9b00<0VC>I00D0IS>I09TcV@2I<iT0IS>I09TcV@0206Hc
V@0309TcV@1V<iT0IS>I00D0IS>I00H0IS=V06HcV@1V<fH0IS=V06HcV@1E05D206HcV@0505D0E@1E
0:X0E@2Z06HcIP1E0:X00P1V<fH01P0c09T0IS=V03<0V@0c09T0<fK<0:YEZP80<fK<00D0IVJI0<aV
c01VIYT0IVJI0<aVc00206IVV@060<aVc01VIYT0IVJI06IVV@1V<fH0IVJI0P1V<fH01P1EEJX0IS=V
05EEZP1EEJX0IS=V09VIc080IS?<00<0VIW<06Hcc03oool08@3oool001l0oooo00<0002Z0?ooo`3o
ool0403oool00`000000VL`c0?ooo`050?ooo`050000V@1EEOl0EEGo0000IP00EJX00`0007L01@00
06H005FZ001EZP0009T0001g0080001V00<0001g0?ooo`3oool0103oool50000000500L71`000140
000A00004@0002800P00014500008P80001V100007L01@0006H0001g0000M`0007L0002I00<0001g
00H0001V0000V@0006H0001V0000V@0007L20000V@050000M`0009T0002I001EE@0009T00P00EED0
1P0009T005EE0000V@0009T005EE0000V@8005EE00D0002I001EE@0009T0002I001EZP020000V@06
03=VIP0009T0<fIV03=VIP0009T0<fIV0P0009T01P0cIVH0002I0000M`0007L0002I0000M`80002I
00D005FZ0000V@00EJX005FZ0000ZP020000M`040000ZP00EJX0002Z0000ZP8005FZ0P1V<l`01P00
EJX0IS?<001EZP00EJX0EEFZ001EZP80EEFZ00D006K<0000c0000<`006K<0000c002001Vc0040000
c000I/`0003<0000c0H0<fK<0P0cc?l01@0cI/`0<lco03=Vc00cI/`009W<0080<fKo00H0IS>I001E
ZP1V<iT0IS>I001EZP1EEJX2001EZP0605EEZP00EJX0IS?<06Hcc000EJX0IS?<0P1EEJX00`0cI/`0
EEFZ05EEZP0203=Vc08005FZ00H0<fK<001EZP0cI/`0<fK<03<0V@0cI/`203<0V@060000E@1E05D0
001E0000E@1E05D0001E0P1E05D01@0005D0EEFZ05EEZP00EJX0EEFZ0080IS?<00H0002Z06Hcc01V
<iT0IS>I03=Vc01V<iT203=Vc005001EZP0cI/`005FZ001EZP1EEJX00P0cI/`01P1EEJX0<fK<05EE
ZP1EEJX0<fK<05EEZP80<fK<00H0VC=V06HcIP1bLW80LW9b06HcIP1bLW8209TcV@0506HcIP2I<iT0
IS=V06HcIP1VIYT00P1V<fH00`2IVFH0IS=V06HcIP0506HcIP0609TcIP1V<fH0IS>I06HcV@1V<fH0
IS>I0P1V<fH01@1V<iT0IS=V06HcV@1V<iT0IS=V0080<fIV00<0IS=V03=VIP1V<fH01@1V<fH01P1E
EJX0VIW<05EEZP1EEJX0EEGo05EEZP80EEGo00D0EEFZ05EEo`1EEOl0EEFZ05EEo`0206HcV@0606Hc
IP1V<iT0IS=V06HcIP1V<iT0DU9B0P1V<iT00`1BDU80IVJI06IVV@0306IVVB80oooo000`0?ooo`<0
c9UV1`3oool30000E@030000M`0005D0001V0080001V00<0001g0000IP0006H01@0007L60?ooo`@0
00000P00014200<30`T0000R0P0006H00`0007L0001V0000M`030000M`80002I00@0001g0000V@00
06H0001V0P0009T20000M`040000IP0007L0001V0000IP<0001g00H0002I0000M`0009T0002I0000
IP0009T20000IP030000V@0007L0002I00H0002I0`00EJX01@000:X0002I0000V@00EJX0002I0080
05FZ00H0002I001EZP00EJX005FZ03<0V@00EJX203<0V@05001EZP0c09T005FZ001EZP1V<iT00P00
EJX01P1V<iT005FZ05EEZP1EEJX005FZ05EEZP80002Z00H0E@2Z0000ZP1E0:X0E@2Z0000c01V<l`2
0000c00503=Vc00c09T0<`2I03=Vc00c09T00P00I/`01P1V<l`006K<06Hcc01V<l`005FZ001Eo`80
05FZ00D005Go001EZP00I_l006Ko03=Vc00303=VV@0505EEZP0cIYT0<fJI05D0ZP0c09T00P1E0:X0
0`0c09T0E@2Z05D0ZP0505D0ZP0506HcV@1E0:X005FZ001EZP000:X00P00EJX01P000:X0IS>I03<0
V@0c09T0IS>I03<0V@80002I00@0IS>I0000V@1V<iT0IS>I2@1E05D205D0ZP0606Hcc01E0:X005EE
001EE@00EJX005EE0P0c09T01P1EEJX0<`2I05EEZP1EEJX0IS>I03<0V@80IS>I00D0<`2I03=Vc00c
I/`0<`2I03=Vc00203<0V@0603=Vc01V<l`0<fK<03=Vc01V<l`0ZP2Z0P1E05D01P2Z0:X0LW9b09Tc
V@2I<iT0LW9b09TcV@80IS=V00<0VC>I06HcIP1V<fH00P2I<iT206HcV@0309TcV@1V<iT0IS>I00D0
IS>I00H0IS=V06HcV@1V<fH0IS=V06HcV@1E05D206HcV@0506HcIP1E0:X0E@2Z06HcIP1E0:X00P1V
<fH01P0c09T0IS=V06Hcc01V<l`0<fK<0:YEZP80<fK<00D0IVJI0<aVc01VIYT0IVJI0<aVc00206IV
V@060<aVc01VIYT0IVJI06IVV@1V<fH0IVJI0P1V<fH01P1EEJX0IS=V05EEZP1EEJX0IS=V09VIc080
IS?<00<0VIW<06Hcc03oool08@3oool00300oooo0`3<VFH70?ooo`<0001E00<0001g0000E@0006H0
0P0006H00`0007L0001V0000IP050000M`H0oooo1000000200004@800`<32@0002820000IP030000
M`0006H0001g00<0001g0P0009T0100007L0002I0000IP0006H20000V@80001g00@0001V0000M`00
06H0001V0`0007L01P0009T0001g0000V@0009T0001V0000V@80001V00<0002I0000M`0009T01P00
09T3001EZP050000ZP0009T0002I001EZP0009T00P00EJX01P0009T005FZ001EZP00EJX0<`2I001E
ZP80<`2I00D005FZ03<0V@00EJX005FZ06HcV@02001EZP0606HcV@00EJX0EEFZ05EEZP00EJX0EEFZ
0P000:X01P1E0:X0002Z05D0ZP1E0:X0003<06Hcc080003<00D0<fK<03<0V@0c09T0<fK<03<0V@02
001Vc00606Hcc000I/`0IS?<06Hcc000EJX005Go0P00EJX01@00EOl005FZ001Vo`00I_l0<fK<00<0
<fJI00D0EEFZ03=VV@0cIYT0E@2Z03<0V@0205D0ZP0303<0V@1E0:X0E@2Z00D0E@2Z00D0IS>I05D0
ZP00EJX005FZ0000ZP02001EZP060000ZP1V<iT0<`2I03<0V@1V<iT0<`2I0P0009T0101V<iT0002I
06HcV@1V<iT905D0E@80E@2Z00H0IS?<05D0ZP00EED005EE001EZP00EED203<0V@0605EEZP0c09T0
EEFZ05EEZP1V<iT0<`2I0P1V<iT01@0c09T0<fK<03=Vc00c09T0<fK<0080<`2I00H0<fK<06Hcc00c
I/`0<fK<06Hcc02Z0:X205D0E@060:X0ZP1bLW80VC>I09TcV@1bLW80VC>I0P1V<fH00`2I<iT0IS=V
06HcIP0209TcV@80IS>I00<0VC>I06HcV@1V<iT01@1V<iT01P1V<fH0IS>I06HcIP1V<fH0IS>I05D0
E@80IS>I00D0IS=V05D0ZP1E0:X0IS=V05D0ZP0206HcIP0603<0V@1V<fH0IS?<06Hcc00cI/`0ZUFZ
0P0cI/`01@1VIYT0c6K<06IVV@1VIYT0c6K<0080IVJI00H0c6K<06IVV@1VIYT0IVJI06HcIP1VIYT2
06HcIP0605EEZP1V<fH0EEFZ05EEZP1V<fH0VIW<0P1V<l`00`2IVL`0IS?<0?ooo`0Q0?ooo`00803o
ool20000A0h0oooo0P0000000`3<ofH0oooo0?ooo`060?ooo`<0002I00@0001V0000M`0007L0001g
0`0006H01@0009T0001g0000IP0006H0001g0080001V0P3oool60000000300004@071`L0000A0080
000A00<0000R00004@0001400P0002820000<`030000IP0007L0001g00@0001g00D0001V0000M`00
07L0001g0000V@040000M`050000V@0006H0001V0000V@0007L00P0009T01@0007L0002I0000V@00
06H0002I008005EE00H0002I001EE@0009T0002I001EE@0009T2001EE@050000V@00EED0002I0000
V@00EJX00P0009T01P00EJX0002Z001EZP00EJX0002I03=VIP80002I00H0<fIV0000V@0007L0001g
0000V@0007L20000V@05001EZP0009T005FZ001EZP000:X00P0007L01P000:X005FZ0000ZP000:X0
05FZ0000ZP80IS?<00H005FZ06Hcc000EJX005FZ05EEZP00EJX205EEZP05001Vc0000<`0003<001V
c0000<`00P00I/`01@000<`006K<0000c0000<`006K<00<0<fK<00H0<`2I0000V@0cIYT0<fJI0000
ZP0cIYT20000ZP0503=VV@000:X0002Z06HcV@00EJX00P1V<iT01P00EJX0EEFZ001EZP00EJX0EEFZ
001EZP80IS?<00D005FZ06Hcc01EEJX0EEFZ03=Vc00205EEZP80<fK<0P00EJX01P0cI/`005FZ03=V
c00cI/`0<`2I03=Vc080<`2I00H0<fK<05D0E@0005D0001E05D0E@0005D205D0E@050000E@1EEJX0
EEFZ001EZP1EEJX00P00EJX01P000:X0IS?<06HcV@1V<iT0<fK<06HcV@80<fK<00@005FZ03=Vc000
EJX005FZ0`0cI/`01P1EEJX0<fK<05EEZP1EEJX0<fK<05EEZP80<fK<00@0EEFZ06HcIP1bLW80LW9b
0P1V<fH209TcV@0506HcIP2I<iT0IS=V06HcIP1VIYT00P1V<fH01P1VIYT0IS=V06HcV@1V<iT0IS=V
09TcIP80IS=V00H0VC=V06HcIP1V<iT0IS>I06HcIP1V<iT206HcIP0506HcV@1V<fH0IS>I06HcV@1V
<fH00P0cIVH00`1V<fH0<fIV06HcIP0306HcIP80VIW<00H0EEFZ09VIc01EEJX0EEFZ05EEo`1EEJX2
05EEo`0505EEZP1EEOl0EEGo05EEZP1EEOl00P1EEJX01P1V<fH0IS>I06HcIP1V<fH0IS>I059BDP80
IS>I00<0DU9B06IVV@1VIYT00`1VIYTR0?ooo`00803oool20000<`h0oooo0P3oc9T90?ooo`80000c
0P0005D20000V@040000E@0007L0001V0000IP80001g0P0006H30000M`80oooo1000000200<30`@0
000A200002830000IP030000M`0006H0001g00<0001g0P0006H01P0007L0002I0000IP0006H0002I
0000IP80001g00@0002I0000M`0006H0001V100007L01@0006H0002I0000V@0006H0002I0080001V
00D0002I0000IP0009T0002I0000M`040000V@8005FZ00@0002I0000ZP00EJX005FZ0P000<`2001E
ZP060000V@00EJX0002I0000V@0c09T005FZ0P0c09T01@00EJX0<`2I001EZP00EJX0IS>I008005FZ
00H0IS>I001EZP1EEJX0EEFZ001EZP1EEJX20000ZP0605D0ZP000:X0E@2Z05D0ZP000<`0IS?<0P00
0<`01@1V<l`0<`2I03<0V@0cI/`0<`2I0080<fK<00H0IS?<001Vc00cIYT0<fJI03<0V@0cIYT2001E
ZP0605EEZP00EJX0<fJI03=VV@1V<iT0<fJI0P1V<iT01@1EEJX0<fJI03=VV@1EEJX0<`2I0080E@2Z
00<0<`2I05D0ZP1E0:X01@1E0:X01@1V<iT0E@2Z06HcV@1V<iT0002Z008005FZ00H0002Z001EZP0c
09T0<`2I06HcV@0c09T306HcV@040000V@1V<iT0IS>I0000V@P0E@1E0P1E0:X01P1V<l`0E@2Z06Hc
c01V<l`005FZ001EE@80<`2I00H0EEFZ03<0V@1EEJX0EEFZ06HcV@0c09T206HcV@0503<0V@0cI/`0
<fK<03<0V@0cI/`00P0c09T01P0cI/`0IS?<03=Vc00cI/`0IS?<0:X0ZP80E@1E00H0ZP2Z079bLP2I
<iT0VC>I079bLP2I<iT206HcIP0509TcV@1V<fH0IS=V09TcV@2I<fH00P1V<iT00`2I<fH0IS>I06Hc
V@0506HcV@0606HcIP1V<iT0IS=V06HcIP1V<iT0E@1E0P1V<iT01@1V<fH0E@2Z05D0ZP1V<fH0E@2Z
0080IS=V00H0<`2I06HcIP1V<l`0IS?<03=Vc02ZEJX203=Vc00506IVV@3<I/`0IVJI06IVV@3<I/`0
0P1VIYT01P3<I/`0IVJI0<aVc03<I/`0IS=V06IVV@80IS=V00H0EEFZ06HcIP1EEJX0EEFZ06HcIP2I
VL`206Hcc00309VIc01V<l`0oooo00D0oooo00<0MWIf0?ooo`3oool06@3oool00200oooo0P0006H=
0?ooo`030000002Ic3<0VL`c00T0oooo0`0005D01@0006H0001E0000E@0007L0002I0080001g0P00
06H30000M`80001V00<0001g0?ooo`0000000`00000200L71`80000A0P000280100001404@000000
4@00014200008P80001E0`0006H00`0005D0001V0000IP020000IP<0001g00<0002I0000M`0007L0
0`0007L20000IP050000V@0007L0002I0000V@0007L00P0009T01P0007L0002I0000IP0006H0002I
001EE@80002I00H005EE0000V@00EED005EE0000V@00EED20000V@05001EE@0009T0002I001EZP00
0:X00P00EJX01P000:X006K<001EZP00EJX0<fIV0000V@80<fIV00H0002I0000M`0009T0002I001E
ZP0009T2001EZP050000V@0007L0001g0000ZP0007L00P000:X00`00EJX0002Z001EZP02001EZP05
06Hcc000EJX005FZ06Hcc000EJX00P1EEJX01@00EJX0003<0000c000I/`005FZ0080002I00H005FZ
0000V@0cI/`0<fK<0000V@0cI/`20000V@0603<0V@0009T0<fJI03=VV@000:X0<fJI0P000:X01@0c
IYT0002Z0000ZP0cIYT005FZ0080IS>I00H005FZ06HcV@00EJX005FZ05EEZP00EJX206Hcc005001E
ZP1V<l`005FZ001EZP0cI/`00P1EEJX01P0cI/`0EEFZ001EZP00EJX0<fK<001EZP80<fK<00H0<`2I
03=Vc00c09T0<`2I03=Vc01E05D20000E@0505D0E@0005D0E@1E05D0E@0005D00P1EEJX01P00EJX0
EEFZ001EZP00EJX0002Z06Hcc080002Z00H0<fK<06HcV@0cI/`0<fK<001EZP0cI/`2001EZP<0<fK<
00H0EEFZ03=Vc01EEJX0EEFZ03=Vc01EEJX203=Vc00405EEZP1V<fH0LW9b079bLP80IS=V0P2I<iT0
1@1V<fH0VC>I06HcIP1V<fH0IVJI0080IS=V00H0IVJI06HcIP1V<iT0IS>I06HcIP2I<iT206HcIP06
09TcV@1V<fH0IS>I06HcV@1V<fH0IS>I0P1V<fH01@1V<iT0IS=V06HcV@1V<iT0IS=V0080<fIV00<0
IS=V03=VIP1V<fH00`1V<fH209VIc00605EEZP2IVL`0EEFZ05EEZP2IVL`0EEFZ0P1EEOl01@1EEJX0
EEGo05EEo`1EEJX0EEGo0080EEFZ00H0IS=V06HcV@1V<fH0IS=V06HcV@1BDU8206HcV@03059BDP1V
IYT0IVJI00D0IVJI00D0EEFZ06HcV@1V<iT0EEFZ06HcV@0K0?ooo`00803oool20000IPd0oooo00<0
000009W<<`2Ic3<02@3oool30000E@050000IP0005D0001E0000M`0009T00P0007L20000IP<0001g
0P0006H00`0007L0oooo00000003000000801`L70P00014200008P0400004@0A0000000A00004@80
000R0P0005D30000IP030000E@0006H0001V0080001V0`0007L00`0009T0001g0000M`030000M`80
001V00D0002I0000M`0009T0002I0000M`020000V@060000M`0009T0001V0000IP0009T005EE0P00
09T01P00EED0002I001EE@00EED0002I001EE@80002I00D005EE0000V@0009T005FZ0000ZP02001E
ZP060000ZP00I/`005FZ001EZP0cIVH0002I0P0cIVH01P0009T0001g0000V@0009T005FZ0000V@80
05FZ00D0002I0000M`0007L0002Z0000M`020000ZP03001EZP000:X005FZ008005FZ00D0IS?<001E
ZP00EJX0IS?<001EZP0205EEZP05001EZP000<`0003<001Vc000EJX00P0009T01P00EJX0002I03=V
c00cI/`0002I03=Vc080002I00H0<`2I0000V@0cIYT0<fJI0000ZP0cIYT20000ZP0503=VV@000:X0
002Z03=VV@00EJX00P1V<iT01P00EJX0IS>I001EZP00EJX0EEFZ001EZP80IS?<00D005FZ06Hcc000
EJX005FZ03=Vc00205EEZP0603=Vc01EEJX005FZ001EZP0cI/`005FZ0P0cI/`01P0c09T0<fK<03<0
V@0c09T0<fK<05D0E@80001E00D0E@1E0000E@1E05D0E@1E0000E@0205EEZP06001EZP1EEJX005FZ
001EZP000:X0IS?<0P000:X01P0cI/`0IS>I03=Vc00cI/`005FZ03=Vc08005FZ0`0cI/`01P1EEJX0
<fK<05EEZP1EEJX0<fK<05EEZP80<fK<00@0EEFZ06HcIP1bLW80LW9b0P1V<fH209TcV@0506HcIP2I
<iT0IS=V06HcIP1VIYT00P1V<fH01P1VIYT0IS=V06HcV@1V<iT0IS=V09TcV@80IS=V00H0VC>I06Hc
IP1V<iT0IS>I06HcIP1V<iT206HcIP0506HcV@1V<fH0IS>I06HcV@1V<fH00P0cIVH00`1V<fH0<fIV
06HcIP0306HcIP80VIW<00H0EEFZ09VIc01EEJX0EEFZ09VIc01EEJX205EEo`0505EEZP1EEOl0EEGo
05EEZP1EEOl00P1EEJX01P1V<fH0IS>I06HcIP1V<fH0IS>I059BDP80IS>I00<0DU9B06IVV@1VIYT0
1@1VIYT01@1EEJX0IS>I06HcV@1EEJX0IS>I01/0oooo000R0?ooo`030000A03oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool01@0006H0001g0000A00004@0001V00<0001g100006H40000M`@0
000000D00`<300004@0001404@0000004@0300008P0500004@000280000R00008P0003<00P0004@0
0`0009T0001V0000IP020000IPL0001g00@0002I0000IP0006H0002I100006H0100007L0001V0000
IP0007L20000IP060000M`0006H0002I0000V@0006H0002I0P0006H01@0009T0001V0000V@0009T0
001g00@0002I0P00EJX01P0009T0002Z001EZP00EJX0002Z001EZP@0003<0P00EJX01P0c09T005FZ
03<0V@0c09T005FZ03<0V@8005FZ00D0<`2I001EZP00EJX0IS>I001EZP0205EEZP06001EZP1EEJX0
05FZ001EZP1E0:X0002Z0P1E0:X01@000:X0IS?<0000c0000<`0002I008005FZ00H0<`2I001EZP0c
09T0<`2I03=VV@0c09T203=VV@0603<0V@0cIYT005FZ001EZP1EEJX005FZ0P0cIYT01@1V<iT0<fJI
06HcV@1V<iT0EEFZ0080<fJI00D0EEFZ03<0V@1E0:X0E@2Z03<0V@0705D0ZP0506HcV@1E0:X0IS>I
06HcV@000:X00P00EJX01@000:X005FZ03<0V@0c09T0IS>I00H0000000<0IS>I0000V@1E05D01`1E
05D205D0ZP0606Hcc01E0:X0IS?<06Hcc000EJX005EE0P00EJX0101EEJX0<`2I05EEZP1EEJX203<0
V@80IS>I00D0<`2I03=Vc00cI/`0<`2I03=Vc00203<0V@0603=Vc01V<l`0<fK<03=Vc01V<l`0ZP2Z
0P1E05D01P2Z0:X0LW9b09TcV@2I<iT0LW9b09TcV@80IS=V00D0VC>I06HcIP1V<fH0VC>I09TcIP02
06HcV@0609TcIP1V<iT0IS=V06HcIP1V<iT0IS=V0P1V<iT01P1V<fH0IS>I05D0E@1E05D0IS>I05D0
E@80IS>I00D0IS=V05D0ZP1E0:X0IS=V03<0V@0206HcIP0603<0V@1V<fH0IS?<06Hcc00cI/`0ZUFZ
0P0cI/`01@2ZEJX0c6K<06IVV@1VIYT0c6K<0080IVJI00H0c6K<06IVV@3<I/`0c6K<06HcIP1VIYT2
06HcIP0605EEZP1V<fH0EEFZ05EEZP1V<fH0VIW<0P1V<l`01@2IVL`0IS?<09VIc02IVL`0IS=V0080
MWIf00<0IS=V07IfMP3oool06P3oool00280oooo00<0000c0?ooo`3oool02P3oool00`000000oooo
0?ooo`0;0?ooo`060000<`0005D0001V0000IP0007L0001E0P0007L20000IP<0001g0P0006H00`00
07L0001V000000020000000500<30`071`L01`L70140000001400P0002800`0c0000000R00008P02
00008P040?ooo`0005D0001E0000E@80001V00@0001E0000IP0006H0001V0P0007L20000IPH0001g
0P0006H01@0009T0001g0000V@0009T0001g0080002I00H0001g0000V@0006H0001V0000V@00EJX2
0000V@06001EE@0009T005EE001EE@0009T005EE0P0009T01@00EED0002I0000V@00EJX0002I0080
05FZ00H0002Z001EZP00EJX005FZ001Vc000EJX3001Vc0050000ZP00I/`006K<0000M`0009T00P00
EJX01@0009T0001g0000M`000:X0001g0080002Z00H005FZ0000V@00EED005EE0000V@00EED20000
V@0503=VIP0009T0<`2I03<0V@0009T00P0c09T01P000:X005EE0000ZP000:X0<`2I0000V@80<fK<
00H0002I03=Vc00009T0002I03<0V@0009T203=VV@050000ZP0cIYT0002Z0000ZP0cIYT00P000:X0
1P0cIYT005FZ06HcV@1V<iT005FZ06HcV@8005FZ00H0EEFZ001EZP1EEJX0EEFZ001EZP1V<l`2001E
ZP0603=Vc01EEJX0EEFZ03=Vc01EEJX005FZ2P0000001@1E05D0001E0000E@1E05D0001E0080E@1E
00D0001E0000c0000<`005FZ05EEZP02001EZP060000ZP1V<l`0002Z0000ZP0cI/`0IS>I0P0cI/`0
1@1V<iT0<fK<001EZP00EJX0<fK<008005FZ00H0EEFZ03=Vc01EEJX0EEFZ03=Vc01EEJX203=Vc006
05EEZP0cI/`0LW9b079bLP2I<iT0IS=V0P2I<iT01@1V<fH0IVJI06HcIP1V<fH0IVJI0080IS=V00H0
IS>I06HcIP1V<iT0IS>I06HcIP2I<iT206HcIP0609TcV@1V<fH0E@1E05D0E@1V<fH0E@1E0P1V<fH0
1@1EEJX0IS=V06HcV@1V<iT0IS=V0080<fIV1P1V<fH209VIc00605EEZP2IVL`0EEFZ05EEZP2IVL`0
EEFZ0P1EEOl01@1EEJX0EEGo05EEo`1EEJX0EEGo0080EEFZ00H0IS=V06HcV@1V<fH0IS=V06HcV@1B
DU8206HcV@04059BDP1VIYT0VIW<09VIc0@0IVJI00D0EEFZ06HcV@1V<iT0EEFZ06HcV@0K0?ooo`00
8P3oool00`0003<0oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00H0000c0000E@0006H0
001V0000M`0005D20000M`80001V0`0007L20000IP030000M`0006H000000080000000D00`<300L7
1`071`L04@0000004@0200008P0303<000000280000R0080000R00@0oooo0000E@0005D0001E0P00
06H0100005D0001V0000IP0006H20000M`80001V1P0007L20000IP050000V@0007L0002I0000V@00
07L00P0009T01P0007L0002I0000IP0006H0002I001EZP80002I00H005EE0000V@00EED005EE0000
V@00EED20000V@05001EE@0009T0002I001EZP0009T00P00EJX01P000:X005FZ001EZP00EJX006K<
001EZP<006K<00D0002Z001Vc000I/`0001g0000V@02001EZP050000V@0007L0001g0000ZP0007L0
0P000:X01P00EJX0002I001EE@00EED0002I001EE@80002I00D0<fIV0000V@0c09T0<`2I0000V@02
03<0V@060000ZP00EED0002Z0000ZP0c09T0002I0P0cI/`01P0009T0<fK<0000V@0009T0<`2I0000
V@80<fJI00D0002Z03=VV@000:X0002Z03=VV@020000ZP0603=VV@00EJX0IS>I06HcV@00EJX0IS>I
0P00EJX01P1EEJX005FZ05EEZP1EEJX005FZ06Hcc08005FZ00@0<fK<05EEZP1EEJX0<fK<10000006
0?ooo`@0000000<0001E05D0E@0005D00P1E05D01@0005D0003<0000c000EJX0EEFZ008005FZ00H0
002Z06Hcc0000:X0002Z03=Vc01V<iT203=Vc00506HcV@0cI/`005FZ001EZP0cI/`00P00EJX01P1E
EJX0<fK<05EEZP1EEJX0<fK<05EEZP80<fK<00H0EEFZ03=Vc01bLW80LW9b09TcV@1V<fH209TcV@05
06HcIP1VIYT0IS=V06HcIP1VIYT00P1V<fH01P1V<iT0IS=V06HcV@1V<iT0IS=V09TcV@80IS=V00H0
VC>I06HcIP1E05D0E@1E06HcIP1E05D206HcIP0505EEZP1V<fH0IS>I06HcV@1V<fH00P0cIVH606Hc
IP80VIW<00H0EEFZ09VIc01EEJX0EEFZ09VIc01EEJX205EEo`0505EEZP1EEOl0EEGo05EEZP1EEOl0
0P1EEJX01P1V<fH0IS>I06HcIP1V<fH0IS>I059BDP80IS>I00@0DU9B06IVV@2IVL`0VIW<101VIYT0
1@1EEJX0IS>I06HcV@1EEJX0IS>I01/0oooo000R0?ooo`030000E@0004@0oooo00T0oooo00<00000
0?ooo`3oool0303oool00`2I<`00001E0000IP030000IP80001g100006H70000M`0600<30`000140
4@00014000000140000R0P0A000010071`L0000A00008P0002820?ooo`800014100006H0100005D0
001g0000M`0006H40000M`<0001V00<0002I0000IP0006H00P0006H0100007L0001V0000IP0007L2
0000IP80001g0P0009T01P0006H0002I0000V@0009T005FZ0000ZP80002I00<0001g0000V@0009T0
0P0009T2001EZP060000V@00EJX005FZ001EZP000:X005FZ0P000:X50000c005001EZP0006H0001V
0000M`0009T00P0007L0100009T0001g0000M`0006H40000V@05001EZP0009T0002I001EZP0009T0
0P00EJX01@0009T005FZ001EZP00EJX0002I008005FZ00D0<`2I001EZP0cIYT0<fJI001EZP0303=V
V@0603<0V@0cIYT0<`2I03<0V@1EEJX005FZ0P0cIYT01@1V<iT0<fJI06HcV@1V<iT0EEFZ0080<fJI
00D0EEFZ03<0V@1E0:X0E@2Z03<0V@0705D0ZP0506HcV@1E0:X0IS>I06HcV@000:X00P00EJX30000
00X0oooo0`00000505D0E@80<`2I00H0<fK<05D0ZP1V<l`0IS?<05D0ZP00EED2001EZP0405EEZP0c
09T0EEFZ05EEZP80<`2I0P1V<iT01@0c09T0IS>I06HcV@0c09T0<fK<0080<`2I00H0<fK<06Hcc00c
I/`0<fK<06Hcc00cI/`207inOP0609TcV@1bLW80VC>I09TcV@1bLW80VC>I0P1V<fH01@2I<iT0IS=V
06HcIP1V<iT0VC=V0080IS>I00H0VC=V06HcV@1V<fH0IS=V06HcV@1V<fH206HcV@0606HcIP1V<iT0
IS>I06HcV@1E05D0IS>I0P1E05D01@1E0:X0E@1E05D0E@1E0:X0<`1V0080E@2Z00H0<`1V05D0ZP1V
<l`0IS?<03=Vc02ZEJX203=Vc0050:YEZP3<I/`0IVJI06IVV@3<I/`00P1VIYT01P3<I/`0IVJI0<aV
c03<I/`0IS=V06IVV@80IS=V00H0EEFZ06HcIP1EEJX0EEFZ06Hcc02IVL`206Hcc00509VIc01V<l`0
VIW<09VIc01V<fH00P1fMWH00`1V<fH0MWIf0?ooo`0J0?ooo`008P3oool00`0005D000140?ooo`09
0?ooo`030000003oool0oooo00d0oooo00<0001V0000A00004@00P0005D60000IP050000M`0006H0
001V0000M`0006H00`0007L01@1E00000`<300<30`000140<`0000804@0000<0000A00008P3oool0
1@3oool00`0005D0001V0000IP020000E@80001V0P0007L20000IP030000M`0006H0001g00D0001g
00D0002I0000IP0009T0002I0000M`020000V@060000M`0009T0001V0000IP0009T0001V0P0009T0
1P00EJX0002Z001EZP00EJX0002I001EE@80002I00D005EE0000V@0009T005FZ0000V@02001EZP04
0000ZP00EJX0002Z0000ZP8005FZ0P00I/`01P0009T0001g0000V@0009T0001V0000V@80001g00D0
002I0000M`0007L0002I001EE@020000V@06001EZP0009T005EE001EE@0009T005EE0P0009T01@0c
IVH0002I03=VIP0cIVH0002I0080<`2I00H0002Z001EE@000:X0002Z03<0V@000:X203=Vc0060000
ZP0cI/`0002I0000V@0c09T0002I0P0c09T01@000:X0<fJI0000ZP000:X0<fJI0080002Z00H0<fJI
001EZP1V<iT0IS>I001EZP1V<iT2001EZP0605EEZP00EJX0EEFZ05EEZP00EJX0IS?<0P00EJX00`1V
<l`0EEFZ05EEZP02000000<0oooo1@0000040?ooo`80000000D0E@1E0000E@1E05D0E@1E0000E@02
0000c004001EZP1V<l`005FZ001EZP80IS?<0P000:X01P0cI/`0IS>I03=Vc00cI/`0IS>I03=Vc080
05FZ00D0<fK<001EZP00EJX0EEFZ03=Vc00205EEZP0603=Vc01EEJX0<fK<03=Vc01EEJX0<fK<0P1V
<fH01P1^KVh0IS=V09TcV@2I<iT0IS=V06IVV@80IS=V00D0IVJI06HcIP1V<fH0IS>I06HcIP0206Hc
V@0606HcIP2I<iT0IS=V06HcIP2I<iT0IS=V0P1E05D01P1V<fH0E@1E06HcIP1V<fH0EEFZ06HcIP80
EEFZ00<0IS=V05EEZP1EEJX01P1V<fH209VIc00605EEZP2IVL`0EEFZ05EEZP2IVL`0EEFZ0P1EEOl0
1@1EEJX0EEGo05EEo`1EEJX0EEGo0080EEFZ00H0EEGo06HcV@1V<fH0IS=V06HcV@1BDU8206HcV@06
09VIc01VIYT0VIWo09VIo`1VIYT0EEGo0P1VIYT01@1EEJX0IS>I06HcV@1EEJX0IS>I01/0oooo000S
0?ooo`030000A03oool0oooo00H0oooo0`00000?0?ooo`050000A00005D0001E0000E@0006H00P00
05D0100007L0001V0000E@0005D90000M`80E@0000@04@0000L71`0A00004@00203oool30000E@80
001V0P0007L00`0006H0001g0000M`030000M`80001V00@0002I0000IP0009T0002I0P0006H30000
M`80001V0P0007L20000V@030000IP0009T0002I00<0002I0P00EJX00`000:X0002I0000V@050000
V@05001EZP0009T0002I0000ZP00EJX00P000:X01@0007L0002I0000IP0006H0001g00<0001V00D0
001g0000V@0007L0001g0000V@020000M`030000IP0009T0002I0080002I00D005FZ0000V@0009T0
05FZ0000V@02001EZP030000V@00EJX0002I0080002I0P00EJX01P0c09T005FZ03<0V@0c09T005FZ
03=VV@8005FZ00H0<fK<001EZP0cI/`0<fK<05EEZP00EJX205EEZP0506HcV@0cIYT0IS>I06HcV@1E
EJX00P0cIYT01@1EEJX0<`2I05D0ZP1E0:X0<`2I00L0E@2Z00H0IS>I05D0ZP1V<iT0IS>I05D0ZP00
EJX2000000@0oooo0P0000020?ooo`800000103oool2000000<0E@1E00D0IS?<03<0V@0c09T0IS?<
05D0ZP0203=Vc080E@2Z0P1V<l`01000EED0<`2I05EEZP1EEJX203<0V@80IS>I00D0<`2I06HcV@1V
<iT0<`2I03=Vc00203<0V@0603=Vc01V<l`0<fK<03=Vc01V<l`0<fK<0P1nOWh01P2I<iT0VC=V09Tc
V@2I<iT0LW9b09TcV@80IS=V00D0VC>I06HcIP1V<fH0IS>I09TcIP0206HcV@0609TcIP1V<iT0IS=V
06HcIP1V<iT0IS=V0P1V<iT01P1V<fH0IS>I06HcV@1V<iT0E@1E06HcV@80E@1E00D0E@2Z05D0E@1E
05D0E@2Z03<0IP0205D0ZP0603<0IP1E0:X0IS?<06Hcc02IVL`0ZUFZ0P0cI/`01@2ZEJX0c6K<06IV
V@1VIYT0c6K<0080IVJI00@0c6K<06IVV@3<I/`0c6K<0P1VIYT206HcIP0605EEZP1V<fH0EEFZ05EE
ZP1VIYT0ZUGo0P1VIYT01@2ZEOl0IVJI0:YEo`2ZEOl0IS=V0080MWIf00<0IS=V07IfMP3oool06P3o
ool002<0oooo00<000140?ooo`3oool01P3oool3000000l0oooo00D000140000E@0005D0001E0000
IP020000E@040000M`0006H0001E0000E@T0001g0P1E0000100A00001`L70140000A00080?ooo`<0
001E0P0006H20000M`030000IP0007L0001g00<0001g0P0006H0100009T0001V0000V@0009T20000
IP<0001g0P0006H20000M`80002I00<0001V0000V@0009T00`0009T2001EZP030000ZP0009T0002I
00D0002I00D005FZ0000V@0009T0002Z001EZP020000ZP050000M`0009T0001V0000IP0007L00`00
06H01@0007L0002I0000M`0007L0002I0080001g00<0001V0000V@0009T00P0009T01@00EJX0002I
0000V@00EJX0002I008005FZ00<0002I001EZP0009T00P0009T2001EZP0603<0V@00EJX0<`2I03<0
V@00EJX0<fJI0P00EJX01P0cI/`005FZ03=Vc00cI/`0EEFZ001EZP80EEFZ00D0IS>I03=VV@1V<iT0
IS>I05EEZP0203=VV@0505EEZP0c09T0E@2Z05D0ZP0c09T01`1E0:X01P1V<iT0E@2Z06HcV@1V<iT0
E@2Z001EZP8000001@3oool2000000L0oooo0P00000305D0E@0506Hcc00c09T0<`2I06Hcc01E0:X0
0P0cI/`205D0ZP80IS?<00@005EE03<0V@1EEJX0EEFZ0P0c09T206HcV@0503<0V@1V<iT0IS>I03<0
V@0cI/`00P0c09T01P0cI/`0IS?<03=Vc00cI/`0IS?<03=Vc080OWin00H0VC>I09TcIP2I<iT0VC>I
079bLP2I<iT206HcIP0509TcV@1V<fH0IS=V06HcV@2I<fH00P1V<iT01P2I<fH0IS>I06HcIP1V<fH0
IS>I06HcIP80IS>I00H0IS=V06HcV@1V<iT0IS>I05D0E@1V<iT205D0E@0505D0ZP1E05D0E@1E05D0
ZP0c06H00P1E0:X01P0c06H0E@2Z06Hcc01V<l`0VIW<0:YEZP80<fK<00D0ZUFZ0<aVc01VIYT0IVJI
0<aVc00206IVV@040<aVc01VIYT0c6K<0<aVc080IVJI0P1V<fH01P1EEJX0IS=V05EEZP1EEJX0IVJI
0:YEo`80IVJI00D0ZUGo06IVV@2ZEOl0ZUGo06HcIP0207IfMP0306HcIP1fMWH0oooo01X0oooo000S
0?ooo`030000E@0003<0000c00H0oooo0P00000@0?ooo`0309Tc000004@000140080001E0P0006H0
0`0005D0001V0000IP040000IP030000M`0006H0001g00D0001g303oool01@0003<000140000A000
06H0001g0080001V00@0001g0000IP0006H0001V200007L01@0009T0001V0000V@0009T005FZ0080
002I00H0001g0000V@0006H0001V0000V@0006H20000V@06001EZP0009T005FZ001EZP000:X005FZ
0P0009T01@00EED0002I0000V@00EJX0002I008005FZ00<0002Z0000M`0007L00`0007L20000IP06
0000V@0007L0002I0000V@0007L0002I0P0007L01@0009T0001g0000M`0009T005EE0080002I00H0
05EE0000V@00EJX005FZ0000V@00EED20000V@0503=VIP0009T0<fIV03=VIP0009T00P0c09T01P00
09T005EE0000ZP000:X0<`2I0000ZP80<`2I00H0002Z03=Vc0000:X0002Z06Hcc000EJX203<0V@05
0000ZP0cIYT0002Z0000ZP0cIYT00P000:X01P0cIYT0002Z06HcV@1V<iT005FZ06HcV@8005FZ00H0
EEFZ001EZP1EEJX0EEFZ001EZP1V<l`2001EZP0306Hcc0000000000000L0oooo0P0000070?ooo`80
00000P1E05D01@00EJX0003<0000c000EJX0IS?<008005FZ00H0IS?<001EZP0cI/`0<fK<001EZP1V
<iT203=Vc00506HcV@0cI/`005FZ001EZP0cI/`00P00EJX01P1EEJX0<fK<05EEZP1EEJX0<fK<05EE
ZP80<fK<00H0EEFZ03=Vc01V<fH0IS=V06i^KP1V<fH206i^KP0506HcIP1VIYT0IS=V06HcIP1VIYT0
0P1V<fH01P1V<iT0IS=V06HcV@1V<iT0IS=V09TcV@80IS=V00H0VC>I06HcIP1E05D0E@1E06HcIP1E
05D206HcIP0505EEZP1V<fH0EEFZ05EEZP1V<fH00P1EEJX606HcIP80VIW<00H0IVJI09VIc01EEJX0
EEFZ09VIc01EEJX205EEo`0505EEZP1EEOl0EEGo05EEZP1EEOl00P1EEJX01P1EEOl0IS>I06HcIP1V
<fH0IS>I059BDP80IS>I00H0VIWo06IVV@2IVOl0VIWo06IVV@1EEOl206IVV@0505EEZP1V<iT0IS>I
05EEZP1V<iT06`3oool002<0oooo00<0001E0000A00004@01P3oool200000140oooo0P0006H01000
04@0001V0000E@0005D20000IP80001E00@0001V0000E@0005D0001V1@0007L>0?ooo`030<`c0000
05D0001E00D0001V00D0001g0000IP0006H0001g0000IP020000M`040000V@0006H0002I0000V@@0
001V00D0001g0000V@0009T0002I0000M`020000V@040000IP0009T0001V0000IP@0002I00@0002Z
0=3@d03<oiT0c?nI0`3@d=00103<V@00001E0000E@0005D20000M`80002I00D0001g0000V@0009T0
002I0000M`030000IP050000M`0009T0001g0000M`0009T00P0007L00`0006H0002I0000V@020000
V@04001EZP0009T0002I0000V@<005FZ00<0002I001EZP0009T00P0009T2001EZP060000V@00EJX0
<`2I03<0V@00EJX0<fJI0P00EJX01P0cI/`005FZ03=Vc00cI/`005FZ03=Vc080003<00@0IS>I03=V
V@1V<iT0IS>I0`0cIYT01P1EEJX0<fJI05D0ZP1E0:X0<`2I05D0ZP80<`2I1P1E0:X206HcV@0305D0
ZP000000000000P0oooo0P0000060?ooo`8000000P1E05D01@1V<l`0<`2I03<0V@1V<l`0E@2Z0080
<fK<0P1E0:X206Hcc00605D0ZP0c09T0<fK<03=Vc00c09T0EEFZ0P1V<iT01@0c09T0IS>I06HcV@0c
09T0<fK<0080<`2I00H0<fK<03<0V@0cI/`0<fK<06Hcc00cI/`206Hcc00409TcV@2I<fH0VC>I09Tc
V@80VC=V0P1V<iT01@2I<iT0VC=V09TcIP1V<iT0VC=V0080IS>I00H0IS=V06HcV@1V<fH0IS=V06Hc
V@1V<fH206HcV@0606HcIP1V<iT0IS>I06HcV@1E05D0IS>I0P1E05D01@1E0:X0E@1E05D0E@1E0:X0
<`1V0080E@2Z00H0<`1V05D0ZP1V<l`0IS?<09VIc02ZEJX203=Vc0050:YEZP0cI/`0IVJI06IVV@3<
I/`00P1VIYT01P3<I/`0IVJI09VIo`2IVOl0IS?<06IVV@80IS=V00H0EEFZ06HcIP1EEJX0EEFZ06IV
V@2ZEOl206IVV@050:YEo`1VIYT0ZUGo0:YEo`1VIYT00P1fMWH00`1V<fH0MWIf0?ooo`0J0?ooo`00
903oool30000A0<0oooo00@0<`0000000000000000004@3oool20000<`80001E0P0007L00`0005D0
001V0000IP040000IP050000M`0006H0001g0000M`3oojX0403oool30000E@050000M`0006H0001V
0000M`0006H02P0007L00`0009T0001V0000V@040000V@06001EZP0009T0001g0000M`0009T0001V
0P0009T01P00EJX0002I0;fm_@2m_Kd0olc<0?o<V@80olc<00D0olbI0?o<c03oc<`0c?nI0000E@03
0000IP<0001g00H0001V0000M`0007L0001g0000V@0007L20000V@050000M`0009T0001V0000IP00
09T00P0007L01P0009T0001g0000V@0009T005EE0000V@8005FZ0P0009T20000ZP05001EE@0009T0
<fIV03=VIP0009T00P0c09T01P0009T005EE0000ZP000:X005EE0000ZP80<`2I00H0002Z03=Vc000
0:X0002Z03=Vc000EJX206Hcc0@006K<00D0<fJI0000ZP000:X0<fJI0000ZP0206HcV@06001EZP1V
<iT005FZ001EZP1EEJX005FZ0P1EEJX01@00EJX0IS?<001EZP00EJX0IS?<008000002@3oool20000
00D0oooo0P00000203=Vc005001EZP000<`0003<001EZP1V<l`00P00EJX01P1V<l`005FZ03=Vc00c
I/`005FZ05EEZP80<fK<00D0EEFZ03=Vc01V<l`0IS?<03=Vc00206Hcc080<fK<0P1EEJX01P0cI/`0
EEFZ03=Vc00cI/`0EEFZ03=Vc080EEFZ00H0KVi^06HcIP1^KVh0KVi^06HcIP1V<iT206HcIP0506Hc
V@1V<fH0IS=V06HcV@1V<fH00P1V<iT01P1V<fH0VC>I06HcIP1V<fH0VC>I06HcIP80E@1E00H0IS=V
05D0E@1V<fH0IS=V05EEZP1V<fH205EEZP0306HcIP1EEJX0EEFZ00H0IS=V0P2IVL`01P1VIYT0VIW<
05EEZP1EEJX0VIW<05EEZP80EEGo00D0EEFZ0:YEo`2ZEOl0IVJI03=Vc00206IVV@0603=Vc01V<iT0
IS=V06HcIP1V<iT0DU9B0P1V<iT01P2IVOl0IVJI09VIo`2IVOl0IVJI05EEo`80IVJI00D0EEGo06Hc
V@1V<iT0EEFZ06HcV@0K0?ooo`00903oool30000A0<0oooo00@0<`0000000000000000004@3oool2
0000<`80001E0P0007L00`0005D0001V0000IP040000IP050000M`0006H0001g0000M`3oojX0403o
ool30000E@050000M`0006H0001V0000M`0006H02P0007L00`0009T0001V0000V@040000V@06001E
ZP0009T0001g0000M`0009T0001V0P0009T01P00EJX0002I0;fm_@2m_Kd0olc<0?o<V@80olc<00D0
olbI0?o<c03oc<`0c?nI0000E@030000IP<0001g00H0001V0000M`0007L0001g0000V@0007L20000
V@050000M`0009T0001V0000IP0009T00P0007L01P0009T0001g0000V@0009T005EE0000V@8005FZ
0P0009T20000ZP05001EE@0009T0<fIV03=VIP0009T00P0c09T01P0009T005EE0000ZP000:X005EE
0000ZP80<`2I00H0002Z03=Vc0000:X0002Z03=Vc000EJX206Hcc0@006K<00D0<fJI0000ZP000:X0
<fJI0000ZP0206HcV@06001EZP1V<iT005FZ001EZP1EEJX005FZ0P1EEJX01@00EJX0IS?<001EZP00
EJX0IS?<008000001@3oool200000080oooo0P0000050?ooo`8000000P0cI/`01@00EJX0003<0000
c000EJX0IS?<008005FZ00H0IS?<001EZP0cI/`0<fK<001EZP1EEJX203=Vc00505EEZP0cI/`0IS?<
06Hcc00cI/`00P1V<l`203=Vc080EEFZ00H0<fK<05EEZP0cI/`0<fK<05EEZP0cI/`205EEZP0606i^
KP1V<fH0KVi^06i^KP1V<fH0IS>I0P1V<fH01@1V<iT0IS=V06HcIP1V<iT0IS=V0080IS>I00H0IS=V
09TcV@1V<fH0IS=V09TcV@1V<fH205D0E@0606HcIP1E05D0IS=V06HcIP1EEJX0IS=V0P1EEJX00`1V
<fH0EEFZ05EEZP0606HcIP80VIW<00H0IVJI09VIc01EEJX0EEFZ09VIc01EEJX205EEo`0505EEZP2Z
EOl0ZUGo06IVV@0cI/`00P1VIYT01P0cI/`0IS>I06HcIP1V<fH0IS>I059BDP80IS>I00H0VIWo06IV
V@2IVOl0VIWo06IVV@1EEOl206IVV@0505EEo`1V<iT0IS>I05EEZP1V<iT06`3oool002@0oooo0P2Z
E@020000A080VC<000<0<`0009Tc003oool04P3oool40000A080001E1@0006H20000E@050000IP00
07L0c?mV0<coIP3oc9T0403oool20000A0060000E@0006H0001V0000IP0005D0001g100006H40000
M`80002I100006H30000M`@0002I00H0001V0000V@3<oiT0c?nI0?ooZP3<oiT20?ooZP040;fm_@3@
d=00c?nI0<coV@<0d=3@00H0`<300000A00005D0001E0000IP0007L20000IP030000M`0009T0001g
0080001g0`0006H01@0007L0001V0000M`0007L0002I0080001g1@0009T00`00EJX0002I0000V@02
001EZP80002I0P00EJX30000V@8005FZ00H0002I001EZP0c09T0<`2I001EZP0cIYT2001EZP0603=V
V@00EJX0<fK<03=Vc000EJX0<fK<0P000<`01@0cI/`0IS?<0000ZP000:X0IS?<008006K<00H0<fJI
001Vc00cIYT0<fJI002ZZP0cI/`203<0V@H0E@2Z0P1V<iT00`1E0:X00000000000060?ooo`@00000
1P3oool20000008005FZ00D0IS?<03<0V@0c09T0IS?<03<0V@0203=Vc00605D0ZP0cI/`0IS?<06Hc
c01E0:X0IS?<0P0cI/`01@0c09T0<fK<05EEZP1EEJX0<`2I0080EEFZ00H0<`2I05EEZP1V<l`0IS?<
05EEZP1V<l`205EEZP0606Hcc01EEJX0IS?<06Hcc02I<iT0VC=V0P2I<iT209TcIP80IS>I00D0VC=V
09TcV@2I<iT0IS=V09TcIP0206HcV@0606HcIP1V<iT0IS=V06HcIP1V<iT0IS=V0P1V<iT01P1V<fH0
E@1E06HcV@1V<iT0E@1E06HcV@80E@1E00D0E@2Z05D0E@1E05D0E@2Z03<0IP0205D0ZP0603<0IP1E
0:X0IS?<06Hcc02IVL`0ZUFZ0P0cI/`01@1VIYT0ZUGo06IVV@1VIYT0EEGo0080IVJI00H0VIWo06Hc
c02IVOl0VIWo06Hcc01VIYT206HcIP0605EEZP1V<fH0EEFZ05EEZP1VIYT0ZUGo0P1VIYT01@2ZEOl0
IVJI0:YEo`2ZEOl0IVJI0080MWIf00<0IS=V07IfMP3oool06P3oool002@0oooo0P2ZE@001@2I<`00
000c0000A00004@0c3<001@0oooo0P2ZE@020000A080001E00D000140000E@0005D0001E0000IP02
09W<IP050?o<V@3oojX0c9UV0<bIIP3oojX0403oool20:YE0080001E0P0006H00`0005D0001V0000
M`050000M`030000IP0007L0001g0080001g00@0001V0000V@0009T0001V100009T20?ooIP060?oo
c02e]KD0olc<0?o<c030`<00olc<0P3<oiT01@3oc<`0d=3@0?o<c03oc<`0c?nI0080olc<00@0c?nI
0000A00005D0001E0P0006H70000M`050000IP0009T0002I0000M`0009T00P0006H01@0009T0001V
0000IP0009T0001g0080002I00@005EE0000V@00EJX005FZ0P0009T20000ZP050000V@000:X0<fIV
03=VIP0009T00P0c09T01P0009T005EE0000ZP000:X005EE0000ZP80<`2I00H0002Z03=Vc0000:X0
002Z03=Vc0000:X206Hcc003001EZP00I/`006K<00@006K<00H0<fK<001Eo`0cI/`0<fK<001Eo`0c
c<`2001Vo`0603?<c000I_l009W<002Ic000VOl009W<0P00VOl00`00VL`000000000000@0?ooo`80
00000P1V<l`01@000:X0003<0000c000EJX0003<008005FZ00D0IS?<001EZP0cI/`0<fK<001EZP03
03=Vc00505EEZP0cI/`0EEFZ05EEZP0cI/`00P1V<l`01P0cI/`0EEFZ03=Vc00cI/`0EEFZ03=Vc080
ZUFZ00H0<fK<0:YEZP0cI/`0<fK<06i^KP1V<fH206i^KP0506HcIP1V<iT0IS=V06HcIP1V<iT01`1V
<fH01@2I<iT0IS=V06HcIP2I<iT0IS=V0080E@1E00H0IS=V05EEZP1V<fH0IS=V05EEZP1V<fH205EE
ZP0306HcIP1EEJX0EEFZ00D0IS=V00D0IVJI09VIc02IVL`0IVJI05FZo`0206IVV@0505FZo`1VIYT0
ZUGo0:YEo`1VIYT00P2ZEOl01P1VIYT0<fK<06IVV@1VIYT0<fK<06IVV@80IS=V00H0IS>I059BDP1V
<iT0IS>I09VIo`1VIYT209VIo`0506IVV@1EEOl0IVJI06IVV@1EEOl00P1V<iT00`1EEJX0IS>I0?oo
o`0J0?ooo`009P3oool01@3<V@00ZUD009Tc002I<`00ZUD001H0oooo00H000140000E@0004@00014
0000IP0005D20000IP0509W<IP2Ic3<0VL`c0?o<V@2ZZUD00P3<ofHA0?ooo`80c9T00P0005D20000
IP030000E@0007L0001V00D0001V0P0007L20000V@050000M`0009T0001V0000IP3oojX00P0007L0
0`3oc9T0d=3@0?o<V@030?o<V@80c?nI00H0b<S80?o<V@3<ol`0c?o<0<coV@3@d=020<coV@050<S8
b03<oiT0c?nI0?o<c03oZZX00`0005D01@0006H0001g0000M`0007L0002I00L0001g00<0001V0000
M`0007L02`0009T01P00EJX0002I0000V@0009T005FZ0000V@D005FZ00H0002I001EZP0c09T0<`2I
001EZP0cIYT2001EZP0603=VV@00EJX0<fK<03=Vc000EJX0<fK<0P000<`01@0cI/`0003<0000ZP00
0:X0IS?<0080002Z00H0IS?<001Vc00cIYT0<fJI001Vc00cIYT2002ZZP0603=Vc000ZZX0<fK<03=V
c000VL`0<fK<0P3<VIT0103<VL`0c9VI00000000000>0?ooo`80000000@005FZ0000ZP000:X0003<
0P0c09T01P1V<l`0<`2I03=Vc00cI/`0E@2Z03=Vc080IS?<00H0E@2Z06Hcc00cI/`0<fK<03<0V@0c
I/`303<0V@80EEFZ00H0<`2I05EEZP1V<l`0IS?<05EEZP1V<l`205EEZP0606Hcc01EEJX0IS?<06Hc
c02I<iT0VC=V0P2I<iT01@1V<iT0VC=V06HcV@1V<iT0VC=V0080VC>I00D0IS=V09TcV@1V<fH0IS=V
05D0E@0306HcIP0606HcV@1V<fH0IS>I06HcV@1V<fH0E@1E0P1V<iT01@1E05D0IS>I05D0E@1E05D0
E@2Z0080E@1E00H0E@2Z03<0IP1E0:X0E@2Z03<0IP2IVOl206IVV@0609VIo`1VIYT0ZUGo0:YEo`1V
IYT0ZUGo0P1VIYT01@1EEOl0IVJI06IVV@1EEOl0IS?<0080VIWo00<0IS?<09VIo`1V<iT01@1V<iT0
1P1VIYT0ZUGo06IVV@1VIYT0ZUGo06IVV@80ZUGo00D0IVJI07IfMP1fMWH0IS=V07IfMP0K0?ooo`00
9P3oool01@3<V@00ZUD009Tc002I<`00ZUD001H0oooo00H000140000E@0004@000140000IP0005D2
0000IP0509W<IP2Ic3<0VL`c0?o<V@2ZZUD00P3<ofHA0?ooo`80c9T00P0005D20000IP030000E@00
07L0001V00D0001V0P0007L20000V@050000M`0009T0001V0000IP3oojX00P0007L00`3oc9T0d=3@
0?o<V@030?o<V@80c?nI00H0b<S80?o<V@3<ol`0c?o<0<coV@3@d=020<coV@050<S8b03<oiT0c?nI
0?o<c03oZZX00`0005D01@0006H0001g0000M`0007L0002I00L0001g00<0001V0000M`0007L02`00
09T01P00EJX0002I0000V@0009T005FZ0000V@D005FZ00H0002I001EZP0c09T0<`2I001EZP0cIYT2
001EZP0603=VV@00EJX0<fK<03=Vc000EJX0<fK<0P000<`01@0cI/`0003<0000ZP000:X0IS?<0080
002Z00H0IS?<001Vc00cIYT0<fJI001Vc00cIYT2002ZZP0603=Vc000ZZX0<fK<03=Vc000VL`0<fK<
0P3<VIT0103<VL`0c9VI00000000000>0?ooo`80000000@005FZ0000ZP000:X0003<0P0c09T01P1V
<l`0<`2I03=Vc00cI/`0E@2Z03=Vc080IS?<00H0E@2Z06Hcc00cI/`0<fK<03<0V@0cI/`303<0V@80
EEFZ00H0<`2I05EEZP1V<l`0IS?<05EEZP1V<l`205EEZP0606Hcc01EEJX0IS?<06Hcc02I<iT0VC=V
0P2I<iT01@1V<iT0VC=V06HcV@1V<iT0VC=V0080VC>I00D0IS=V09TcV@1V<fH0IS=V05D0E@0306Hc
IP0606HcV@1V<fH0IS>I06HcV@1V<fH0E@1E0P1V<iT01@1E05D0IS>I05D0E@1E05D0E@2Z0080E@1E
00H0E@2Z03<0IP1E0:X0E@2Z03<0IP2IVOl206IVV@0609VIo`1VIYT0ZUGo0:YEo`1VIYT0ZUGo0P1V
IYT01@1EEOl0IVJI06IVV@1EEOl0IS?<0080VIWo00<0IS?<09VIo`1V<iT01@1V<iT01P1VIYT0ZUGo
06IVV@1VIYT0ZUGo06IVV@80ZUGo00D0IVJI07IfMP1fMWH0IS=V07IfMP0K0?ooo`009P3oool0101V
IP00ZUD009Tc002I<`0G0?ooo`040:YE000003<0001E0000E@@0VC<000D0VLaV0<coIP3<ofH0c9UV
0?ooZP020<bIIQ<0oooo00<0000c0000A00005D00P0005D0100006H0001g0000M`0006H30000M`03
0000IP0009T0001g0080001g00@0]KFe0?ooZP3oojX0c9VI0P3ool`01P3oofH0ooo<0?ooIP3oofH0
ooo<0?o<V@80ooo<00H0olbI0?o<c03<oiT0c?nI0?o<c03@d=020?o<c0050<30`03oc<`0olc<0:[o
ZP3oc<`00`0005D00`0006H0001g0000M`050000M`050000IP0009T0002I0000M`0009T00P0006H0
1@0009T0001V0000IP0009T0001g0080002I00H005EE0000V@00EJX005FZ0000V@00EJX20000ZP05
0000V@000:X005Go001Eo`000:X00P0c09T01P0009T0<`2I0000ZP000:X005EE0000ZP80<`2I00H0
002Z03<0V@000:X0002Z03=Vc0000:X206Hcc003001EZP1V<l`006K<00D006K<00D005Go03=Vc00c
I/`005Go03=Vc002001Eo`0603?<c000I_l0c6K<0<aVc02a/K40c6K<0P2IVL`00`2QXJ40c9W<0<bI
c002000000`0oooo0P0000001000EJX0002Z06Hcc01V<l`4001EZP050000c000EJX005FZ06Hcc000
EJX00P0cI/`01P00EJX0<fK<001EZP00EJX0EEFZ03=Vc080EEFZ00D0<fK<06Hcc01V<l`0<fK<06Hc
c00203=Vc00605EEZP0cI/`0EEFZ05EEZP0cI/`0ZUFZ0P0cI/`01P2ZEJX0IS=V06i^KP1^KVh0IS=V
06HcV@X0IS=V00D0ZP2Z06HcIP1V<fH0E@1E06HcIP0205D0E@0606HcIP1EEJX0IS=V06HcIP1EEJX0
IS=V0P1EEJX00`1V<fH0EEFZ05EEZP0506HcIP0506IVV@2ZEOl0ZUGo06IVV@2ZEOl00P1VIYT01@1E
Z_l0IVJI05FZo`1EZ_l0IVJI0080ZUGo00H0IVJI03=Vc01VIYT0IVJI03=Vc01VIYT203<0IP0606Hc
IP0c06H0IS=V06HcIP2IVOl0IVJI0P2IVOl01@1VIYT0EEGo06IVV@1VIYT0EEGo0080IS>I00<0EEFZ
06HcV@3oool06P3oool00440oooo00@0c9T00<`c002Z0000ZP000P2ZE@020:[oZP0505D0002Ic9T0
VLbI0<coIP3oc9T05@3oool00`2ZE@0000140000E@020000E@<0001V00<0001g0000IP0006H00`00
06H30<coV@040?ooZP3oc9T0olbI0<coc080oonZ00H0olbI0=3@d03oc9T0olbI0<coV@38b<P20?nZ
ZP060<S8b03oc9T0d=3@0=3@d03<oiT0d=3@0P3<oiT01@38b<P0c?nI0<coV@34a<@0_Kfm00800014
00H0001E0000IP0006H0001V0000M`0006H40000V@80001g00D0002I0000IP0007L0001g0000V@02
0000M`80002I0P0006H40000V@06001EZP0009T0002I0000V@00EJX0002I0P00EJX01@00I/`0003<
0000c000EJX0003<0080<`2I00H005FZ03<0V@00EJX005FZ03=VV@00EJX203=Vc006001EZP0cI/`0
05FZ001EZP0cI/`0003<0P000:X01@1V<l`0002Z0000ZP1V<l`0002Z0080<fJI00<006K<0<bIc03<
VL`00P3<VL`01@2UYJD0c9W<0<bIc02IVOl0c9W<0080c9VI00<0c9W<0:6QX@2QXJ400`00000:0?oo
o`<000000P00EJX20000ZP050000c0000:X0002Z06Hcc0000<`00P1V<l`01P1E0:X0<fK<06Hcc01V
<l`0E@2Z06Hcc080E@2Z00D0<`2I03=Vc00c09T0<`2I03=Vc00205EEZP0603<0V@1EEJX0IS?<06Hc
c01EEJX0IS?<0P1EEJX01P1V<l`0EEFZ06Hcc01V<l`0EEFZ09TcIP80VC>I00D0IS>I09TcIP1V<iT0
IS>I06HcIP0209TcV@0606HcIP2I<iT0IS=V06HcIP1E05D0IS=V0P1E05D00`1V<fH0E@1E06HcIP02
06HcIP0505D0E@1V<iT0IS>I05D0E@1E0:X00P1E05D01@1E0:X0E@1E05D0E@1E0:X0<`1V0080E@2Z
00H0<`1V09VIo`1VIYT0IVJI09VIo`1VIYT20:YEo`0506IVV@2ZEOl0IVJI06IVV@1EEOl00P1VIYT0
1P1EEOl0IS?<09VIo`2IVOl0IS?<09VIo`H0IS>I00H0IVJI0:YEo`1VIYT0IVJI0:YEo`1VIYT20:YE
o`0506IVV@1fMWH0MWIf06HcIP1fMWH06`3oool00480oooo00<0ZUD00?mV003oIP000P2ZE@0203<0
000403?oV@2ZojX0Z_nZ0<coVAH0oooo00@0ZUD00000E@0005D0001E0P0006H20000M`060000IP00
07L0E@0005D0002Ic9T0oonZ0P3<VC<01@3oojX0c9VI0?ooc03ool`0oonZ0080ooo<00H0oomV0?oo
c02a/K40/K6a0?ooc03oc9T20?ooc0060<coV@3oc<`0d=3@0=3@d03oc<`0d=3@0P3oc<`01@30`<00
olc<0?o<c02ZojX0olc<0080Z_nZ00@0001E0000IP0006H0001V1@0007L01@0006H0002I0000V@00
06H0002I0080001g00D0002I0000IP0006H0002I0000IP020000ZP06001EE@0009T005FZ001EZP00
09T005FZ0`0009T010000:X0002I0000V@000:X2001Eo`06001Vc000EJX006K<001Vc000EJX006K<
0P0c09T01P000:X0<`2I0000ZP000:X0<fK<0000ZP80<fK<00@005FZ06Hcc000EJX005FZ0`00I/`0
1P30`<00c9W<09VIo`2IVOl0]KFe09VIo`80]KFe00H0VIWo0<bIc03<I/`0c6K<0;6a/@3<I/`20;6a
/@040:6QX@3<VL`0c9W<06K<c0@000001P3oool4000000030000ZP00EJX0002Z0080IS?<00<005FZ
06Hcc01V<l`01000EJX01P1V<l`005FZ06Hcc01V<l`005FZ03=Vc08005FZ00D0EEFZ03=Vc01EEJX0
EEFZ03=Vc00206Hcc00603=Vc01V<l`0<fK<03=Vc01EEJX0<fK<0P1EEJX01P0cI/`0ZUFZ03=Vc00c
I/`0ZUFZ06HcIP80KVi^00<0IS=V06HcV@1V<fH01P1V<fH20:X0ZP0606HcIP2Z0:X0IS=V06HcIP1E
0:X0IS=V0P1E0:X01P1V<fH0LW9b05D0E@1E05D0LW9b06HcIP80EEFZ00<0IS=V05EEZP1EEJX01@1V
<fH01@1VIYT0ZUGo0:YEo`1VIYT0ZUGo0080IVJI00D0EJ[o06IVV@1EZ_l0EJ[o06IVV@020:YEo`06
06IVV@2ZEOl0IVJI06IVV@0cI/`0IVJI0P0c06H01P1V<fH0<`1V06HcIP1V<fH0VIWo06IVV@80VIWo
00D0IVJI09VIo`1VIYT0IVJI05EEo`0206IVV@0305EEZP1V<iT0oooo01X0oooo00120?ooo`030:YE
003oIP00ofH00080ZUD00P0c0000100coiT0Z_nZ0:[oZP3<oiTF0?ooo`040:YE000005D0001E0000
E@80001V0P0007L01P0006H0001g05D0001E0000VLbI0?ooZP80c9Tc00D0oonZ0<bIV@3ool`0ooo<
0?ooZP020?ooc0060?ooIP3ool`0/K6a0;6a/@3ool`0olbI0P3ool`01P3<oiT0olc<0=3@d03@d=00
olc<0=3@d080olc<00D0`<300?o<c03oc<`0Z_nZ0?o<c0020:[oZP040000E@0006H0001V0000IPD0
001g00D0001V0000V@0009T0001V0000V@020000M`050000V@0006H0001V0000V@0006H00P000:X0
1P00EED0002I001EZP00EJX0002I001EZP<0002I00@0002Z0000V@0009T0002Z0P00EOl01P00I/`0
05FZ001Vc000I/`005FZ001Vc080<`2I00H0002Z03<0V@000:X0002Z03=Vc0000:X203=Vc004001E
ZP1V<l`005FZ001EZP<006K<00H0`<300<bIc02IVOl0VIWo0;Fe]@2IVOl20;Fe]@0609VIo`3<VL`0
c6K<0<aVc02a/K40c6K<0P2a/K401P2QXJ40c9W<0<bIc01Vc<`0c9W<0:YEZPX000000`000:X01@00
EJX0002Z06Hcc01V<l`005FZ0080IS?<1000EJX01P1V<l`005FZ06Hcc01V<l`005FZ03=Vc08005FZ
00D0EEFZ03=Vc01EEJX0EEFZ03=Vc00206Hcc00603=Vc01V<l`0<fK<03=Vc01EEJX0<fK<0P1EEJX0
1P0cI/`0ZUFZ03=Vc00cI/`0ZUFZ06HcIP80KVi^00<0IS=V06HcV@1V<fH01P1V<fH20:X0ZP0606Hc
IP2Z0:X0IS=V06HcIP1E0:X0IS=V0P1E0:X01P1V<fH0LW9b05D0E@1E05D0LW9b06HcIP80EEFZ00<0
IS=V05EEZP1EEJX01@1V<fH01@1VIYT0ZUGo0:YEo`1VIYT0ZUGo0080IVJI00D0EJ[o06IVV@1EZ_l0
EJ[o06IVV@020:YEo`0606IVV@2ZEOl0IVJI06IVV@0cI/`0IVJI0P0c06H01P1V<fH0<`1V06HcIP1V
<fH0VIWo06IVV@80VIWo00D0IVJI09VIo`1VIYT0IVJI05EEo`0206IVV@0305EEZP1V<iT0oooo01X0
oooo00120?ooo`050<`c003<V@00c9T00:YE001E00000P00ZZX0103oc9T0ZZYE0:ZZE@3<ofHG0?oo
o`050000A00005D0001E0000E@0006H00P0005D01P0007L0ZP000?o<V@3oc9T0c?mV0:[oZP80oonZ
00<0c?nI0<coc03oc9T00P3oc9T30=3@d0050?ooc03oc<`0olc<0?nZZP38b<P00P3oZZX01P3<ol`0
olbI0=3@d03@d=00c?nI0=3@d080c?nI00D0b<S80;fm_@2m_Kd0a<C40;fm_@020<C4a080001E1000
06H30000M`040000V@0007L0001g0000M`@0002I0P0007L40000V@060000c0000:X0002I0000V@00
EJX0002I0`00EJX0100009T005FZ001EZP00I/`2001EZP06001Vc0000<`005FZ001EZP000<`0^KVi
0P3oc<`01P2i^KT0b<S80?o<c03oc<`0b<S80<c<c080c9W<00D0c<c<0<bIc03<c<`0c<c<0<bIc002
0<30`0030;^k^`30`<00c9W<00H0c9W<00D0VIWo0<bIc03<VL`0VIWo0<bIc00209VIo`0509VIc02Q
XJ40XJ6Q09VIc02QXJ400P2a/K400`3<I/`0000000000004000000030000ZP00EJX005FZ0080002I
0P00EJX20000ZP050000c0000:X0002Z06Hcc0000<`00`1V<l`01@000<`0E@2Z05D0ZP1E0:X0IS?<
0080E@2Z00D0<`2I03=Vc00c09T0<`2I03=Vc00205EEZP0603<0V@1EEJX0<`2I03<0V@1EEJX0IS?<
0P1EEJX01@1V<l`0EEFZ06Hcc01V<l`0EEFZ00<0VC=V00D0IS>I09TcIP1V<iT0IS>I06HcIP0209Tc
V@0606HcIP2I<iT0IS=V06HcIP1E05D0IS=V0P1E05D01P1V<fH0E@1E06HcIP1V<fH0E@1E06HcIP80
IS>I1`1V<fH01P0c06H0IS=V03<0IP0c06H0IS=V06Hcc080IVJI00H0VIWo06IVV@2ZEOl0ZUGo06IV
V@2ZEOl206IVV@0505EEo`1VIYT0IVJI05EEo`1VIYT00P2IVOl00`1V<l`0VIWo06HcV@0506HcV@06
06IVV@2ZEOl0IVJI06IVV@2ZEOl0IVJI0P2ZEOl00`1VIYT0ZUGo0:YEo`0203<0<a/0oooo00150?oo
o`050:YE000coiT0c3<00<`c001E00006P3oool0102ZE@0000140000A00005D30000IP0603<0002E
UID0c?nI0<coV@30`<00oonZ0P2e]KD20?ooZP80ooo<00D0_Kfm0?ooc03ool`0c?nI0?ooc0020;6a
/@060?ooc03oc9T0ooo<0?ooc03<oiT0olc<0P3@d=001@3oc<`0d=3@0?o<c03oc<`0`<300080olc<
00D0Z_nZ0?o<c03oZZX0ojZZ0000A0030000IPD0001g0`0009T0100006H0002I0000M`0007L30000
ZP040000V@0006H0002I0000V@8005FZ0P00I/`00`0009T005FZ0000V@020000V@040000ZP0009T0
002I0000ZP8005Go00H0002Z001Eo`00I/`006K<0;Vi^@3<c<`20;Vi^@060<S8b03<VL`0b<S80<S8
b03<VL`0`<300P3oc<`01@30`<00olc<0<30`030`<00olco0080c9W<0P30`<0209VIo`060;Fe]@2I
VOl0]KFe0;Fe]@2IVOl0/K6a0P3<I/`01@2a/K40c6K<0;6a/@2a/K40I/c<0080c9W<00H0I/c<0<bI
c02ZEJX0ZUFZ09VIc02e]KD209VIc0050:YEZP0009T0001V0000IP0009T01@000:X3001EZP80IS?<
1000EJX01P00EOl005FZ001Eo`00EOl005FZ03=Vc08005FZ0P0cI/`205EEZP0503=Vc01V<l`0IS?<
03=Vc01V<l`00P0cI/`01P1EEJX0<fK<05EEZP1EEJX0<fK<0:YEZP80<fK<00H0ZUFZ06HcIP1V<iT0
IS>I06HcIP1V<iT706HcIP80ZP2Z00H0IS=V0:X0ZP1V<fH0IS=V05D0ZP1V<fH205D0ZP0606HcIP1b
LW80E@1E05D0E@1bLW80E@1E0P1V<iT01@1E05D0IS>I06HcV@1E05D0CTi>0080E@1E00H0CTi>06IV
V@2ZEOl0ZUGo06IVV@2ZEOl206IVV@0505FZo`1VIYT0EJ[o05FZo`1VIYT00P2ZEOl01P1VIYT0ZUGo
06IVV@1VIYT0<fK<06IVV@80<`1V00H0IS=V03<0IP1V<fH0IS=V09VIo`1VIYT209VIo`0506IVV@2I
VOl0IVJI06IVV@1EEOl00P1VIYT00`1E05D0E@000?ooo`0J0?ooo`00AP3oool309Tc01`0oooo0P2Z
E@001P2Z0000001E0:X0002Z000009UV0<coV@80olbI00H0Z_nZ0<coV@3oojX0oonZ0?o<V@3<ol`3
0?o<V@80ooo<00H0d=3@0<coV@3oc<`0olc<0?nZZP38b<P20?o<V@060<coc03<oiT0d=3@0=3@d03<
oiT0b<S80P3<oiT01@38b<P0_Kfm0;fm_@34a<@0_Kfm0080olc<00D0b<S80000E@0005D0001E0000
IP040000M`030000V@0007L0001g0080001g0`0009T3001EZP@0002I00D005FZ0000c0000<`0002Z
0000c0020000ZP80002I0P00EJX01@0009T005FZ001EZP00I/`0olc<0080d=3@00<0olc<0;Vi^@3o
c<`00P3oc<`01038b<P0olc<0?o<c038b<P30<bIc0050<c<c03<VL`0c<c<0<c<c03<VL`00P30`<00
1@2k^k/0_Kfm0<bIc03<VL`0_Kfm00@0c9W<00D0ZZ[o0<bIc03<VL`0VIWo0<bIc00209VIo`0509VI
c02QXJ40XJ6Q09VIc02QXJ400P2IVL`01P3<I/`0c9W<0;Fe]@2e]KD0/K6a0<aVc080001g00H0002I
0000ZP0009T0002I001EZP00I/`2001EZP030000c0000:X0002Z0080003<0P1V<l`20000c080IS?<
00H0<`2I001EZP0c09T0<`2I06Hcc00cI/`203<0V@0503=Vc00c09T0<`2I03<0V@1EEJX00P0c09T0
1P1EEJX0IS?<05EEZP1EEJX0IS?<05EEZP80IS?<00H0EEFZ06Hcc02I<fH0VC=V05D0E@2I<fH209Tc
V@0506HcIP2I<iT0VC>I06HcIP2I<iT00P1V<fH01P1E05D0IS=V05D0E@1E05D0IS=V05D0E@80IS=V
00@0IS>I06HcIP1V<iT0IS>I1`1V<fH01P0c06H0IS=V03<0IP0c06H0IS=V06Hcc080IVJI00H0VIWo
06IVV@2IVOl0VIWo06IVV@2ZEOl206IVV@0505EEo`1VIYT0IVJI05EEo`1VIYT00P2IVOl0101V<l`0
VIWo06Hcc01V<l`406HcV@0606IVV@2ZEOl0IVJI06IVV@2ZEOl0IVJI0P2ZEOl0101VIYT0ZUGo0:YE
o`0c03<L0?ooo`00AP3oool309Tc01`0oooo0P2ZE@001P2Z0000001E0:X0002Z000009UV0<coV@80
olbI00H0Z_nZ0<coV@3oojX0oonZ0?o<V@3<ol`30?o<V@80ooo<00H0d=3@0<coV@3oc<`0olc<0?nZ
ZP38b<P20?o<V@060<coc03<oiT0d=3@0=3@d03<oiT0b<S80P3<oiT01@38b<P0_Kfm0;fm_@34a<@0
_Kfm0080olc<00D0b<S80000E@0005D0001E0000IP040000M`030000V@0007L0001g0080001g0`00
09T3001EZP@0002I00D005FZ0000c0000<`0002Z0000c0020000ZP80002I0P00EJX01@0009T005FZ
001EZP00I/`0olc<0080d=3@00<0olc<0;Vi^@3oc<`00P3oc<`01038b<P0olc<0?o<c038b<P30<bI
c0050<c<c03<VL`0c<c<0<c<c03<VL`00P30`<001@2k^k/0_Kfm0<bIc03<VL`0_Kfm00@0c9W<00D0
ZZ[o0<bIc03<VL`0VIWo0<bIc00209VIo`0509VIc02QXJ40XJ6Q09VIc02QXJ400P2IVL`01P3<I/`0
c9W<0;Fe]@2e]KD0/K6a0<aVc080001g00H0002I0000ZP0009T0002I001EZP00I/`2001EZP030000
c0000:X0002Z0080003<0P1V<l`20000c080IS?<00H0<`2I001EZP0c09T0<`2I06Hcc00cI/`203<0
V@0503=Vc00c09T0<`2I03<0V@1EEJX00P0c09T01P1EEJX0IS?<05EEZP1EEJX0IS?<05EEZP80IS?<
00H0EEFZ06Hcc02I<fH0VC=V05D0E@2I<fH209TcV@0506HcIP2I<iT0VC>I06HcIP2I<iT00P1V<fH0
1P1E05D0IS=V05D0E@1E05D0IS=V05D0E@80IS=V00@0IS>I06HcIP1V<iT0IS>I1`1V<fH01P0c06H0
IS=V03<0IP0c06H0IS=V06Hcc080IVJI00H0VIWo06IVV@2IVOl0VIWo06IVV@2ZEOl206IVV@0505EE
o`1VIYT0IVJI05EEo`1VIYT00P2IVOl0101V<l`0VIWo06Hcc01V<l`406HcV@0606IVV@2ZEOl0IVJI
06IVV@2ZEOl0IVJI0P2ZEOl0101VIYT0ZUGo0:YEo`0c03<L0?ooo`00I`3oool01P2I<`00E@00001E
ZP00EJX009W<09W<V@80oonZ00<00:ZZ0?ooZP3ool`00P3ool`0103oojX0ooo<0?ooc03<oiT20?oo
c0060<coV@3ool`0olbI0?o<V@3ool`0d=3@0P3Ph>001P38b<P0f=SH0?o<c03oc<`0f=SH0<coc080
f=SH00D0Z_nZ0?o<c03oc<`0Z_nZ0<c<c0020?nZZP030<c<c00005D0001V0080001V1@0007L20000
V@050000IP0009T0001g0000M`0009T00P0007L60000ZP<005FZ00D0/K6a0?ooc03ool`0c9VI0?oo
c0020<30`0050?o<c03oc9T0olbI0=CDe03oc9T00P3<c<`01P3@d=00c<c<0;Vi^@2i^KT0b<S80<bI
c080b<S800H0oj[o0<S8b03oc<`0olc<0<30`03oc?l20<30`0030?o<o`30`<00`<300080`<300P2I
VOl01P30`<00VIWo0;Fe]@2e]KD0c9W<0;^k^`80c6K<00D0/K6a0<aVc02m_Kd0_Kfm0:ZZo`020<bI
c00606K<c03<VL`0I/c<06K<c02IVL`0]KFe0P2IVL`01P2ZEJX0VIW<0:YEZP2ZEJX0002I001EZP@0
002Z2`00EJX2001Eo`06001EZP1E0?l0<fK<03=Vc01E0?l0<fK<0P1V<l`01@0cI/`0EEFZ05EEZP0c
I/`0IS?<0080<fK<00H0IS?<03=Vc01EEJX0EEFZ03=Vc01EEJX203=Vc0060:YEZP0cI/`0VC=V09Tc
IP1V<fH0VC=V1`1V<fH20:X0ZP0606HcIP2Z0:X0IS=V06HcIP1E0:X0IS=V0P1E0:X01P1E05D0LW9b
05D0E@1E05D0LW9b05D0E@80IS>I00D0E@1E04i>CP1>CTh0E@1E04i>CP0205D0E@0609VIc01VIYT0
ZUGo0:YEo`1VIYT0ZUGo0P1VIYT01@1EZ_l0IVJI05FZo`1EZ_l0IVJI0080ZUGo00H0IVJI0:YEo`1V
IYT0IVJI03=Vc01VIYT203=Vc00606HcIP0c06H0IVJI06IVV@2IVOl0IVJI0P2IVOlT0?ooo`00J03o
ool00`2ZE@00c3<00<`c000405FZo`06002Io`3<ol`0c?oo0<coo`3oc9T0Z_oo0P3<c<`00`3@d=00
ooo<0?ooc0020?o<c080ooo<00H0c?o<0?ooc038b<P0b<S80?ooc03<c<`20?ooc0050<c<c03oc<`0
c?o<0<coc03Hf=P00P2m_Kd01P34a<@0b<S80?o<c03oc<`0b<S80?o<c080001V00H0001E0000M`00
06H0001V0000M`0009T20000M`040000V@0007L0002Z0000ZP@0002I0`00EJX01P3ool`0olbI0?o<
c03oc<`0c<c<0?ooc080c?o<00D0ooo<0<C4a03<ol`0c?o<0<C4a0020?o<c0060=3@d03oc<`0d=3@
0=3@d03oc<`0d=3@0P38b<P01@3oc<`0b<S80?o<c03oc<`0d=3@00<0c9W<00D0c<c<0<bIc03<c<`0
c<c<0<bIc0020<c<c0050<bIc02m_Kd0c9W<0<bIc02m_Kd0103<VL`01@2ZZ_l0c9W<0<bIc02IVOl0
c9W<0080VIWo00D0c9W<0:6QX@2QXJ40VIW<0:6QX@0209VIc0060;Fe]@3<VL`0]KFe0;Fe]@2a/K40
c6K<0P2a/K401P3<I/`0002I0000V@0009T005FZ0000V@8005FZ00D006K<0000c0000<`0003<0000
ZP0206Hcc080003<0P1V<l`01P000<`005FZ03<0V@0c09T005FZ03<0V@80<fK<00D0002Z03=Vc00c
I/`0IS?<03=Vc00206Hcc00605EEZP1V<l`0EEFZ05EEZP1V<l`0EEFZ0P1V<l`01@1EEJX0IS?<09Tc
IP2I<fH0E@1E00<0VC=V00D0E@1E09TcV@2I<iT0IS=V05D0E@0206HcIP0605D0E@1V<fH0E@1E05D0
E@1V<fH0E@1E0P1V<fH0101V<iT0IS=V06HcV@1V<iT706HcIP0603<0IP1V<fH0<`1V03<0IP2IVOl0
IS?<0P1VIYT01P2IVOl0IVJI09VIo`2IVOl0IVJI0:YEo`80IVJI00D0ZUGo06IVV@1VIYT0EEGo06IV
V@0205EEo`0406Hcc02IVOl0IS?<06Hcc080IS>I:P3oool006T0oooo0P3<<`001P0cc?l00:ZZ002I
c000VL`0<lco0<coc080oonZ00D0Z_oo0<coc03ool`0ooo<0<coV@020:[oo`060<S8b03<ool0d=3@
0=3@d03Ph>00b<S80P3Ph>001P3oc<`0f=SH0?o<c03oc<`0f=SH0<coc080f=SH00D0c<c<0=SHf03H
f=P0Z_nZ0<c<c0020?nZZP060<c<c02m_Kd0001E0000E@0006H0001g0P00EJX0100009T0001g0000
M`0007L40000V@05001EZP3<oiT0c?nI0<coc03oc9T00P3ool`01P2Ic9T0ooo<0<bIo`3<VOl0ooo<
0<S8b080h>3P00D0b<S80>3Ph034a<@0a<C40=CDe0020?o<V@060=CDe03@d=00c<c<0<c<c03@d=00
c<c<0P3oc?l01P38b<P0c9W<0<S8b038b<P0oj[o0<S8b080oj[o00D0`<300?o<o`30`<00`<300?o<
o`020<30`00609VIo`30`<00VIWo09VIo`30`<00VIWo0P2k^k/01P3<VL`0^k^k0<bIc03<VL`0/K6a
0:ZZo`80_Kfm00D0ZZ[o0<bIc03<VL`0I/c<0<bIc00206K<c00609VIc02e]KD0VIW<09VIc02ZEJX0
VIW<0P2ZEJX0102m_Kd0VIW<0000V@0009T20000ZP8005FZ00<0002Z001EZP00EJX01P00EJX2001E
o`06001EZP1E0?l0<fK<03=Vc01E0?l0<fK<0P1V<l`00`0cI/`0IS?<06Hcc00603=Vc080EJZZ00H0
<fK<05FZZP0cI/`0<fK<05FZo`0cI/`209TcIP0506HcIP2I<fH0IS=V06HcIP2I<c<00P1V<fH01P2I
<c<0IS=V0:X0ZP2Z0:X0IS=V0:X0ZP80IS=V00H0E@2Z06HcIP1E0:X0E@2Z05D0E@1bLW8205D0E@05
06HcV@1E05D0IS>I06HcV@1E05D00P1>CTh01P1E05D0CTi>05D0E@1E05D0VIW<06IVV@80VIW<00H0
IVJI0:YEo`1VIYT0IVJI0:YEo`1VIYT205FZo`0506IVV@2ZEOl0ZUGo06IVV@2ZEOl00P1VIYT01P0c
I/`0IVJI03=Vc00cI/`0IS=V03<0IRX0oooo001Y0?ooo`80c3<000H0<lco002ZZP00VL`009W<03?<
o`3<ol`20?ooZP050:[oo`3<ol`0ooo<0?ooc03<oiT00P2Zool01P38b<P0c?oo0=3@d03@d=00h>3P
0<S8b080h>3P00H0olc<0=SHf03oc<`0olc<0=SHf03<ol`20=SHf0050<c<c03Hf=P0f=SH0:[oZP3<
c<`00P3oZZX01P3<c<`0_Kfm0000E@0005D0001V0000M`8005FZ00@0002I0000M`0007L0001g1000
09T01@00EJX0c?nI0<coV@3<ol`0olbI0080ooo<00H0VLbI0?ooc03<VOl0c9Wo0?ooc038b<P20>3P
h0050<S8b03Ph>00a<C40<C4a03De=@00P3oc9T01P3De=@0d=3@0<c<c03<c<`0d=3@0<c<c080olco
00H0b<S80<bIc038b<P0b<S80?nZo`38b<P20?nZo`050<30`03oc?l0`<300<30`03oc?l00P30`<00
1P2IVOl0`<3009VIo`2IVOl0`<3009VIo`80^k^k00H0c9W<0;^k^`3<VL`0c9W<0;6a/@2ZZ_l20;fm
_@050:ZZo`3<VL`0c9W<06K<c03<VL`00P1Vc<`01P2IVL`0]KFe09VIc02IVL`0ZUFZ09VIc080ZUFZ
00@0_Kfm09VIc00009T0002I0P000:X2001EZP030000ZP00EJX005FZ00H005FZ0P00EOl01P00EJX0
E@3o03=Vc00cI/`0E@3o03=Vc080IS?<00<0<fK<06Hcc01V<l`01P0cI/`205FZZP0603=Vc01EZZX0
<fK<03=Vc01EZ_l0<fK<0P2I<fH01@1V<fH0VC=V06HcIP1V<fH0VC<c0080IS=V00H0VC<c06HcIP2Z
0:X0ZP2Z06HcIP2Z0:X206HcIP0605D0ZP1V<fH0E@2Z05D0ZP1E05D0LW9b0P1E05D01@1V<iT0E@1E
06HcV@1V<iT0E@1E0080CTi>00H0E@1E04i>CP1E05D0E@1E09VIc01VIYT209VIc00606IVV@2ZEOl0
IVJI06IVV@2ZEOl0IVJI0P1EZ_l01@1VIYT0ZUGo0:YEo`1VIYT0ZUGo0080IVJI00H0<fK<06IVV@0c
I/`0<fK<06HcIP0c06HZ0?ooo`00K@3oool203=Vc0060<coo`1Vc<`0Z_oo0:[oo`3<c<`0c?oo0P3o
ol`00`2Zool0VIWo09VIo`020<coc080ooo<00H0c?o<0?ooc038b<P0b<S80?ooc03<c<`20?ooc005
0<coc03oc<`0ooo<0?ooc03Hf=P00P3ool`01P3Lg=`0c?o<0=cLg03Lg=`0b<S80?o<c080b<S800D0
001E0000IP0007L0001g0000V@030000M`050000V@0007L0c?mV0<coIP3<oiT00P3ool`01@3oojX0
c?o<0<coc03<ol`0c?oo00@0c?o<00D0ooo<0<coc03<ol`0ooo<0<C4a0020?ooc0050<coc03Lg=`0
g=cL0=3@d03oc<`00P3@d=001P3oc<`0d=3@0=CDe03De=@0olc<0<S8b080c9W<00H0d=3@0<bIc03@
d=00d=3@0<c<c03<VL`20<c<c0050<bIc03<c<`0c<c<0<c<c02m_Kd00P3<VL`01P2m_Kd0c9W<0:ZZ
o`2ZZ_l0c9W<0:ZZo`80c9W<00D0VIWo0<bIc02IVOl0VIWo0<bIc0020:6QX@0409VIc02QXJ40ZZ[o
0:ZZo`80c9W<0P2e]KD01P3<VL`0c6K<09VIo`2IVOl0c9W<09VIo`80c6K<0P0009T2001EZP03001V
c000EJX005FZ0080003<0P00I/`01P000:X0IS?<06Hcc01V<l`0003<06Hcc080<`2I00D005FZ03<0
V@0cI/`0<fK<0000ZP0203=Vc0060000ZP0cI/`0IS?<06Hcc00cI/`0EEFZ0P1EEOl01P1EEJX0EEGo
05EEo`1EEOl0IVJI05EEo`80IVJI00D0E@1E09TcIP2I<fH0VC=V05D0E@0209TcIP0605D0E@2I<fH0
IS=V06HcIP2I<fH0IS=V0P1E05D01P1V<fH0E@1E06HcIP1V<fH0IS>I06HcIP80IS>I1`1V<fH01P0c
06H0IS=V03<0IP0c06H0VIWo06Hcc0<0VIWo00D0IVJI09VIo`2IVOl0IVJI0:YEo`0206IVV@050:YE
o`1VIYT0IVJI05EEo`1Vc?l00P0cc?l206K<o`80EJ[o00<0I/co06HcV@3oool0:@3oool007<0oooo
00D006K<06K<c02Zool0Z_oo06K<c0020<coo`060<S8b03Ph>00d=3@0=3@d03Ph>00b<S80P3Ph>00
1P3oc<`0f=SH0?o<c03oc<`0f=SH0<coc080f=SH00<0c<c<0=SHf03Hf=P0103Lg=`01P3Ph>00_Kfm
0<c<c03<c<`0e=CD0000M`80001V00H0001g001EZP0009T0002I001Vc00cc<`20:[oZP050<coc03<
oiT0c?nI0?ooc03oojX00P3ool`01P2a/K40ooo<0<bIo`3<VOl0h>3P0<S8b080h>3P00D0a<C40>3P
h034a<@0a<C40=cLg0020?o<c0040>3Ph03@d=00c<c<0<c<c080d=3@0P3oc?l01P3@d=00c9W<0<S8
b038b<P0oj[o0<S8b080oj[o00D0c<c<0?o<o`30`<00`<300?o<o`030<c<c0050<30`02IVOl0VIWo
0<30`02IVOl00P3<c<`01P3<VL`0^k^k0<bIc03<VL`0_Kfm0:ZZo`80_Kfm00D0ZZ[o0;fm_@2m_Kd0
I/c<0;fm_@020<c<c0050;fm_@2e]KD0VIW<09VIc02e]KD00`2IVL`00`2m_Kd0VIW<09VIc00209VI
c0@0002Z1P00EJX01P000<`006K<001Eo`00EOl005FZ001Eo`80<fK<00D0E@3o03=Vc01E0?l0E@3o
03=Vc00206Hcc0H0<fK<0P1EZZX01P0cI/`0EJZZ03=Vc00cI/`0EJ[o03=Vc080EJ[o00D0IS=V09Tc
<`1V<fH0IS=V09Tc<`0206HcIP0409Tc<`1E05D0VC<c09Tc<`D0E@1E00D0IS=V079bLP1bLW80E@1E
079bLP0205D0E@0506HcV@1E05D0IS>I06HcV@1E05D00P1>CTh01P1E05D0CTi>05D0E@1E05D0VIW<
06IVV@80VIW<00H0IVJI0:YEo`0cc<`0<lc<002Ic00cc<`2002Ic00503?<o`1VIYT0IVJI03?<o`1V
c<`00P1EZ_l01P1Vc<`0EJ[o03?<c00cc<`0EJ[o03?<c2X0oooo001c0?ooo`05001Vc01Vc<`0Z_oo
0:[oo`1Vc<`00P3<ool01P38b<P0h>3P0=3@d03@d=00h>3P0<S8b080h>3P00H0olc<0=SHf03oc<`0
olc<0=SHf03<ol`20=SHf0030<c<c03Hf=P0f=SH00@0g=cL00H0h>3P0;fm_@3<c<`0c<c<0=CDe000
07L20000IP060000M`00EJX0002I0000V@00I/`0<lc<0P2ZojX01@3<ol`0c?nI0<coV@3ool`0oonZ
0080ooo<00H0/K6a0?ooc03<VOl0c9Wo0>3Ph038b<P20>3Ph0050<C4a03Ph>00a<C40<C4a03Lg=`0
0P3oc<`0103Ph>00d=3@0<c<c03<c<`20=3@d080olco00H0d=3@0<bIc038b<P0b<S80?nZo`38b<P2
0?nZo`050<c<c03oc?l0`<300<30`03oc?l00`3<c<`01@30`<00VIWo09VIo`30`<00VIWo0080c<c<
00H0c9W<0;^k^`3<VL`0c9W<0;fm_@2ZZ_l20;fm_@050:ZZo`2m_Kd0_Kfm06K<c02m_Kd00P3<c<`0
1@2m_Kd0]KFe09VIc02IVL`0]KFe00<0VIW<00<0_Kfm09VIc02IVL`00P2IVL`40000ZPH005FZ00H0
003<001Vc000EOl005Go001EZP00EOl203=Vc00505D0o`0cI/`0E@3o05D0o`0cI/`00P1V<l`603=V
c080EJZZ00H0<fK<05FZZP0cI/`0<fK<05FZo`0cI/`205FZo`0506HcIP2I<c<0IS=V06HcIP2I<c<0
0P1V<fH0102I<c<0E@1E09Tc<`2I<c<505D0E@0506HcIP1bLW80LW9b05D0E@1bLW800P1E05D01@1V
<iT0E@1E06HcV@1V<iT0E@1E0080CTi>00H0E@1E04i>CP1E05D0E@1E09VIc01VIYT209VIc00606IV
V@2ZEOl0<lc<03?<c000VL`0<lc<0P00VL`01@0cc?l0IVJI06IVV@0cc?l0I/c<0080EJ[o00H0I/c<
05FZo`0cc<`0<lc<05FZo`0cc<`Z0?ooo`00N`3oool01@00VOl0EJ[o05FZo`2IVL`0I/co0080<lco
00H0I/co03?<c01Vc?l0I/co03?<c03oc<`20?ooc0050=SHf03<ol`0c?o<0=cLg03<ol`00P3Lg=`0
1P3<ol`0c?oo0<S8b038b<P0c<c<0?o<c080002I00H0001V0000V@00EJX005FZ002Ic03<ol`20:[o
o`050?ooZP1Vc?l0I/co0<coc03<ool00`3<ol`01@3<c<`0c?o<0<coc03<ol`0ooo<0080a<C400D0
ooo<0<C4a03Lg=`0g=cL0<coc0020=cLg0060<C4a03<ool0d=3@0=3@d03oc<`0d=3@0P3De=@01P3@
d=00f=SH0<bIc03<VL`0d=3@0<bIc080c<c<00<0olco0<bIc03<c<`00P3<c<`20<bIo`060<c<c02m
_Kd0c9W<0<bIc02m_Kd0c<c<0P2ZZ_l01P3<VL`0ZZ[o0<bIc03<VL`0h>3P0<bIc080VIWo00D0c9W<
09VIo`2IVOl0VIW<0<bIc0020:ZZo`80c9W<0P2e]KD20<bIc080VIWo00H0c9W<09VIo`3<I/`0c6K<
0;6a/@0007L2001EZP030000V@00I/`006K<00@0003<00H0002Z001Vc01V<l`0IS?<001Vc01V<l`2
03<0V@05001EZP0c09T005FZ001EZP000:X00P0cI/`01P000:X0<fK<06Hcc01V<l`0<fK<06Hcc080
EEGo00H0EEFZ05EEo`1EEJX0EEFZ06IVV@1EEOl206IVV@0505EEo`1E05D0VC=V09TcIP1E05D00P2I
<fH01P1V<fH0VC=V06HcIP1V<fH0VC=V06HcIP80VC<c00H0IS=V09Tc<`1E05D0E@1E03lo?`1E05D2
06HcV@@0IS=V00D0<`1V06HcIP1V<fH0<`1V06HcIP0206Hcc00309VIo`1V<l`0oooo0400oooo002>
0?ooo`040=cLg02Zool0Z_oo0>3Ph0@0Z_oo00D0e=CD0=3@d03@d=00002I0000M`0203?<c00503?o
c02Zool0Z_nZ0:[oZP2Zool00P3oojX01P3<ool0/K6a0?ooc03ool`0c9Wo0?ooc080b<S800H0h>3P
0<S8b03Ph>00h>3P0<C4a03Ph>020?o<c0050=cLg034a<@0a<C40>3Ph034a<@00P3Ph>001P3oc?l0
d=3@0?o<o`3oc?l0d=3@0<c<c080f=SH00H0oj[o0<S8b02Zool0Z_oo0<c<c02Zool20<30`0D0c<c<
0P2IVOl01P3<c<`0ZZ[o0<c<c03<c<`0c9W<0;^k^`80c?oo00D0c<c<0<coo`2m_Kd0_Kfm0:ZZo`02
0;fm_@060<c<c02m_Kd0c<c<0<c<c02m_Kd0c<c<0P2IVL`01P2e]KD0e=CD09VIc02IVL`0_Kfm09VI
c080_Kfm0P2IVL`2001EZP040000ZP00EJX005FZ0000ZP@005FZ00D006K<0000c0000<`006K<0000
c002001Vc00505D0o`0cI/`0E@3o05D0o`0cI/`00P1V<l`00`0cI/`0IS?<03=Vc00303=Vc080EJZZ
00H0<fK<05FZZP0cI/`0<fK<05FZo`0cI/`205FZo`0503=Vc02I<c<0IS=V06HcIP2I<c<00P1V<fH0
102I<c<0E@1E09Tc<`2I<c<605D0E@80VC<c00H0E@1E09Tc<`1E05D0E@1E0492@P1E05D20492@P05
05D0E@1E0000E@0005D0E@1E0000A@3oool009/0oooo0P00VL`01@1Vc?l0I/c<06K<o`1Vc?l0c?o<
0080I/co00H0I/c<06K<o`38b<P0b<S80:[oo`3<ool20>3Ph0060<coo`3Ph>00c?oo0<coo`3Ph>00
a<C40P3Lg=`01@3<ol`0c?oo0<coo`34a<@0c?oo0080a<C40P3@d=020=CDe0060:[oo`3Hf=P0Z_oo
0:[oo`3Hf=P0c9W<0P3<c<`01@3oc?l0c<c<0=3@d03@d=00c<c<0080c9Wo00H0c<c<0<bIo`3<c<`0
c<c<0:ZZo`3<c<`20:ZZo`060<c<c02ZZ_l0ZZ[o0:ZZo`3Ph>00ZZ[o0P2IVOl01@3<VL`0VIWo09VI
o`3<c<`0c9W<0080ZZ[o00H0c9W<0:ZZo`2e]KD0]KFe0:[oo`2ZZ_l20:[oo`060<bIc02IVOl0c9W<
0<bIc02a/K40ZZ[o0P2Zool01@00EJX006K<001Vc000EJX0002Z00<0003<00D006K<0000ZP000:X0
06K<06Hcc002001Vc00503=VV@0cI/`0<fJI03=VV@0c09T00P0cI/`01P000:X0<fK<06Hcc01V<l`0
<fK<06Hcc080<fK<00@0EEFZ05EEo`1EEJX0EEFZ0P1EEOl206IVV@0505EEo`1E05D0VC=V09TcIP1E
05D00P2I<fH01P1V<fH0VC=V06HcIP1V<fH0VC<c06HcIP80VC<c00H0IS=V03lo?`1E05D0E@1E03lo
?`1E05D203lo?`0305D0E@1E0000E@1E0080E@1E0P0c03<00`1E05D0<`0c0?ooo`140?ooo`00V`3o
ool2002Ic00506K<o`1Vc<`0I/co06K<o`3<ol`00P1Vc?l01P1Vc<`0I/co0<S8b038b<P0Z_oo0<co
o`80h>3P00H0c?oo0>3Ph03<ool0c?oo0>3Ph034a<@20=cLg0050<coc03<ool0c?oo0<C4a03<ool0
0P34a<@20=3@d080e=CD00H0Z_oo0=SHf02Zool0Z_oo0=SHf03<VL`20<c<c0050?o<o`3<c<`0d=3@
0=3@d03<c<`00P3<VOl01P3<c<`0c9Wo0<c<c03<c<`0ZZ[o0<c<c080ZZ[o00H0c<c<0:ZZo`2ZZ_l0
ZZ[o0>3Ph02ZZ_l209VIo`050<bIc02IVOl0VIWo0<c<c03<VL`00P2ZZ_l01P3<VL`0ZZ[o0;Fe]@2e
]KD0Z_oo0:ZZo`80Z_oo00H0c9W<09VIo`3<VL`0c9W<0;6a/@2ZZ_l20:[oo`05001EZP00I/`006K<
001EZP000:X00`000<`01@00I/`0002Z0000ZP00I/`0IS?<008006K<00D0<fJI03=Vc00cIYT0<fJI
03<0V@0203=Vc0060000ZP0cI/`0IS?<06Hcc00cI/`0IS?<0P0cI/`0101EEJX0EEGo05EEZP1EEJX2
05EEo`80IVJI00D0EEGo05D0E@2I<fH0VC=V05D0E@0209TcIP0606HcIP2I<fH0IS=V06HcIP2I<c<0
IS=V0P2I<c<01P1V<fH0?clo05D0E@1E05D0?clo05D0E@80?clo00<0E@1E05D0001E05D00P1E05D2
03<0<`0305D0E@0c03<0oooo04@0oooo002O0?ooo`80<lc<00D0Z_oo03?<o`0cc?l0Z_oo0<S8b002
0:[oo`060=3@d02Zool0d=3@0=3@d02Zool0d=3@0P2Zool01@38b<P0Z_oo0<S8b038b<P0g=cL0080
a<C400H0h>3P0<C4a03<ool0c?oo0<30`03<ool20?o<o`050=SHf03<c<`0f=SH0=SHf03<c<`00`2Z
ool01@3<c<`0Z_oo0<coo`3<ool0Z_oo00@0c<c<0P2k^k/01P3<c<`0ZZ[o0<c<c03<c<`0I/c<0:[o
o`80c?oo00D0c<c<0<coo`3<c<`0c<c<0:ZZo`020<coo`050:ZZo`2m_Kd0c<c<0<c<c02m_Kd00`3o
ool01P3<VOl0e=CD0<bIo`3<VOl0_Kfm09VIc080_Kfm0P3oool20:ZZo`050=CDe000EJX005FZ0000
ZP00EJX00P00I/`01P00EJX006K<0000c0000<`006K<0000c08006K<00D0003<001Eo`1EEJX0EEFZ
001Eo`0;03=Vc00505FZZP0cI/`0<fK<05FZZP0cI/`00P1EZ_l01@0cI/`0EJ[o05D0E@1E05D0VC<c
0080E@1E00@0VC<c05D0E@2I<c<0VC<c1P1E05D209Tc<`0605D0E@2I<c<0E@1E05D0E@12@T80E@1E
0P12@T80101E05D0E@0005D0001E05E60?ooo`00[@3oool01@3Ph>00b<S80<S8b02Zool0b<S80080
`<3000D0I/c<0<30`030`<00a<C40=3@d0020<coo`060=3@d01Vc9T0I/c<06K<c01Vc9T0f=SH0P3<
ool01P3<ol`0c?oo0<coc03<ol`0olco0<coc080d=3@00D0c?o<0=3@d03@d=00c<c<0:[oo`020<co
c0030:[oo`3<c<`0oooo00D0oooo00<0h>3P0:ZZo`3oool0103oool20<c<c080ZZ[o1@3oool01@2Z
Z_l0Z_oo0:[oo`2ZZ_l0VIWo00T0oooo00H0ZZZZ0000ZP00EJX005FZ0000ZP000<`2001Vc0060000
c01V<l`006K<001Vc01V<l`006K<0P0cIYT01@0cI/`0<fJI03=VV@0cI/`006Ko0080<fK<00H0<fKo
03?<o`0cI_l0<fKo05EEZP0cc<`205EEZP0603?<c01EZZX0EJ[o05FZo`1EZZX0EJ[o0P1E000309Tc
<`0605D0002I<fH0IS=V06HcIP2I<c<0IS=V0P2I<c<01P1V<fH0?clo05D0E@1E05D0?clo05D0E@80
E@0000<0E@1E05D0001E05D00P1E05D203<0<`0305D0E@3oool0oooo04@0oooo003l0?ooo`060000
ZP00I/`005FZ001EZP00I/`0003<0P00I/`01@000<`006K<05EEZP1EEJX005Go0080EEFZ2@0cI/`0
1@1EEOl0<fKo03=Vo`1EEOl0<fKo0080TI6A00D0<fKo096AT@0cI_l0<fKo0:X0E@0205D0E@030:X0
001E05D0E@1E00D0E@1E00H0VC<c05D0E@2I<c<0VC<c05D0E@2I<c<205D0E@050492@P1E05D0E@00
05D0001E05D00P1E00000`1E05D0oooo0?ooo`140?ooo`00o03oool01P000:X006K<001EZP00EJX0
06K<0000c08006K<00D0003<001Vc01EEJX0EEFZ001Eo`0205EEZPT0<fK<00D0EEGo03=Vo`0cI_l0
EEGo03=Vo`02096AT@0503=Vo`2ATI40<fKo03=Vo`2Z05D00P1E05D00`2Z0000E@1E05D0E@0505D0
E@0609Tc<`1E05D0VC<c09Tc<`1E05D0VC<c0P1E05D01@12@T80E@1E05D0001E0000E@1E0080E@00
00<0E@1E0?ooo`3oool0A03oool00?d0oooo00D0ZP000000ZP000:X0003<001Vc0020000c005001E
o`00I/`0IS?<06Hcc00cI/`00P0cIYT01P0cI/`006Ko03=Vc00cI/`006Ko03?<o`80<fKo00H0<lco
03=Vo`1EEJX0EEFZ03?<c01EEJX203?<c00505FZZP1EZ_l0EJZZ05FZZP1EZ_l00P2I<c<00`1E0000
VC<c05D0E@0505D0E@0603<0<`1E05D0<`0c03<0<`0o?cl0E@1E0P1E00001@1E05D0E@0003<0<`0c
03<0E@1E0080<`0cA`3oool00?h0oooo0P1E00001@00I/`0003<001Vc000I/`0003<00<006K<00@0
06Ko002ZZP00ZZX006Ko2@0cI/`203=Vo`0605EEo`0cI_l0EEGo05EEo`0cI_l0TI6A0P0cI_l0102A
TI40E@1E05D0E@2Z000305D0E@0605D0001E05D0E@0005D0001E05D0E@000P1E05D605D00080<`0c
00<0E@0003<0<`0c03<0A`3oool00?l0oooo0P3oool3001EZP05001Vc0000<`005Go001Eo`00I/`0
0P0cI/`01P00VL`0<fK<03=Vc00cI/`0<lc<03=Vc080<fKo00H0<lco03=Vo`0cc?l0<lco03?<c01E
EJX203?<c00505EEZP1EZ_l0EJZZ05FZZP1EZ_l00P1EZZX00`1E0000E@1E05D0E@0505D0E@0503<0
<`1E05D0<`0c03<0<`1E05D01@0c03<202<S8`0303<0000S8b<08b<S04L0oooo003o0?ooo`80oooo
0`00EJX01@00I/`0003<001Eo`00EOl006K<0080<fK<00H009W<03=Vc00cI/`0<fK<03?<c00cI/`2
03=Vo`0603?<o`0cI_l0<lco03?<o`0cc<`0EEFZ0P0cc<`01@1EEJX0EJ[o05FZZP1EZZX0EJ[o0080
EJZZ00<0E@0005D0E@1E05D01@1E05D01@0c03<0E@1E03<0<`0c03<0E@1E00D0<`0c0P0S8b<00`0c
00008b<S02<S8`170?ooo`00o`3oool30?ooo`8005FZ00D0002Z001Vc000EJX005FZ001Vc002002I
c006001Vo`00ZZX006Ko001Vo`0cI/`006Ko0P0cI/`01P00I_l009W<03=Vo`0cI_l009W<03?<o`80
ZUFZ00D0<lco0:YEZP0cc?l0<lco09VIc00203?<o`0609VIc01E0000E@1E05D0E@1E0000E@1E0P1E
0000101E05D0E@0005D0E@1E05D605D00080<`0c00<0E@000?ooo`3oool0A`3oool00?l0oooo1`3o
ool3001EZP8006Ko00@009W<001Vo`00I_l006Ko0P0cI/`203?<c00603=Vc00cc<`009Wo002Io`0c
c<`009Wo0P00EOl01@0cI/`005Go03=Vc00cI/`0<fKo0080<fK<00@0<fKo03=Vc00c0000<`000P1E
000203<0000305D0001E05D0<`0c00H0<`0c00@0<`0002<S8`0S8b<0<`00B@3oool00?l0oooo3@3o
ool00`00EJX006K<001Vc004002Ic006002Io`1EZZX009Wo002Io`0cI/`009Wo0P0cI/`01@00VOl0
IVJI002Zo`00Z_l0IVJI00800:[o00D0IVJI002Zo`0cIYT0<fJI002Zo`0=03<004`0oooo003o0?oo
o`d0oooo00<005FZ001Vc000I/`01000VL`01P00VOl0EJZZ002Io`00VOl0<fK<002Io`80<fK<00D0
09Wo06IVV@00Z_l00:[o06IVV@02002Zo`0506IVV@00Z_l0<fJI03=VV@00Z_l03@0c001<0?ooo`00
o`3ooolA0?ooo`05002Ic000I/`006K<002Ic000I/`00`00VL`01@0cI/`0<lc<03?<c00cI/`0<lc<
0080<fK<00D0<lc<002Io`00VOl0<lc<002Io`0203?<c00503?<o`0cc<`0<lco03?<o`0cc<`01`0A
001>0?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3o
oon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3o
oon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3o
oon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3o
oon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00o`3ooon10?ooo`00\
\>"], "Graphics",
  CellMargins->{{Inherited, 311}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageSize->{384, 196},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Gradient Strategies",
    FontWeight->"Bold"],
  " as Hillclimbers: Following a gradient will in most cases not lead to the \
discovery of a global optimum. Depending on the starting point, the local \
maximum found might be just far off (4) the actual global optimum. It might \
be close to the global maximum, but there is no way to get closer (1, 2), or \
the global maximum is discovered by chance (3)."
}], "NumberedFigure"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multimodal and Noisy Testfunctions", "Subsection"],

Cell["\<\
Gradient functions need gradient information (derivatives, etc.)!\
\
\>", "Text"],

Cell["Can gradient strategies cope with noisy data sets?", "Text"],

Cell[CellGroupData[{

Cell["What if the test function looks like this?", "Subsubsection"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000oQ000`40O003h00OogoomGoo003oOooe
Ool00?moooEoo`00ogoo27oo0`00jWoo003oOol;Ool00`00Oomoo`3WOol00?moo`]oo`03001oogoo
0>Moo`00ogoo27oo0`00jWoo003oOol8Ool00`00Oomoo`3ZOol00?moo`Qoo`@00>Uoo`00ogoomGoo
003oOooeOol00?moooEoo`00ogoo87oo0`00dWoo003oOolSOol00`00Oomoo`3?Ool00?mooaYoo`D0
00Aoo`03001oogoo0<moo`00ogoo2Goo0`0057oo0`00dWoo003oOol6Ool300000goo001oo`02000B
Ool00`00Oomoo`3BOol00?moo`=oo`<000Aoo`04001oogooOol3000?Ool4003AOol00?moo`<000Mo
o`03001oogoo00Aoo`800>9oo`00oGoo0P004goo0P00h7oo003jOol3000GOol3003MOol00?Moo`<0
01eoo`800=]oo`00m7oo0`008Woo0P00fGoo003aOol3000WOol2003GOol00>moo`8002aoo`<00=Ao
o`00k7oo0`0000=oo`00Ool0;7oo00@007oo00000=9oo`00MGoo0P0000=oo`000000Kgoo0`0017oo
00<007ooOol0:goo00@007ooOomoo`800=1oo`00MWoo00<007oo0000KGoo0`00=Goo00<007ooOol0
0goo0`00GWoo0`00K7oo001gOol00`00Oomoo`1ZOol2000hOol00`00Oomoo`06Ool2001MOol00`00
Oomoo`1[Ool007Ioo`03001oo`0006Qoo`<004Eoo`8005aoo`03001oogoo06Yoo`00MGoo0P0000=o
o`000000I7oo0`00BWoo0P00FWoo00<007ooOol0JWoo003KOol3001?Ool3001FOol00`00Ool0001[
Ool00=Uoo`8005Eoo`8005Aoo`03001oo`0006]oo`00eWoo0`00FGoo0P00DGoo0P0000=oo`000000
JWoo003COol30002Ool00`00Oomoo`1GOol00`00Ool00002002mOol00=1oo`<000Eoo`03001oogoo
05Moo`03001oogoo009oo`800;]oo`00cGoo0`00JGoo0P00^Goo003;Ool2001^Ool2002gOol00<Qo
o`<0079oo`<00;Aoo`00aGoo0`00N7oo0P00/Woo0032Ool3001mOol2002`Ool00<1oo`<0085oo`80
0:ioo`00VGoo0P008Woo0`000Woo00<007ooOol0Ogoo00<007oo00000P00Zgoo002HOol01000Oomo
o`007Woo0`001Goo00<007ooOol0Ogoo00<007ooOol00Woo0P00ZGoo002HOol01000Oomoo`006goo
0`00TGoo0P00Ygoo002HOol01000Oomoo`006Goo0P00UWoo0`00Y7oo002HOol01000Oomoo`005Woo
0`00Vgoo0P00XWoo002IOol2000DOol3002POol2002POol00:aoo`<00:Eoo`8009ioo`00ZGoo0`00
00=oo`00Ool0Cgoo00<007ooOol0E7oo10006Woo0P00Ogoo002WOol20004Ool00`00Oomoo`1;Ool3
00000fg8001oo`1DOol01000Oomoogoo0P005goo00@007ooOol007ioo`00Y7oo0`00DWoo0`000fg8
00<01P00Ool0FGoo0P005Goo00@007ooOol007ioo`00XGoo0`00=Goo0S`177oo00=UA@0000001Fg8
00<01V500000Fgoo0`004Woo00@007ooOol007ioo`00WWoo0`00=goo13`16Goo0fE51Vg80`0600=Q
@7ooOol0G7oo0P0047oo00@007ooOol007ioo`00W7oo0P00>Goo1S`15Woo0fE526g80`060V508Woo
00<hAgooOol0>Woo0P003goo0P00Ogoo002IOol3000jOol8?04COol4IDD9KLP400H2HD0POol3>4Lm
Ool2002>Ool009Ioo`<00003Ool007oo03Uoo`Xl0A1oo`AUA@]]b0@01P=Q@1moo`<hAaMoo`03809o
ogoo02Aoo`@008]oo`00Tgoo0`0017oo00<007ooOol0=goo2c`13Woo16E500<006g8KLP02Vg81@06
0V501FE06Goo1CQ75Goo0b0257oo0WOB3goo00@007ooOomoo`8008Uoo`00T7oo0`001goo00<007oo
Ool0=Woo2c`10QP037oo0fE50`0000=@aFg8KLP026g81P060f5026E05Goo1SQ72Goo00=<PgooOol0
1goo00<03b0280800R024Woo00=_nWOBMm805Goo0P00Qgoo002>Ool20011Ool3JJL9?044600;Ool5
0002D<D:KLP700H2HD09ID0COol7>4L8Ool3C8<8Ool6808AOol00fojMm9gdP0GOol30024Ool008]o
o`<0049oo`EYY`Ll0@DH00Yoo`D000=@a@Y]b0L01P=Q@0UU@0Moo`<000=oo`=E:@800`PhA`Ioo`E<
P`Ioo`0300lP0R0200DP0Pmoo`03KoYgdWOB009gdQUoo`80089oo`00R7oo0`008goo0TS[7Woo26VW
1C`11aP027oo00<006DP00000P001E352Fg820060V502VE017oo0P000R@01eDY1@031CQ71Goo1db3
17oo00<03b0280801b023Woo00=_nWOBMm800WOB6goo0P00P7oo0025Ool4000UOol4B>/KOol:JJL3
?04860000e30Oomoo`04Ool00`00IB0000030005D<D8KLP900H3HD0:ID000goo000T00049007EBT8
00<3>4L3Ool8C8<3Ool200l:808<Ool2KoX4Mm8MOol2001nOol008=oo`8000=oo`03001oogoo029o
o`M8jaQoo`aYY`03?04H01P000PH00Eoo`03001U86DP00<000I@a@Q]b0X01P=Q@0UU@0HT00QE:@P0
0`@hA`03Oom<Pdb300Q<P`9oo`803`/P0PQoo`9CW`9_nPEgdQeoo`03001oo`00008007]oo`00P7oo
0`001Goo00<007ooOol08Woo1dS[10004goo00<T0CR:JJL02VVW1@011aP00goo00=@`6DPIB000`00
25351fg82P0600=YH650HD002FE01R@01eDY2@0300Eb8CQ7>4LhAc0100]<P`803`/P0PH0<`ECW`9_
nPIgdQeoo`04001oogooOol2001iOol007eoo`<002aoo`Q8j`H0008L0`ioo`03904hRSR:00]YY`L0
0@=U808H0003D<1ooe3000=U808000U@a@M]b0X01P04LRYYH650HD07ID069008EBT800<2LR`3>4L2
<04;C8<00`0?808P0P07808703<5Dil3KoX6Mm8MOol00`00Oomoo`03Ool2001gOol007Yoo`<002mo
o`Q8j`H000<L0`Uoo`03501oogoo008T0@8hRPYYY`P00@03C>UU86DP00=U8003D<1U86DP009U8080
0003=:e@aE3500I@a@M]b0T01P9b:P9YH003HD1U@6E000AU@0LT00QE:@P00`9b;003LR4hAc0100<`
0@U<P`H000<P0P03BY/0<`0c00D0<`ICW`9_nPMgdREoo`<007Aoo`00N7oo0P00<Goo24S[1P001A`3
1goo0a@00b@10cR:2FVW1`010TcY2FDP0P0000=8YcB]=:d025351Fg82@06178Z0VUP00=Q@6E0ID00
0VE01b@02EDY1`030g8/00=b8C01<04013011db30`0000<`04ZKBY/01TZK1@0c1U>O0foj27OB9goo
0P00LWoo001eOol3000cOol8B>/6000670<5Ool350039044>8X9JJL70043C>T8IB000`00B:Ld[@02
=:d8D<D5KLP800H5LRX3JF03ID07900:EBT700<3LR`2LR46<045C8<20003<008BY/403<6Dil4KoX8
Mm8YOol2001`Ool0079oo`<0009oo`03001oogoo031oo`U8j`D000LL0`@800<D00@T0@@hRPQYY`L0
0@A<j@MU80800003B:Ld[CB]008d[@M@a@E]b0L01PIb:PAYH003ID0T02@000HT00UE:@L00`Eb;003
LR4`0C0100D`0@=<P`03000`0300008`00U:V`<0<`MCW`=_nPUgdRYoo`<006ioo`00Kgoo0`001Goo
00<007ooOol07Goo0Vn>4Goo24S[1P001a`31PP012@11SR:1fVW1P011TcY1VDP00<004RWB:L013B]
253516g81P06278Z1VUP1B@02UDY1P031W8/00=b8C01<0401S0100=<Pc00<00013002TZK00<0<e>O
Dil01E>O16oj2GOB:Woo00<007ooOol00`00Jgoo001;Ool3000NOol3000XOol3Khh01@3eOomoogoo
50000W7S27oo2DS[1@001a`31`P012@11SR:1VVW1`011dcY16DP00@004RWB:M8Y`Dd[@M@a@=]b0D0
1P03H>1b:W8Z00Mb:PUYH08T00YE:@H00`Ib;09b8@L`0@H`0003?S]:VdZK00Q:V`9KePICW`A_nP9g
dP037Yh0]P2f00EgdRmoo`8006Uoo`00CWoo00<007ooOol06Goo0P00:goo1Fn>11@00W7S1goo2DS[
10001a`31`P012@123R:1FVW1P0124cY16DP00@004RWB:M8Y`Hd[@I@a@=]b0@01P9Ph0Yb:PUYH0]E
:@D00`Mb;09b8@H`0@L`0003?S]:VdZK00Q:V`=KePACW`A_nP9gdP8NWP03CYX0]P2f00AgdPEoo`03
LoQoogoo00Moo`03Ok9oogoo01moo`8006Moo`00AGoo1@0017oo00<007ooOol05Woo0`00;7oo1fn>
00<0m@5i0GT0177S17oo2DS[1@001a`31PP01B@123R:1FVW1P012DcY0fDP0dRW1cB]1e350Vg80`06
0V3P0VW]2G8Z2FUP00=UR5DYEBT025DY1@03278/0W8Q13011c000chk24ZK1E_F0U>O1Foj00=gdQjN
7Yh00TjJ102f0WOB17oo0g?h1goo00=6FWnbOol08Woo0`00I7oo001;Ool3000FOol4000^Ool3Khh4
MkT00fn>0?D1N@060GT25009B>/4000770<620069048>8X4JJL6004:C>T2IB001000B:M8YdRW23B]
1U350Vg80P060f3P0VW]2W8Z1fUP0VF82EDY1@032G8/0W8Q0c0123000chk1dZK1e_F00=CWfojKoX0
0foj0QjN14jJ1@2f00AgdWooOol0]PAcn0Eoo`04AUYo/WnbOk8UOol2001ROol004]oo`03001oogoo
01=oo`<000=oo`03001oogoo02=oo`03IL1oogoo00Ioo`=_SPEg^@80]P030?D1N@5i00@1N@Y8j`@0
00HL0`H800HT0@XhRP=YY`D00@a<j@03IB18YdRW0098Y`Pd[@=Ph0=@a@9]b00400IPh63PH>03JNd:
LRX6JF04IHP8EBT500<9LR`3LR400c01<00`0006<005?S/5BY/6FmH46_L67Yh4CYX60;H00goo0;Ic
n005LoP3Ool2AUX4Ok8TOol01000Ool00000H7oo001;Ool4000@Ool20006Ool00`00Oomoo`0ROol2
Jg`7Ool3Khh6MkT017^f0;H0]P2f0`5i0`2f24S[10001a`31PP01R@12SR:0VVW1P0134cY1DRW23B]
00<01V3PH>000f3P00=@a@06H>000f3P0fW]2W8Z1FUP1VF81eDY100300<h9T3]LR`01g8/1G8Q1c00
1Chk14ZK15_F00@JmfmIKeUkT@PNWPE>VPP0]PMcn004Oom6FTIJAUX4Ok86Ool4MhlJOol01000Oomo
ogoo0P00GWoo001LOol3000]Ool2Jg`2IFH5Ool3Khh5MkT2NkH40;H00`5i0;H0]P020;H8B>/40006
70<62006904;>8X2JJL400400b02C>U<j@0;C>T4B:L9=:d200H9H>05JNd:LRX4JF06IHP7EBT400<2
@>d9LR`7LR43<006?S/3BY/2FmH00cilKeU_F@03KeT2Ni467Yh7CYX70;H7LoP4AUX5Ok84Ool00fmJ
MhmgS`03MhlOOol3000HOol30010Ool005Uoo`<002Uoo`03HH/01@0500=oo`=[O003IL1UIVEV00Ao
o`9_SP03IL1g^GNi00=g^@=k]PL0]P9_FPM8j`<0008VOPDL0`D800LT0@`hRP03JJL00B0200<P0P03
>6U<jDcY00U<j@E8Y`Td[@801PUPh0EYk@Yb:P=YH0QUR0IE:@<00`03>2I0kD3]00Ub;0Ub8@03<00n
>chk00Dn>`03BY/nO3il008nO0E_F@=kT@@NWPQ>VPH0]PMcn0A6FPIo/P=oo`9_FPEgSb9oo`8001Uo
o`03001oogoo03eoo`00EWoo0`00:goo0V6;0`050VEV0f]l00AU`6EVIFIUIP9oo`=_SPIg^@=k]PL0
]P9_FPI8j`@000DVOP0370<800P0009Bg0<8m`DT0@dhRPDP0P8hJ@]<j@E8Y`Pd[@@01PMPh0IYk@]b
:P03JF1UR6F800MUR0EE:@<00`8h9P90k@Ub;0Ub8@Ln>`DnO0E_F@EkT@<NWPU>VPD0]PIcn0E6FPMo
/P03Oom_FVmJ00EgS`9[6B=oo`8001Moo`03001oogoo03eoo`00E7oo0P000Woo00<007ooOol0:7oo
0f6;0`0500<006]lJg`00f]l00EU`6EVIFIUIWoo009_SP03IL1g^GNi00Ag^@Ak]PD0]PA_FPE8j`<0
0003KcTVORIn00<VOPEBg0D8m`<T0@dhRPDP0P<hJ@U<j@I8Y`Pd[@D01PIPh0IYk@]b:P]UR0AE:@<0
0`8h9P90k@Ub;0Ub8@Hn>`HnO0E_F@IkT@037Yi>VTjJ00Q>VP@0]PIcn0I6FPMo/P=_FPEgS`9[6BAo
o`@0015oo`<0041oo`00DGoo0`0017oo00<007ooOol09Woo166;0`0500<006]lJg`016]l00EU`6EV
IFIUIWoo009_SPIg^@Ik]P@0]PE_FPA8j`80009_>@0400dVORIn9Wh6D]`72?L00b@1>8XhRP0:>8X5
8084>6T8C>T7B:L8=:d500H6H>07JNd:LRX00cR:IHQUR008IHP4EBT200<3>2H3@>d8LR`9LR44?S/8
?W`5KeT6Ni4<CYX30;H5LoP7AUX7Ok83KeX5Mhl2JaT@Ool2Io/BOol01000Oomoogoo0P003goo00<0
07ooOol0@7oo001>Ool3000_Ool5HH/300D00`00Jga[O004Jg`016G0IFIUIVEV0Vn>00=U`7NiMkT0
17Ni1W^f102f1FmJ0dS[0P0016li00<03BInD]`01e;L1PSg3CR:1B021CQY1dcY1TRW2CB]1P06163P
26W]2W8Z00<hRVF8IHP02FF80eDY0P030SPV143]2G8/1g8Q00A?Gchk?S/n>`PnO0I_F@IkT@03G[U>
VTjJ00U>VP80]PEcn0M6FPMo/PA_FPAgS`=[6A1oo`AWnaIoo`8000eoo`@003moo`00Bgoo0`00<Goo
1V6;0`0526]l00AU`6EVIFI_SP9U`0Ig^@Ik]P03Fa`0]P2f00M_FP98j`8000A_>@0300eBg5;L00MB
g0L8m`/hRPHP0PHhJ@E<j@M8Y`Td[@H01PAPh0QYk@Ub:P<hRP]UR09E:@0400<h9SPV>2H4@>d9LR`7
LR422AL00chk?W`nO007?W`6KeT5Ni42G[T;CYX20;H4LoP8AUX7Ok84KeX4Mhl4JaT>Ool00`P3Io]W
n`02Io/HOol2001>Ool004Qoo`<003=oo`IQR`<01@03001[O6]l00I[O005IL1UIVEVKhiU`007MkT5
NkH2Fa`20;H7KeX2B>/00`00KcU_>@04KcT00`0=D]aBg006D]`82?L9>8X68087>6T5C>T7B:L9=:d7
00H2H>09JNd9LRX3>8X;IHP00eDY00<h9P03>2H4@>d9LR`7LR422AL9?W`6KeT6Ni43G[T;CYX0102f
LoQ>NTij2DIJ1Wnb16mJ1GN?16/I3Goo00<80fOkIo/00VOk0U>f2Woo00=OngooOol037oo0`00Bgoo
0016Ool20002Ool00`00Oomoo`0`Ool7HH/300D2Kfd7Jg`2IL000fn>IL1U`006MkT6NkH3Fa`00`2f
KeY_FP06KeX00`00KcU_>@05KcT200d8D]`72?L00eJk>8XhRP06>8X68088>6T3C>T8B:L8=:d900H0
0f3PJNeYk@08JNd8LRX3>8X<IHP00`03>2Hh9P02>2H4@>d9LR`6LR442AL8?W`6KeT6Ni43G[T;CYX4
CWX9AUX6Ok84KeX4Mhl5JaT<Ool220<3Io/3DkH9Ool2Go/@Ool30019Ool004=oo`<000=oo`03001o
ogoo031oo`QQR`<01@9_K@03018oGf]l00A[O09U`003KhiU`7Ni00Ig^@Ak]P031?MK75/L009K70Q_
FPU_>@803@QBg0H8m`=F^`HhRPHP0PThJ@9<j@U8Y`Pd[@T01P]Yk@Mb:PDhRP]UR0Dh9PE0k@Ub;0Eb
8@@95`PnO0I_F@EkT@AN^@]>VPA>NP03F^I6FTIJ00E6FPMo/PA_FPAgS`E[6@]oo`<80`9Wn`EC]PMo
o`04001OneokGo/?Ool00`00Oomoo`020017Ool0041oo`<000Ioo`03001oogoo02moo`QQR`<01@03
001_KEKl00804P030;I[O6]l00=[O0=U`0Mg^@9k]P@4m`AK70M_FPY_>@803@MBg0H8m`=F^`HhRPHP
0PXhJ@03C>U8YdRW00I8Y`Td[@T01P]Yk@Mb:PDhRP]UR0@h9PI0k@Ub;0Eb8@D95`HnO0M_F@EkT@EN
^@U>VPA>NP9JiPM6FPIo/PE_FPAgS`I[6@Uoo`@80`03Io]C]U>f00EC]PEoo`8000=OnaAoo`8004Eo
o`00?Goo0`00>Woo00<0066;HH/01V6;0`0500<006m]E_`00`0B00<0]U<MJg`00V]l00=_SV]lIL00
1WNi00=k]U;LD]`01@Cg15/L1VmJ2Vli0P1D00<03E;LD]`01E;L10Sg1EJk13R:1R022cQY2DRW2CB]
20060Uf;2VW]1g8Z1SR:2FF81CPV1T3]2G8/178Q1PTG1Sil1fmI1G^A1Eji24jJ1Dij0U[V1dIJ1Wnb
1FmJ0gN?1f/I27oo10P300=Wne>f00000aUi0e>f17oo0P001Eok5Goo0`00@Woo000kOol2000lOol0
0`00508D0P07HH/300D016m]E_aFo5Kl0`0B25<M0`0>1E;L1PCg15/L16mJ2fli0`1D00<03E;LD]`0
15;L0`Sg1UJk00<04CR:>8X01b022cQY00=4R4RWB:L01TRW2CB]20060Uf;2VW]1W8Z1cR:2FF81CPV
1T3]2G8/178Q1`TG1Cil1VmI1G^A1eji1djJ1Dij0e[V1TIJ1Gnb1FmJ17N?1f/I1goo1@P30`0000=W
eAUi6GT00aUi00=C]WooOol00`001Eok67oo0P00@7oo000hOol300000goo001oo`0jOol01000508D
0Q@21V6;0`0500<006m]E_`00UKl100B25<M00<03U;LD]`015;L1PCg1E/L0fmJ2Vli0W>j0`1D1U;L
0`Sg1UJk0P0A00<hRR0280801B022SQY0dB81dRW2CB]20060Uf;2fW]1G8Z23R:1fF81SPV1d3]2G8/
0g8Q1`TG13il1fmI1G^A1eji1TjJ1Tij0e[V1TIJ1Gnb1FmJ17N?1f/I1goo1@P30P000VOE2AUi0P00
11WL0Uok67oo0`00?Woo000eOol30004Ool00`00Oomoo`0hOol200035086HH/300D00`00KfeFo002
E_`50186Dad00e[KD]aBg006D]`61?L5Fa`2KeX:KcT2LkX405@6D]`00`SgE[]F^`06E[/40144808;
>6T4A8P5B:L9=:d800H3GH/;JNd5LRX8>8X7IHP6>2H7@>d9LR`3LR472AL4?W`7KeT5Ni48G[T4CYX7
CWX3F^H5AUX5Ok86KeX3Mhl9JaT5Ool520<20003ImD:6GT00cjn6M`Ig0046M`IOol00`00Ool00002
000kOol0039oo`<0045oo`8000DD0PEQR`<01@03001Fo5Kl00=Fo0D04PEC7@9Jf`MBg0L4m`EK70]_
>@9c^PD0E0EBg0032?MF^eJk00IF^`L04@03808hJCQY00PhJ@I4R0A8Y`Td[@P01PAMR`YYk@Eb:PTh
RPEUR0Hh9PQ0k@Ub;09b8@9NV0L95`8nO0Q_F@AkT@UN^@=>VPM>NPEJiPA6FPEo/PI_FP=gS`U[6@Eo
o`D80`8000AWe@TIN@03?[hIg1WL00DIg1Qoo`03001oogoo009oo`8003Uoo`00<7oo0P00A7oo00<0
01@2508011@2166;0`0500<006m]E_`015Kl1P0B15<M0e[K1e;L1`Cg0U/L0R6j2Vli17>j101D1AUi
2EJk1`0A2cQY1TB814RW2CB]1`061Ef;2VW]178Z2SR:1FF81SPV243]2G8/0W8Q0UjH1`TG0Sil1fmI
1G^A2Eji0djJ1dij1E[V14IJ1Gnb1FmJ17N?2F/I17oo00=3UUn@Gi000`P300<006OEImD00fOE21Ui
0cjn1QWL7goo0P00=goo000]Ool30015Ool200065084HH/300D00`00E_aFo004E_`70182Dad4F]/7
D]`71?L58KX9KcT4LkX505@56GT9E[/70149>6T8A8P3B:L9=:d700H5GH/;JNd3LRX:>8X4IHP7>2H8
@>d:LR`00g8QGYQNV0082AL00cilKeU_F@05KeT5Ni4:G[T00djJCWY>NP06CWX20=H3F^H4AUX4Ok86
KeX3Mhl:JaT4Ool015nbGi1OT5n@0PP31VOE1aUi1Cjn1AWL00=<HWooOol07Woo0P00=Goo000ZOol3
0002Ool00`00Oomoo`12Ool00f<7000D0P075083HH/300D00`0009EFo005E_`701800e<MF]]Jf`03
F]/6D]`71?L00d8k8KXQ^P038KX7KcT5LkX505@56GT9E[/60142Hc`7>6T:A8P2B:L9=:d700H6GH/:
JNd3LRX;>8X3IHP7>2H9@>d9LR`4GYP52AL28_h8KeT4Ni4;G[T9CWX00flG0=H0eP03F^H2AUX5Ok86
KeX3Mhl;JaT2Ool00enbGi1OT003Gi0016OEJm9cn7?h16OE1AUi1Sjn1QWL00=<HWooOol07Woo1000
<Woo000WOol30005Ool00`00Oomoo`11Ool00f<7000000085082HH/300D01000KfeW>`2E1EKl1`0B
1e[K1U;L1@Cg0T8k1R6j1Vli1W>j101D1QUi25Jk1P0A0f<l1SQY2dB82CB]1`061ef;2VW]0W8Z33R:
0VF823PV2D3]2G8/15jH0PTG1R;n1fmI17^A2eji24ij00=JiVlG0=H00P3F0U[V0TIJ0gnb00<0eVmJ
KeX01FmJ0gN?2f/I00=ooenbGi0015n@00=NfV_BJm800W?h0V^?0VOE11Ui00=OeCjn?[h01Cjn1AWL
00=<HWooOol07Woo00@007ooOomoo`80031oo`0097oo0`00Bgoo00=S1`0000002A@20V6;0`050SHk
0VLk1EKl1`0B00=G7E[KF]/015[K1U;L10Cg148k1R6j1Fli1W>j1@1D1AUi25Jk1@0A16<l1CQY34B8
2CB]1`061ef;2VW]0W8Z3CR:00=UR3PV>2H01CPV2T3]2G8/15jH0gnd1R;n1VmI17^A2Uji0V/I1dij
0VlG103F00=JiTIJAUX00Wnb0P3F00=_mfmJKeX016mJ0WN?36/I0Unb0Un@0ekJ0V_B0g?h0V^?00=O
eFOE6GT00QUi0UoE1Sjn0c/O0aWL0TaR9Goo0P00;Woo000ROol2001=Ool2H`L01000LmAce7?D21@2
00EQR`05A00003Hk00AW>`EFo0D04P=G7@IJf`EBg0<4m`E2>`HQ^P0400i_>FliKcT7LkX505@66GT8
E[/40145Hc`4>6T<A8P00b`5=:dd[@06=:d600H8GH/;JNd00g8Z>8XhRP0;>8X2FBT6>2H:@>d8LR`5
GYP6Ok@38_h5KeT4Ni4;G[T2JaT7CWX3KaL40=H00e[VAUYo/P020=H3KoL4KeX3Mhl00eKKJaU[6@09
JaT00enbGi1NfP04G]X2Jm82LoP3Jhl3GmD00aUiGmEOe@02GmD2?[h5>al00gOf03<Ig0026M`2C68V
Ool3000[Ool001moo`<00003Ool007oo04aoo`03H`L0000000=ce003KoEge7OD00=4008D0P0400E4
03Hk=S/4Ic/00fmk00iFo003E_`40184Ead7F]/5D]`00`Cg@S]2>`04@S/78KX00`0>KcU_>@07LkX6
05@56GT8E[/30147Hc`2>6T<A8P2;0D8=:d600H9GH/:JNd>>8X3FBT5>2H;@>d7LR`5GYP6Ok@21;D2
8_h4KeT4Ni4;G[T2JaT7CWX3KaL50=H017nb0=H0eP3F0fog16mJ0WN?0UKK2V/I00=O/Un@G]X01EkJ
00A[dW?hLoQcn09[S`03GmD]^BWk00PYn`@k7`=gmP80<`036Ma<HTaR02Qoo`<002Uoo`0077oo0`00
17oo00<007ooOol0BWoo00<T1V<700000g?D00=_mGODMm@00WOD1D@00SHk1FLk00A_N`0>00h0<@9F
o0<04PIG7@IJf`DA^`Q2>`HQ^P803P03KcUc^W>j00Ic^PD0E0HIN@MF^`<04@MS?003?QXhJDB800]4
R0</1@Ld[@H01PUMR`YYk@dhRPEI:@@h9P]0k@Mb;0ANV0Mo]0<4]@8RoP=_F@=kT@031;EkUeji00QN
^@A[6@I>NP=_5`P0ePE_m`=_FP9gS`=Ff`Q[6@9O/P03Gi1NfUkJ00ANfP05Jm9cn7?hLoQ[S`04;KT9
:O/3>al3MoH203<01000C69<HTaR9goo00<007ooOol00P009goo000IOol3001DOol00f<7001ce002
Lm@2KoD3Mm@2IoX3A003=S/4Ic/3Kg/200h00`0a00iFo0020186Ead7F]/54K/7@S/68KX600h5LkX5
05@66GT8E[/00`0AHcaS?007Hc`<A8P4;0D7=:d500H:GH/:JNd00`@2>8XhRP09>8X7FBT3>2H;@>d6
LR`5GYP7Ok@00f[h1;D4]@021;D3KeT2Ni400`BeNiMkU`09G[T4JaT5CWX00f^aKaM_5`02KaL60=H6
KoL3KeX00gN?E]]Ff`02E]/8JaT00enbGi1NfP05G]X01F_BLoQcn7?hJhl01Bfi2RWk00<k7gOfMoH0
0gOf0P0c00<004aRC680;7oo0P009Goo000HOol00`00Oomoo`1EOol01000LmAce7?D0foe0WOD0fOj
00EKnd@0NmQW>cHk00EW>`=_N`D03P03019G7ELM00IG7@IJf`03CahA^a6k008A^`Q2>`HQ^PL03P=c
^PH0E0HIN@MF^`03015S?6<l00MS?003?QY4R4B800U4R0D/1@Dd[@H01P0320UMRef;00MMR`UYk@<4
0PXhRPQI:@03>2I0kD3]00Y0k@Ib;0ENV0Io]09Zn0D4]@9_F@03Ni44]@Be009kU`UN^@A[6@E>NPE_
5`H0ePM_m`9_FPIFf`I[6@9O/PMNfP05Jm9cn7?hLoQ[S`06;KT8:O/00e_NMoIgmP04MoH303<20180
0daROomoo`0[Ool3000ROol006moo`0490Ice7?DLm@3KoD2Mm@00``0IoYKn`02Fo/3NmP5Ic/4Kg/6
00h9Ead4F]/2Cah54K/7@S/68KX700h0100bLkYc^W>j1@1D1QUi1UJk00<UEf<lHc`026<l0ShJ2DB8
1b`513B]1@0600=b2PP9GH/02Ef;26W]10@223R:2UTY343]1G8/1UjH1Wnd0V[h1PBe00AkT@Be1;D4
]@=kU`MN^@I[6@A>NPE_5`D0ePU_m`03MhmFfeKK00AFf`E[6@9O/PQNfP=cn003Jhl]^Bfi00D]^@LY
n`9KgPIgmP@0<`<04Rmoo`80021oo`00Kgoo0g?D00IcSfoeKoE_mGOD3004Fo/3NmP25GX4Ic/5Kg/4
00h2LgT8Ead3F]/3Cah00`0?4K/A^`024K/8@S/58KX600h2@QT00`0bLkYc^P0605@66GT2E[/59EL:
Hc`00chJA8Q4R007A8P7;0D4=:d400H2LPX00`P9GH]MR`08GH/8JNd51086>8X;FBT=@>d4LR`5GYP7
Ok@2J_P91;D4NiL7G[T6JaT4CWX6KaL40=H7KoL00bmKE]]Ff`06E]/5JaT00enbKfeW6P07G]X3LoP2
Lm@6;KT6:O/2Fmh8MoH303<3018_Ool01000Ool000007Woo001^Ool012@6LmAce7>?16oe00=cme_k
Fo/00U_k00<007_H5GX011Ej0VLk1Vmk100>0g=i25LM00=JfdlNCah00dlN00@03a6k4K/A^`Q2>`HQ
^P@03P=26@80<P03LkX0E01D00@0E0DIN@03:ITUEbEG00HUE`US?08n6PM4R0T/1@<d[@<01P9b2P<8
2@UMR`MYk@H40PHhRP]I:@03@<]0kD3]00Y0k@Ab;0ENV0Io]0=Zn0T4]@AkU`MN^@I[6@=>NP03F^I_
5flG00A_5`<0ePE_m`<_F`YFf`=[6@04Gk9SOFLJIaX7G]X3LoP2Lm@7;KT4:O/3Fmh7MoH00bmK6AHI
5P0203<3018bOol3000KOol006ioo`0490Ice7>?Lhl2KoD3LoL4Fo/00g_HCY]>V`055GX00fLkKg]_
N`04Kg/400h4LgT6Ead00d>NCai?7P04Cah00`0?4K/A^`024K/7@S/68KX400h3@QT303800g>j05@0
E00305@36GT3:IT99EL8Hc`3?QX6A8P9;0D3=:d200H3LPX320T9GH/7JNd71084>8X<FBT00d3;@>e0
k@0:@>d3LR`6GYP6Ok@4J_P81;D5NiL5G[T8JaT2CWX7KaL20=H3KoL00gnFOgEoM@02OgD;E]/3JaT0
16=mKfeW6VLJ1UkJ00=cn7^@Ni000g?D1bfi0bWk0e_N1GOf12mK0aTF00@0<`0@01804SEoo`8001Uo
o`00KGoo00@T1V<7LhmcS`9_m@=cm`AKn`04NmA>VdjKCY/55GX2F]X6Kg/200h6LgT3Ead4@ih5Cah2
00l34K/8@S/58KX300h4@QT4038605@00aUi:ITYV@03:IT99EL8Hc`00chJ<ILaU`04A8P;;0D2=:d2
00H3LPX320T:GH/6JNd81083>8X;FBT3@</;@>d3LR`6GYP6Ok@4J_P71;D6NiL5G[T8JaT2CWX8KaL0
0`3FOiIoUP02OiH4OgD00g]^E]]Ff`09E]/00f/IHgeSO@04IaX5G]X3Ni04Lm@7;KT00bWkFmiKgP02
Fmh3MoH6;e/46AH00`0c01804P0gOol00`00Oomoo`0FOol006eoo`0390IcSg>?009_m@=cm`=Kn`=k
e0A>V`DENP=JfPA_N`803PMcN@03Eae3WT>N00A3WPE?7P803`<A^`M2>`<<]@<Q^P803PA26@@0<PHI
=`HYV@XUE`IS?0049GPaUc6G<IL4A8P;;0D00cB]00H01P04LPX420T9GH/5JNd:10800cR:FBUI:@0:
FBT3@</;@>d2LR`6GYP6Ok@5J_P71;D6NiL5G[T8JaT2CWX8KaL5OiH4OgD00g]^E]]Ff`09E]/3Hgd4
IaX5G]X2Ni05Lm@6;KT4>MT2Fmh00gOf5ALE5`035AL4;e/46AH00`0c01804P1?Ool006eoo`0490Ic
Sg>?KoD3LoL00e_kNmAke003Nm@6CY/45GX4F]X00f<kKg]S>`0200h9LgT20144@ih4Cah200l00`0c
4K/A^`07@S/63;D00`0>@QU26@04@QT303876CL5:IT;9EL2Hc`49GP4<IL2A8P=;0D00`06LPYb2P03
LPX420T9GH/5JNd910800g7XFBUI:@0;FBT4@</;@>d00g8/GYQNV004GYP6Ok@5J_P71;D6NiL4G[T:
JaT00dijKaM_5`06KaL4OiH5OgD2Nfh:E]/2Hgd00fm]IaYW6P03IaX4G]X2Ni05Lm@5;KT6>MT2?iD5
5AL0100@;e/_FbmK1ATF00<0400BOol0CWoo001/Ool290H017>?KoEcmg?g0WnB1G_D1djK1AEj0e[J
16<k2G=i00=?f`Be1;D00P0A0PBe00A3WTlNCai?7P<03`0303<A^a6k00E2>`9>oPD<]@M26@@0<PHI
=`HYV@XUE`LUN0@aU`03A8P/1B`500X/1@Mb2P@82@YMR`=Yk@T40P=aj0]I:@E0b`]0k@03LRaNV5jH
00ANV0Io]0IZn0D4]@QkU`=N^@Y[6@03Jk5_5flG00I_5`AoUPAoM@=kKPUFf`=SO@IW6P=NfP=kT09J
n`Ace08]^@03GhlifCWI00Dif@0300doUADG00@E5`04010_FbmK;e/66AH00`0@019oo`1=Ool006ao
o`0390IS1g>?009cm`=oTPEke003LiU>VdjK00E>V`@ENP9JfPMS>`03NmMcNG=i00=cN@9?f`P4]@=?
7P<03`0303<A^d8k00=2>`=>oPD<]@M26@@0<PHI=`HYV@XUE`LUN0HaU`X/1@Mb2PH82@UMR`=Yk@P4
0PAaj0]I:@I0b`Y0k@03G]UNV5jH00ANV0Eo]0MZn0D4]@QkU`=N^@Y[6@Q_5`EoUPAoM@AkKPMFf`AS
O@MW6P9NfP9kT0EJn`03MmMce2fi009OS`Lif@0300doUADG00DE5`<_F`HI5P0301004Woo04eoo`00
Jgoo0R@600=cSe[WOi800gnB1G_D0W>I1djK1AEj00=JfV<kHc/01F<k0W_G0P0@00=cNDoKCm/00P0@
1`Be0dlN0`0?0P0c0d8k14kn1Pbe1T8I100b1aTg1BVI2BEG0W=i1REh1c6G22`5278:1PP92Ef;0fW]
1`@21W7X2UTY1T3;2T3]00=NfEjHGYP015jH1Gnd1f[h1@Be27^G0Uji2f/I26lG1GnF17me17]^1UKK
16=m26LJ0UkJ0W^@1E[k0WOG0en?23WI0SnE1ADG00<042mK;e/01aTF00<047ooOol0C7oo001[Ool2
90H00g>?F^MoTP03Oi85Nm@3LiT7CY/25GX4CUT5Hc/3NmL701081;D2Cah400l203<00d8kC_i>oP03
C_h63;D6@QT503866CL5:IT99EL2LgT69GP9<IL5;0D9LPX620T9GH/2JNd71087LNP:FBT6@</9@>d2
G]T5GYP6Ok@7J_P51;D9NiL00ejiJaU[6@08JaT00f^aKaM_5`06KaL5OiH4OgD4Nfh5E]/5Hgd8IaX2
G]X2Ni001002F_]Jne[k0WOG15n?23WI00<03CnE5AL011DG00@042mK;e/_F`HI5P03018047oo04ao
o`00JWoo0b@600=g/7nBOi800gnB17_D1G>I1TjK1diI16<k17_G1P0@20Be00<04TlNCah00`0?0P0c
1Tkn1Pbe1d8I100b1QTg1RVI22EG0W=i1REh2S6G0b`52W8:1`P92Ef;00=Yk@@210800P@20VE62G7X
25TY243;1d3]15kI15jH1Gnd2F[h0`Be2W^G00=N^F/IJaT026/I00=[/FlGKaL01VlG17nF1Gme1G]^
15KK1F=m2FLJ0W^@0P1C0U[k0gOG1En?1cWI00<Q=SnE5AL011DG00@042mK;e/_F`HI5P03018047oo
04aoo`00JWoo0R@600=cSe[WOi800gnB17_D1W>I1DjK00=k^4iICUT01TiI0f<k0g_G00=>V`0@0100
100@00=[d`Be1;D01@Be0P0B00=?7P0?00l00P0?0P0c1Tkn1Pbe1T8I100b1aTg1BVI1bEG17=i1REh
2C6G00=o]B`5LPX02W8:1`P92Ef;00=Yk@@2IDH016E62G7X25TY243;1d3]15kI15jH1Gnd2F[h0`Be
2W^G2V/I00=[/FlGKaL01VlG1GnF17me1W]^0eKK1F=m2VLJ0W^@0P1C00Igee[kMmMgeen?Ech4Ghl7
>MT28CH55AL20102;e/76AH00`0B011oo`1;Ool006Uoo`<T1P03Mk1JignB00=oTPAke0McV@=>V`9k
^0Q>F@0403=S>f<kNmL3CY/50102Jm<81;D2018500l203<5C_h63;D6@QT503866CL5:IT79EL4LgT6
9GP9<IL00gneLPYb2P0:LPX720T8GH/8IDH00`05LNQaj007LNP7FBT9@</5@>d5G]T4GYP5Ok@9J_P3
1;D:NiL00fOfJaU[6@07JaT00f^aKaM_5`06KaL5OiH4OgD7Nfh00eKKHgeSO@04Hgd:IaX2Ni0205<3
MmL015n?EciG?P0A0en?1SWI0U[J00<Q=SnE5AL011DG00<042mK;e/01aTF0P0BC7oo001YOol390H0
0gN`Oi9oTP03Oi83Nm@00`00LiUcV@06LiT00djKMk9k^002NkP8CUT00`0cNmL0<`04CY/401000f_C
Io/4]@071;D3018400l303<4C_h63;D6@QT503866CL5:IT79EL4LgT69GP9<IL00gneLPYb2P09LPX9
20T6GH/8IDH200D9LNP6FBT:@</5@>d6G]T2GYP5Ok@:J_P21;D:NiL2IoH9JaT00f^aKaM_5`06KaL5
OiH4OgD7Nfh00f]JHgeSO@04Hgd9IaX2Ni000`0505=ge`03MmL4Ech0100AGhmOSen?1CWI0U[J0R4f
1ADG0P0@00<_FaTF6AH01ATF0P0B00<047ooOol0BGoo001XOol390H00f<7F^MoTP04Oi82Nm@00fOg
LiUcV@06LiT00fN>Mk9g/P03NkP8CUT2CY/00`0cCY]>V`02CY/3010016_CIo]WnfOk20Be0P0B11Dh
00@03`0c03<0<`=>oPH<]@I26@D0<PLI=`DYV@DUE`EcN@HUN0TaU`9o]@Yb2PT82@EMR`UUAP801@Ya
j0EI:@]0b`=0k@MNf@9NV0Eo]0YZn084]@UkU`=WmPQ[6@9[/@Q_5`EoUPAoM@MkKP9[FPASO@03OiEW
6VLJ00MW6P9kT003CY/0DgOG00MG?P804@9OS`@if@=JfP8Q=PDE5`804003;e/I5QTF00HI5P804T]o
o`00J7oo0b@600=g/5[WOi800gnB0W_D0VOg1g>I00=WSWNbMk801G^h1diI0djK00@15TjK0AI_S`<0
4004Jm=Wne/mFcd81;D301845CP21AL203<3C_h63;D6@QT403876CL5:IT59EL6LgT59GP8<IL3OkD:
LPX920T4GH/:IDH200D:LNP5FBT;@</2@>d8G]T2GYP5Ok@;J_P00`BeNiMkU`07NiL4IoH7JaT2Jk48
KaL4OiH5OgD6Nfh4JeX3Hgd00gnEIaYW6P06IaX3Ni02CY/00`1BEciG?P06Ech00`0AGhmOS`03>MT4
F]X38CH45AL20102;e/76AH201800`0@Oomoo`18Ool002aoo`03A01oogoo03Qoo`@T1P03Mk1oTWnB
00=oTP9ke003IoL007>I00EcV@04IhiGCGNbMk85NkP6CUT5CY/20AH01ED0Hd/046_C>QX00e/m20Be
0`0B1ADh10DG0Tkn1Pbe1T8I1@0b1QTg1BVI1BEG1W=i1REh1c6G0gne2W8:2PP90Uf;2VE610052W7X
15TY343;00=0kEkIG]T01ekI00=NV7ndOk@00Wnd36[h2G^G1FOf1V/I0V^a26lG1GnF1Gme1W]^1F]J
0V=m0WnE1fLJ0W^@0djK0P1B1eLn0P0A00AOScWI>MTif@AJfP<Q=P@E5`<04003;e/I5QTF00DI5P<0
4TYoo`00:Goo1D@0>Goo12@600=JignBOi800gnB00=ke6OgIoL01W>I0VN>0gNb1G^h1DiI1djK00A_
SeD0>QX040<j6P9K?@T4]@804PDE>0@55`9>oPH<]@I26@D0<PLI=`DYV@<UE`McN@HUN0LaU`=o]@Yb
2PX82@03GH]UAVE600UUAP@01@Yaj0=I:@e0b`YNf@=o]09[_0aZn09W6PIkU`MWmPE[6@9[/@Q_5`Eo
UPAoM@IkKPM[FPAoU@EW6P=kT0=>V`<0DPMG?P804@03GhlifE[J00EJfP<Q=P<E5`<04003;e/I5QTF
00HI5P<04TUoo`009goo00=gmd@0A0001D@0=goo12@600=S1e[WOi800gnB00Ake6OgIoL000EoT`9W
SP=g/PMk^0A>F@M>V`9E00@j6P9cS`03Fcd04@Be00L4]@<04PDE>0@55`03C_h<]@be00@<]@I26@D0
<PLI=`DYV@<UE`QcN@DUN0LaU`Ao]@Qb2P/82@aUAP@01@]aj09I:@e0b`YNf@E[_003KeYZn6[h00UZ
n0=W6PAkU`9WmP03Nm@0m`3g00=WmPA[6@=[/@03Jm=_5flG00E_5`EoUPAoM@IkKPM[FPAoU@AW6P04
E[]kT7^@Ni03CY/40583Ech3=MT301400cWIF]YJfP04F]X48CH35AL201000bmK6AHI5P056AH014=c
01804P0BBGoo000WOol2MoL6A00gOol490H00gN`KgYoTP03Oi83IoL00`00Oi=oT`03Oi<2Ihh3Mk87
NkP3CUT2NgL7CY/00f=;>QXj6P02>QX2Lhl00gnf0144]@081;D201855CP41AL00dkn3;D<]@053;D5
@QT603866CL5:IT39EL8LgT59GP6<IL5OkD8LPX;20T00eE;IDIUAP09IDH500D:LNP2FBT<@</00dHj
G]UNf@08G]T4Jk`2KeX:J_P5IaX3NiL3Nm@00fmI0?L0m`03IoH3JaT2Jk42Jm<7KaL5OiH4OgD5Nfh8
JeX5OiD3IaX00eJkNi1kT005CY/30587=MT20147F]X48CH35AL301066AH2@g<010bd01804P0BB7oo
000VOol4MoL6A00eOol2Kk4390H00gN`Oi9oTP03Oi83IoL00gnEOi=oT`02Oi<2Ihh017>aMk9g/WNb
0g^h00AgF7nDOiAk^0=>F@=kM`I>V`Dj6P04Lhlg7gnfOkH91;D201855CP41AL2C_h63;D6@QT50387
6CL4:IT29EL9LgT59GP6<IL5OkD8LPX:20T2ED/:IDH600D;LNP=@</00dHjG]UNf@07G]T5Jk`3KeX9
J_P6IaX00g^GNmAke002Nm@00fmI0?L0m`020?L01VOfJaU[6F/IJk40m`9[d`I_5`EoUPEoM@EkKPM[
FPIoU@9W6P9F^`9kT0E>V`<0DPPef@804@IJfPDQ=P8E5`<04004;e/I5QTF6AH4@g<23;@20198Ool0
02Ioo`Agm`EDP09403Aoo`9_/@04LhlT1R@6F^L4Oi82IoL00f^`OiEoT`04Oi<2Ihh3Mk800g^hMeQg
F002MeP4Oi@00diINgMkM`02NgL6CY/4>QX2Lhl3OkH00`071;D4]@061;D301855CP41AL00dkn3;D<
]@043;D6@QT503876CL5:IT00bEGLgUcN@07LgT69GP5<IL5OkD00befLPYb2P05LPX:20T3ED/9IDH6
00D;LNP=@</00dHjG]UNf@06G]T6Jk`3KeX8J_P7IaX4Nm@2KeT50?L2JaT00f^a0?M[d`03Jm<5KaL5
OiH5OgD5Nfh7JeX7OiD00fLJE[]kT002Ni000dIJCY]>V`02CY/40587=MT20147F]X48CH25AL30100
1BmK6AHI5T=cBY/014=c00<<]00B01809goo00<H;GooOol07Woo000UOol4MoL27[h6E80cOol3Kk43
Mk000fmjOi9oTP02Oi8016OgJk1oUGnE1GnC00=WSW>aMk800WNb1GMH17nD1W]g14jK00=oUCXJ>QX0
0SXJ00=cScLOOkH00gnf2@Be0P0B1ADh10DG00=>oPbe3;D01@be1D8I1P0b1ATg00<Z70UI2ET00PUI
00<YVBEGLgT02G=i1BEh1C6G1Wne1g8:2PP90eE;2FE61P052g7X00<0043;@</02D3;0dHj1ekI1F^l
16mJ26[h1fLJ17_D0fmI1@3g00=[6@3g0?L016_C1FlG1GnF17me1G]^1f]J00=c^WnEOiD01GnE0UJk
0W^@0TIJ00@044jKCY]>V`@0DPPef@03015JfU[J00EJfPDQ=P035AL0400@008040056AH044ZKBY/0
2P03@g<23;@2018SOol462d00dnOOomoo`0MOol002Eoo`=gm`@N_PEDP005MTAoogooOom@aP0^Ool3
Kk43Mk0016mjOi9oTWnB0V^`0gnE17nC0VN>00Ac/GNbMk9g/PEgF0AoU0IkM`=>V`9oU@@j6P8g7`Ao
]PP4]@03;O/04P0B00HE>0<55`03C_h<]@be00D<]@E26@H0<P8I=`DZ70H9F@UcN@DUN0DaU`Io]@Mb
2PT82@AEB`QUAPP01@Uaj0<000Y0b`=6>PINf@I[_0E_FPMZn0MW6PAke0=_F@L0m`I[d`A_5`EoUPAo
M@EkKPM[FP03LkYoUGnE00EoU@9F^`03Ni16FTIJ0096FP03011>VdjK00@0DPPef@804@IJfPHQ=P04
5AL0400@0105BY/3@g<33;@00`0BOomoo`0OOol662d00dnOOomoo`0MOol002Eoo`03MoMoU7nD009o
U0<N_PADP003MTAoogoo009@aP03OZaoogoo02]oo`9_/@05MoQg/7N`F^M_NP03Oi800f^`OiEoU@02
OiD4Oi<00fN>Lk5g/P02Mk800gnAMeQgF002MeP5Oi@7NgL00djKOiEoU@02OiD2>QX00g>?=amo]P04
OkH00`071;D4]@021;D4;O/00`0A01804P055CP41AL00dkn3;D<]@043;D20=L3@QT503800bhL:Q`Z
7005:Q`72ET8LgT59GP4<IL7OkD6LPX:20T5ED/7IDH800D9LNP3000:@</3ASX5G]T7Jk`5KeX6J_P7
IaX4Nm@5KeT50?L7Jm<3KaL6OiH4OgD4Nfh8JeX7OiD015/8E[]F^g^@14IJ00<044jKCY/01@1B23GI
00<04E[JF]X015[J1R4f00<E5`0@01001TZK0d=c10bd00<04WooOol07Goo1aP]00=?WgooOol07Goo
000TOol00gOgNgIoU005Oi@00ajnE81DP003E804D<H00gj/Ool0000ZOol2Kk4017OhMk1g/7N`0Vmj
0WnB00=[/7nEOiD00gnE17nC00EWSW>aMk9g/WnA00EgF0AoU0QkM`EoU@8j6P8g7`Eo]P0400L4]@Be
1;D6;O/00`0A018E>0055CP31AL00dkn3;D<]@043;D014kL0=L0e`3G0T8I0P0b12hL1bXL1`UI27=i
12Eh136G1gne00<]MW8:LPX00g8:2@P91UE;1fE62005277X1@00243;1DHj15kI1V^l1fmJ1F[h1fLJ
17_D1FmI1@3g1f_C0flG1GnF1Gme17]^1f]J00=c^WnEOiD01GnE00<1MU?JNi001TIJ00<044jKCY/0
101B23GI00<4Le[JF]X01E[J1R4f00<044ZKBY/01DZK00<02T=c@g<010bd00<04WooOol07Goo1aP]
0TnO7Woo000TOol2NgH6Oi@00g>kNXQDP003E80017I4D<I@aU360Wj/00=cmWooOol027oo0WZ>7Woo
0Vna00Egn7N`Mk1g/6mj00=oTPEoU@AoT`03Ihic/G>a009g/P03Oi5gF7MH00=gF0AoU0QkM`IoU@03
>QXg7cLO00=o]P03DWU6>@0700801`84]@D]n`0301404QDh00DE>0<55`03C_h<]@be00<<]@9>g0D0
e`03038^72hL00<^70LZ70P9F@McN@DUN0<aU`Mo]@03;GIb2W8:00=b2PT82@MEB`EUAPT01@Qaj0D0
00Q0b`E6>P=Nf@M[_0M_FPAZn0QW6PAke0I_F@<0m`9[d`03MmP<mPcf00A[d`9_5`EoUPEoM@=kKPQ[
FP03LkYoUGnE00AoU@03IbUkeDIJ00M6FP035AH044jK00@0DPLef@03Ga`4L`0A00IJfPHQ=PU:V`93
L`D<]0moo`<@30Yoo`80000330dH;AP]00@H;@=?Waioo`008goo0W]f1gnD00=c^gZ8E8000eB000Af
A536D<I@aP9n[09cmPUoo`=jSQaoo`9_/@9gn09g/09_NP9oTP03Jk1oUGnE00=oU@AoT`04Ihic/G>a
Mk82Oi45MeP4Oi@7NgL6OiD3=al3OkH2DWT00dHi00L01`0300L5;O/201400`0B5CPE>0035CP41AL4
3;D4C]`40=L7;Q`7:Q`82ET3LgT38GT00`1c9GPUN0029GP3<IL8OkD5LPX920T7ED/5IDH:00D6LNP7
0007@</5ASX3G]T6Jk`9KeX3J_P7IaX4Nm@7KeT30?L00f_CMmQgf0043?H2Jm<2KaL5OiH5OgD3Nfh0
0elZJeY[FP04JeX2LkX6OiD00fLYNmE6FP07AUX25AH00`0@0580DP030585=MT3Ga`00`AcF]YJfP04
F]X68CH00dYkBY]:V`06BY/3@g<53;@>Ool640`7Ool200000``=62dH;@0462d3CilNOol0029oo`=k
MPIoU0=c^`04NXQDP5B0E802MT@2D<H3OZ`00g?fOomoo`06Ool00`00NXijSP02NXhKOol00fnaMoQg
n003Mk02KgX2Oi800g^fOiEoU@03OiD4Oi<2Lk42Mk800gnAMeQgF004MeP4Oi@6NgL00f_iOiEoU@02
OiD5=al2OkH3DWT00gn@AST01`0300L00eg0;O/]n`02;O/201400`0B5CPE>0045CP31AL33;D5C]`5
0=L6;Q`7:Q`82ET68GT207<39GP2<IL9OkD5LPX820T9ED/4IDH:00D6LNP80005@</7ASX00ekIJka[
_005Jk`9KeX2J_P8IaX4Nm@7KeT20?L01F_CMmQgf7OHNmH010cf00=[dflGKaL01GnF17me0g]^0UlZ
1V]J0W>j1WnE00=ke@5iAUX01TIJ0Vmk0QDF0P4G0`1B13GI15lL00<4LaEi5GT015[J1B4f0TYk24ZK
00<02T=c@g<01@bd3Goo00<<210<40`01A0<1Goo0P000P`=1QP]0`gl00=?WgooOol06goo000QOol4
NgH6Oi@3Lk/017Z8E81DP5B00WI40e360gj/00=UP7ooOol017oo0`0017Z>6Woo00=_/GOhMoP00WN`
0fmj00=oTV^`OiD01GnE0gnC00AWSW>aLk5g/P9oT@EgF0AoU0MkM`AoU@9oTP@g7`04OkIBNE9iDWT2
Oi000dHi00L01`0200L00`0>;O/]n`02;O/301455CP01BFj1CT5>@DGC_h00Pbe1DkL1P3G1RhL1bXL
1`UI00<j6R5i8GT0125i0P1c0REh0S6G17ne00<0LgneOkD00Wne00<]MW8:LPX00W8:20P92EE;16E6
2P051G7X2@001D3;1dHj0W?J1V^l2FmJ0V[h26LJ17_D26mI00@0mgOHMmQgf09kePH<mPIoUPAoM@=k
KP=O:PA[FP9c^PIoU@9ke@81N@I6FP9_N`<E5P815`80DP@ef@AO700317<03AEi008EN@9JfP@Q=PA:
N`Q:V`93L`D<]0eoo`0330P@310<00D@3004B>YoogooOol2000330d662d43O`MOol0021oo`EkMPIo
U0=c^`9jR09DP0=fA09@aP=n[003LoIoogoo00=oo`@000EjSQQoo`04Kk5gn7OhMoP2Mk03KgX00gnB
NkIoU@04OiD4Oi<3Lk43Oi45MeP4Oi@6NgL01F_iOiEoUGnENgL01GnB00=o]U9iDWT00U9i0Wn@00=6
>@0700L00`0700=M`2gk;O/00Rgk0`0A00<E>2Fj9KX00bFj0`Di00<<]DkLC]`01DkL1@3G1bhL1RXL
1PUI0SXJ1R5i0`1c00<UN36G<IL00gne0P1c00D03gneOkEo]Bef00=b2PT82@UEB`=UAP`01@Aaj0X0
00A0b`M6>P=cfPA[_0]_FP03J_QW6VLJ00EW6PAke0U_F@Agf09kePP<mP=oUPEoM@9kKP04JoEO:UlZ
GbX4JeX2LkX6OiD2?QX00`0A0GU6FP04AUX3Kg/45AH30AL00`1B=MTef@05Ga`217<45GT2F]X28CH5
BW/8BY/2@g<53;@=Ool00``840`@300440`2B>X3Ool2000330d662d2:EH33O`LOol001moo`IkMPEo
U0Ac^`=jR004E81fA7I4MT@2D<H4OZ`00fF0G@AM1003G@@30005NXh2MT/FOol00fnaMoQgn002Mk00
1P00KgY_NWnBJk1k]PEoU@AoT`9c/@04Mk9oTGnAOi45MeP4Oi@4NgL00e>oJoU[n@02OiD2NgL5Oi85
DWT3Oi0400L00e[K00h]n`03;O/301469KX31CT8C]`60=L6;Q`7:Q`42ET3>QX68GT407<00bEh<IMo
]@0407<01FKHOkEo]Gne;GH00g8:20P92eE;0VE61P0500<P1gHTMR@00`05177X2P000d3;1dHj1W?J
0V^l2fmJ26LJ17_D2FmI17OH0W_F2`cf1Gme00=kKV_eGbX015lZ0f]J0W>j1GnE0chJ0P0A1DIJ0fmk
1ADF0`4G00<efElLGa`015lL0PAc1QEi00<Q=TYkBW/014Yk24ZK00<02T=c3;@01@bd2goo0P`81Q0<
0dSZ00=oo`00000010`=1QP]12UF0Pgl6goo000OOol6NgH5Oi@4Lk/3NXP2E802MT@2D<H4OZ`00fF0
G@AM1003G@@30005NXh4MT/DOol3MoP2Mk03Nfl00gnBNkIk]P05OiD3Oi<3Lk43Oi46MeP3Oi@2NgL4
Dkl2JoT017nENgMkMg]g1GnB1E9i0gn@0`070U[K00<03Rgk;O/00Rgk100A1RFj0`Di24kL1@3G1bhL
1RXL0`UI1CXJ1B5i1@1c00=o]@1c07<00P1c0VKH00<03gneOkD00Ref0W8:20P92eE;0VE60`051207
0gHT0P050g7X30000T3;1dHj1g?J00=[_6mJKeX02FmJ00=O?6LJIaX01FLJ17_D26mI17OH17_F2Pcf
0WOi0gme00=kKV_eGbX015lZ0V]J0g>j1GnE13hJ00<04@5iAUX00TIJ1Fmk11DF00<Q5@4G0AL01elL
0`Ac1AEi1dYk00<02TZKBY/01TZK0T=c1@bd2goo0P`81A0<14SZ00=oo`00000010`=1QP]1BUF00<=
o7ooOol06Goo000OOol5NgH6Oi@2Lk/3Ok@3NXP01EB0MTAfA7I4D<H01Gj/00=UP5d4G@@00ed40P00
1WZ>17I;4Woo17Oh00=g/000Nfl00W]_0g^f1GnE0WnC00ASnG>aLk5c/@=oT@IgF0=oU0EC_`9[n@04
OiEkMg]gNgL5Oi86DWT3Oi000dHi00L01`03F]/0100>;O/]nbgk100A1RFj0`Di00<044kLC]`01DkL
1P3G1RhL1bXL00<9FCXJ>QX013XJ1R5i2@1c0VKH00D03gneOkEo]Bef009b2PL82@eEB`0300DP1b07
00DP1`0520Mf97HTMR@01@03LNP500000gHTJia[W003Ji`200000d3;ASY6>P04ASX8LmX;KeX2Gc`7
IaX3Nm@9KeT4MmP4NmH:3?H3MoT00gmeNfi[m@07GbX00f]JLkYc^P05OiD5?QX20143AUX5Kg/45AH2
8AD20AL6Ga`317<65GT6BW/00`0:BY]:V`06BY/2@g<53;@:Ool330P540`4B>X2000530d562d20006
:EHJOol001ioo`IkMPEoU0Io]0=jR005E81fA7I4MTA@aP05OZ`00fF0G@AM1003G@@20006NXh4MT/B
Ool4MoP01GN`NfmkKg]_Jk000W^f1GnE0gnC00ASnG>aLk5k]`=oT@EgF0AoU0EC_`03JoU[>G]g00=k
M`EoTPEBN@EoT00300MJfe[K009Jf`0300h]nbgk008]n`@04@HU^P<5>@Q>g0H0e`H^70<Z70<M5@Lj
6PHQN@T0L`=Vf00400mo]Gne;GH2LPX720T=ED/780L220L4MR@00`05LNP000020004MR@8Ji`6ASX8
LmX00e[lKeY_FP07KeX4Gc`5IaX4Nm@9KeT4MmP4NmH93?H5MoT00g]^JoE_/003Kk021WP4LkX5OiD5
?QX20142AUX6Kg/55AH28AD00`4GGaaO7005Ga`317<55GT7BW/00`09BY]:V`02BY/3=MP00`0:@g<<
]0043;@:Ool330P440`20082B>X3000530d562d20006:EHJOol001ioo`IkMPEoU0Eo]003MoQjR7Z8
009jR0=fA003MV=n[7j/00=n[003OZUUP5d400=M108000IjSPAfB`03O/Yoogoo00ioo`Agn003Mk00
07]_009kK`=k]PEoU@9oT`04HoUc/G>aNkL4Oi45MeP3Oi@5Dkl00f_iJcU[>@04NgL4Oi86DWT5Oi00
0`07F]]Jf`02F]/200h3;O/401479KX21CT00`0@C]a>g005C]`60=L5;Q`00bFH7ADM5@057AD7>QX5
8GT907<3I]P0100?OkEo]Bef0W8:1`P93EE;1b070PP71GHT00=aj7HTMR@01GHT26^L1DHj27?J0e[l
26mJ15ll1FLJ17_D26mI17OH1G_F2@cf1GOi00=[mElZKk0016n`0P000g>j1GnE1ShJ0P0A00=6FVmk
Kg/01Fmk11DF0b4E00<15elLGa`015lL0`Ac1AEi1dYk00<02CGH=MP01CGH00<@]4=c3;@010bd2Woo
0``8110<0`0200A8jP00000LCP@<3@HH;@8000HYEQYoo`007Woo1W]f17nD00=37gndOk@00gnd00=g
n7Z8NXP00WZ80gI400=fHgj/OZ`00gj/00AnZFF0MTUfB@=M108000EjSPAfB`03O/Yoogoo00Aoo`03
FFejRWoo00Moo`Agn003Mk1kKg]_009kK`=k]PEoU@9oT`04HoUc/G>aNkL3Oi46MeP2Oi@5Dkl016_i
JcU[>F/i17]g17nB1U9i0Wn@0VlG00=oT5[KF]/015[K00@03Rgk;O/]n`D04@HU^P85>@03011>g4kL
00E>g0L0e`03;Q`UV2FH008UV0LM5@Lj6PDQN@P0L`AVf0803`03OkD]MRef00D82@92o`eEB`PP1`88
1`af90U[W0E6>PMcfPAJo0M_FPIO?0AW6P=ke0U_F@Agf0IkePL<mPIgn@03JoE_/6n`00A_/0<0009c
^PAoU@034=Dn6ShJ00<n6P03>OTQN25h00804@I_N`@E5P@Q5@IO70<4L`HEN@I:N`0300Xef3GH00De
f0034;A3L`bd00@<]0Uoo`<<20@@3004@k/00P020082000274h430d662d20006:EHJOol001ioo`Ik
MPAoU0Eo]09gn0AjR004MVAfA7I4MT@5OZ`00gjYIH1fB@02MTT2G@@20006NXh3MT/00gk:Oomoo`03
Ool2FFd00gZ:Oomoo`05Ool5MoP015OkNfmkKg]_17^f1GnE00AoTf?iHoUc/@9k]`=oT@IgF09oU09o
TP=C_`=[>@EkM`=oTPMBN@9oT0=_5`03Oi1Jfe[K00=Jf`803P8]n`D04@LU^P031CT0400@00M>g0<0
e`<QF0HUV0HM5@Lj6PDQN@P0L`AVf0803`03OkD]MRef00882@03;GI2od;o00=2o`aEB`PP1`<81`]f
9003MmU[W6^L00M[W0A6>PMcfPEJo0E_FPMO?0=W6P=ke003HoY_FFmI00I_F@Egf0IkePL<mPEgn@9[
m@E_/0D000EoU@034=Dn6ShJ00@in@@QN003015_Nfmk00=_N`@E5PDQ5@EO70@4L`DEN@I:N`0300X0
2CGH00Def08@]0H<]0Qoo`<<20@@30<00P0300P00000008LCP@<3@HH;@03Ool002UF00HYEQUoo`00
7Woo1G]f17nD00=37gndOk@00gnd0WOh17Z800EfI7I4MTAfA7IS00An[09nZ@05IH1fBGI9MTUM1002
0006NXh4MT/017k:Oomoogoo15U]00=jRWooOol017oo17Oh00=g/2;nNfl00W]_17^f1GnE0V?i0W>a
0W^g0gnA1WMH00=oU7nBOi800gnB16/i17]g17nB1e9i00=oT6=mKaL00flG1E[K0P0>0Rgk1@0A1bFj
00@5>@0@010040E>g003:KXQF25H00@QF0HUV0LM5@Lj6PDQN@L0L`EVf0803`04OkD]MRef;GH6@_l<
ED/780L420L;MR@2MmT8Ji`3ASX7LmX6F_`4KeX9Gc`2IaX2Nm@2HoX00dijKeU_F@05KeT4MmP7NmH6
3?H6MoT00f_eFmi_/003Kk0:;KT2<IL7>OT58GP4Kg/45AH58AD5Ga`417<29EH35GT7BW/00`09=MPe
f005=MP00a2d@g<<]0043;@00dD_72dL;@0272d3Ool330P340`014>k00800P080P000aa>10`=1AP]
00@42Woo000000HYEQUoo`007Goo1W]f0gnD0T<O17nd00Agn7_DNmAke0AjR0=fA003MV=n[7j/00=n
[003OZUUP7I900=fB@03G@@007Z>00EjSPAfB`03O/Yoogoo00EIK@9jRPAoo`Agn09Gn`AkK`=k]PEo
U@04Oi=SnF?iLk42NkL3Oi46MeP2Oi@5Oi84JcT4NgL3Oi87DWT2Oi000f=mKaM_5`03KaL4F]/300h2
;O/501479KX30103C]`3:KX78EP59IP77AD7>QX58GT707<5I]P200l00gne;GH]MP07@_l;ED/880L4
20L;MR@3MmT7Ji`3ASX6LmX8F_`3KeX9Gc`2IaX00g_DHoYSnP03CWX6KeT4MmP7NmH63?H5MoT2JoD5
Kk0:;KT3<IL6>OT58GP2:EH3Kg/45AH48AD00`1CGaaO7002Ga`417<49EH25GT6BW/00`0:=MPef005
=MP00a2d@g<<]0043;@00dD_72dL;@0472d430P340`01D>k00802008000011a>10`=11P]00<42Woo
Ool00P001RUF6Goo000MOol6NgH3Oi@00d<OOkAo]003Ok@4Nm@4NXP017ITMTAfA7IS1Gj/00=nZFF0
MTT017I900<007Z>NXh017Z>17I;00=nbWooFFd01EU]0WZ:17oo0WOh00AGT5OkEo/RoP=kK`Ak]PEo
U@=Sn@=k]`=oT@Ao]@9gF003OiAoTWnB00=oTPE[>@AkM`=oTP03Og=BNE9i00ABN@9oT0I_5`03MaIJ
fe[K009Jf`803P8]n`D04@HU^P03>Wd5>@0@00804003C]`Y^RVj00<Y^PHQF0DUV0LM5@Lj6PDQN@H0
L`IVf0<03`03;GI2od;o00I2o`03FYUEBeE;00QEB`PP1`D81`Yf90Agf@M[W003ASYcfW?J00AcfPYJ
o003KeYO?5ll00UO?003NmASnV?j00A>NPE_F@Egf0QkeP@<mPIgn@03JoEO:Vn`00=_/003H_YgKBfi
00L]^@@aU`Hin@DQN0DYEP@E5PDQ5@EO70<4L`HUEPI:N`0300Xef3GH00Def08@]0D<]003ABlL;A`]
00@L;@@<208@3003@k/00P0800802003000LCQa>008LCP@<3@<H;@842P=oo`03000YERUF00@YEQUo
o`007Goo1W]f0WnD0T<O17nd1G_D17Z800=fI7I4MT@00WIS17j/0WjY1GI900<007Z>NXh017Z>17I;
0Wk:1UU]0gZ:0Woo0WOh00EGT5OkEo]Gnb;n00=kK`Ak]PAoU@04HhmSnF?iLk43NkL3Oi46OkD6Oi85
JcT4NgL2Oi800dijOg=BN@05DWT00gn@Hge_5`04KaL2MaH4F]/200h2;O/601449KX2>Wd010Di0100
400@1RVj1R5H1BFH21dE1cXJ125i1P1c1fKH0`0?1d;o0UZI2UE;22071@P72GHT1GOI1A5I0V^L00=6
>W?JLmX017?J2U[l35ll0f?j1Dij16mI17OH2G_F10cf1GOi0V_e00AKgVn`Kk1_/09RnP03Mfd]^Bfi
00H]^@@aU`Lin@@QN0DYEP@E5PDQ5@0305=O75lL009O70@4L`DUEP8QE`A:N`0300X02CGH00Def08@
]0D<]003ABlL;A`]00@L;@@<208@300574h0200800P0000474h530d362d210X3Ool00`00:EHYEP04
:EHIOol001eoo`IkMP9oU0937`Ao]0Ake003LoMjR7Z8009jR09fI09fA003MV=n[7j/009n[09nZ@03
IH1fBGI9009fB@03NTQjSWZ>00EjSP=fB`9nbPIIK@=jRP9oo`9GT0=Gn`03Kd/RoW]_009kK`Ak]P=o
U@04HhmSnF?iOi<4NkL2Oi400eoiOkEo]@04OkD5Oi85JcT5NgL2Oi800dijOg=BN@05DWT00gn@Hge_
5`04KaL3MaH3F]/300h00bgk01404@0401439KX3>Wd00`Di010040020105:KX68EP69IP77AD7>QX5
8GT507<7I]P400l6@_l2FYT9ED/880L620L9MR@5MmT00cgG4ETAF@084ET2LmX;F_`00eJJGcaO?008
Gc`3HoX6CWX3KeT5MmP9NmH33?H5MoT3JoD3Kk02H_X2Mfd8;KT5<IL6>OT58GP4:EH0100A5AHE5QDF
1B4E0P1C0elL10Ac1BEF125G0TYk00<02P09=MP01CGH0a2d1@bd1A`]1@`80aa>0`081Aa>1@`=0QP]
0`@:0goo00<002UF:EH01BUF67oo000MOol6NgH017nD@am37d<O0gnd00=k/W_DNm@00W_D00=cmgYW
NXP00WZ80WIT0WI400=fHgj/OZ`00Wj/0WjY00=UP7I9MTT00gI900=jB7Z>NXh017Z>0gI;0Wk:1eU]
0gZ:0eN@0eOk0R;n0W]_1G^f0WnE00=SSf?iOi<00WnC0g^g0gnA1Wne00=kUgnBOi800gnB1F/i1G]g
0WnB00=>NWmcOg<01E9i00=oT6=mKaL016lG0gLF15[K0P0>0Rgk1P0A00<U^SYm>Wd00cYm100@1RVj
1R5H1BFH1adE1cXJ1B5i1@1c1fKH1@0?1D;o0eZI25E;22071PP72GHT17OI0SgG2a5I2e[l0eJJ25ll
0f?j24ij0VmI1GOH2G_F0`cf1GOi00=[m@GLFmh00fn`0V;j0WM]1bfi1S6G1SWi1B5h12UF00@04ADF
5AHE5PDQ5@80D`=O70@4L`HUEP@QE`9:N`0300Xef3GH00@ef0@@]0@<]0DL;@<<20DLCP<020DLCPD<
3@0362d42P@:00842PAoo`03000YERUF00@YEQQoo`0077oo1W]f00AoU4<O@am37`=o]003Nk9ke7_D
00=ke003OomjIgYW00=jR003MVAfA7I4009fH`=n[0=nZ@EfB@9jB0AjSP04901fBgI;MT/3O/X6FFd3
NXX2Ei02Eo/017nfKd/RoR;n0W]_17^f0WnE00=SSgnCOi<00WnC17^g0WnA00=OnGneOkD00gne0W^G
17nB1V/i17]g0WnB00A>NWmcOg=oL`ABN@03Oi1SOF=m00E_5`Ag5P=Jf`<03P03;O/04@0A00@04@Hj
O@@040HY^PHQF0DUV0PM5@Lj6P@QN@@0L`QVf0H03`=2o`AJV@QEB`PP1`L81`Qf90=gf@@me`XAF@03
IeaJo5[l00QJo0AFVPIO?0=SnPY>NP03KeUgf7OH009gf09keP9kMP=cB`AkeP033?IgnGOi00=gn@04
JoD5g5_NFmh2Kk03H_X3Mfd6;KT00eKl<ILaU`03<IL7>OT48GP5:EH0100A5AHE5QDF1B4E0P1C0UlL
10Ac1REF1R5G00<02SGH=MP013GH112d10bd1A`]00<<221_74h01Aa>0P0800=8jQa>74h00aa>1@`=
10@:1Goo00<002UF:EH012UF67oo000LOol6NgH017nD@am37d<O0gnd00=k/W_DNm@00W_D0goo00Aj
IgZ8NXQjR09fI003MTAfHgIS00=n[0=nZ@EfB@9jB09jSP<T0004OZYfBgI;MT/2O/X6FFd2NXX2Ei04
OkH00fm;8_ikK`02Nfl4NkH00gnEHhmoT`04Oi<4NkL2Oi400eoiOkEo]@03OkD2NiL4Oi86JcT4NgL2
Oi800dijOg=oL`02Og<3DWT00gn@Hge_5`05KaL4MaH34I/300h00bgk01404@0401400dZK>WdjO@03
>Wd50105:KX68EP59IP87AD7>QX48GT407<9I]P600l2@_l5FYT6ED/980L720L8MR@3MmT4?ML94ET3
Ie`8F_`5EYX5Gc`4HoX:CWX5JaX4NgH5Ld/00gOCNmH<mP05MoT00`GLFmiKgP02Kk04H_X3Mfd5;KT2
E_`6<IL6>OT48GP5:EH0100A5AHE5QDF1B4E0P1C0UlL10Ac1REF1R5G00<02SGH=MP01CGH112d0`bd
11`]0b1_1Aa>0`0800=8jQa>74h00aa>1@`=10@:1Goo00<002UF:EH012UF67oo000LOol5NgH5@al2
Ok@2Nk84Nm@3Ool2NVL2NXP2MV@00gI4MV=fH`03OZ`3OZT00fF0MTUfB@02MTT3NTP4900017jZMT]f
BgI;0Wk:1UU]0WZ:00=GT7nfOkH00gnf00A_Bb;nNfmkK`Ek]P9SS`EoT`Ak]`03Oi5OnEoi00Ao]@=k
U`AoTPI[>@AkM`03Oi9>NTij00AoL`=BN@03Oi1SOFlG00E_5`Eg5P<AV`<03PD04@=:V`@jO@031CT0
400@008040HY^PHQF0@UV0PM5@Hj6P03:ELQNB5i00<QN@<0L`UVf0L03`03@_mJVEZI00=JV@IEB`PP
1`P81`Mf90=gf@Dme`TAF@=WG0QJo0IFVP=O?0ASnP]>NPE[6PAkMPAcB`Agd`D5g0=KgP9_/0ARnP=g
K@D]^@9Fo0HaU`Hin@@QN0DYEP04014E5QDF5AH58AD305<00elL17<4L`0317<69EH58EL00`bC00Te
f005=MP54;@23;@272d586l574h300P00dSZ74hLCP0374h430d00`0010X42P0210X6Ool6:EHHOol0
01aoo`AkMPI37`03OkAk/W^b00Ake0Aoo`9jI`9jR0=fI0=fH`9n[0AnZ@EfB@=jB0<T0004OZYfBgI;
MT/3O/X5FFd00gZ:Ei1o]P04OkH00`008_hRoP02Nfl4NkH00gN@HhmWF`04Oi<5NkL00gnAGoUo]@04
OkD2NiL4Oi86JcT5NgL00gnBCWY>NP05Og<2DWT2Hgd6KaL5MaH00gmc4I/AV`0300h40144BY/4>Wd0
0`Di010040030105:KX68EP59IP87AD3>QX3:EL00`0c8GTQN@028GT307<9I]P600l00cILFYUJV@04
FYT6ED/880L820L7MR@3MmT6?ML74ET5Ie`6F_`8EYX00ellHoYSnP02Nm@;CWX6JaX4NgH4Ld/5Mm<3
1M`4Fmh00fn`H_YRnP02H_X5Mfd4;KT2E_`6<IL7>OT48GP4:EH201425AH58AD405<00elL17<4L`02
17<69EH58EL00`bC00Xef005=MP64;@00`bd72dPK`0586l574h200P2B>X574h430d00`0010X42P02
10X6Ool7:EHGOol001aoo`9kMP03?e537d<O00A37`9o]09k/P=ke0Eoo`=jI`05NXQfI7ITMVAfA002
MV<2OZ`4OZT00gYZMTUfB@02MTT3NTP39002OZX2MT/3O/X6FFd00eN@OkIo]P03OkH00fm;8_hRoP02
Nfl3NkH00gN@HhmWF`05Oi<4NkL2Oi400eoiOkEo]@02OkD3NiL4Oi86JcT5NgL3CWX5Og<2DWT2Hgd5
KaL6MaH2Og<34I/0100>;O/04@0A1TZK13Ym1@0@1BVj1R5H1BFH21dE00<j6RUG:EL012UG00@0<b5i
8GTQN@80L`]Vf0<03`<fG0MJV@AEB`TP1`T81`If909gf@Lme`LAF@EWG0IJo0QFVPEke003EWQ>NTij
00Q>NPE[6PAkMPEcB`Igd`031MaKgU_N009KgP03Kk1Wnf;j00=RnPEgK@<]^@AFo0HaU`Hin@@QN0@Y
EP804@8E5PDQ5@@0D`03Ga`4L`Ac0084L`HUEPDQE`8<T`Hef0H@]08<]0HPK`DLCP802098jPDLCP@<
3@0300042P@:00842PIoo`03000YERUF00@YEQMoo`006goo0W]f00=[>G]fNgH01D<O00Ao]7^bNk9k
/P9ke0Ioo`AjI`04NXQfI7ITMT@2MV<3OZ`3OZT2NVX3MTT3NTP490000gjZMT]fB`03O/X3G>02FFd0
0eN@OkIo]P04OkH016m;8_hRoW]_0g^f0WN@00=SSfMKOi<017nC17^g00=oTEoiGoT00gne17^G1GnB
1F/i17]g00AoTTijCWY>NPEoL`04DWUoT6=mHgd5KaL6MaH2Og<34I/00`2e00h04@07BY/4>Wd50105
:KX68EP59IP87AD7:EL203<28GT207<;I]P00`0?=U`fG004=U`6FYT4ED/980L920L6MR@00gOI?MLm
e`07?ML54ET7Ie`4F_`9EYX4Nm@2EWP:CWX5JaX4NgH4Ld/7Mm<2Imd3Fmh00fn`H_YRnP03H_X5Mfd3
;KT4E_`6<IL3>OT3>MP48GP4:EH301425AH58AD405<417<69EH68EL00`bC=MPef004=MP64;@00`1C
3;@PK`0586l574h200P2B>X574h330d00`0010X42P0210X8Ool6:EHGOol001]oo`03NgI[>F/i00Ak
MP=37`03OkAk/W^b009ke0Qoo`=jI`04NXQfI7ITMV@3MV<2OZ`4OZT2NVX2MTT3NTP017k:900T02@0
0WjZ00=fBgk:O/X00Wk:15cP00=[:WnfOkH00gnf00D002;n8_hRoW]_009k]P9gT003HhmWFfMK00Ao
T`Ek]`03Oi5OnGne00=o]@AkU`IoTPA[>@AkM`04Oi9>NTijCWX6Og<3Hgd5KaL6MaH3Og<34I/00`2e
BY]:V`07BY/3>Wd60105:KX68EP49IP87AD7:EL303<00b5i07<0L`0;I]P7=U`6FYT4ED/880L:20L5
MR@2MmT9?ML54ET8Ie`3F_`9EYX4Nm@2EWP9CWX6JaX4NgH4Ld/7Mm<4Imd00e_NIo]RnP04H_X5Mfd2
;KT00bTe5?EFo002E_`6<IL6>MP0101C8GPQN25h1BUF0P0A0QDF1B4E101C10Ac1bEF1B5G0PbC1CGH
1a2d00<0De2P86l0121_1Aa>00<024SZB>X01Qa>0``=00<000@:10X00P@:27oo0bUF6Woo000KOol3
JcT6NgH017ndNk9k/W^b0W_D27oo17YW0gIT0gIS0Wj/17jY0gYZ00EfBGY8NTQjB7k:00<T009nZP03
MT]nbWk:00=nbP9Lh09[:PEo]P03000RoR;n009kK`04NkIgT7N@Mi03Ie/4Oi<5NkL2GoT3OkD00e/M
NiMkU`02NiL2Oi800g^GOi9oTP03Oi82JcT3NgL017?jCWY>NTij1gmc0V=m1VlG1GLF1Gmc0Q6K0P2e
2DZK0SYm1P0@1BVj1R5H12FH21dE00=gdbUG:EL01BUG0`0c00<QN@1cI]P02VKH00=cN3IL=U`013IL
1eZI0UE;2B072PP71GHT00<Y^CgG?ML02CgG0a5I2FML0U[l2EJJ1G_D0eIh24ij1V/J17]f17=;1WOC
1FOM0VOk1F;j1WM]00@]^BTe5?DDm@9Fo0DaU`03BW/if3WH00Dif0<QN0DYEP<04@035AHQ5B4E00<Q
5@D0D`@4L`HUEPDQE`8<T`Def0L@]00305=@X21_00<PK`DLCP802098jPHLCP<<3@0300042P@:0084
2REoo`006Woo16/i1W]f17^b00=ke7ooOol01goo17YW0gIT00EjRGISMV=<H7j/00AnZ@AjJP04MTUj
B7Y8NTP39002OZX00gI;O/YnbP04O/X00ecPJbYYQP05OkH01@008_hRoW]_NkH00gN@00ASSfMKIe]W
F`AoT`Ak]`03Oi5OnEoi009o]@03FaekUg^G00=kU`9oTP03NiMoTWnB00AoTP03NgMcnW?j009cnP=>
NPMoL`9SO@I_5`Eg5PEoL`04LiXAV`2e0;D9BY/2>Wd70104:KX68EP59IP67AD2Mm<7:EL403<<I]P0
0g=h=U`fG005=U`6FYT2ED/980L;20L4MR@00bVi?MLme`09?ML34ET:Ie`00e[lEYYFVP07EYX4Nm@4
EWP7CWX6JaX5NgH3Ld/6Mm<6Imd00fOkH_YRnP03H_X7Mfd00bfi:CDDm@025?D00eKl<ILaU`02<IL3
BW/6>MP00`1C8GPQN005:EH301400aDF8ADQ5@038AD505<0101D17<4L`Ac1REF1B5G0PbC1SGH1Q2d
0P1C00A@X21_86lPK`DLCP802098jPHLCP8<3@8000<42RIoo`006Goo16/i1g]f0g^b00=ke7ooOol0
27oo17YW00AIP7ITMVAjR@9fH`9<H0AnZ@EjJP=jB003O/XT02@000=nZP03MT]nbWk:009nbP03E@QL
h6/Z00Eo]P05001_Bb;n8_ikK`04Mi03Ie/4Oi<4NkL01G>?GoUOnEoiOkD00U/M1G^G2GnB17?j14ij
1Wmc0f=m1VlG1GLF1Gmc00=cVQ6K4I/00P2e24ZK00<03cYm1CT01P0@1BVj1B5H1BFH1QdE0WOC1bUG
100c2fKH0g=h1SIL1UZI0UE;2B072`P717HT0Vli2SgG0Q5I2fML2UJJ17_D15Ih1dij1V/J17]f17=;
1GOC1VOM0VOk1F;j1gM]0RTe11Ce00=Fo36G<IL014Yk1SWH00@0Db5h8GPQN0@YEP<04@035AHQ5B4E
00@Q5@@0D`0405@4L`Ac17<69EH58EL339<5=MP64;@305<386l574h01008B>Y8jTSZ1Qa>0P`=0P00
0`@:9Woo000HOol5JcT7NgH3Nk8;Ool5NVL3MV@017Z9MV=fHdaP17jY1GYZ0gY800=nbR@090000gjZ
00AfBgk:O/YnbP9E209[:PEo]P05000RoR;n8_ikK`03Mi0016>?Ie]WFfMK17nC0g^g0W>?0Uoi00Ao
]E/MFaeK7@AkU`9oTP03NiMoTWnB00EoTPAcnPA>NPEoL`ASO@I_5`Eg5PAoL`=cVP034I/0]@2e00M:
V`9O6`8jO@H040DY^PHQF0@UV0HM5@9gd`LYE`D0<`YVf0=cN0HfG0MJV@TP1``81`Af909_>@/me`03
4EUWG6ML00UWG003C[]FVUJJ00IFVPEke0EFN0E>NPM[6PAkMPAcB`Agd`IWg@9Wn`IRnPIgK@<Y=@DD
m@03<IM:NdYk00=:N`Hif080D`8QN0@YEP@04@035AHQ5B4E00<Q5@D0D`0305@4L`Ac00LUEP@QE`<<
T`0300lef3GH008ef0L@]0<0D`8PK`DLCP0400Q8jTSZB>X574h230d3000210X00`00Oomoo`0TOol0
01Qoo`E[>@IkMPAk/Paoo`AjI`=fI005NXUfHgISC61nR`04OZT4NVX3NTP00gk:900T0003OZX00gI;
O/YnbP03E@P2JbX5OkH01@008_hRoR;nMk000gN@16MK17nC00Ak]g>?LhmcS`9On@03MfeK7E/M009K
7@AkU`9oTP03NiMoTWnB00AoTPAcnPE>NPAoL`ESO@E_5`Ig5PAoL`=cVP044I/0]@2e0;D6BY/2Ga/0
0`0?>Wd040060104:KX68EP49IP57AD4Mm<7:EL403<:I]P4LgP5=U`6FYT3I_T780L=20L2MR@00bVi
KcU_>@0;?ML;Ie`2C[/8EYX4Nm@6EWP5CWX7JaX4NgH3Ld/4Mm<6Imd3Io/6H_X5Mfd5:CD45?D6BW/6
>MP205<28GP5:EH301400aDF8ADQ5@028AD00cgh5?H0D`0305<205@00`Ac9EHUEP059EH48EL439<4
=MP74;@405<00b1_74hLCP0374h01008B>Y8jTSZ1Aa>0P`=0`000P@:9goo000GOol6JcT6NgH3Nk8=
Ool4NVL00eV0MVAfI002NXT017ISC61nRgj;0gjY17YZ00=Z87Y8NTP00Wk:00<T07jZOZX00WjZ00=n
bUD8E@P00UD800=[:VV6OkH00gnf0P000b;n0gN@1FMK0gnC00Ek]g>?LhmcSeoi00=gK@=K7@EkU`03
Oi9kUg^G00IoTP=cnPI>NP=oL`9_F@=SO@I_5`Ig5PAoL`AcVP034I/0]@2e00E:V`=O6`0300ljO@0@
00H0409OnP<Y^P@QF0038ELUV2FH008UV0DM5@Agd`LYE`@0<`UVf0EcN0HfG0EJV@EVn@DP1`d81`9f
90=_>@/me`03LhiWG6ML00MWG0=>^`QFVPAke0IFN0E>NPM[6PAkMP=cB`=gd`MWg@9Wn`MRnPAgK@03
G[TY=BTe00<Y=@DDm@I:N`Hif080D`038GPYERUF00<YEP@04@038ADmn3gh008mn08DmP<0D`80E084
L`HUEP@QE`D<T`<ef0L@]0@0D`0386lLCQa>00<LCPA8jPDLCP8<3@<0000310X007oo02Ioo`005goo
1V/i1W]f0g^b3Goo1GYW0WIT0gZ900=fHdaPOX/00gjY17YZ00=Z87Y8NTP00Wk:00<T07jZOZX00WjZ
1ED800=[:WnfOkH00gnf00D007NI8_hRoW]_00=gT0EWF`=oT`=cS`AgK@AK7@EkU`03Oi9kUg^G00Eo
TPAcnPI>NP=oL`E_F@I_5`Eg5PAoL`A^m`04?QXAV`2e0;D4BY/4Ga/200l60105GoX00`5g8EPQE`04
8EL49IP47AD4Mm<7:EL503<8I]P5LgP6=U`5FYT6I_T013GI80LP1b071@P70WOH0RVi10P70WHT0fli
2cgG0W>>1fML1Djk1UJJ1G_D1eIh0dij1f/J1G]f0g=;0WOC0W=H1FOM0fOk1V;j17M]0Uji1BTe1ACe
1TYk1SWH0P1C00<QN2UF:EH00bUF100A1Sgh0QCf0`1C0P1D00<4LbEF9EH01BEF125G10bC00<03cGH
=MP0212d0`1C00<PKaa>74h00Qa>00<024SZB>X00TSZ1Aa>00@<3@00000000842P0320Qoogoo02Eo
o`005goo1F/i1W]f0g^b3Woo0V400gYW0WIT0gZ900AfHdaPOX]nR`9nZ@EjJP9jB09nbP03901nZWjZ
00=nZPAE2003JbYo]Wnf00=o]P05001gVGNIMiUg/002Mi05Ie/4Oi<2Lhl4Mfd5Fad5NiL00gnBNiMk
U`04Oi83LoX00gnDCWY>NP04CWX3Og<00f^>KeU_F@03KeT6KaL5MaH4Og<4K_L00g]E?QX0]@020;D3
BY/5Ga/00`0?010040030107GoX68EL0100>9IPUV2FH0adE1GOC1bUG1@0c26KH1W=h1CIL15ZI26Ki
0SGI0PP70SGI17OH12Vi0PP70WHT16li2CgG17>>1FML1Tjk1UJJ17_D25Ih0dij1f/J17]f0g=;0gOC
1G=H00=WgFOkIo/00VOk1V;j0gM]0eji1BTe1ACe1TYk1SWH0`1C00<QN2UF:EH00RUF100A1Sgh0aCf
0P1C0`1D1bEF125G1@bC0SGH212d0`1C00<PKaa>74h00Qa>00<024SZB>X00TSZ1Aa>00L<3@000000
00@:0008200WOol001Ioo`I[>@IkMP9k/Q1oo`9Q009jI`03FH1fI7Z900=jR@05C61nRgj;OX]nZ@05
NVX01FXPNTQnbWk:90001WjZ0UD80V/Z17nf00<007NIMiT00WNI00=g/7N@Mi001FMK0gnC00=;_W>?
Lhl017M]1E/M1g^G1GnB17nD00=_64ijCWX00dij0gmc1VmI00=gV6lGKaL00flG1GLF0gmc00=2Ffkg
K_L00Vkg00=kEChJ4I/00P2e0TZK1UlK0P0?0`0@1Uoj2B5G0bFH0adE1WOC1bUG100c1fKH1g=h1CIL
15ZI26Ki1CGI1WOH12Vi0PP700=f96liKcT00Vli2CgG1G>>0fML1djk1UJJ17_D25Ih0Tij26/J17]f
0g=;0WOC00=gSg=HLeP00g=H17nd1f;j0WM]00AkeejiG[UN^@HY=@DDm@E:N`Hif0<0D`038GPYERUF
008YEPD04@Dmn0@DmP0405<0E01D05@7<KP48EL539<00`3G=MPef0064;@00d]o05<0D`0205<474h5
B>X574h01@`=0000000010X00PP89goo000FOol6JcT6NgH2Nk8@Ool4H@000gYWMVAfI003NXT017IS
OX]nRgj;0WjY17YZ00=Z87Y8NTP00Wk:00<T07jZOZX00gjZ0UD800=[:VV6OkH00gnf00<007NIMiT0
0WNI00=g/7N@Mi001FMK0gnC0W>?00AcVWM]MfegK@EK7@EkU`03Oi9kUg^G00AoTPEoU003KaQ>NTij
00=>NP=oL`I_F@9gV0A_5`Eg5P=oL`E^m`9kE@05?QX0]ChJ;MU:V`06Ga/200l20103GoX00bVi8ELQ
E`0:8EL00`0>9IPUV0037AD3Mm<00dXi00agd`07:EL503<6I]P8LgP5=U`3FYT8I_T5=MT6MmP6:KT5
KcT9?ML6Lhh00fMLC[]>^`07C[/4EYX5Nm@9EWP00dijJaY[6P06JaX4NgH3Ld/00gOCMhmcF005LeP4
Ok@00gnfH_YRnP04H_X2Mfd017_GG[UN^Eji1RTe1ACe1TYk1CWH101C12UF1@0A1Cgh1ACf00<0D`1D
05@01c6h00@04R5G8ELQE`H<T`8ef0@@]0=;O`0400`0D`1C05<474h5B>X574h300001009000820P8
9goo000FOol6JcT6NgH00g^bOomoo`0@Ool4H@02MV@4NXT4OX/00gjYNVYjJP02NVX00fXPNTQjB002
O/X00b@0OZYnZP04OZX00eD8JbYo]P03OkH00fofMiUgV@02MiT00gN`Mi1gT006Ie/2Oi<00d^nLhmc
S`03Mfd2Oi@4Fad5NiL00gnBNiMkU`04Oi84Oi@3KaP4CWX2Og<00f^>KeU_F@03KeT4MiP3KaL5MaH2
Og<00d9KK_M^m`02K_L3NeD3?QX00bgIGa]O6`05Ga/200l00`0@GoXY^@03:KT=8EL0100>9IPM5AdE
0gOC0dXi00=gdbUG:EL01BUG1@0c1VKH27=h0P2g0cIL0UZI2FKi1CGI1WOH1RVi1Fli2CgG1W>>2Tjk
15JJ17_D2UIh00=>NV/JJaX01F/J1G]f0W=;00=gdgN?Mhl01W=H17nd00=o]V;jH_X016;j00=gKG_G
NmL015ji1BTe1ACe1TYk1SWH0`1C0RUg0bUF100A1Cgh1QCf0`1D1S6h00@04R5G8ELQE`H<T`030=Le
f12d008@]0E;O`<0D`<LCPI8jPDLCP8000802@8822Qoo`005Goo1f/i1G]f0W^b4Woo164000=IP7IT
NXT00gZ91Gj;17YZ00=Z87Y8NTP00Wk:00<T07jZOZX00gjZ00=Z3GJ>JbX00gnf00=_mWNIMiT00gNI
00=g/7N@Mi001VMK0WnC00=;_W>?LiX00gM]0gnD0e/M17^G00AS?7^GNiMkU`=oTP03LiYoU7nD009o
U0=_60A>NP9oL`I_F@EgV003KaMg5WLF00Ag5P03Og=2Fd9K00A^m`AkE@<n6P03;MUO6elK00AO6`<0
3`HY^@`QE`0400hUV2FH7AD2Mm<01@0>BSU:>DXiMm<022UG1@0c16KH2G=h00=gf@2g0;L00SIL0UZI
2VKi0cGI27OH12Vi1fli1cgG1g>>00<if4jkC[/01djk15JJ17_D2UIh26/J1G]f0W=;0gN?1G=H17nd
0gnf16;j0WM]0W_G15ji1BTe1QCe1DYk1SWH0`1C12Ug00<YEP0A01400P0A1Sgh1ACf0`1D1c6h0b5G
1`bC00<0ea2dBgl01T]o0`1C0Qa>00<00TSZB>X014SZ11a>00D0000900T02@00008822Qoo`005Goo
1f/i1G]f00=k/WooOol04Woo0f4000=^07ITNXT017Z917j;17YZ0VXP00AjB7k:O/YnbP=nZP=Z3@04
MXiYQWnfOkH2KoH5MiT00gN`Mi1WF`05Ie/2Oi<2Bkh00g>?LiYgK@02Mfd4Oi@2Fad2NiL3Hc`3NiL3
Oi85Oi@4KaP3CWX00gmcJhi_F@05KeT6MiP6MaH00gmc@U]2F`04K_L4NeD3?QX2;MT6Ga/300l5:KT=
8EL01@0>9IPM5GOC00h014Xi00<032UG:EL01RUG1@0c16KH27=h0gOI0`2g00<fG5ZII_T02FKi0cGI
27OH12Vi1fli1cgG1W>>0SWH2Tjk0UJJ1G_D2UIh00=cSV/JJaX01F/J17]f0g=;0WN?1W=H17nd0gnf
16;j0WM]00=keejiG[T00eji1BTe1ACe00<m]bEG9EL00dYk1SWH101C12Ug1@0A1Cgh1ACf00<0D`1D
05@01c6h00<04R5G8EL01`bC0`3G1T]o00<0301C05<00Qa>00<00TSZB>X014SZ0aa>00<0000900T0
0P0900<000P820P0:7oo000EOol6JcT6NgHEOol4H@000gITNXUjR@03NXT4OX/017Z=NVYjJWYZ0VXP
00EjB7k:O/YnbWjZ00EZ3@03JbYYQWnf009_mPEgV@9g/003Mi1WFfMK00AWF`9oT`04BkicSg>?LiX2
Mfd6Oi@00g^GHcaS?002Hc`4NiL2Oi800g>JOiAoU003Oi@4KaP3CWX00gmcJhi_F@04KeT7MiP2Jm`3
MaH00gmc@U]2F`05K_L5NeD2?QX3;MT5Ga/300l5:KT=8EL200h00gOC00h03P04BST00`0<Mm<YE`06
:EL503<4I]P8LgP3MmT40;L;I_T2=MT9MmP4:KT7KcT7?ML5Lhh4>MP9C[/2EYX3Nm@00doMEWQFN009
EWP2Lhh6JaX4NgH2Ld/00`CgMhmgS`06LeP4Ok@4OkH3H_X00gM]NmMke`05G[T6:CD25?D3?KL49EL2
BW/5>MP405<4:GL50145?OP65?H205@7<KP0100B8ELQEb5G1PbC1@3G1D]o0P1C00<LCP02B>X01DSZ
11a>1@090`P8:7oo000DOol7JcT5NgH00g^bOomoo`0COol01GZ9H@1Q0640FH001GZ917j;0WZ=0gYZ
00=Z87Y8O/X00Wk:1FV600=Z3F/ZOkH00fof1GNI00Ag/7N@Mi1kePEWF`04Oi=;_T^nLhl2LiX2Mfd6
Oi@5Hc`3NiL3Oi800g>JOiAoU002Oi@6KaP00dijOg=[SP06KeT7MiP5Jm`00gmc@U]2F`05K_L5NeD2
?QX00g=H;MT]f@05Ga/300l5:KT>8EL300h5BST00`0<Mm<YE`06:EL603<2I]P8LgP5MmT30;L<I_T0
0cGIMmQgf008MmP2:KT8KcT7?ML4Lhh5>MP9C[/2EYX017_DCme?gDoM2UIh0g>>1F/J1G]f0W=;0gN?
1W=H0gnd1Gnf0f;j00=gKCHJ=QX01Eji1RTe00<DmCfg?KL00cfg1BEG1CWH101C12Ug00<<]00A0140
0P0A1Cgh1QCf00<0D`1D05@01S6h00@04R5G8ELQE`L<T`@0e`E;O`<0D`03008XKBQ]00A8jP<LCPD0
2@04000820P820PXOol001Ioo`E[>@AkMQMoo`05NXUQ0640H@1^0006NXT3OX/3NXd2NVX00fXPNTQn
bP02O/X00g^eJHIYQP03JHH016/ZKoI_mVof1GNI0WN`00AgT7_FNmIkePAWF`05Oi=;_T^nLhmcVP03
Mfd6Oi@5Hc`3NiL2Oi82LiX4Oi@6KaP00dijOg=[SP06KeT6MiP5Jm`4@U/5K_L6NeD2LeP3;MT4Ga/4
00l5:KT58EL00`098ELQE`058EL200h6BST200`8:EL503<2I]P8LgP5MmT40;L;I_T00cGIMmQgf003
Hgd25?D3MmP2:KT8KcT6?ML4Lhh7>MP9C[/017_DCme?gDoM0V=m2EIh17>>16/J1G]f0W=;0WN?1W=H
17nd1Wnf0V;j13HJ15ji1RTe1Sfg1bEG13WH0`1C1BUg00@<]00A01404@Hmn0DDmP0305<0E01D00Ha
^0804P8QE`L<T`@0e`035?E;Od]o009;O`0400`0D`1C0083:6d3B>X374h500T420PXOol001Moo`A[
>@=kMQUoo`05NXUQ0640KP1fI005NXT3OX/4NXd00gYZJR1Z8003O/X00g^eJHIYQP03JHH017^eKoI_
mVof1GNI0WN`00=gT7_FNmH00g_F0VMK0T^n00=cSg>JLiX00WM]00=S/GnDOi@00gnD1F<l17^G0WnB
0W>J17nD1flH00=oLf^>KeT016mI1WNH1F_L1D9K1Fkg1W]E0Wne12gI15lK0`0?1BVi3R5G00<03TXi
BST01DXi00<032UG:EL01RUG1@0c0VKH1g=h1gOI0`2g2fKi1V=m11Ce00=gf2Vi:KT02Fli1CgG0g>>
23WH24jk14oM0f=m2EIh1G>>0f/J1G]f00AcB`CgMhmgS`IcF0Ao]0Io]P03H_YgKC5f00<aMP8U=P9N
^@DY=@03D]`m]cfg00@m]`TUE`8if0<0D`DYM`8<]0<04@Dmn0DDmP80D`0305@a^36h00Da^003018Q
Eb5G00L<T`0400d0e`3G0=L25?D3Bgl0100<05<0D`0912Q]0TSZ0Qa>00<0100900T00`0910P8:7oo
000HOol3JcT2NgHJOol01GZ9H@1Q0640KP001GZ917j;17Z=0VXP00AjB7k:NkEk]@EYQP9_mPMgV@9g
/0MkeP04Oi=;_T^nLhl2LiX2Mfd6Oi@5Hc`4NiL2Oi800g>JOiAoU003Oi@7KaP00f^>KeU_F@04KeT6
MiP4Jm`5@U/5K_L7NeD3OkD4;MT3Ga/400l4:KT>8EL8BST00`0<Mm<YE`06:EL43GX203<8LgP8MmT3
0;L:I_T5Hgd00gOG5?DDm@045?D:KcT5?ML2Lhh9>MP7C[/5Cmd3Hgd8EWP6Lhh3JaX4NgH2Ld/00`Cg
MhmgS`06LeP4Ok@7OkH00gM]<GHaMP02<GH39CH2G[T3:CD2D]`6?KL;9EL405<4:GL33;@20145?OP5
5?H205<205@6<KP00`0B8ELQE`0639<2Ie/40=L25?D3Bgl205<00`09:6dXK@03:6d014SZ74h00004
10091@P8:7oo000IOol00f/iNgIkMP0KOol2NXT2H@000fh0NXUjR@04NXT3OX/4NXd2JR000gY8O/Yk
]@02NkD3JHH00f/ZKoIkS`03MiT3NiH3Mk06NmH4Bkh3LiX2Mfd5Oi@6Hc`4NiL00gnBLiYcVP05Oi@7
KaP00f^>I_UVn@04KeT5MiP2Jm`2OkD6@U/5K_L7NeD3OkD4;MT3Ga/400l4:KT>8EL8BST200`6:EL2
DkD63GX7LgP8MmT30;L9I_T6Hgd2MmL55?D:KcT4?ML3Lhh:>MP4C[/6Cmd4Hgd8EWP7Lhh2JaX4NgH0
0g=;1?MgS`02Mhl6LeP3Ok@8OkH5<GH49CH00eji:CDY=@04D]`6?KL:9EL405<4:GL33;@20145?OP6
5?H205<00`1D<KPa^004<KP201800b5G39<<T`0339<3Ie/40=L35?D2Bgl00`0<05<02@06:6d00aa>
0000100400T520PXOol001Yoo`03NgIoogoo01Yoo`=jR@03H@1^06E400EUA0=nR`AjS@04NTMZ86XP
O/X3NkD3JHH00f/ZNhmkUP06NiH2Mk000gN@NmIkeP03NmH5Bkh3LiX00gM]Hk5oU003Oi@6Hc`5NiL0
0gnBLiYcVP04Oi@7KaP2Jhh5I_T3MiP2MgL5OkD00ejI@U]2F`03@U/5K_L6NeD4OkD5;MT2Ga/400l5
:KT58EL00`098ELQE`048EL2E[/7BST200`5:EL00e>e00aC]@073GX5LgP:MmT30;L7I_T7Hgd2MmL6
5?D9KcT4?ML2Lhh00aUHMeLif008>MP3C[/6Cmd6Hgd7EWP8Lhh5NgH017=;1?MgSgN?1W=H17nd27nf
1S5f12Df00<Y=E;LD]`00e;L1Sfg2REG101C12Ug10bd00<04Cgh?OP00cgh1QCf0P1C00<0E36h<KP0
136h0P0B00<QE`bC39<00`bC0fMK00@03@3G0=L0e`@Dm@04Bgl0301C05<6:6d00`0000@02@0300T0
0`0020P8200220PYOol003Moo`=jR@03H@1^06h000EUA003NTInRgj;00EjS@03NTMZ87^e00Ak]@9Y
QP9kS`MkUP9g/0EkePE;_P03LhmcVW>J009gK@03Hk5oU7nD009oU0IS?0AkU`04Oi9cVW>JLiX4Oi@7
KaP00f^>I_UVn@04I_T5MgL4OkD2GYT5@U/5K_L6NeD4OkD00eJJ;MT]f@02;MT3Ga/400l4:KT58EL0
0`098ELQE`048EL2E[/7BST200`4:EL01E>e00`0300BDkD01`ej17=h2GOI0RUg00<0<P2g0;L01VKi
1V=m0gOG1aCe2Fli0cgG0W>>0WMG2SWH00=>^doMCmd01DoM1V=m1eIh1g>>00<4m`00NgH00g]f00Ac
B`CgMhmgS`IcF0Ao]0Mo]P03BSTaMS5f00@aMP@U=PIBg0Hm]`/UE`<0D`DYM`@<]003014mn3gh00<m
n0DDmP<0D`Ha^0804P038EL<T`bC008<T`AWF`0400d0e`3G0=L55?D00d]o05<0D`06:6d00`0000@0
2@0300T00`0020P8200220PYOol003Moo`AjR@9^00IUA003NTInRgZ=00AjS@9jA`Ek]@9YQP03NhmM
H7^F00EkUP=g/0AkePIk^0=cVP9gK@AoU003Oi9S?6<l00AS?0AkU`03Oi9cVW>J00EoU0M_6003JhiV
nFKi00AVn@EgM`Ao]@=NV@A2F`E^m`IkE@Ao]@=FVP8]f@0300mO6elK00@03`@Y^@DQE`0300TQEb5G
00<QE`=F^`Q:>@80308YE`<0309ke003018=NPej00H=NP9cN0Qgf@DYM`030380]fKi00AVn@MSO@=g
e`LDm@U_>@<me`04LhhIF7MGMeL:>MP4LgT3Cmd7Hgd6EWP5Lhh2Hd/015kk1?L4m`000g]f0PCg0WN?
1W=H17nd1gnf00=:>C5f<GH0135f1BDf1E;L1Sfg2bEG0`1C1BUg1@bd1Cgh1ACf0`1C00<0E36h<KP0
0c6h0`0B00@QE`bC39<<T`EWF`0300d0e`3G00HDm@0300`0DbQ]00DXK@030000100900802@030008
20P800<822Uoo`00=goo17Z900=Q06h0KP001FE400=jAWj;NXd017Z=0WY71G^e0VV600=kSg^FNiH0
1G^F0WN`1G_F1W^h0g>J00=gKF>aOi@00gnD0WnB16<l17^G00ACGg>JLiYcVPEoU0I_6003Jhi_/FKi
00EVn@AgM`Eo]@=NV@=2F`I^m`IkE@=o]@IFVP03;MT03elK00D03`<Y^@HQE`0300TQEb5G008QE`AF
^`M:>@803003:EL0300<0080309ke003019C]@ej00L=NP03LgQgfGOI00Agf@PYM`030380]fKi009V
n@MSO@Age`PDm@Q_>@8me`9cSP036EQgEgMG00Xif0IcN@03KfeSOF=m00ESO@IFN0=cSP=SB`9Nn`@4
m`03NgIcB`Cg009gS`McF0=o]0Mo]P9:>@HaMPHU=PABg0Lm]`XUE`@0D`@YM`P<]082E`034?HDmQCf
00<DmP<0D`Ha^0804P038EL<T`bC00IWF`0400d0e`3G0=L55?D00`0<05<XK@04:6d00`0000@01003
00T00`0020P8200320PYOol003Qoo`AjR@9^00EUA09jAPIjS@03NTMk]G^e009k]@04OiEkSg^?Nhl7
NiH2Mk05NmH5NkP4LiX00gM]Hk5oU002Oi@013iLOi9oTWnB0f<l0g^G0U=O0g>J17nD1flH00=[SVKi
I_T016Ki1GMg17ne15jI0d9K1Vkg1G]E0gne25JJ00<03elK00l0100?12Vi1B5G00@02B5G8ELQE`EF
^`M:>@L0309ke0804P03DkD=NPej00D=NPHef@XYM`04039VnFKiI_T7Hgd5MmL75?D8KcT2?ML00g>>
6EPIF002MeL9>MP7LgT2Kfd7Hgd5EWP2Lhh3Hd/3G_/51?L017=;1?MgSgN?1W=H17nd1gnf0TXi1S5f
1RDf1E;L1Sfg2REG101C12Ug20bd00@0DP9G4?H@mP@DmP@0D`Da^0804P038EL<TfMK00IWF`0400d0
e`3G0=L55?D00`0?05<XK@04:6d00`0000@0100300T00`0020P8200320PYOol003Qoo`AjR@9^00EU
A0=jAPEjS@Ek]@04OiEkSg^?GF06NiH2Mk000f=^NmIkeP02NmH6NkP4LiX01GM]Hk5oU7nD?U`01GnB
0V<l00AkUe=ODemCG`AcVPAoU003G_Y_66lH00A_6003Kk5VnFKi00AVn@EgM`Ao]@ENV@92F`E^m`Ik
E@=o]@QFVPL03`@Y^@DQE`0400TQEb5G8EL5E[/7BST600`3Nm@301863GX7=MT;:GL00`0bI_USO@07
Hgd5MmL85?D7KcT2?ML00g>>6EQgE`03MeL8>MP7LgT3Kfd6Hgd5EWP2Lhh3Hd/4G_/61?L2Mhl6LeP4
Ok@6OkH3BST7<GH69CH4D]`6?KL:9EL405<4:GL73;@015ZI0582E`9G0Q3f0aCf1@1C136h0`0B00<<
TfMKIe/01FMK0P0=0P3G1QCe00<032Q]:6d00bQ]00<0000400@00P090P0010P800=DiGooOol09goo
000hOol5NXT2KP04ID@3NTH4NXd00`00NkEk]@02NkD2OiD2Nhl00eePNiIkUP04NiH2Mk05NmH5NkP4
LiX00gM]Hk5S/@02Oi@00ciLOi9oTP04Oi800g^GDemCG`02Del4LiX4Oi@2G_X4KaP00f^>Kk5Vn@05
I_T5MgL4OkD5GYT2@U/5K_L6NeD2OkD8EYX2FYP00`0?Ga/03`0400l3:KT58EL200T00b5GE[]F^`05
E[/6BST600`4Nm@201800e>e3GX=NP023GX8=MT00gMG:GLYM`09:GL20386Hgd6MmL95?D7KcT00cgG
6EPIF004MeL8>MP6LgT5Kfd5Hgd4EWP2Lhh00`2fHd]SB`05G_/51?L2Mhl7LeP3Ok@7OkH4BST6<GH7
9CH3D]`6?KL;9EL305<5:GL53;@3FYT20UL34?H25?H405<2CUT3<KP30189Ie/00`0=0=L0e`065?D0
0`0<05<XK@03:6d300@200T2000320P2E>DYOol003Qoo`EjR@03MP=^06E400AUA0=jAP=jS@04001k
]G^eNkD2OiD2Nhl00eePNiIkUP05NiH00gN`HfikeP04NmH5NkP4LiX017M]Hk5oU7nD0SiL1WnB1E=O
0g>J17nD15kj0flH00=[SVKiI_T01FKi17Mg17ne1ejI1Vkg1G]E0gne00=W6EJJEYX01EJJ0UZH00=J
V@0?00l00P0?0R6j0bVi1B5G0P0900<QEeJkE[/01EJk1TXi1P0<17_D0`0B0`ej23GI0WMG2bUg0P3F
00<0<V=mHgd00f=m1WOG2ACe1AUH0Vli00=cSQUH6EP017MG1cWH1g=i1Vm]16=m15Ih0W>>0V=;1Ukk
1@Cg0WN?1g=H0gnd1Wnf1DXi1S5f1bDf0e;L1cfg2REG0`1C1BUg1@bd0eZI00<0DP9G4?H00a3f00@D
mP1C05<0D`A>F@8a^0@04PQWF`803@030=LDmACe00@Dm@0300l0DbQ]00<XK@<0100400T000000002
20P3E>DYOol003Qoo`EjR@9f0`03KP1UA6E4009UA0AjAP03NXd00000009k]@=oU@9kS`03GF1kUW^F
00AkUP9g/003HfikeW_F009kePEk^0EcVP04MfeS/GnDOi@2?U`5Oi85Del4LiX3Oi@00fN?G_YNnP03
G_X2KaP00fnaI_UVn@04I_T5MgL4OkD7GYT6K_L5NeD2OkD2IaT7EYX3FYP00`0>8KXQ^P048KX3:KT4
8EL200T8E[/7BST400`5Nm@401800`ej=MTef@07=MT2MeL;:GL016lh0=H0eP0b0f=m1gOG2ACe00=[
FQUH6EP01aUH17MG1cWH1g=i1Vm]00<0]V=mHgd00V=m0eIh00AcSP2fHd]SB`MNn`@4m`9gS`03Io]c
F7=H00=cF0Ao]0Io]P0305=:>DXi009:>@HaMPLU=P0329ABg5;L00Lm]`XUE`@0D`@YM`@<]0AJV@03
0582Ea3f00@@mP035?H0D`1C00A>F@0317<a^36h00@04PMWF`803@80e`DDm@0300l032Q]008XK@05
0000100400@02@02000220P4E>DYOol003Qoo`IjR@9f0`04KP1UA6E4ID@4NTH20002NkD4OiD00g^?
GF1MH006NiH00gN`HfikeP04NmH5NkP5LiX2Hk4017nD?U`nG3iL17nB1U=O17>J0WnD00=WSekjG_X0
1Ekj00=[SVnaI_T01FKi1GMg17ne1ejI00=k^6kgK_L00fkg1G]E00=o]G_DIaT00VLI1EJJ15ZH00=J
V@0?8KX01B6j0RVi1B5G0P091eJk1dXi100<1G_D100B2SGI0WMG2bUg00=_>03F0=H00P3F0V=m27OG
1aCe0V]J2AUH1GMG1SWH1W=i1Vm]0UOG00@0]V=mHgeSO@9FN09cSP030;ISBekk00MNn`@4m`04MhmG
GVOkIo/4LeP4Ok@5OkH205<4BST6<GH69CH00fKi29ABg002D]`6?KL3;GH79EL405<4:GL43;@4FYT0
0`1B0UL2E`054?H00`1CCUU>F@03CUT217<00c6h01804P030186Ie/200d20=L65?D0100?00X02P0:
0`0400D02@00000000P800ADiBYoo`00>7oo1WZ90gH300=Q86E4ID@00WY60Vh<0P000W^e17nE00=k
SeePGF001W^F00=g/6=^NmH017_F17^h1W>J0V>a0ciL17nB1U=O1G>J0WnD00=WSekjG_X01Ekj00=_
/FKiI_T01FKi1GMg0gne1ejI0g^h16kg1G]E00=o]G_DIaT00fLI15JJ1EZH00<03R6j8KX01B6j00<Y
^B5G8EL00b5G0P0925Jk1TXi100<1W_D0`0B2SGI0gMG2BUg0Vlh1@3F00=SOGOGMmL00P3F17OG1aCe
0V]J21UH1WMG1CWH1g=i1Fm]0eOG0P2f0V=m0UIh00AcSP2fHd]SB`QNn`<4m`9gS`AWn`=cF0=o]0Io
]P80D`A:>@HaMPHU=P9Vn@0329ABg5;L00Hm]`H]MP@UE`@0D`89>@8YM`<<]0EJV@80DP030UL@mQ3f
00<@mPI>F@<4L`H04PIWF`803@030=LDmACe00@Dm@0400l0300:00X300@01009000000001ECU:Woo
000iOol5NXT4MP<00f4PIHU^3002KP`300000g^eOiEoU@03OiD00g^?GF1kUP06NiH00gN`?kYkeP03
NmH5NkP5LiX00gM]Hk5oU003?U`3Oi83Nk84Del5LiX00gnDIhmNnP07G_X00fnaI_UVn@05I_T4MgL4
OkD00flHGYUNV@04GYT4NkP3K_L4NeD00gneNmAW6@04IaT4EYX5FYP00eZI8KXQ^P058KX00bVi8ELQ
E`038EL300T7E[/6BST300`7Nm@40188=MT4MeL9:GL3KcP90=H017?eMmMgegOG1aCe0f]J1aUH1WMG
1CWH1g=i16m]15OG0`2f00ISOEIhEWQcSP2fHd/:G_/21?L00gN?EeiWn`02Io/2>U`2LeP2Ok@2Lk43
0CT015jH5?HDmP1C1DXi1S5f1BDf0VKi00<8U5;LD]`01Cfg0UZj1Bef0REh0bEG101C0`Ti00<YM`bd
FYT01EZI0P1B00<2Ea3f4?H00a3f1diI0PAc1RhL12WJ0VMK0P0=00<0eaCe5?D011Ce00<03`0<00X0
100400@02@00000000EDiBYoo`00>Goo1WZ900=f0fF9IHT00VF90fh<0P0000=k]GnEOiD00gnE00=k
SeePGF001W^F00=g/3njNmH017_F0g^h00=kefnkKk/00Vnk0W>J0V>a13iL0gnB1W^b00=CGg>JLiX0
0W>J00=oU6N?Ihl01ekj0Vna00=c>6KiI_T00fKi1GMg0gne00=g^6lHGYT01EjI1G^h00=^mg]ENeD0
0W]E00=:_7_DNm@01VLI0UJJ1UZH0UZI1R6j00=_NRVi8EL00b5G0`091eJk1TXi0`0<0g_D00@a^00?
NmAke0@04PPef@AgE`TYM`=_>0P0eP9cm@=ge`HDm@A[FPLIF0IgE`Dif0IcN@A_K@03EmMge5OG00=G
e`<0]P04HgeFN02f0;H;G_/21?L00gN?EeiWn`05>U`00gndLk5c/@02Lk430CT01EjH5?HDmQCf05<0
14Xi1S5f12Df0fKi0PRD00=Bg3fg?KL00Sfg0eZj1Bef1BEh101C10Ti00<<]5ZIFYT015ZI0P1B00<2
Ea3f4?H0113f1TiI0PAc00=Lh2hL;Q`012hL1BWJ0`0=1aCe00<03`0:00@00P0400@40000000000ID
iBYoo`00>Goo1GZ91fF900=^3000Ji`00V^L1GnE00=kSeePGF001W^F00=g/3njNmH017_F00Ak^7_G
NmMke`I_^`9S/@@nG09oTP030EQk/W^b00=k/PHjG09WS`QNnP04Kk5SOG<hLcP4I_T5MgL2OkD00gNh
KaQ_6005GYT7NkP00g]EB[a:_002B[`2Nm@6IaT2EYX7FYP00flH8KXQ^P048KX2KgX48EL400T7E[/5
BST300`2Nm@3<KP2Nm@40188=MT4MeL8:GL4KcP80=H2LoD00`0=MmMge`065?D4JeX76EP7MeL3>MP7
LgT3Kfd4Mm@3EmL40;H017>>0;ISBe;m2Ukk0PCg00=GGSYL>U`01CYL1W>a0P4i00=NV1Cf5?H00QCf
14Xi1S5f12Df0fKi0PRD00=Bg3fg?KL00Sfg0eZj1Ref12Eh0RDf0P1C10Ti25ZI0P1B1Q3f1TiI0`Ac
1RhL1RWJ0P0=00<0eaCe5?D011Ce00@03`0<00@01084008000MDiBYoo`00>goo0Pil26F91F^L1GnE
0eeP1W^F00<o^W_FNmH00g_F00Ak^7_GNmMke`M_^`03Hk4nG3iL008nG0=oTPAk/PPjG09WS`03Ha]N
nUkj00ENnP03Kk5c>7<h009c>0=Vn@EgM`03OkEg^7Nh00=_60ANV@Mk^0A:_09ke0QW6@03EYYJV5ZH
00EJV003KcU_626j00<Q^PE_NP<QE`<02@MF^`I:>@0300ake7_D00@a^00300mke00B00@04PLef@Eg
E`LYM`E_>0H0ePAcm@=ge`@Dm@I[FPDIF0QgE`<if0McN@9_K@Ige09Ge`H0]P9Bo@]Nn`03MhmGGSYL
00HjG0Ic/@030CUNV5jH00@DmPA:>@HaMP<U=PAVn@<8U003D]`m]cfg00AJ^PH]MP@UN0<U=P80D`@9
>@MJV@80DP030UL@mQ3f00<@mPI>F@<4L`03G>0^72hL00<^70HYfP0300h03@3G00HDm@0300l03004
0084000300003d8j0092>PEDiBYoo`00?Woo1fF916^L1WnE0UeP1W^F00=g/3njNmH00g_F00<1NW_G
NmL00W_G1Vnk00=S/CiL?U`00ciL0WnB00@1F7^bNk9k/PPjG09WS`=S6`ENnP03Kk5SOG<h00Ac>09V
n@AgM`04OkEg^7NhMkP3KaP4GYT6NkP5B[`2Nm@8IaT8FYP2KcT48KX5KgX20380125G00T02@091eJk
1TXi00<037_D<KP0136h00<03g_DNm@0100B1SGI1WMG1bUg1Flh1P3F17?e00<03GOGMmL011Ce1V]J
1AUH27MG0cWH1W=i0Vm]1gOD0eOG1@2f0e;m2Ekk0eMN1SYL27>a0ejH11Cf0dXi1S5f0bDf16Ki0`RD
00=Bg3fg?KL015Zj1Ref1BEh0bDf00<0D`Ti2CT00PTi1eZI0P1B00<2Ea3f4?H0113f1DiI10Ac1RhL
1RWJ0P0=1QCe0P0?0`@00P0?0d8j1ECU:Woo000nOol6IHT5Ji`5OiD00g^?GF1MH005NiH00d^O?kXo
^P03NmH20GX3NmL7Kk/00f>a?U`nG003?U`2Oi801@5HNk9k/W^bKeT01cYL00=WSe]]Ha/00f<K15kj
0V=m1W<h0gMg0W^H17Nh16lH0UjI1W^h1TZl0W_D26LI00=WFeZHFYP015ZH16li0b6j1Fmj0`0b1009
1eJk1DXi00<0336h<KP01C6h00<03g_D01800`0B1SGI1WMG1bUg1Flh1@3F1G?e00<03GOGMmL011Ce
1V]J1AUH27MG0SWH1g=i0Vm]27OD0UOG102f00=SBe;mD_d00U;m1ekk0eMN00=[SSYL>U`013YL1G>a
00=5mejHGYP00ejH11Cf00<<mTXiBST01c5f00<U=VKiI_T00fKi10RD00<m]eZjF[X015Zj1Bef1BEh
12Df10Ti1eZI0`1B1Q3f1TiI0`Ac1RhL1bWJ00@03AFk5K/E^`@Dm@0300l0300?00803`A2>P0300ID
iECU009DiBYoo`00?goo1FF91F^L1GnE00=[FeePGF000g^F0d^O00<o^W_FNmH00`5j17_G1Vnk00=S
/CiL?U`013iL00=oTP5H0EP00W^b0fmI1CYL0VN?1F<K0ekj00=_/F=mHgd01W<h1G^H0gNh1FlH0UjI
1G^h1TZl0W_D00=oTfLIIaT01FLI0VMK1UZH16li0R6j1fmj100b0P091eJk0dXi00<NGV^lJk`01c6h
00<03g_D01800`0B1SGI1WMG1RUg1flh103F1W?e00<03GOG5?D00QCe26]J11UH27MG0SWH1g=i00=_
KGODMm@027OD00=Ge`2f0;H00P2f1E;m1Ukk15MN0V^>13YL0g>a00A;LDGgAOM5m`ENV0@DmP8<mP9:
>@HaMP039CIVnFKi00AVn@<8U0MJ^PH]MP@UN0DU=P@9>@IJV@<0DPH@mPI>F@@4L`H^70HYfP0300h0
3AFk00@E^`035?D03d8j00<03`=2>P9oo`0400IDiECUE>DZOol003moo`AUR@I[W0EoU@03Je]MH5eP
009kUP=;W`8o^P03NmH1NP5j0081NP=ke`M_^`9o/P@nG09oTP040EQk/W^bNk84KeT4>U`00fN?FfeS
6`05Ha/2G_X2Hgd7LcP4NiP4MkP5KaP2GYT3NkP00f/IB[a:_005B[`2Nm@2Oi<6IaT2Ie/6FYP4KcT2
8KX7KgX503822EX3E[/77Uh2Jk`7<KP200l50184=MT8MeL5:GL7KcP30=H7LoD00`0=MmLDm@025?D8
JeX36EP:MeL00cWHLgUcN@05LgT00fm]MmAge008Mm@2EmL30;H6D_d4G_/5Eeh2Jhh4>U`3Lk4013gH
AOM5mdGg1EjH1ACf0Pcf00=:>C5f<GH0135f00<U=VKiI_T016Ki10RD1UZj1Ref12Eh1BDf00@8ePTi
2CT9>@IJV@<0DP030UL@mQ3f00<@mPI>F@@4L`8AVP@^70LYfP0300dE^aFk00@E^`92>P803`A2>P=o
o`9DiB]oo`00?goo16F91F^L1GnE0f]K00=kUT^OBil00d^O0Snj105j17_G1Vnk00AS/GnbOk9o/P<n
G09oTP040EQk/W^bKm84KeT4>U`00e]]Ha]S6`06Ha/00ekjHgeSO@07LcP4NiP4MkP6KaP00g^hJaU[
6@02JaT00gncB[a:_004B[`00g_D>OUoT`02Oi<4IaT4Ie/4FYP6KcT00b6jKgY_NP05KgX503832EX8
7Uh3Jk`8<KP00`0?Nm@04P030184=MT8MeL5:GL7KcP30=H2LoD00foC09D0U@02LoD200d00gOG5?E[
FP08JeX36EP:MeL7LgT00fm]FoYge008Mm@2@W/015OG0;H0]V=;1U;m0ekk1EMN0f^>13YL0W>a00@0
]SgH?MQ5m`MNV0@DmP<<mP<aMP<j>`MVn@@8U0IJ^PH]MP@UN0HU=P032=H9>@Ti00IJV@@0DPH@mPE>
F@D4L`@AVP03;Q`YfRWJ00@YfP8I=`0300dE^aFk00<E^`92>P0300`03d8j00=2>PAoo`03E>Eoogoo
02Uoo`00@7oo0fF91F^L17nE0f]K1T^O00<o^P5j0GX0105j0g_G13il0fnk17nb0ciL00=oTP5H0EP0
0W^b1VmI0SYL00=WSe]]Ha/01f<K0f=m1W<h1G^H17Nh1VlH1F/I0Wnc14Zl0W_D00<inGnCOi<00WnC
0VLI1FMK15ZH1Fli00=ke`0500D01Vmj1P0b0`UJ1aiN16^l1c6h0P0?100B13GI27MG12Ug2Flh00<0
eW?eKm<00VoC00=S>`2E09D00W?e00<03GOG5?D02V]J0QUH2WMG1g=i00=_KGODMm@01gOD0d9k00=G
e`2f0;H025;m00=NneMNEeh015MN16^>0SYL0W>a00Ege02f0;Hmf4Gg00MNV0@DmP<<mPLj>`IVn@D8
U0EJ^PH]MPDUN0DU=P88eP89>@IJV@<0DP8AF0@@mPE>F@D4L`HAVP8YfP9[N`<I=`0300dE^aFk00@E
^`92>P0400m2>T8j@SXaOol0041oo`9UR@I[W0=oU@=[F`M;W`0307@1NP5j00<1NP=ke`LnO003HL1o
/Wnb00=o/P8nG005Oi81F7^bNk9_dP07KeT013YLFfeKoE_m1f<K0f=m1W<h17^H17Nh1flH16/I17nc
0dZl00=ke3WiOi<01GnC00=W6FMKIe/00fMK15ZH1Fli00Akea8M00D01@I_NPH0<P<9FPDNGPE[_0La
^0803`0405@04P0B0184=MT8MeL4:GL9KcP0103FKm=_dfoC0V<k0`2E00Acm@0=00dDm@Y[FP8IF0Yg
E`03IiecNG=i00AcN@03FoYge7OD00Ige0E2N`03EmL0]U;m00IBo@9?g@IGGPA[SP8jG003Lk5ge7OD
00<0]P03AOMNV5jH00ENV0DDmP<<mPHj>`IVn@D8U0IJ^PD]MPDUN0DU=P<8eP032CUJVEZI00AJV@@0
DP<AF08@mPE>F@H4L`DAVPA[N`@I=`HE^`I2>S5oo`00@Goo00=URF^LJi`016^L0WnE00=oo`09Je/0
1d^O0`1d105j0W_G23il00AQ`7nbOk9o/P9Jn`8nG081F003Nk9_dVoB00M_F@9KK@=Ko@ES6`=SO@Mc
>0AkV0Ag^0I_60E[6@Eo/`9:_08in@IoT`9gm`EWF`9JV0I_>@9ke`@01@A_NPH0<P@9FP@NGPE[_0Pa
^0803`0405@04P0B0182=MT:MeL3:GL9KcP4Km<2Hc/409D200d;JeX26EP9MeL3Iid4LgT00fm]FoYg
e006Mm@7@W/00f=;D_eBo@04D_d4Cmd4Eeh2>S/20SX2Jhh00cYLMmAge002Mm@20;H8GYP55?H33?H7
>S/5I_T529@6F[X6;GH49GP69CH32=H6FYT405844EP24?H5CUT617<34IX5Jg/56CL55K/5@SXbOol0
04Aoo`A[W004OiEoogooOol500T3Bil307@40GX00g_G?W`nO006?W`00f70Ok9o/P02Ok83F_/01GnB
0EP1F7^bKm8026mI00=KKE_mFod00e_m0f<K16=m1W<h1G^H17Nh1VlH1F/I1Wnc00=ke3Wi>OT01WnC
0gOg16MK0UZH1Fli0g_G1@050fmj1`0b0`UJ00<UfQiN7Uh01V^l236h0P0?0P1D0P0B0SGI2WMG0bUg
2Flh0foC16<k102E0P0=2f]J2GMG1FNM0g=i00=_KGODMm@017OD00=GGT9k@W/01d9k1E;m1ToM0eMN
1CXk00<2>WODMm@00gOD0`2f25jH11Cf10cf1SXk1FKi1PRD1EZj1Ref12Eh1RDf10SF1EZI1@1B1A5H
1DiI1PAc0a6J1V]k11Tg00=ooaFk5K/00QFk1D8j<Woo0017Ool00gnEOomoo`02Ool400T015]^Oomo
ogoo0P1d0Woo0P5j00=kegoo?W`01cil00AQ`7nbOk9o/PEJn`81F09_dPM_F@09FfeKo@0900USmWoo
0EQKoF<K00ESO@Ic>0AkV0Eg^0I_60E[6@Eo/`@in@EoT`Egm`=WF`9JV0E_>@Ake`AW>`=_NPL0<PDU
fP037Ui[_6^l00E[_0La^0<03`80E003018efCGI00YgE`8YM`U_>0A_d`AS>`@0U@80eP0300e[FV]J
00M[FP03Hf`0UGMG00MgE`IWW@9cN@03FoYge7OD00=ge09GGP03FbU2Nd9k00M2N`=Bo@Q?g@9GGPDj
>`9ge0@]U`03Mm@0]P2f00QNV0DDmP@<mPDj>`IVn@D8U0EJ^PH]MP@UN0HU=PD8ePAJV@D0DPDAF003
0=M>FDiI009>F@L4L`034IY[Nf]k00E[N`@I=`9oo`@E^`A2>S9oo`00C7oo10092Goo00@1NWooOomo
o`LnO004HL1o/WnbOk86F_/00g^bKm9_dP07KeT015]]00T02@0917oo0P5H16=m1W<h17^H17Nh1VlH
1F/I1Gnc1CWi1GnC17Og00E?Ga6K4I/AVfMK00I_>@Ake`03DWQW>fLk009W>`=_NPH0<P03MmXUfRGJ
00<UfP80]PE[_0Pa^0803`<0E003018efGMG00UgE`8YM`U_>0=_d`ES>`D0U@80eP0300e[FV]J00E[
FP9SK080U@IgE`QWW@03Kfege7OD00=ge09GGP9K:@Y2N`03D_e?gDoM00Q?g@Hj>`03MmAO?2fG00@]
U`80]PQNV0@9o0035?H<mPcf008<mPHj>`EVn@H8U0AJ^PD]MP03E]/0U2Eh00<UN0HU=P@8eP04OomJ
VEZIFYT505864EP0103GCUU>FDiI1PAc00<006]kJg/01V]k11Tg0goo0aFk0d8j<goo001<Ool300T?
Ool5?W`2HL02Ok87F_/2Km87KeT015]]00T02@091Woo105H1W<h1G^H0gNh00=2W6lHKaP016lH1F/I
17nc1CWi1GnC0gOg14mO1A6K0fli0g_G00@kOe9hDWQBN0=W>`0300m_NVmj00D0<P9gfPHUfP@0]P9[
_0Pa^0<03`<0E0agE`03:GM_>6lh00I_>0A_d`IS>`@0U@@0ePE[FP030=ISK6=/00<0U@AgE`UWW@03
FoYge7OD009ge0=GGP9K:@Y2N`EWW@EkePHj>`04=GIO?5llGc`5;IL20;H7GYP00fLJ2O`9o0022O`4
:O/010cf>S/j>cXk0S]n15<M00AVn@RD29@8U0<j>`85>@=J^P<]MP=Ff`0409@UN2Eh9GP69CH32=H3
Ool2FYT605854EP20=L2CUT517<00`5j00000007Jg/36CL5Ool25K/3@SXcOol004eoo`0300UKKWoo
00ioo`DnO09Q`09o/PMJn`9_dP9cm`E_F@<02@Moo`HQV@Ac>0AkV003MkQ2W4:L0092W003MiQ_66lH
00=_60E[6@=o/`Hin@EoT`9gm`9We0A?G`DAV`9_>@03NmMcN7=h008kO`=BN0=W>`0300m_NP0b00<0
<P0300mgfWOJ00HUfP@0]P=[_0La^004Ii`0<@0?00l405@:MeL9KcP4Km<6Hc/409D50=H3JeX20=H3
Hf`309D3MeL9Iid015_jMmAge00?15MN0e/Y2D9k1FNM17_F00=[SSXk>S/013Xk15ll1BfG0P2f1UjH
0fLJ10Wl1bWk00<kOU<MDad00e<M00<043Xk>S/01CXk0`Di00=J^Ref;GH015KK00@0U2Eh9GPUN0HU
=P<8ePAoo`9JV@D0DPDAF0<0e`9>F@<4L`050001NP5j0GX00006Jg/36CL6Ool00aFk@SY2>P0dOol0
04eoo`0300Uoogoo00moo`<nO09Q`09o/PMJn`=_dPAcm`9_F@03Ffeoo`0900Uoo`LQV@9c>0=kV0E2
W0=gV0=_60I[6@=o/`03LhlinCWi00<in@EoT`03MoM_n6OD00AWe09?G`DAV`03KcUcN7=h009cN003
>gmBN59h009BN09W>`0300m_NP0b0080<P0300mgfWOJ009gfPHUfP@0]P9[_0La^09WW00303403`1D
00@0E0QgE`031;E_>6lh00I_>0A_d`QS>`@0U@D0eP03JeX0eP3F00ASK0@0U@03MeMWWFNM00MWW@04
FoYge7OD00l4Eeh4FbT8@W/5Iid5NmH6>S/5Gc`6;IL00`2fGYQNV004GYP4IaX32O`7:O/00elLDaeC
7@04Dad00b`0>S/j>`04>S/41CT00befE]]Ff`03E]/209@29GP79CH00`SFOomoo`04Ool00eZI0580
DP0405854EP30=L00diI17<4L`0300040GX6Jg/00aTgOomoo`06Ool00aFk@SYoo`0cOol0061oo`8n
O09Q`09o/PMJn`9_dPIcm`03KeUoogoo00Yoo`PQV@03NiQW/FNa00I2W0AgV09_60I[6@9o/`03Jkac
ScWi00@in@AoT`04MoM_n6ODIm@2Ool20S/23CP01DmO4I/AVa6K3CP01G=h00=keE9hDWP00e9h0VLk
00D03fmj0380<P0?00AgfPLUfP<0]P9[_0Ha^0AWW00303403`1D00@0E0IgE`<4]@M_>0A_d`QS>`@0
U@P0ePASK0H0U@MWW@9KnP03Mm@03eMN00AGGP03FbUg/E/Y009K:@I2N`IWW@EkePHj>`038KYO?5ll
009O?0H]U`03MmD0]UjH00=NV0EW6P03Ool9o0Wl00LYn`9O70EC7@03010j>cXk00Dj>`<5>@MFf`80
U0039GPU=RDf00DU=P032=Ioogoo00Aoo`040040DP1B0585Ool34EP40=L01@AcOomoogoo00000`5j
1Goo0V]k00<I=gooOol01goo00=2>WooOol0<Woo001QOol00cilHL1Q`002Ok87F_/016oBLP5cmg?g
4Woo1b6I0VNa1d:L1GNH00=_66/IJaT00f/I0Wnc00=[_7>?Lhl01CWi17nC0Voh0VOD17oo00D2>`dh
3CP=>16K008=>0AcN09ke@04>gmBN59hDWP3NeD200l00`0b00mgfP05MmX69MX30;H00`0>Jk`a^005
<KP5Ii`00`0a05@0E00405@3MeL61;D6KcP2Km<00`1dHc]S>`07Hc/509D70=H00f=/Gi1SK002Hf`6
09D5Iid3FoX00`0?EeiGGP04Eeh00eNOMk40<`02FbT6@W/5Iid00em^NmIkeP0209D00f^l>S/j>`03
>S/38KX4Gc`5;IL00gOE0;INV002GYP6IaX2Ool22O`5:O/4Ga`5Dad00`0@>S/j>`04>S/41CT6E]/2
09@29GP59CH00d^OOomoo`06Ool30;D7Ool0115H0=L0e`3G1goo00<1NWooOol0AGoo001ROol2HL00
0gnbOomJn`05F_/2Km82LoLCOol78IT00fNa@Ya2W005@Y`6MiP2E_`4JaT2Ok<016^lLhmoogoo13Wi
0gnC0Voh0VOD1Goo00<2>`dh3CP010dh17=h0W_E00@kOe9hDWQBN0=kE@@03`IgfPLUfP<0]P0300i[
_36h00<a^0MWW0030340E01D00@0E003MeMW>`Be00H4]@A_>09_d`<0M0US>`@0U@H0eP04HfaOT5n@
Gi02Hf`709D3Iid2FoX200l6Eeh01E/YMk5g/GNa03<00U/Y149k1VNM1@2E00=[_3Xk>S/00cXk126j
0ell1BfG0WOE0ejH1FLJ17oo00<9o2Wk:O/00RWk1UlL15<M00<043Xk>S/013Xk10Di1UKK0`2D00@U
N2Df9CHU=P9;W`Uoo`80]@Yoo`030=Moogoo04ioo`00HWoo0V7000=o/WooOol01E[k00=_dW81LoL0
5Goo1B6I0VNa00=ood:L@Y`014:L1WNH0eKl0f/I00Ao/f^lJkacS`9oo`<in@AoT`9_n003ImAoogoo
00Eoo`D=>0EcN0=ke@=BN0AkE@803`QgfPHUfP<0]P0300i[_36h008a^0UWW003035W>fLk00IW>`H4
]@A_>003Km<0M01d00<0M0QS>`@0U@H0eP03HfaOT37j008anP03Hf`0U@2E00H0U@05Iid4m`Cg1?L0
3`07Eeh015NOMk5g/GNa0P0c00AK:D9k@W]2N`IWW@03Gfh0U@2E0080U@9[_0@j>`05IidQ^R6j8KYo
o`03Gc`4;IL3MmD00`2fGYQW6P05IaX5Ool3:O/7Ga`2Ool2Dad20106>S/41CT5E]/409@00bDfBim;
W`02Bil9Ool00`010;Eoo`1JOol006=oo`03Ok9oogoo009oo`=Jn`03Km9b0G?g01Ioo`DQV@04Ik5o
ogooOol5@Y`5MiP5E_`2JaT017ncJkacSg>?0Woo0cWi0gnC0foh27oo00<2>`dh3CP00Pdh17=h17_E
00<kOe9hDWP017]E0P0?27OJ1bGJ0`2f00@03S6h<KPa^0UWW0UW>`D4]@9kU`9_>003Km=kUg^G00D0
M0MS>`D0U@@0eP03HfaOT37j00<anP9SK0H0U@03Khl4m`Cg0084m`MGGP03FbUGWgNa00=g/@80<`=2
N`IWW@@0U@A[_0<j>`8Q^PAoo`=O?0<]U`Age@03GYQW6VLJ00AW6PIoo`03:O]O75lL00IO70Eoo`03
010j>cXk00<j>`=3O`<5>@EFf`H0U09;W`Yoo`030;Eoogoo05Uoo`00Hgoo00=o/WooOol00goo0U[k
00=_dW81Ool05Woo126I00=W/GooOol00goo0d:L1GNH1eKl00Ao/f^lJkacS`Aoo`8in@9oT`9_n0]o
o`@=>0AcN0=ke@9oo`9BN0AkE@05Ool03gOJMmYoo`020AP33M`69MX2?]h20;H00`0>Jk`a^009Ii`2
Dad8Ic/51;D3NiL016lhNiMkUg^G1@1d26<k102E103F00=SK5n@Fdd0137j00=SK02E09D00`2E0Vn?
1@Cg1UMN00=GWgNaMk400gNa0`0c00=2NfNMIid01FNM102E16^l0SXk00=oob6jOol01Goo0Ull0bfG
17OE1VLJ27oo1elL27oo00<j>d=o@gl014=o0Woo00<5>EKKE]/00eKK1P2DJ7oo001ZOol00e[kOomo
o`0HOol38IT00g81Oomoo`04Ool2@Y`4MiP8E_`3Jk`00g>?Oomoo`02Ool2>OT2Oi<=Ool00`8k3CP=
>005LgP2NmD3Ool2DWP2NeD8Ool20AP33M`29MX6?]h20;H00`0><KQWW007Ii`4Dad7Ic/51;D7NiL6
07@6Hc/3<Q/309D30=H00en@FdeKC@05<OX309D4Khl61?L5Eeh00eNOMk5g/@03Mk4503<5Iid409D6
Jk`00cXkOomoo`07Ool00ell;IL]U`02MmD2Ool2MmD5IaX9Ool5Ga`<Ool00d=oOomoo`05Ool4E]/5
09AYOol008Eoo`8QV@03Ik5oogoo00Ioo`03@YagV7oo00=oo`MFo0=[_0Eoo`8in@03Oi=oogoo00eo
o`8=>0AcN09ke@Aoo`03>gmkEG]E00Yoo`8160<=g0PngP040;H03P0>00h6Ii`6Dad7Ic/31;D9NiL6
07@2Hc/7<Q/209D20=H016=/HmAKCE]=1S7j00<0UC7jKhl016n?1PCg0eMN00=K:ENOMk401GNa1@0c
16NM0`2E00=K?ELMEad03Woo00=O?2fG;IL00WOE1Goo0fLJ2goo0elL5goo0eKK0P2DJgoo0026Ool0
0b6IOomoo`0>Ool5E_`3Jk`00g>?Oomoo`04Ool2Oi<?Ool23CP4LgP00g_EOomoo`04Ool00g]EOomo
o`09Ool20AP016Ki3M`=g0gL23kN1@0>0fNL1e<M1fLk0`Be2G^G1Q7l2S8K00H0]03F0=ISe5]==cl2
Fdd6<OX6Khl71?L2Eeh00eNOMk5g/@05Mk4603<2Iid01Wnd09D0U@2EFceG7A1oo`03Gc`]UgOE00Mo
o`9W6Paoo`03Gaaoogoo01Uoo`0309Aoogoo06Yoo`00V7oo0eKl16^l1goo00=oTgooOol03goo1G=h
57oo0P4H10gL1SkN0V/j1@0>00=WW5<MDad01e<M1VLk0`Be2G^G00=SoA7l4O`0117l2S8K00<0]03F
Hm@00SLo0U]=1S7j0Vn?00AWmfn?Khm_S`P4m`03EeiGWgNa00Mg/@H0<`05Iieo]7nd09EK?@02EadA
Ool00gOEOomoo`07Ool00fLJOomoo`2COol009Uoo`03E_a[_6^l00=[_3Eoo`<=g003GkhngSkN008n
gPI[>P8YfP]C7@EW>`84]@UkU`=So@DAo0Xb6`9Se0051I/g?cLo=cmKC@06<OX2Khl2IoL3Khl61?L3
Eil5Mk43;S`9Ok@015/mOomooeLM/Goo002MOol00f^lLhmoo`0eOol010gLGkiO_Unn0ckN1V/j0bWJ
2U<M0Pcf0fLk0PBe27^G1F?m1A7l2C8K00=Se5]=>iX00cLo0U]=137j0Vn?0fOg00=keFn?Khl01@Cg
0eNO0gNa1Rhl2Gnd00=K?GooOol0/Woo003GOol3Gkh00ckNJcY[>P05JcX4:MX9Dad33?H013IMIc]W
>`Be1g^G1f?m117l238K0V?D0c^J0cLo00=KCC7j<OX00S7j0Vn?0VOg0g_E00=_S`Cg1?L00PCg15NO
0gNa00=WgBhl;S`00bhl27nd00=K?GooOol0/goo003JOol00ennJcY[>P05JcX00gOH:MXYfP02:MX7
Dad53?H2=Ud7NiL9Hod44O`6<Q/2Hm@01E]=7M`Mg6ojIg`00SLo00<0337j<OX00S7j00A_SfOgIoMW
m`=ke@04LiY_S`Cg1?L5Eil2Mk42Imd5;S`7Ok@2FcfeOol00=Yoo`M[>P9gf0DYfPEC7@L<mP03=Uec
nW?j009cnP9kU`QSo@8QN080DP8Ao0Hb6`9Se0<Mg09_nP04Ig`g?`0<Fdd2<OX016n?IoMWmfOg17_E
0W>J00<4meNOEil00eNO0WNa0P0c0VOM0bhl1gnd0U/m]Woo003KOol6JcX2MmP5:MX01AUHDaeC7E<M
6EP01`cf1Dnd00@g?g?jLoYcnPD040@QN080DP034O`b6c8K00<b6`03Hm@Mg1gL008Mg0A_nP03Ig`g
?`0<008anP04KhmWm`0?00l3NmD5LiX4Eil017Na00moo`0c0Woo0bhl1Wnd0U/m]goo003LOol5JcX3
MmP5:MX00aUHDadIF0026EP63?H2Ck@5=cl2LoX401000gOH8GPQN0038GP205801A7l<Q/b6c8KHm@0
11gL1Voj00EWO00<<OXanVMl00803`Ake@EcVP0500003eNOEimg/@06Ool2;S`5Ok@2Ool00e/mOomo
o`2eOol00=eoo`=[>PEgf004OolYfRWJ:MX56EP53?H309H4=cl2MmP00g?j0100400201000gOH8GPQ
N0048GP20583<Q/57M`6KoX2Emh01@0<KhmWO6Ml00l00W_E00=S_GooOol01G>J0P0?00=g/@0?Ool0
1Goo0Rhl0gnd_7oo003NOol2JcX5MmP3Ool00bWJ6EPIF0036EP43?H709H00cLoMmQgf002LoX30100
0gOH8GPQN0038GP2LoX205800c8K7M`Mg0037M`6KoX4Emh35Ud2NmD00f>mKfeoo`02Ool3LiX017oo
00l03`0?27oo00=o]7ooOol0_Goo003OOol00f/jMmQgf008Ool56EP23?H00goo07@0UP0409H2Ool3
0GX00g?j01004003MmP48GP3LoX00`1BLoXMg0047M`5KoX6Emh25Ud00g_EHkeS_@05Ool01G>JOomo
o`0000l0bGoo003^Ool00aUH3?Ioo`02Ool309H5Ool20GX017?j010046oj0WOH0b5h1g?j0agL1Foj
25ON00@FGF>mHkeS_@Uoo`0300moogoo0<Moo`00m7oo00<0UWooOol01Goo0P5j00EcnP0@KoYoogOH
00<QN0McnP8Mg0E_nPQGgPAoo`03Kfeoogoo0=5oo`00oGoo00<1NWooOol00goo00=gf25hLoX027?j
00<Mg6ojKoX00Q4h17oo0UONfgoo003oOol5Ool00b5hLoYcnP05LoX5Ool00a4hOomoo`3POol00?mo
ooEoo`00ogoomGoo003oOooeOol00?moooEoo`00ogoomGoo003oOooeOol00?moooEoo`00ogoomGoo
003oOooeOol00?moooEoo`00ogoomGoo003oOooeOol00?moooEoo`00ogoomGoo003oOooeOol00?mo
ooEoo`00ogoomGoo003oOooeOol00?moooEoo`00ogoomGoo003oOooeOol00?moooEoo`00ogoomGoo
003oOooeOol00?moooEoo`00ogoomGoo003oOooeOol00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{500, 254.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[Ellipsis] or like this?"], "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .82055 
MathPictureStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249355 0.99742 -0.0396341 0.99742 [
[(-10)] .09737 .24064 1 .96527 Msboxa
[(-5)] .217 .19356 .94911 1 Msboxa
[(0)] .34275 .1441 .86223 1 Msboxa
[(5)] .4751 .09206 .77536 1 Msboxa
[(10)] .61458 .03725 .68849 1 Msboxa
[(x)] .30204 .09689 .86223 1 Msboxa
[(-10)] .71798 .0618 -1 .38197 Msboxa
[(-5)] .78117 .15856 -1 .35992 Msboxa
[(0)] .83872 .24668 -1 .34028 Msboxa
[(5)] .89134 .32727 -1 .32267 Msboxa
[(10)] .93965 .40125 -1 .3068 Msboxa
[(y)] .89773 .2266 -1 .34028 Msboxa
[ 0 0 0 0 ]
[ 1 .82055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.10634 .2493 m
.11082 .25363 L
s
P
[(-10)] .09737 .24064 1 .96527 Mshowa
p
.002 w
.22558 .20261 m
.22987 .20713 L
s
P
[(-5)] .217 .19356 .94911 1 Mshowa
p
.002 w
.35089 .15354 m
.35496 .15826 L
s
P
[(0)] .34275 .1441 .86223 1 Mshowa
p
.002 w
.48274 .10191 m
.48656 .10684 L
s
P
[(5)] .4751 .09206 .77536 1 Mshowa
p
.002 w
.62165 .04752 m
.62519 .05265 L
s
P
[(10)] .61458 .03725 .68849 1 Mshowa
p
.001 w
.12972 .24014 m
.13239 .24276 L
s
P
p
.001 w
.15334 .2309 m
.15598 .23354 L
s
P
p
.001 w
.17718 .22156 m
.17981 .22422 L
s
P
p
.001 w
.20126 .21213 m
.20386 .21482 L
s
P
p
.001 w
.25014 .19299 m
.25269 .19573 L
s
P
p
.001 w
.27495 .18327 m
.27748 .18604 L
s
P
p
.001 w
.30001 .17346 m
.30251 .17625 L
s
P
p
.001 w
.32532 .16355 m
.32779 .16636 L
s
P
p
.001 w
.37672 .14343 m
.37914 .14628 L
s
P
p
.001 w
.40282 .13321 m
.4052 .13609 L
s
P
p
.001 w
.42918 .12288 m
.43154 .12579 L
s
P
p
.001 w
.45582 .11245 m
.45815 .11538 L
s
P
p
.001 w
.50994 .09126 m
.5122 .09424 L
s
P
p
.001 w
.53743 .0805 m
.53965 .0835 L
s
P
p
.001 w
.5652 .06962 m
.5674 .07265 L
s
P
p
.001 w
.59328 .05863 m
.59543 .06168 L
s
P
p
.001 w
.08318 .25837 m
.08589 .26094 L
s
P
p
.001 w
.65033 .03629 m
.65242 .03939 L
s
P
[(x)] .30204 .09689 .86223 1 Mshowa
P
p
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
P
p
.002 w
.70633 .06625 m
.70051 .06848 L
s
P
[(-10)] .71798 .0618 -1 .38197 Mshowa
p
.002 w
.76944 .16279 m
.76358 .1649 L
s
P
[(-5)] .78117 .15856 -1 .35992 Mshowa
p
.002 w
.82692 .2507 m
.82101 .25271 L
s
P
[(0)] .83872 .24668 -1 .34028 Mshowa
p
.002 w
.87948 .3311 m
.87354 .33301 L
s
P
[(5)] .89134 .32727 -1 .32267 Mshowa
p
.002 w
.92773 .40491 m
.92177 .40674 L
s
P
[(10)] .93965 .40125 -1 .3068 Mshowa
p
.001 w
.71945 .08631 m
.71595 .08763 L
s
P
p
.001 w
.73231 .10598 m
.7288 .10729 L
s
P
p
.001 w
.74492 .12528 m
.74141 .12657 L
s
P
p
.001 w
.7573 .14421 m
.75378 .14549 L
s
P
p
.001 w
.78136 .18102 m
.77784 .18227 L
s
P
p
.001 w
.79306 .19892 m
.78954 .20016 L
s
P
p
.001 w
.80455 .21649 m
.80102 .21772 L
s
P
p
.001 w
.81584 .23375 m
.8123 .23497 L
s
P
p
.001 w
.8378 .26735 m
.83425 .26854 L
s
P
p
.001 w
.84849 .28371 m
.84494 .28489 L
s
P
p
.001 w
.859 .29978 m
.85545 .30095 L
s
P
p
.001 w
.86933 .31557 m
.86577 .31673 L
s
P
p
.001 w
.88945 .34636 m
.88589 .3475 L
s
P
p
.001 w
.89926 .36137 m
.8957 .3625 L
s
P
p
.001 w
.90891 .37612 m
.90534 .37724 L
s
P
p
.001 w
.9184 .39064 m
.91482 .39174 L
s
P
p
.001 w
.69296 .0458 m
.68947 .04715 L
s
P
p
.001 w
.93691 .41895 m
.93333 .42004 L
s
P
[(y)] .89773 .2266 -1 .34028 Mshowa
P
0 0 m
1 0 L
1 .82055 L
0 .82055 L
closepath
clip
newpath
p
P
p
.88 .545 .41 r
.40176 .65208 .40807 .64947 .4177 .66075 .41071 .68416 Mtetra
.631 .338 .454 r
.41071 .68416 .4177 .66075 .42727 .6786 .42068 .69149 Mtetra
.435 .082 .266 r
.42068 .69149 .42727 .6786 .43722 .68802 .43103 .68846 Mtetra
.953 .791 .643 r
.43103 .68846 .43722 .68802 .44762 .68318 .44228 .65082 Mtetra
.623 .474 .659 r
.44228 .65082 .44762 .68318 .45811 .67451 .45264 .64613 Mtetra
.753 .569 .647 r
.45264 .64613 .45811 .67451 .46913 .63508 .46342 .6209 Mtetra
.856 .503 0 r
.46342 .6209 .46913 .63508 .47962 .62021 .47321 .65353 Mtetra
.585 .315 .473 r
.47321 .65353 .47962 .62021 .4896 .653 .48363 .6567 Mtetra
.87 .519 .383 r
.48363 .6567 .4896 .653 .50002 .66109 .49389 .68634 Mtetra
.16 0 .282 r
.49389 .68634 .50002 .66109 .51056 .66677 .50468 .66675 Mtetra
.936 .893 .762 r
.50468 .66675 .51056 .66677 .52118 .69233 .51541 .6494 Mtetra
.639 .47 .637 r
.51541 .6494 .52118 .69233 .53194 .68118 .52609 .64012 Mtetra
.732 .537 .628 r
.52609 .64012 .53194 .68118 .54263 .66016 .5367 .61024 Mtetra
.691 .499 .623 r
.5367 .61024 .54263 .66016 .55327 .64082 .54722 .58682 Mtetra
.488 .349 .618 r
.54722 .58682 .55327 .64082 .56373 .6115 .55804 .6005 Mtetra
.443 .511 .833 r
.55804 .6005 .56373 .6115 .57417 .58963 .56888 .60411 Mtetra
.304 0 .239 r
.56888 .60411 .57417 .58963 .58495 .59024 .5796 .59604 Mtetra
.856 .498 .373 r
.5796 .59604 .58495 .59024 .5959 .59512 .5911 .62514 Mtetra
.53 .257 .445 r
.5911 .62514 .5959 .59512 .60672 .59122 .60211 .62266 Mtetra
.688 .402 .483 r
.60211 .62266 .60672 .59122 .61764 .58958 .61376 .64193 Mtetra
.489 .254 .484 r
.61376 .64193 .61764 .58958 .62879 .59292 .62466 .63004 Mtetra
.589 .321 .478 r
.62466 .63004 .62879 .59292 .64054 .61078 .63609 .63415 Mtetra
.673 .368 .448 r
.63609 .63415 .64054 .61078 .65161 .60646 .64796 .64736 Mtetra
.525 .271 .473 r
.64796 .64736 .65161 .60646 .66203 .58573 .65925 .64255 Mtetra
.549 .307 .501 r
.65925 .64255 .66203 .58573 .67353 .59033 .67065 .63948 Mtetra
.541 .294 .49 r
.67065 .63948 .67353 .59033 .68462 .58441 .68208 .63584 Mtetra
.483 .249 .483 r
.68208 .63584 .68462 .58441 .69547 .57356 .69308 .62302 Mtetra
.442 .215 .472 r
.69308 .62302 .69547 .57356 .70714 .57731 .70379 .60535 Mtetra
.535 .255 .437 r
.70379 .60535 .70714 .57731 .71745 .55668 .71538 .6036 Mtetra
.336 .129 .444 r
.71538 .6036 .71745 .55668 .72883 .55423 .72539 .57544 Mtetra
.414 .128 .367 r
.72539 .57544 .72883 .55423 .74041 .55372 .73658 .56715 Mtetra
.197 0 .193 r
.73658 .56715 .74041 .55372 .75114 .54044 .74758 .55597 Mtetra
.123 0 .206 r
.74758 .55597 .75114 .54044 .76419 .55845 .75827 .54068 Mtetra
.569 .504 .743 r
.75827 .54068 .76419 .55845 .77615 .55992 .77016 .54138 Mtetra
.787 .621 .675 r
.77016 .54138 .77615 .55992 .78866 .56703 .78041 .52081 Mtetra
.586 .429 .636 r
.78041 .52081 .78866 .56703 .80051 .56497 .79224 .51989 Mtetra
.35 .271 .624 r
.79224 .51989 .80051 .56497 .81502 .59191 .80667 .54757 Mtetra
.349 .272 .627 r
.80667 .54757 .81502 .59191 .82861 .60594 .82138 .57516 Mtetra
.325 .287 .661 r
.82138 .57516 .82861 .60594 .8399 .59447 .83573 .59603 Mtetra
.579 .928 .744 r
.83573 .59603 .8399 .59447 .85012 .57248 .8474 .58767 Mtetra
0 0 .004 r
.8474 .58767 .85012 .57248 .85733 .52264 .8566 .5552 Mtetra
.356 .126 .422 r
.8566 .5552 .85733 .52264 .87014 .52713 .86703 .53582 Mtetra
.742 .769 .267 r
.86703 .53582 .87014 .52713 .88225 .52433 .87622 .50601 Mtetra
.554 .494 .743 r
.87622 .50601 .88225 .52433 .89674 .54143 .8889 .5077 Mtetra
.354 .299 .657 r
.8889 .5077 .89674 .54143 .91097 .5546 .90406 .52934 Mtetra
.532 .443 .7 r
.90406 .52934 .91097 .5546 .92292 .54795 .91733 .53361 Mtetra
.4 .443 .789 r
.91733 .53361 .92292 .54795 .93419 .53581 .93112 .54106 Mtetra
.118 0 0 r
.93112 .54106 .93419 .53581 .94143 .49333 .94335 .53552 Mtetra
.298 .108 .446 r
.94335 .53552 .94143 .49333 .95408 .49234 .95193 .50269 Mtetra
.623 .346 .476 r
.3943 .68246 .40176 .65208 .41071 .68416 .40419 .69012 Mtetra
0 0 0 r
.40419 .69012 .41071 .68416 .42068 .69149 .41467 .68283 Mtetra
.886 .706 .653 r
.41467 .68283 .42068 .69149 .43103 .68846 .42602 .64656 Mtetra
.612 .45 .639 r
.42602 .64656 .43103 .68846 .44228 .65082 .43637 .64207 Mtetra
.843 .706 .712 r
.43637 .64207 .44228 .65082 .45264 .64613 .4471 .62261 Mtetra
0 0 .489 r
.4471 .62261 .45264 .64613 .46342 .6209 .45682 .64982 Mtetra
.689 .405 .487 r
.45682 .64982 .46342 .6209 .47321 .65353 .46694 .6676 Mtetra
.678 .342 .399 r
.46694 .6676 .47321 .65353 .48363 .6567 .47734 .6773 Mtetra
0 0 .095 r
.47734 .6773 .48363 .6567 .49389 .68634 .48822 .65448 Mtetra
.693 .523 .653 r
.48822 .65448 .49389 .68634 .50468 .66675 .49895 .63955 Mtetra
.72 .55 .66 r
.49895 .63955 .50468 .66675 .51541 .6494 .50966 .62252 Mtetra
.721 .552 .66 r
.50966 .62252 .51541 .6494 .52609 .64012 .52032 .60553 Mtetra
.726 .54 .639 r
.52032 .60553 .52609 .64012 .5367 .61024 .53092 .58207 Mtetra
.366 .311 .663 r
.53092 .58207 .5367 .61024 .54722 .58682 .54164 .59613 Mtetra
.787 .432 .386 r
.54164 .59613 .54722 .58682 .55804 .6005 .55257 .61568 Mtetra
.566 .23 .358 r
.55257 .61568 .55804 .6005 .56888 .60411 .56347 .61768 Mtetra
.773 .439 .421 r
.56347 .61768 .56888 .60411 .5796 .59604 .57476 .63963 Mtetra
.553 .298 .483 r
.57476 .63963 .5796 .59604 .5911 .62514 .58584 .63855 Mtetra
.606 .254 .347 r
.58584 .63855 .5911 .62514 .60211 .62266 .5971 .64306 Mtetra
.544 .236 .395 r
.5971 .64306 .60211 .62266 .61376 .64193 .60834 .64323 Mtetra
.666 .141 0 r
.60834 .64323 .61376 .64193 .62466 .63004 .61988 .65107 Mtetra
.127 0 .248 r
.61988 .65107 .62466 .63004 .63609 .63415 .63068 .63238 Mtetra
.858 .407 .108 r
.63068 .63238 .63609 .63415 .64796 .64736 .64284 .65311 Mtetra
.582 .844 .491 r
.64284 .65311 .64796 .64736 .65925 .64255 .65387 .63989 Mtetra
.936 .845 .728 r
.65387 .63989 .65925 .64255 .67065 .63948 .66457 .61919 Mtetra
0 .045 .59 r
.66457 .61919 .67065 .63948 .68208 .63584 .67732 .64443 Mtetra
.386 0 .127 r
.67732 .64443 .68208 .63584 .69308 .62302 .68894 .64191 Mtetra
0 0 .056 r
.68894 .64191 .69308 .62302 .70379 .60535 .69917 .61255 Mtetra
.778 .379 .297 r
.69917 .61255 .70379 .60535 .71538 .6036 .71191 .62938 Mtetra
.141 0 .306 r
.71191 .62938 .71538 .6036 .72539 .57544 .72236 .60537 Mtetra
.667 .372 .463 r
.72236 .60537 .72539 .57544 .73658 .56715 .73524 .62052 Mtetra
.386 .175 .466 r
.73524 .62052 .73658 .56715 .74758 .55597 .74547 .59413 Mtetra
.228 .033 .395 r
.74547 .59413 .74758 .55597 .75827 .54068 .75525 .56322 Mtetra
.615 .305 .422 r
.75525 .56322 .75827 .54068 .77016 .54138 .76772 .56971 Mtetra
.12 0 .326 r
.76772 .56971 .77016 .54138 .78041 .52081 .77752 .54107 Mtetra
0 0 .22 r
.77752 .54107 .78041 .52081 .79224 .51989 .78745 .51573 Mtetra
.843 .862 .858 r
.78745 .51573 .79224 .51989 .80667 .54757 .79858 .50543 Mtetra
.385 .299 .635 r
.79858 .50543 .80667 .54757 .82138 .57516 .81269 .52799 Mtetra
.562 .412 .636 r
.81269 .52799 .82138 .57516 .83573 .59603 .82518 .53081 Mtetra
.394 .282 .607 r
.82518 .53081 .83573 .59603 .8474 .58767 .84083 .56463 Mtetra
.416 .38 .711 r
.84083 .56463 .8474 .58767 .8566 .5552 .85448 .5755 Mtetra
.167 0 .294 r
.85448 .5755 .8566 .5552 .86703 .53582 .86501 .55558 Mtetra
.297 .029 .327 r
.86501 .55558 .86703 .53582 .87622 .50601 .87614 .54163 Mtetra
0 0 .324 r
.87614 .54163 .87622 .50601 .8889 .5077 .88312 .49162 Mtetra
.729 .611 .726 r
.88312 .49162 .8889 .5077 .90406 .52934 .89442 .48086 Mtetra
.234 .192 .604 r
.89442 .48086 .90406 .52934 .91733 .53361 .91239 .5247 Mtetra
.166 .398 .842 r
.91239 .5247 .91733 .53361 .93112 .54106 .9264 .53373 Mtetra
.639 .719 .905 r
.9264 .53373 .93112 .54106 .94335 .53552 .93901 .53075 Mtetra
.776 .858 .911 r
.93901 .53075 .94335 .53552 .95193 .50269 .95107 .52318 Mtetra
.264 0 .047 r
.38753 .69109 .3943 .68246 .40419 .69012 .39792 .68678 Mtetra
.925 .748 .644 r
.39792 .68678 .40419 .69012 .41467 .68283 .40957 .64673 Mtetra
.685 .51 .644 r
.40957 .64673 .41467 .68283 .42602 .64656 .42027 .63126 Mtetra
.382 .408 .763 r
.42027 .63126 .42602 .64656 .43637 .64207 .4303 .63787 Mtetra
0 .369 .786 r
.4303 .63787 .43637 .64207 .4471 .62261 .44047 .64275 Mtetra
.793 .496 .486 r
.44047 .64275 .4471 .62261 .45682 .64982 .45006 .67851 Mtetra
.563 .282 .447 r
.45006 .67851 .45682 .64982 .46694 .6676 .46059 .67959 Mtetra
.889 .895 .476 r
.46059 .67959 .46694 .6676 .47734 .6773 .47166 .65088 Mtetra
.788 .596 .641 r
.47166 .65088 .47734 .6773 .48822 .65448 .48265 .61825 Mtetra
.721 .535 .637 r
.48265 .61825 .48822 .65448 .49895 .63955 .49342 .59488 Mtetra
.634 .462 .633 r
.49342 .59488 .49895 .63955 .50966 .62252 .504 .58607 Mtetra
.324 .256 .625 r
.504 .58607 .50966 .62252 .52032 .60553 .51451 .60635 Mtetra
.55 0 0 r
.51451 .60635 .52032 .60553 .53092 .58207 .52521 .61114 Mtetra
.706 .417 .483 r
.52521 .61114 .53092 .58207 .54164 .59613 .53607 .63262 Mtetra
.615 .343 .482 r
.53607 .63262 .54164 .59613 .55257 .61568 .54704 .64065 Mtetra
.655 .357 .454 r
.54704 .64065 .55257 .61568 .56347 .61768 .55817 .65185 Mtetra
.568 .296 .463 r
.55817 .65185 .56347 .61768 .57476 .63963 .5693 .65331 Mtetra
.045 0 .092 r
.5693 .65331 .57476 .63963 .58584 .63855 .58026 .64018 Mtetra
.932 .963 .762 r
.58026 .64018 .58584 .63855 .5971 .64306 .59114 .62412 Mtetra
.201 .261 .701 r
.59114 .62412 .5971 .64306 .60834 .64323 .60271 .63875 Mtetra
.895 .808 .755 r
.60271 .63875 .60834 .64323 .61988 .65107 .61358 .62135 Mtetra
.734 .554 .649 r
.61358 .62135 .61988 .65107 .63068 .63238 .62427 .59991 Mtetra
.681 .514 .653 r
.62427 .59991 .63068 .63238 .64284 .65311 .63517 .5867 Mtetra
.472 .33 .606 r
.63517 .5867 .64284 .65311 .65387 .63989 .64727 .60601 Mtetra
.74 .55 .637 r
.64727 .60601 .65387 .63989 .66457 .61919 .65771 .58006 Mtetra
.611 .455 .646 r
.65771 .58006 .66457 .61919 .67732 .64443 .669 .57572 Mtetra
.478 .333 .606 r
.669 .57572 .67732 .64443 .68894 .64191 .6815 .5951 Mtetra
.589 .43 .634 r
.6815 .5951 .68894 .64191 .69917 .61255 .6931 .59339 Mtetra
.588 .507 .731 r
.6931 .59339 .69917 .61255 .71191 .62938 .70483 .59283 Mtetra
.482 .374 .654 r
.70483 .59283 .71191 .62938 .72236 .60537 .71727 .60317 Mtetra
.827 .931 .899 r
.71727 .60317 .72236 .60537 .73524 .62052 .72864 .594 Mtetra
.515 .425 .692 r
.72864 .594 .73524 .62052 .74547 .59413 .74098 .59923 Mtetra
.747 .304 .199 r
.74098 .59923 .74547 .59413 .75525 .56322 .75398 .61221 Mtetra
.416 .193 .464 r
.75398 .61221 .75525 .56322 .76772 .56971 .76465 .59154 Mtetra
.108 0 .272 r
.76465 .59154 .76772 .56971 .77752 .54107 .77513 .56931 Mtetra
.431 .167 .411 r
.77513 .56931 .77752 .54107 .78745 .51573 .78649 .55898 Mtetra
.259 .068 .42 r
.78649 .55898 .78745 .51573 .79858 .50543 .79588 .5256 Mtetra
0 0 .164 r
.79588 .5256 .79858 .50543 .81269 .52799 .80534 .49492 Mtetra
.545 .424 .666 r
.80534 .49492 .81269 .52799 .82518 .53081 .81785 .49871 Mtetra
.499 .397 .67 r
.81785 .49871 .82518 .53081 .84083 .56463 .83089 .50679 Mtetra
.406 .296 .615 r
.83089 .50679 .84083 .56463 .85448 .5755 .84611 .53499 Mtetra
.286 .237 .627 r
.84611 .53499 .85448 .5755 .86501 .55558 .8619 .56583 Mtetra
.365 0 .175 r
.8619 .56583 .86501 .55558 .87614 .54163 .87419 .56144 Mtetra
.158 0 .287 r
.87419 .56144 .87614 .54163 .88312 .49162 .88477 .54146 Mtetra
.197 .04 .428 r
.88477 .54146 .88312 .49162 .89442 .48086 .89204 .49387 Mtetra
.473 .116 .279 r
.89204 .49387 .89442 .48086 .91239 .5247 .90453 .49189 Mtetra
.348 .299 .66 r
.90453 .49189 .91239 .5247 .9264 .53373 .92001 .51325 Mtetra
.204 .26 .699 r
.92001 .51325 .9264 .53373 .93901 .53075 .93556 .53314 Mtetra
.268 0 0 r
.93556 .53314 .93901 .53075 .95107 .52318 .94875 .53343 Mtetra
.764 .599 .674 r
.38188 .67112 .38753 .69109 .39792 .68678 .39286 .65147 Mtetra
.722 .537 .64 r
.39286 .65147 .39792 .68678 .40957 .64673 .40389 .62856 Mtetra
.173 .241 .694 r
.40389 .62856 .40957 .64673 .42027 .63126 .41365 .64149 Mtetra
.517 .133 .252 r
.41365 .64149 .42027 .63126 .4303 .63787 .42392 .64206 Mtetra
.866 .524 .401 r
.42392 .64206 .4303 .63787 .44047 .64275 .43345 .67228 Mtetra
.307 .053 .356 r
.43345 .67228 .44047 .64275 .45006 .67851 .44433 .6566 Mtetra
.747 .583 .672 r
.44433 .6566 .45006 .67851 .46059 .67959 .45523 .6385 Mtetra
.754 .552 .623 r
.45523 .6385 .46059 .67959 .47166 .65088 .46641 .60143 Mtetra
.676 .488 .624 r
.46641 .60143 .47166 .65088 .48265 .61825 .47715 .58212 Mtetra
.457 .35 .644 r
.47715 .58212 .48265 .61825 .49342 .59488 .4875 .59315 Mtetra
.896 .5 .259 r
.4875 .59315 .49342 .59488 .504 .58607 .49787 .61828 Mtetra
.731 .446 .496 r
.49787 .61828 .504 .58607 .51451 .60635 .50845 .64797 Mtetra
.638 .369 .495 r
.50845 .64797 .51451 .60635 .52521 .61114 .51931 .66099 Mtetra
.591 .335 .497 r
.51931 .66099 .52521 .61114 .53607 .63262 .5303 .66645 Mtetra
.45 .191 .428 r
.5303 .66645 .53607 .63262 .54704 .64065 .54132 .65684 Mtetra
.518 .185 .342 r
.54132 .65684 .54704 .64065 .55817 .65185 .55242 .65632 Mtetra
.954 .95 .662 r
.55242 .65632 .55817 .65185 .5693 .65331 .56334 .63478 Mtetra
.787 .621 .675 r
.56334 .63478 .5693 .65331 .58026 .64018 .57417 .6132 Mtetra
.765 .58 .647 r
.57417 .6132 .58026 .64018 .59114 .62412 .58485 .58722 Mtetra
.678 .504 .643 r
.58485 .58722 .59114 .62412 .60271 .63875 .59566 .57259 Mtetra
.658 .463 .61 r
.59566 .57259 .60271 .63875 .61358 .62135 .60629 .55201 Mtetra
.524 .364 .607 r
.60629 .55201 .61358 .62135 .62427 .59991 .61776 .56256 Mtetra
.576 .433 .65 r
.61776 .56256 .62427 .59991 .63517 .5867 .62904 .56281 Mtetra
.641 .512 .691 r
.62904 .56281 .63517 .5867 .64727 .60601 .64018 .55746 Mtetra
.667 .482 .625 r
.64018 .55746 .64727 .60601 .65771 .58006 .65089 .54037 Mtetra
.486 .368 .644 r
.65089 .54037 .65771 .58006 .669 .57572 .66274 .55069 Mtetra
.623 .497 .688 r
.66274 .55069 .669 .57572 .6815 .5951 .67407 .54687 Mtetra
.617 .447 .63 r
.67407 .54687 .6815 .5951 .6931 .59339 .6853 .54004 Mtetra
.442 .32 .618 r
.6853 .54004 .6931 .59339 .70483 .59283 .69798 .55973 Mtetra
.645 .489 .657 r
.69798 .55973 .70483 .59283 .71727 .60317 .70928 .5516 Mtetra
.427 .313 .62 r
.70928 .5516 .71727 .60317 .72864 .594 .72238 .57258 Mtetra
.62 .514 .712 r
.72238 .57258 .72864 .594 .74098 .59923 .73414 .56949 Mtetra
.294 .267 .657 r
.73414 .56949 .74098 .59923 .75398 .61221 .74758 .58993 Mtetra
.306 .312 .702 r
.74758 .58993 .75398 .61221 .76465 .59154 .76085 .6048 Mtetra
.361 .015 .237 r
.76085 .6048 .76465 .59154 .77513 .56931 .7727 .59873 Mtetra
.236 .015 .362 r
.7727 .59873 .77513 .56931 .78649 .55898 .78321 .57542 Mtetra
0 0 0 r
.78321 .57542 .78649 .55898 .79588 .5256 .79246 .53837 Mtetra
.167 0 .166 r
.79246 .53837 .79588 .5256 .80534 .49492 .80374 .52678 Mtetra
.214 .011 .374 r
.80374 .52678 .80534 .49492 .81785 .49871 .81357 .49943 Mtetra
.121 0 0 r
.81357 .49943 .81785 .49871 .83089 .50679 .82592 .49976 Mtetra
.335 .566 .923 r
.82592 .49976 .83089 .50679 .84611 .53499 .83869 .50348 Mtetra
.469 .38 .672 r
.83869 .50348 .84611 .53499 .8619 .56583 .85227 .51393 Mtetra
.413 .307 .624 r
.85227 .51393 .8619 .56583 .87419 .56144 .86753 .53838 Mtetra
.165 .216 .671 r
.86753 .53838 .87419 .56144 .88477 .54146 .88292 .56155 Mtetra
0 0 .038 r
.88292 .56155 .88477 .54146 .89204 .49387 .8903 .51315 Mtetra
.126 0 .275 r
.8903 .51315 .89204 .49387 .90453 .49189 .90067 .49224 Mtetra
.861 .995 .762 r
.90067 .49224 .90453 .49189 .92001 .51325 .91187 .47864 Mtetra
.325 .279 .652 r
.91187 .47864 .92001 .51325 .93556 .53314 .92789 .50298 Mtetra
.333 .299 .67 r
.92789 .50298 .93556 .53314 .94875 .53343 .94372 .52372 Mtetra
.839 .676 .681 r
.37588 .65932 .38188 .67112 .39286 .65147 .38713 .63395 Mtetra
.758 .607 .69 r
.38713 .63395 .39286 .65147 .40389 .62856 .39793 .61784 Mtetra
.801 .399 0 r
.39793 .61784 .40389 .62856 .41365 .64149 .40735 .63962 Mtetra
.916 .566 .36 r
.40735 .63962 .41365 .64149 .42392 .64206 .41655 .67439 Mtetra
.556 .282 .454 r
.41655 .67439 .42392 .64206 .43345 .67228 .42703 .67487 Mtetra
.967 .788 .609 r
.42703 .67487 .43345 .67228 .44433 .6566 .43885 .626 Mtetra
.697 .528 .655 r
.43885 .626 .44433 .6566 .45523 .6385 .44965 .61096 Mtetra
.708 .542 .661 r
.44965 .61096 .45523 .6385 .46641 .60143 .46042 .59569 Mtetra
.772 .768 .849 r
.46042 .59569 .46641 .60143 .47715 .58212 .47103 .58821 Mtetra
.844 .493 .39 r
.47103 .58821 .47715 .58212 .4875 .59315 .48122 .61483 Mtetra
.783 .481 .478 r
.48122 .61483 .4875 .59315 .49787 .61828 .49157 .64892 Mtetra
.494 .221 .428 r
.49157 .64892 .49787 .61828 .50845 .64797 .50245 .64398 Mtetra
.869 .424 .09 r
.50245 .64398 .50845 .64797 .51931 .66099 .5133 .66434 Mtetra
.985 .846 .622 r
.5133 .66434 .51931 .66099 .5303 .66645 .52433 .62834 Mtetra
.632 .471 .646 r
.52433 .62834 .5303 .66645 .54132 .65684 .53529 .621 Mtetra
.716 .531 .639 r
.53529 .621 .54132 .65684 .55242 .65632 .54617 .59931 Mtetra
.711 .508 .612 r
.54617 .59931 .55242 .65632 .56334 .63478 .55685 .56591 Mtetra
.633 .444 .609 r
.55685 .56591 .56334 .63478 .57417 .6132 .56764 .55152 Mtetra
.547 .385 .613 r
.56764 .55152 .57417 .6132 .58485 .58722 .57872 .55664 Mtetra
.749 .561 .641 r
.57872 .55664 .58485 .58722 .59566 .57259 .58928 .53112 Mtetra
.502 .374 .638 r
.58928 .53112 .59566 .57259 .60629 .55201 .60056 .53991 Mtetra
.741 .648 .756 r
.60056 .53991 .60629 .55201 .61776 .56256 .61147 .53055 Mtetra
.42 .339 .658 r
.61147 .53055 .61776 .56256 .62904 .56281 .62307 .54341 Mtetra
.762 .603 .681 r
.62307 .54341 .62904 .56281 .64018 .55746 .63377 .52563 Mtetra
.614 .47 .662 r
.63377 .52563 .64018 .55746 .65089 .54037 .64495 .52171 Mtetra
.557 .49 .735 r
.64495 .52171 .65089 .54037 .66274 .55069 .65638 .52288 Mtetra
.674 .52 .668 r
.65638 .52288 .66274 .55069 .67407 .54687 .66737 .51245 Mtetra
.62 .468 .655 r
.66737 .51245 .67407 .54687 .6853 .54004 .67862 .50737 Mtetra
.548 .425 .664 r
.67862 .50737 .6853 .54004 .69798 .55973 .69033 .51042 Mtetra
.64 .462 .626 r
.69033 .51042 .69798 .55973 .70928 .5516 .70131 .4987 Mtetra
.506 .365 .623 r
.70131 .4987 .70928 .5516 .72238 .57258 .71364 .50972 Mtetra
.408 .288 .604 r
.71364 .50972 .72238 .57258 .73414 .56949 .7272 .53758 Mtetra
.646 .492 .661 r
.7272 .53758 .73414 .56949 .74758 .58993 .73862 .52952 Mtetra
.48 .342 .615 r
.73862 .52952 .74758 .58993 .76085 .6048 .75183 .54627 Mtetra
.399 .287 .61 r
.75183 .54627 .76085 .6048 .7727 .59873 .76607 .57401 Mtetra
.297 .293 .686 r
.76607 .57401 .7727 .59873 .78321 .57542 .77975 .59104 Mtetra
.486 .146 .314 r
.77975 .59104 .78321 .57542 .79246 .53837 .79208 .58914 Mtetra
.358 .149 .454 r
.79208 .58914 .79246 .53837 .80374 .52678 .80219 .56084 Mtetra
.122 0 .351 r
.80219 .56084 .80374 .52678 .81357 .49943 .81159 .52613 Mtetra
.061 0 .299 r
.81159 .52613 .81357 .49943 .82592 .49976 .82121 .49582 Mtetra
.928 .863 .756 r
.82121 .49582 .82592 .49976 .83869 .50348 .83191 .47807 Mtetra
.484 .411 .698 r
.83191 .47807 .83869 .50348 .85227 .51393 .84511 .48529 Mtetra
.077 .128 .613 r
.84511 .48529 .85227 .51393 .86753 .53838 .86118 .51823 Mtetra
.431 .409 .734 r
.86118 .51823 .86753 .53838 .88292 .56155 .87491 .52675 Mtetra
.52 .407 .665 r
.87491 .52675 .88292 .56155 .8903 .51315 .88855 .53316 Mtetra
0 0 .206 r
.88855 .53316 .8903 .51315 .90067 .49224 .89797 .50271 Mtetra
0 0 0 r
.89797 .50271 .90067 .49224 .91187 .47864 .90717 .4718 Mtetra
.825 .8 .827 r
.90717 .4718 .91187 .47864 .92789 .50298 .91872 .46078 Mtetra
.262 .221 .622 r
.91872 .46078 .92789 .50298 .94372 .52372 .93636 .49631 Mtetra
.629 .461 .636 r
.37126 .61728 .37588 .65932 .38713 .63395 .38169 .60976 Mtetra
.839 .556 .014 r
.38169 .60976 .38713 .63395 .39793 .61784 .38998 .6556 Mtetra
.649 .377 .494 r
.38998 .6556 .39793 .61784 .40735 .63962 .39981 .66951 Mtetra
.481 .205 .418 r
.39981 .66951 .40735 .63962 .41655 .67439 .41045 .66402 Mtetra
.89 .697 .636 r
.41045 .66402 .41655 .67439 .42703 .67487 .42231 .61996 Mtetra
.664 .475 .62 r
.42231 .61996 .42703 .67487 .43885 .626 .43324 .60162 Mtetra
.691 .54 .677 r
.43324 .60162 .43885 .626 .44965 .61096 .44393 .59063 Mtetra
.541 .464 .718 r
.44393 .59063 .44965 .61096 .46042 .59569 .45433 .59271 Mtetra
.933 .595 .369 r
.45433 .59271 .46042 .59569 .47103 .58821 .46402 .63856 Mtetra
.569 .315 .491 r
.46402 .63856 .47103 .58821 .48122 .61483 .47473 .6404 Mtetra
.69 .392 .465 r
.47473 .6404 .48122 .61483 .49157 .64892 .48534 .65703 Mtetra
0 0 0 r
.48534 .65703 .49157 .64892 .50245 .64398 .49636 .64612 Mtetra
.977 .834 .635 r
.49636 .64612 .50245 .64398 .5133 .66434 .50749 .61116 Mtetra
.696 .499 .618 r
.50749 .61116 .5133 .66434 .52433 .62834 .51844 .58468 Mtetra
.572 .42 .636 r
.51844 .58468 .52433 .62834 .53529 .621 .52932 .58509 Mtetra
.757 .559 .628 r
.52932 .58509 .53529 .621 .54617 .59931 .54011 .55257 Mtetra
.611 .443 .63 r
.54011 .55257 .54617 .59931 .55685 .56591 .55098 .54701 Mtetra
.671 .554 .713 r
.55098 .54701 .55685 .56591 .56764 .55152 .56186 .54026 Mtetra
.003 .237 .746 r
.56186 .54026 .56764 .55152 .57872 .55664 .57303 .55153 Mtetra
.88 .795 .762 r
.57303 .55153 .57872 .55664 .58928 .53112 .58384 .53544 Mtetra
.566 .076 .052 r
.58384 .53544 .58928 .53112 .60056 .53991 .59506 .53936 Mtetra
.466 0 0 r
.59506 .53936 .60056 .53991 .61147 .53055 .6064 .54445 Mtetra
.749 .403 .397 r
.6064 .54445 .61147 .53055 .62307 .54341 .61824 .56295 Mtetra
.462 .151 .352 r
.61824 .56295 .62307 .54341 .63377 .52563 .62954 .55875 Mtetra
.532 .259 .446 r
.62954 .55875 .63377 .52563 .64495 .52171 .64097 .55683 Mtetra
.336 .101 .401 r
.64097 .55683 .64495 .52171 .65638 .52288 .65177 .53782 Mtetra
.403 .067 .277 r
.65177 .53782 .65638 .52288 .66737 .51245 .66311 .53278 Mtetra
.582 .264 .395 r
.66311 .53278 .66737 .51245 .67862 .50737 .6749 .53624 Mtetra
.239 .008 .348 r
.6749 .53624 .67862 .50737 .69033 .51042 .68554 .51523 Mtetra
.562 .849 .519 r
.68554 .51523 .69033 .51042 .70131 .4987 .69659 .50322 Mtetra
.695 .912 .57 r
.69659 .50322 .70131 .4987 .71364 .50972 .70751 .48931 Mtetra
.299 .316 .71 r
.70751 .48931 .71364 .50972 .7272 .53758 .72011 .50267 Mtetra
.541 .416 .659 r
.72011 .50267 .7272 .53758 .73862 .52952 .73226 .50653 Mtetra
.564 .471 .708 r
.73226 .50653 .73862 .52952 .75183 .54627 .74431 .50753 Mtetra
.492 .376 .649 r
.74431 .50753 .75183 .54627 .76607 .57401 .75708 .5171 Mtetra
.47 .337 .618 r
.75708 .5171 .76607 .57401 .77975 .59104 .77059 .53434 Mtetra
.459 .331 .619 r
.77059 .53434 .77975 .59104 .79208 .58914 .78445 .55309 Mtetra
.492 .384 .659 r
.78445 .55309 .79208 .58914 .80219 .56084 .7977 .56219 Mtetra
.87 .991 .739 r
.7977 .56219 .80219 .56084 .81159 .52613 .809 .54753 Mtetra
.304 .034 .328 r
.809 .54753 .81159 .52613 .82121 .49582 .82035 .53373 Mtetra
.232 .037 .397 r
.82035 .53373 .82121 .49582 .83191 .47807 .82998 .50253 Mtetra
0 0 .213 r
.82998 .50253 .83191 .47807 .84511 .48529 .83886 .46544 Mtetra
.457 .425 .735 r
.83886 .46544 .84511 .48529 .86118 .51823 .85214 .47238 Mtetra
.374 .287 .629 r
.85214 .47238 .86118 .51823 .87491 .52675 .86759 .49791 Mtetra
0 0 .537 r
.86759 .49791 .87491 .52675 .88855 .53316 .88553 .54282 Mtetra
.115 0 .062 r
.88553 .54282 .88855 .53316 .89797 .50271 .89746 .53261 Mtetra
.167 0 .358 r
.89746 .53261 .89797 .50271 .90717 .4718 .90702 .50274 Mtetra
0 0 .246 r
.90702 .50274 .90717 .4718 .91872 .46078 .91333 .4483 Mtetra
0 .208 .722 r
.91333 .4483 .91872 .46078 .93636 .49631 .92856 .46543 Mtetra
.755 .354 .293 r
.36446 .62208 .37126 .61728 .38169 .60976 .37409 .63367 Mtetra
.768 .476 .492 r
.37409 .63367 .38169 .60976 .38998 .6556 .38297 .66616 Mtetra
.64 .27 .326 r
.38297 .66616 .38998 .6556 .39981 .66951 .39314 .67228 Mtetra
.967 .804 .628 r
.39314 .67228 .39981 .66951 .41045 .66402 .40515 .63054 Mtetra
.766 .57 .632 r
.40515 .63054 .41045 .66402 .42231 .61996 .41668 .59679 Mtetra
.744 .576 .667 r
.41668 .59679 .42231 .61996 .43324 .60162 .42761 .5784 Mtetra
.285 .278 .676 r
.42761 .5784 .43324 .60162 .44393 .59063 .43765 .59165 Mtetra
.879 .506 .332 r
.43765 .59165 .44393 .59063 .45433 .59271 .44754 .61764 Mtetra
.778 .483 .488 r
.44754 .61764 .45433 .59271 .46402 .63856 .45745 .6544 Mtetra
.54 .201 .342 r
.45745 .6544 .46402 .63856 .47473 .6404 .46826 .65526 Mtetra
.263 0 .196 r
.46826 .65526 .47473 .6404 .48534 .65703 .47927 .64689 Mtetra
.89 .706 .646 r
.47927 .64689 .48534 .65703 .49636 .64612 .49058 .60933 Mtetra
.716 .53 .637 r
.49058 .60933 .49636 .64612 .50749 .61116 .50161 .58692 Mtetra
.74 .571 .665 r
.50161 .58692 .50749 .61116 .51844 .58468 .51254 .56856 Mtetra
.782 .63 .692 r
.51254 .56856 .51844 .58468 .52932 .58509 .52342 .55073 Mtetra
.632 .476 .653 r
.52342 .55073 .52932 .58509 .54011 .55257 .53428 .54398 Mtetra
.694 .259 0 r
.53428 .54398 .54011 .55257 .55098 .54701 .54533 .56276 Mtetra
.008 0 .105 r
.54533 .56276 .55098 .54701 .56186 .54026 .55624 .54738 Mtetra
.816 .444 .351 r
.55624 .54738 .56186 .54026 .57303 .55153 .56761 .56948 Mtetra
.694 .365 .415 r
.56761 .56948 .57303 .55153 .58384 .53544 .57907 .58326 Mtetra
.583 .322 .487 r
.57907 .58326 .58384 .53544 .59506 .53936 .59051 .5878 Mtetra
.493 .247 .469 r
.59051 .5878 .59506 .53936 .6064 .54445 .60172 .57888 Mtetra
.596 .316 .462 r
.60172 .57888 .6064 .54445 .61824 .56295 .61335 .58465 Mtetra
.648 .331 .421 r
.61335 .58465 .61824 .56295 .62954 .55875 .62523 .59466 Mtetra
.423 .17 .424 r
.62523 .59466 .62954 .55875 .64097 .55683 .63647 .58212 Mtetra
.625 .319 .433 r
.63647 .58212 .64097 .55683 .65177 .53782 .64849 .59031 Mtetra
.5 .256 .477 r
.64849 .59031 .65177 .53782 .66311 .53278 .65991 .58127 Mtetra
.507 .259 .472 r
.65991 .58127 .66311 .53278 .6749 .53624 .67144 .57405 Mtetra
.367 .13 .417 r
.67144 .57405 .6749 .53624 .68554 .51523 .68243 .55574 Mtetra
.382 .148 .429 r
.68243 .55574 .68554 .51523 .69659 .50322 .69336 .5372 Mtetra
.445 .186 .427 r
.69336 .5372 .69659 .50322 .70751 .48931 .70469 .52681 Mtetra
.071 0 .329 r
.70469 .52681 .70751 .48931 .72011 .50267 .71434 .48868 Mtetra
.678 .603 .765 r
.71434 .48868 .72011 .50267 .73226 .50653 .72587 .483 Mtetra
.382 .352 .7 r
.72587 .483 .73226 .50653 .74431 .50753 .73861 .49468 Mtetra
.589 .573 .803 r
.73861 .49468 .74431 .50753 .75708 .5171 .75062 .49379 Mtetra
.282 .289 .69 r
.75062 .49379 .75708 .5171 .77059 .53434 .76401 .51011 Mtetra
.511 .433 .705 r
.76401 .51011 .77059 .53434 .78445 .55309 .77669 .51485 Mtetra
.009 .049 .554 r
.77669 .51485 .78445 .55309 .7977 .56219 .79287 .56014 Mtetra
.502 0 0 r
.79287 .56014 .7977 .56219 .809 .54753 .80633 .56926 Mtetra
.386 .098 .348 r
.80633 .56926 .809 .54753 .82035 .53373 .81823 .55965 Mtetra
0 0 .229 r
.81823 .55965 .82035 .53373 .82998 .50253 .82755 .52304 Mtetra
0 0 0 r
.82755 .52304 .82998 .50253 .83886 .46544 .83493 .46889 Mtetra
.241 0 0 r
.83493 .46889 .83886 .46544 .85214 .47238 .84744 .46772 Mtetra
.378 .693 .981 r
.84744 .46772 .85214 .47238 .86759 .49791 .86026 .46873 Mtetra
.405 .347 .679 r
.86026 .46873 .86759 .49791 .88553 .54282 .87464 .48278 Mtetra
.293 .218 .598 r
.87464 .48278 .88553 .54282 .89746 .53261 .89271 .52698 Mtetra
.886 .844 .797 r
.89271 .52698 .89746 .53261 .90702 .50274 .90416 .51219 Mtetra
.88 .774 .276 r
.90416 .51219 .90702 .50274 .91333 .4483 .91144 .46407 Mtetra
0 0 .122 r
.91144 .46407 .91333 .4483 .92856 .46543 .92097 .43595 Mtetra
.863 .5 .362 r
.35771 .62417 .36446 .62208 .37409 .63367 .36676 .64833 Mtetra
.698 .367 .412 r
.36676 .64833 .37409 .63367 .38297 .66616 .37656 .66042 Mtetra
.84 .764 .778 r
.37656 .66042 .38297 .66616 .39314 .67228 .38755 .64691 Mtetra
.838 .629 .62 r
.38755 .64691 .39314 .67228 .40515 .63054 .40005 .59325 Mtetra
.665 .493 .643 r
.40005 .59325 .40515 .63054 .41668 .59679 .41083 .58082 Mtetra
.548 .503 .758 r
.41083 .58082 .41668 .59679 .42761 .5784 .42117 .58193 Mtetra
.907 .595 .443 r
.42117 .58193 .42761 .5784 .43765 .59165 .42998 .63917 Mtetra
.674 .406 .508 r
.42998 .63917 .43765 .59165 .44754 .61764 .44007 .66261 Mtetra
.383 .145 .424 r
.44007 .66261 .44754 .61764 .45745 .6544 .4513 .64466 Mtetra
.827 .702 .727 r
.4513 .64466 .45745 .6544 .46826 .65526 .46245 .62742 Mtetra
.806 .605 .629 r
.46245 .62742 .46826 .65526 .47927 .64689 .47392 .58709 Mtetra
.702 .499 .611 r
.47392 .58709 .47927 .64689 .49058 .60933 .48508 .55524 Mtetra
.633 .452 .62 r
.48508 .55524 .49058 .60933 .50161 .58692 .49592 .54387 Mtetra
.47 .347 .63 r
.49592 .54387 .50161 .58692 .51254 .56856 .50663 .55522 Mtetra
.776 .648 .721 r
.50663 .55522 .51254 .56856 .52342 .55073 .51753 .54115 Mtetra
.813 .401 0 r
.51753 .54115 .52342 .55073 .53428 .54398 .52846 .56568 Mtetra
.702 .388 .443 r
.52846 .56568 .53428 .54398 .54533 .56276 .53959 .58238 Mtetra
.742 .422 .441 r
.53959 .58238 .54533 .56276 .55624 .54738 .55094 .60444 Mtetra
.605 .348 .501 r
.55094 .60444 .55624 .54738 .56761 .56948 .56238 .61441 Mtetra
.616 .347 .486 r
.56238 .61441 .56761 .56948 .57907 .58326 .57397 .62484 Mtetra
.535 .272 .463 r
.57397 .62484 .57907 .58326 .59051 .5878 .58546 .62265 Mtetra
.519 .247 .442 r
.58546 .62265 .59051 .5878 .60172 .57888 .59699 .61946 Mtetra
.578 .308 .47 r
.59699 .61946 .60172 .57888 .61335 .58465 .60876 .62325 Mtetra
.529 .262 .454 r
.60876 .62325 .61335 .58465 .62523 .59466 .62043 .62063 Mtetra
.519 .224 .406 r
.62043 .62063 .62523 .59466 .63647 .58212 .63219 .61885 Mtetra
.43 .176 .425 r
.63219 .61885 .63647 .58212 .64849 .59031 .64364 .60679 Mtetra
.683 .338 .384 r
.64364 .60679 .64849 .59031 .65991 .58127 .65606 .61912 Mtetra
.369 .129 .413 r
.65606 .61912 .65991 .58127 .67144 .57405 .66732 .60135 Mtetra
.092 0 .277 r
.66732 .60135 .67144 .57405 .68243 .55574 .67814 .57548 Mtetra
.608 .28 .388 r
.67814 .57548 .68243 .55574 .69336 .5372 .69049 .58143 Mtetra
.255 .053 .401 r
.69049 .58143 .69336 .5372 .70469 .52681 .70091 .55029 Mtetra
0 0 .114 r
.70091 .55029 .70469 .52681 .71434 .48868 .71093 .51507 Mtetra
.349 .086 .366 r
.71093 .51507 .71434 .48868 .72587 .483 .72213 .5015 Mtetra
.117 0 .223 r
.72213 .5015 .72587 .483 .73861 .49468 .73305 .48404 Mtetra
.804 .702 .752 r
.73305 .48404 .73861 .49468 .75062 .49379 .74418 .47048 Mtetra
.565 .47 .706 r
.74418 .47048 .75062 .49379 .76401 .51011 .75636 .47127 Mtetra
.581 .435 .648 r
.75636 .47127 .76401 .51011 .77669 .51485 .7685 .47044 Mtetra
.368 .282 .626 r
.7685 .47044 .77669 .51485 .79287 .56014 .78273 .49413 Mtetra
.276 .196 .582 r
.78273 .49413 .79287 .56014 .80633 .56926 .79929 .54169 Mtetra
.355 .32 .682 r
.79929 .54169 .80633 .56926 .81823 .55965 .81343 .55737 Mtetra
.893 .94 .836 r
.81343 .55737 .81823 .55965 .82755 .52304 .82507 .54419 Mtetra
0 0 0 r
.82507 .54419 .82755 .52304 .83493 .46889 .83278 .49115 Mtetra
.383 .099 .354 r
.83278 .49115 .83493 .46889 .84744 .46772 .84453 .48099 Mtetra
.786 .727 .197 r
.84453 .48099 .84744 .46772 .86026 .46873 .85246 .43483 Mtetra
.323 .277 .651 r
.85246 .43483 .86026 .46873 .87464 .48278 .86766 .45718 Mtetra
.187 .218 .661 r
.86766 .45718 .87464 .48278 .89271 .52698 .88334 .48134 Mtetra
.261 .213 .614 r
.88334 .48134 .89271 .52698 .90416 .51219 .9008 .51801 Mtetra
.707 .823 .372 r
.9008 .51801 .90416 .51219 .91144 .46407 .91144 .49602 Mtetra
.075 0 .342 r
.91144 .49602 .91144 .46407 .92097 .43595 .91996 .45801 Mtetra
.863 .536 .43 r
.35069 .62972 .35771 .62417 .36676 .64833 .35926 .66378 Mtetra
.083 0 .094 r
.35926 .66378 .36676 .64833 .37656 .66042 .37022 .65208 Mtetra
.895 .711 .646 r
.37022 .65208 .37656 .66042 .38755 .64691 .38239 .61214 Mtetra
.761 .564 .631 r
.38239 .61214 .38755 .64691 .40005 .59325 .39411 .57889 Mtetra
.63 .566 .763 r
.39411 .57889 .40005 .59325 .41083 .58082 .40455 .57612 Mtetra
.937 .594 .35 r
.40455 .57612 .41083 .58082 .42117 .58193 .41354 .61788 Mtetra
.707 .426 .497 r
.41354 .61788 .42117 .58193 .42998 .63917 .42335 .64386 Mtetra
0 0 0 r
.42335 .64386 .42998 .63917 .44007 .66261 .43421 .63945 Mtetra
.768 .593 .661 r
.43421 .63945 .44007 .66261 .4513 .64466 .44555 .61645 Mtetra
.699 .535 .662 r
.44555 .61645 .4513 .64466 .46245 .62742 .45663 .60235 Mtetra
.828 .623 .625 r
.45663 .60235 .46245 .62742 .47392 .58709 .46821 .55747 Mtetra
.707 .536 .655 r
.46821 .55747 .47392 .58709 .48508 .55524 .47916 .54115 Mtetra
.328 .398 .782 r
.47916 .54115 .48508 .55524 .49592 .54387 .48982 .54826 Mtetra
.644 .178 .131 r
.48982 .54826 .49592 .54387 .50663 .55522 .5006 .55447 Mtetra
.778 .284 .034 r
.5006 .55447 .50663 .55522 .51753 .54115 .51147 .56702 Mtetra
.778 .477 .477 r
.51147 .56702 .51753 .54115 .52846 .56568 .52248 .60462 Mtetra
.609 .333 .474 r
.52248 .60462 .52846 .56568 .53959 .58238 .53373 .61279 Mtetra
.575 .287 .441 r
.53373 .61279 .53959 .58238 .55094 .60444 .54508 .61598 Mtetra
.81 .464 .401 r
.54508 .61598 .55094 .60444 .56238 .61441 .55676 .64351 Mtetra
.212 0 .315 r
.55676 .64351 .56238 .61441 .57397 .62484 .56806 .62317 Mtetra
.868 .923 .862 r
.56806 .62317 .57397 .62484 .58546 .62265 .57945 .61188 Mtetra
.31 .458 .847 r
.57945 .61188 .58546 .62265 .59699 .61946 .59118 .61773 Mtetra
.796 .939 .922 r
.59118 .61773 .59699 .61946 .60876 .62325 .6027 .60957 Mtetra
.584 .562 .795 r
.6027 .60957 .60876 .62325 .62043 .62063 .61443 .60887 Mtetra
.777 .676 .752 r
.61443 .60887 .62043 .62063 .63219 .61885 .62587 .59653 Mtetra
.211 .248 .682 r
.62587 .59653 .63219 .61885 .64364 .60679 .63832 .61322 Mtetra
.323 0 0 r
.63832 .61322 .64364 .60679 .65606 .61912 .65024 .61124 Mtetra
.875 .757 .729 r
.65024 .61124 .65606 .61912 .66732 .60135 .66148 .59163 Mtetra
0 0 .563 r
.66148 .59163 .66732 .60135 .67814 .57548 .67433 .60827 Mtetra
.51 .233 .43 r
.67433 .60827 .67814 .57548 .69049 .58143 .68637 .6047 Mtetra
.266 0 .309 r
.68637 .6047 .69049 .58143 .70091 .55029 .69783 .5894 Mtetra
.39 .148 .423 r
.69783 .5894 .70091 .55029 .71093 .51507 .70917 .57256 Mtetra
.431 .204 .467 r
.70917 .57256 .71093 .51507 .72213 .5015 .72027 .55242 Mtetra
.096 0 .368 r
.72027 .55242 .72213 .5015 .73305 .48404 .72935 .50252 Mtetra
.191 0 .247 r
.72935 .50252 .73305 .48404 .74418 .47048 .74053 .48751 Mtetra
0 0 .051 r
.74053 .48751 .74418 .47048 .75636 .47127 .7508 .46035 Mtetra
.134 .337 .8 r
.7508 .46035 .75636 .47127 .7685 .47044 .7638 .47053 Mtetra
.944 .956 .737 r
.7638 .47053 .7685 .47044 .78273 .49413 .77472 .45291 Mtetra
.343 .271 .63 r
.77472 .45291 .78273 .49413 .79929 .54169 .78911 .47691 Mtetra
.356 .252 .597 r
.78911 .47691 .79929 .54169 .81343 .55737 .80485 .51301 Mtetra
.282 .227 .616 r
.80485 .51301 .81343 .55737 .82507 .54419 .82056 .54466 Mtetra
.966 .938 .67 r
.82056 .54466 .82507 .54419 .83278 .49115 .83139 .52245 Mtetra
.245 .026 .37 r
.83139 .52245 .83278 .49115 .84453 .48099 .84191 .49802 Mtetra
0 0 .078 r
.84191 .49802 .84453 .48099 .85246 .43483 .85166 .46737 Mtetra
.046 0 .325 r
.85166 .46737 .85246 .43483 .86766 .45718 .8604 .42889 Mtetra
.226 .231 .656 r
.8604 .42889 .86766 .45718 .88334 .48134 .87601 .45316 Mtetra
.134 .172 .636 r
.87601 .45316 .88334 .48134 .9008 .51801 .89253 .48263 Mtetra
.313 .27 .649 r
.89253 .48263 .9008 .51801 .91144 .49602 .90877 .50705 Mtetra
.786 .732 .205 r
.90877 .50705 .91144 .49602 .91996 .45801 .91674 .46337 Mtetra
.532 .256 .441 r
.34203 .6635 .35069 .62972 .35926 .66378 .35249 .6622 Mtetra
.936 .77 .651 r
.35249 .6622 .35926 .66378 .37022 .65208 .3648 .62403 Mtetra
.788 .593 .637 r
.3648 .62403 .37022 .65208 .38239 .61214 .37676 .58928 Mtetra
.712 .559 .679 r
.37676 .58928 .38239 .61214 .39411 .57889 .38766 .57618 Mtetra
.919 .561 .338 r
.38766 .57618 .39411 .57889 .40455 .57612 .39673 .60973 Mtetra
.657 .373 .479 r
.39673 .60973 .40455 .57612 .41354 .61788 .40676 .62413 Mtetra
.782 .401 .334 r
.40676 .62413 .41354 .61788 .42335 .64386 .4169 .64001 Mtetra
.843 .829 .834 r
.4169 .64001 .42335 .64386 .43421 .63945 .42799 .62898 Mtetra
.895 .702 .634 r
.42799 .62898 .43421 .63945 .44555 .61645 .43993 .58516 Mtetra
.735 .552 .645 r
.43993 .58516 .44555 .61645 .45663 .60235 .45116 .5623 Mtetra
.735 .539 .627 r
.45116 .5623 .45663 .60235 .46821 .55747 .46245 .5326 Mtetra
.232 .235 .657 r
.46245 .5326 .46821 .55747 .47916 .54115 .47288 .54855 Mtetra
.599 .174 .207 r
.47288 .54855 .47916 .54115 .48982 .54826 .48363 .55296 Mtetra
.843 .468 .342 r
.48363 .55296 .48982 .54826 .5006 .55447 .49429 .57687 Mtetra
.778 .47 .466 r
.49429 .57687 .5006 .55447 .51147 .56702 .50514 .61031 Mtetra
.682 .404 .495 r
.50514 .61031 .51147 .56702 .52248 .60462 .51631 .63448 Mtetra
.535 .248 .425 r
.51631 .63448 .52248 .60462 .53373 .61279 .52768 .63387 Mtetra
.483 .169 .358 r
.52768 .63387 .53373 .61279 .54508 .61598 .53911 .63099 Mtetra
0 0 0 r
.53911 .63099 .54508 .61598 .55676 .64351 .55045 .60998 Mtetra
.455 .36 .658 r
.55045 .60998 .55676 .64351 .56806 .62317 .56208 .61992 Mtetra
.915 .841 .758 r
.56208 .61992 .56806 .62317 .57945 .61188 .57341 .60164 Mtetra
.887 .717 .665 r
.57341 .60164 .57945 .61188 .59118 .61773 .58447 .57131 Mtetra
.586 .426 .632 r
.58447 .57131 .59118 .61773 .6027 .60957 .59602 .56916 Mtetra
.544 .406 .644 r
.59602 .56916 .6027 .60957 .61443 .60887 .60776 .57244 Mtetra
.717 .53 .637 r
.60776 .57244 .61443 .60887 .62587 .59653 .61885 .55026 Mtetra
.335 .251 .611 r
.61885 .55026 .62587 .59653 .63832 .61322 .63143 .57529 Mtetra
.675 .5 .641 r
.63143 .57529 .63832 .61322 .65024 .61124 .6428 .56054 Mtetra
.543 .392 .626 r
.6428 .56054 .65024 .61124 .66148 .59163 .65491 .56478 Mtetra
.32 .296 .675 r
.65491 .56478 .66148 .59163 .67433 .60827 .66763 .58036 Mtetra
.563 .452 .686 r
.66763 .58036 .67433 .60827 .68637 .6047 .67985 .58124 Mtetra
.631 .513 .701 r
.67985 .58124 .68637 .6047 .69783 .5894 .69186 .5766 Mtetra
0 .142 .683 r
.69186 .5766 .69783 .5894 .70917 .57256 .70508 .59272 Mtetra
.116 0 .226 r
.70508 .59272 .70917 .57256 .72027 .55242 .71644 .57419 Mtetra
0 0 .007 r
.71644 .57419 .72027 .55242 .72935 .50252 .72637 .53418 Mtetra
.197 0 .343 r
.72637 .53418 .72935 .50252 .74053 .48751 .73705 .50859 Mtetra
.264 0 .296 r
.73705 .50859 .74053 .48751 .7508 .46035 .74842 .49434 Mtetra
0 0 .248 r
.74842 .49434 .7508 .46035 .7638 .47053 .75741 .44894 Mtetra
.587 .495 .717 r
.75741 .44894 .7638 .47053 .77472 .45291 .76966 .44795 Mtetra
.371 .678 .977 r
.76966 .44795 .77472 .45291 .78911 .47691 .78216 .44917 Mtetra
0 0 .494 r
.78216 .44917 .78911 .47691 .80485 .51301 .79844 .49266 Mtetra
.474 .436 .736 r
.79844 .49266 .80485 .51301 .82056 .54466 .81171 .49837 Mtetra
.423 .319 .632 r
.81171 .49837 .82056 .54466 .83139 .52245 .82638 .51727 Mtetra
.314 .643 .967 r
.82638 .51727 .83139 .52245 .84191 .49802 .83962 .51943 Mtetra
0 0 .025 r
.83962 .51943 .84191 .49802 .85166 .46737 .84771 .4708 Mtetra
.991 .832 .459 r
.84771 .4708 .85166 .46737 .8604 .42889 .85578 .42486 Mtetra
0 .429 .839 r
.85578 .42486 .8604 .42889 .87601 .45316 .86934 .43065 Mtetra
.104 .18 .659 r
.86934 .43065 .87601 .45316 .89253 .48263 .88523 .45525 Mtetra
0 0 .527 r
.88523 .45525 .89253 .48263 .90877 .50705 .90391 .50053 Mtetra
.947 .815 .681 r
.90391 .50053 .90877 .50705 .91674 .46337 .91422 .47487 Mtetra
.846 .681 .677 r
.33574 .65172 .34203 .6635 .35249 .6622 .3476 .62451 Mtetra
.765 .564 .626 r
.3476 .62451 .35249 .6622 .3648 .62403 .35987 .58689 Mtetra
.63 .469 .645 r
.35987 .58689 .3648 .62403 .37676 .58928 .37052 .57974 Mtetra
.915 .525 .124 r
.37052 .57974 .37676 .58928 .38766 .57618 .37966 .60731 Mtetra
.727 .44 .491 r
.37966 .60731 .38766 .57618 .39673 .60973 .38903 .63518 Mtetra
.448 .154 .373 r
.38903 .63518 .39673 .60973 .40676 .62413 .39991 .62952 Mtetra
.027 0 0 r
.39991 .62952 .40676 .62413 .4169 .64001 .41077 .6251 Mtetra
.817 .654 .681 r
.41077 .6251 .4169 .64001 .42799 .62898 .42227 .60152 Mtetra
.792 .597 .636 r
.42227 .60152 .42799 .62898 .43993 .58516 .43399 .56692 Mtetra
.846 .65 .638 r
.43399 .56692 .43993 .58516 .45116 .5623 .44564 .52801 Mtetra
.45 .349 .648 r
.44564 .52801 .45116 .5623 .46245 .5326 .45608 .53789 Mtetra
.877 .536 .401 r
.45608 .53789 .46245 .5326 .47288 .54855 .46616 .57503 Mtetra
.596 .296 .431 r
.46616 .57503 .47288 .54855 .48363 .55296 .47702 .58026 Mtetra
.727 .427 .47 r
.47702 .58026 .48363 .55296 .49429 .57687 .48776 .60549 Mtetra
.688 .389 .463 r
.48776 .60549 .49429 .57687 .50514 .61031 .4988 .62373 Mtetra
.738 .388 .388 r
.4988 .62373 .50514 .61031 .51631 .63448 .51005 .64047 Mtetra
.992 .879 .597 r
.51005 .64047 .51631 .63448 .52768 .63387 .52152 .60485 Mtetra
.677 .52 .665 r
.52152 .60485 .52768 .63387 .53911 .63099 .53288 .59347 Mtetra
.601 .45 .649 r
.53288 .59347 .53911 .63099 .55045 .60998 .54428 .58988 Mtetra
.827 .637 .645 r
.54428 .58988 .55045 .60998 .56208 .61992 .55544 .55693 Mtetra
.639 .449 .61 r
.55544 .55693 .56208 .61992 .57341 .60164 .56668 .54171 Mtetra
.563 .396 .613 r
.56668 .54171 .57341 .60164 .58447 .57131 .57816 .5428 Mtetra
.78 .586 .637 r
.57816 .5428 .58447 .57131 .59602 .56916 .58907 .51214 Mtetra
.584 .413 .617 r
.58907 .51214 .59602 .56916 .60776 .57244 .60051 .50951 Mtetra
.604 .424 .611 r
.60051 .50951 .60776 .57244 .61885 .55026 .61188 .50223 Mtetra
.346 .255 .608 r
.61188 .50223 .61885 .55026 .63143 .57529 .62428 .5269 Mtetra
.645 .465 .626 r
.62428 .5269 .63143 .57529 .6428 .56054 .63561 .51411 Mtetra
.536 .391 .632 r
.63561 .51411 .6428 .56054 .65491 .56478 .64761 .51874 Mtetra
.425 .315 .625 r
.64761 .51874 .65491 .56478 .66763 .58036 .66026 .53577 Mtetra
.38 .287 .624 r
.66026 .53577 .66763 .58036 .67985 .58124 .67328 .5564 Mtetra
.683 .539 .683 r
.67328 .5564 .67985 .58124 .69186 .5766 .68497 .54593 Mtetra
.363 .31 .665 r
.68497 .54593 .69186 .5766 .70508 .59272 .69807 .56142 Mtetra
.442 .362 .671 r
.69807 .56142 .70508 .59272 .71644 .57419 .71109 .57216 Mtetra
.58 .9 .984 r
.71109 .57216 .71644 .57419 .72637 .53418 .72337 .56814 Mtetra
.387 .132 .402 r
.72337 .56814 .72637 .53418 .73705 .50859 .73501 .55365 Mtetra
.152 0 .371 r
.73501 .55365 .73705 .50859 .74842 .49434 .74484 .51362 Mtetra
0 0 0 r
.74484 .51362 .74842 .49434 .75741 .44894 .75404 .4681 Mtetra
.172 0 .248 r
.75404 .4681 .75741 .44894 .76966 .44795 .76523 .45178 Mtetra
.772 .938 .589 r
.76523 .45178 .76966 .44795 .78216 .44917 .7764 .43582 Mtetra
.204 .34 .78 r
.7764 .43582 .78216 .44917 .79844 .49266 .78984 .44676 Mtetra
.466 .347 .634 r
.78984 .44676 .79844 .49266 .81171 .49837 .80369 .46032 Mtetra
.206 .187 .615 r
.80369 .46032 .81171 .49837 .82638 .51727 .81949 .49257 Mtetra
.279 .286 .688 r
.81949 .49257 .82638 .51727 .83962 .51943 .83421 .51021 Mtetra
.928 .759 .652 r
.83421 .51021 .83962 .51943 .84771 .4708 .84422 .47936 Mtetra
0 0 0 r
.84422 .47936 .84771 .4708 .85578 .42486 .85547 .46181 Mtetra
.141 0 .365 r
.85547 .46181 .85578 .42486 .86934 .43065 .86454 .42502 Mtetra
0 .008 .531 r
.86454 .42502 .86934 .43065 .88523 .45525 .87942 .44067 Mtetra
.021 .201 .709 r
.87942 .44067 .88523 .45525 .90391 .50053 .89483 .45891 Mtetra
.291 .241 .628 r
.89483 .45891 .90391 .50053 .91422 .47487 .91197 .4892 Mtetra
.843 .671 .669 r
.32951 .63847 .33574 .65172 .3476 .62451 .34154 .60914 Mtetra
.852 .663 .646 r
.34154 .60914 .3476 .62451 .35987 .58689 .35388 .57147 Mtetra
.388 .417 .769 r
.35388 .57147 .35987 .58689 .37052 .57974 .3639 .57722 Mtetra
.929 .605 .405 r
.3639 .57722 .37052 .57974 .37966 .60731 .372 .62685 Mtetra
.606 .283 .397 r
.372 .62685 .37966 .60731 .38903 .63518 .38238 .63219 Mtetra
.75 .231 0 r
.38238 .63219 .38903 .63518 .39991 .62952 .39261 .64369 Mtetra
.954 .895 .509 r
.39261 .64369 .39991 .62952 .41077 .6251 .40476 .60658 Mtetra
.881 .665 .607 r
.40476 .60658 .41077 .6251 .42227 .60152 .41765 .54202 Mtetra
.656 .464 .612 r
.41765 .54202 .42227 .60152 .43399 .56692 .42879 .52371 Mtetra
.281 .208 .593 r
.42879 .52371 .43399 .56692 .44564 .52801 .43876 .54768 Mtetra
.654 .332 .415 r
.43876 .54768 .44564 .52801 .45608 .53789 .44928 .55758 Mtetra
.765 .45 .453 r
.44928 .55758 .45608 .53789 .46616 .57503 .4596 .58466 Mtetra
.779 .417 .372 r
.4596 .58466 .46616 .57503 .47702 .58026 .4703 .60372 Mtetra
.656 .344 .432 r
.4703 .60372 .47702 .58026 .48776 .60549 .48129 .61523 Mtetra
.718 .337 .328 r
.48129 .61523 .48776 .60549 .4988 .62373 .49244 .62747 Mtetra
.943 .962 .709 r
.49244 .62747 .4988 .62373 .51005 .64047 .50393 .60806 Mtetra
.781 .58 .629 r
.50393 .60806 .51005 .64047 .52152 .60485 .51539 .57228 Mtetra
.713 .535 .647 r
.51539 .57228 .52152 .60485 .53288 .59347 .5267 .55317 Mtetra
.699 .512 .632 r
.5267 .55317 .53288 .59347 .54428 .58988 .53794 .5326 Mtetra
.69 .49 .611 r
.53794 .5326 .54428 .58988 .55544 .55693 .54905 .50543 Mtetra
.499 .357 .619 r
.54905 .50543 .55544 .55693 .56668 .54171 .56047 .51495 Mtetra
.801 .602 .633 r
.56047 .51495 .56668 .54171 .57816 .5428 .57137 .48061 Mtetra
.549 .384 .609 r
.57137 .48061 .57816 .5428 .58907 .51214 .5828 .48388 Mtetra
.562 .446 .679 r
.5828 .48388 .58907 .51214 .60051 .50951 .59427 .48459 Mtetra
.604 .486 .692 r
.59427 .48459 .60051 .50951 .61188 .50223 .60573 .48202 Mtetra
.555 .481 .727 r
.60573 .48202 .61188 .50223 .62428 .5269 .61736 .48292 Mtetra
.71 .514 .622 r
.61736 .48292 .62428 .5269 .63561 .51411 .62818 .45748 Mtetra
.517 .366 .615 r
.62818 .45748 .63561 .51411 .64761 .51874 .64015 .46562 Mtetra
.442 .316 .614 r
.64015 .46562 .64761 .51874 .66026 .53577 .65263 .48293 Mtetra
.406 .292 .611 r
.65263 .48293 .66026 .53577 .67328 .5564 .6655 .50429 Mtetra
.465 .336 .619 r
.6655 .50429 .67328 .5564 .68497 .54593 .67828 .5187 Mtetra
.146 .177 .636 r
.67828 .5187 .68497 .54593 .69807 .56142 .69172 .54221 Mtetra
.47 .443 .746 r
.69172 .54221 .69807 .56142 .71109 .57216 .7044 .54734 Mtetra
.246 .26 .678 r
.7044 .54734 .71109 .57216 .72337 .56814 .71796 .56509 Mtetra
.95 .862 .717 r
.71796 .56509 .72337 .56814 .73501 .55365 .72918 .5428 Mtetra
.827 .716 .742 r
.72918 .5428 .73501 .55365 .74484 .51362 .74072 .52661 Mtetra
0 0 0 r
.74072 .52661 .74484 .51362 .75404 .4681 .75109 .49481 Mtetra
0 0 .191 r
.75109 .49481 .75404 .4681 .76523 .45178 .76089 .45777 Mtetra
.896 .895 .477 r
.76089 .45777 .76523 .45178 .7764 .43582 .77127 .4305 Mtetra
.255 .598 .951 r
.77127 .4305 .7764 .43582 .78984 .44676 .78406 .4335 Mtetra
.724 .643 .768 r
.78406 .4335 .78984 .44676 .80369 .46032 .79594 .4249 Mtetra
0 .051 .561 r
.79594 .4249 .80369 .46032 .81949 .49257 .81255 .46728 Mtetra
0 .085 .603 r
.81255 .46728 .81949 .49257 .83421 .51021 .82852 .4984 Mtetra
.651 .636 .822 r
.82852 .4984 .83421 .51021 .84422 .47936 .8413 .49446 Mtetra
0 0 0 r
.8413 .49446 .84422 .47936 .85547 .46181 .85138 .46417 Mtetra
.95 .925 .57 r
.85138 .46417 .85547 .46181 .86454 .42502 .86181 .43871 Mtetra
0 0 0 r
.86181 .43871 .86454 .42502 .87942 .44067 .87112 .40434 Mtetra
.077 .106 .589 r
.87112 .40434 .87942 .44067 .89483 .45891 .88914 .44568 Mtetra
.208 .35 .788 r
.88914 .44568 .89483 .45891 .91197 .4892 .90398 .4572 Mtetra
.793 .593 .63 r
.32432 .60783 .32951 .63847 .34154 .60914 .33698 .56759 Mtetra
.522 .383 .632 r
.33698 .56759 .34154 .60914 .35388 .57147 .34698 .57246 Mtetra
.875 .506 .344 r
.34698 .57246 .35388 .57147 .3639 .57722 .35602 .59782 Mtetra
.744 .436 .461 r
.35602 .59782 .3639 .57722 .372 .62685 .36538 .62119 Mtetra
.737 .234 0 r
.36538 .62119 .372 .62685 .38238 .63219 .37542 .63441 Mtetra
.966 .854 .679 r
.37542 .63441 .38238 .63219 .39261 .64369 .38736 .60579 Mtetra
.78 .573 .62 r
.38736 .60579 .39261 .64369 .40476 .60658 .39972 .56294 Mtetra
.764 .555 .616 r
.39972 .56294 .40476 .60658 .41765 .54202 .41186 .52049 Mtetra
0 .05 .585 r
.41186 .52049 .41765 .54202 .42879 .52371 .42178 .54055 Mtetra
.592 .253 .365 r
.42178 .54055 .42879 .52371 .43876 .54768 .43236 .54482 Mtetra
.934 .596 .369 r
.43236 .54482 .43876 .54768 .44928 .55758 .44191 .59378 Mtetra
.644 .359 .472 r
.44191 .59378 .44928 .55758 .4596 .58466 .45263 .60748 Mtetra
.669 .354 .432 r
.45263 .60748 .4596 .58466 .4703 .60372 .46353 .62039 Mtetra
.616 .272 .365 r
.46353 .62039 .4703 .60372 .48129 .61523 .47469 .62654 Mtetra
.821 .886 .458 r
.47469 .62654 .48129 .61523 .49244 .62747 .48632 .60109 Mtetra
.818 .615 .628 r
.48632 .60109 .49244 .62747 .50393 .60806 .49797 .56039 Mtetra
.67 .484 .624 r
.49797 .56039 .50393 .60806 .51539 .57228 .50931 .54266 Mtetra
.743 .56 .647 r
.50931 .54266 .51539 .57228 .5267 .55317 .5206 .51966 Mtetra
.759 .563 .631 r
.5206 .51966 .5267 .55317 .53794 .5326 .53179 .48941 Mtetra
.667 .486 .63 r
.53179 .48941 .53794 .5326 .54905 .50543 .54292 .47387 Mtetra
.573 .442 .664 r
.54292 .47387 .54905 .50543 .56047 .51495 .55416 .47355 Mtetra
.699 .509 .628 r
.55416 .47355 .56047 .51495 .57137 .48061 .56519 .45232 Mtetra
.417 .348 .673 r
.56519 .45232 .57137 .48061 .5828 .48388 .57668 .46264 Mtetra
.73 .578 .684 r
.57668 .46264 .5828 .48388 .59427 .48459 .58781 .44826 Mtetra
.581 .437 .65 r
.58781 .44826 .59427 .48459 .60573 .48202 .59922 .44689 Mtetra
.483 .373 .653 r
.59922 .44689 .60573 .48202 .61736 .48292 .61097 .4549 Mtetra
.759 .573 .645 r
.61097 .4549 .61736 .48292 .62818 .45748 .62181 .43023 Mtetra
.493 .404 .684 r
.62181 .43023 .62818 .45748 .64015 .46562 .63363 .43589 Mtetra
.561 .441 .673 r
.63363 .43589 .64015 .46562 .65263 .48293 .64537 .4367 Mtetra
.324 .243 .608 r
.64537 .4367 .65263 .48293 .6655 .50429 .65827 .46233 Mtetra
.511 .38 .639 r
.65827 .46233 .6655 .50429 .67828 .5187 .67056 .4691 Mtetra
.515 .372 .626 r
.67056 .4691 .67828 .5187 .69172 .54221 .68302 .47655 Mtetra
.407 .283 .597 r
.68302 .47655 .69172 .54221 .7044 .54734 .69665 .50279 Mtetra
.2 .164 .59 r
.69665 .50279 .7044 .54734 .71796 .56509 .71107 .53775 Mtetra
.531 .435 .692 r
.71107 .53775 .71796 .56509 .72918 .5428 .72387 .54087 Mtetra
.28 0 0 r
.72387 .54087 .72918 .5428 .74072 .52661 .73692 .54607 Mtetra
0 0 .142 r
.73692 .54607 .74072 .52661 .75109 .49481 .748 .52164 Mtetra
.153 0 .298 r
.748 .52164 .75109 .49481 .76089 .45777 .75904 .49812 Mtetra
.001 0 .311 r
.75904 .49812 .76089 .45777 .77127 .4305 .76821 .4521 Mtetra
0 0 .08 r
.76821 .4521 .77127 .4305 .78406 .4335 .77781 .41475 Mtetra
.737 .6 .705 r
.77781 .41475 .78406 .4335 .79594 .4249 .7893 .40155 Mtetra
0 0 .46 r
.7893 .40155 .79594 .4249 .81255 .46728 .80574 .4431 Mtetra
0 0 .53 r
.80574 .4431 .81255 .46728 .82852 .4984 .82222 .48048 Mtetra
.337 .375 .753 r
.82222 .48048 .82852 .4984 .8413 .49446 .83643 .49086 Mtetra
.235 .664 .958 r
.83643 .49086 .8413 .49446 .85138 .46417 .8499 .49243 Mtetra
0 0 .239 r
.8499 .49243 .85138 .46417 .86181 .43871 .85893 .45178 Mtetra
.837 .74 .219 r
.85893 .45178 .86181 .43871 .87112 .40434 .86628 .39848 Mtetra
0 .057 .581 r
.86628 .39848 .87112 .40434 .88914 .44568 .88121 .41326 Mtetra
0 .066 .578 r
.88121 .41326 .88914 .44568 .90398 .4572 .89961 .45504 Mtetra
.84 .65 .646 r
.31834 .59048 .32432 .60783 .33698 .56759 .33087 .55356 Mtetra
.896 .535 .064 r
.33087 .55356 .33698 .56759 .34698 .57246 .33939 .58421 Mtetra
.779 .443 .419 r
.33939 .58421 .34698 .57246 .35602 .59782 .34866 .60553 Mtetra
.736 .353 .325 r
.34866 .60553 .35602 .59782 .36538 .62119 .3586 .61781 Mtetra
.8 .853 .89 r
.3586 .61781 .36538 .62119 .37542 .63441 .36964 .60975 Mtetra
.79 .602 .647 r
.36964 .60975 .37542 .63441 .38736 .60579 .38167 .5795 Mtetra
.83 .622 .622 r
.38167 .5795 .38736 .60579 .39972 .56294 .39431 .53097 Mtetra
.685 .516 .652 r
.39431 .53097 .39972 .56294 .41186 .52049 .4054 .51708 Mtetra
.926 .567 .324 r
.4054 .51708 .41186 .52049 .42178 .54055 .41476 .55341 Mtetra
.755 .41 .401 r
.41476 .55341 .42178 .54055 .43236 .54482 .42499 .57187 Mtetra
.792 .494 .485 r
.42499 .57187 .43236 .54482 .44191 .59378 .43469 .61635 Mtetra
.47 .158 .354 r
.43469 .61635 .44191 .59378 .45263 .60748 .44591 .61297 Mtetra
.787 .387 .295 r
.44591 .61297 .45263 .60748 .46353 .62039 .45678 .62932 Mtetra
.997 .834 .556 r
.45678 .62932 .46353 .62039 .47469 .62654 .469 .57629 Mtetra
.715 .513 .616 r
.469 .57629 .47469 .62654 .48632 .60109 .48062 .54585 Mtetra
.712 .508 .61 r
.48062 .54585 .48632 .60109 .49797 .56039 .49213 .513 Mtetra
.69 .497 .621 r
.49213 .513 .49797 .56039 .50931 .54266 .50341 .49072 Mtetra
.577 .411 .62 r
.50341 .49072 .50931 .54266 .5206 .51966 .51455 .48897 Mtetra
.672 .51 .658 r
.51455 .48897 .5206 .51966 .53179 .48941 .52574 .47754 Mtetra
.857 .694 .68 r
.52574 .47754 .53179 .48941 .54292 .47387 .53687 .45234 Mtetra
.319 .319 .703 r
.53687 .45234 .54292 .47387 .55416 .47355 .54817 .4636 Mtetra
.758 .693 .789 r
.54817 .4636 .55416 .47355 .56519 .45232 .5594 .45448 Mtetra
.799 .998 .794 r
.5594 .45448 .56519 .45232 .57668 .46264 .5706 .44331 Mtetra
.22 .273 .705 r
.5706 .44331 .57668 .46264 .58781 .44826 .58226 .45654 Mtetra
.496 .062 .143 r
.58226 .45654 .58781 .44826 .59922 .44689 .59382 .45784 Mtetra
.46 .063 .199 r
.59382 .45784 .59922 .44689 .61097 .4549 .60541 .45717 Mtetra
.974 .924 .668 r
.60541 .45717 .61097 .4549 .62181 .43023 .61639 .43357 Mtetra
0 0 0 r
.61639 .43357 .62181 .43023 .63363 .43589 .62795 .42997 Mtetra
.736 .792 .897 r
.62795 .42997 .63363 .43589 .64537 .4367 .63946 .42389 Mtetra
.002 .215 .727 r
.63946 .42389 .64537 .4367 .65827 .46233 .65181 .4371 Mtetra
.681 .534 .679 r
.65181 .4371 .65827 .46233 .67056 .4691 .66327 .42668 Mtetra
.26 .206 .605 r
.66327 .42668 .67056 .4691 .68302 .47655 .67664 .45497 Mtetra
.162 .222 .678 r
.67664 .45497 .68302 .47655 .69665 .50279 .68975 .47279 Mtetra
.121 .149 .616 r
.68975 .47279 .69665 .50279 .71107 .53775 .7036 .49974 Mtetra
.36 .288 .639 r
.7036 .49974 .71107 .53775 .72387 .54087 .71727 .51873 Mtetra
.1 .181 .662 r
.71727 .51873 .72387 .54087 .73692 .54607 .73131 .53967 Mtetra
.653 .769 .934 r
.73131 .53967 .73692 .54607 .748 .52164 .74389 .5359 Mtetra
.186 0 .157 r
.74389 .5359 .748 .52164 .75904 .49812 .756 .52478 Mtetra
0 0 .014 r
.756 .52478 .75904 .49812 .76821 .4521 .76471 .46958 Mtetra
.72 .692 .153 r
.76471 .46958 .76821 .4521 .77781 .41475 .7737 .42226 Mtetra
0 0 0 r
.7737 .42226 .77781 .41475 .7893 .40155 .78529 .40905 Mtetra
.764 .332 .225 r
.78529 .40905 .7893 .40155 .80574 .4431 .79958 .42609 Mtetra
0 0 .55 r
.79958 .42609 .80574 .4431 .82222 .48048 .81516 .45446 Mtetra
.226 .244 .67 r
.81516 .45446 .82222 .48048 .83643 .49086 .83032 .47521 Mtetra
.089 .239 .725 r
.83032 .47521 .83643 .49086 .8499 .49243 .84532 .49166 Mtetra
.982 .906 .645 r
.84532 .49166 .8499 .49243 .85893 .45178 .85603 .46567 Mtetra
.9 .746 .246 r
.85603 .46567 .85893 .45178 .86628 .39848 .86186 .39672 Mtetra
.948 .942 .745 r
.86186 .39672 .86628 .39848 .88121 .41326 .87304 .37861 Mtetra
.106 .131 .603 r
.87304 .37861 .88121 .41326 .89961 .45504 .89076 .41572 Mtetra
.823 .665 .687 r
.31208 .5773 .31834 .59048 .33087 .55356 .32381 .55452 Mtetra
.892 .548 .387 r
.32381 .55452 .33087 .55356 .33939 .58421 .33215 .58766 Mtetra
.892 .57 .431 r
.33215 .58766 .33939 .58421 .34866 .60553 .34016 .63182 Mtetra
.242 0 .275 r
.34016 .63182 .34866 .60553 .3586 .61781 .35159 .61756 Mtetra
.927 .878 .768 r
.35159 .61756 .3586 .61781 .36964 .60975 .36317 .59966 Mtetra
.889 .704 .645 r
.36317 .59966 .36964 .60975 .38167 .5795 .3757 .55998 Mtetra
.823 .635 .649 r
.3757 .55998 .38167 .5795 .39431 .53097 .38775 .52714 Mtetra
.731 .841 .932 r
.38775 .52714 .39431 .53097 .4054 .51708 .39857 .52169 Mtetra
.891 .561 .418 r
.39857 .52169 .4054 .51708 .41476 .55341 .40763 .56585 Mtetra
.777 .434 .407 r
.40763 .56585 .41476 .55341 .42499 .57187 .41779 .58763 Mtetra
.786 .459 .435 r
.41779 .58763 .42499 .57187 .43469 .61635 .42799 .61533 Mtetra
.727 .204 0 r
.42799 .61533 .43469 .61635 .44591 .61297 .4389 .62585 Mtetra
.98 .881 .52 r
.4389 .62585 .44591 .61297 .45678 .62932 .45114 .58328 Mtetra
.661 .479 .627 r
.45114 .58328 .45678 .62932 .469 .57629 .46264 .56792 Mtetra
.923 .721 .612 r
.46264 .56792 .469 .57629 .48062 .54585 .47468 .51596 Mtetra
.731 .551 .649 r
.47468 .51596 .48062 .54585 .49213 .513 .48605 .4953 Mtetra
.831 .648 .654 r
.48605 .4953 .49213 .513 .50341 .49072 .49742 .46524 Mtetra
.557 .452 .69 r
.49742 .46524 .50341 .49072 .51455 .48897 .50851 .466 Mtetra
.634 .512 .697 r
.50851 .466 .51455 .48897 .52574 .47754 .51968 .4611 Mtetra
.745 .614 .713 r
.51968 .4611 .52574 .47754 .53687 .45234 .53087 .44844 Mtetra
.878 .441 .1 r
.53087 .44844 .53687 .45234 .54817 .4636 .54226 .47208 Mtetra
.589 .164 .204 r
.54226 .47208 .54817 .4636 .5594 .45448 .55372 .47659 Mtetra
.527 .209 .372 r
.55372 .47659 .5594 .45448 .5706 .44331 .56522 .47677 Mtetra
.431 .16 .4 r
.56522 .47677 .5706 .44331 .58226 .45654 .57664 .46746 Mtetra
.385 0 .157 r
.57664 .46746 .58226 .45654 .59382 .45784 .58821 .46466 Mtetra
.798 .918 .532 r
.58821 .46466 .59382 .45784 .60541 .45717 .59943 .44545 Mtetra
.762 .672 .764 r
.59943 .44545 .60541 .45717 .61639 .43357 .61083 .43481 Mtetra
.789 .312 .094 r
.61083 .43481 .61639 .43357 .62795 .42997 .62305 .44994 Mtetra
0 0 0 r
.62305 .44994 .62795 .42997 .63946 .42389 .63369 .41529 Mtetra
0 .07 .621 r
.63369 .41529 .63946 .42389 .65181 .4371 .64605 .42881 Mtetra
.754 .735 .835 r
.64605 .42881 .65181 .4371 .66327 .42668 .65766 .42098 Mtetra
.85 .818 .817 r
.65766 .42098 .66327 .42668 .67664 .45497 .66909 .40869 Mtetra
.477 .35 .628 r
.66909 .40869 .67664 .45497 .68975 .47279 .68169 .4196 Mtetra
.332 .24 .599 r
.68169 .4196 .68975 .47279 .7036 .49974 .69545 .44838 Mtetra
.188 .144 .573 r
.69545 .44838 .7036 .49974 .71727 .51873 .71023 .48906 Mtetra
.044 .099 .596 r
.71023 .48906 .71727 .51873 .73131 .53967 .72477 .51943 Mtetra
.047 .162 .662 r
.72477 .51943 .73131 .53967 .74389 .5359 .739 .54023 Mtetra
.977 .892 .536 r
.739 .54023 .74389 .5359 .756 .52478 .74961 .50665 Mtetra
.574 .519 .756 r
.74961 .50665 .756 .52478 .76471 .46958 .76253 .50615 Mtetra
0 0 .244 r
.76253 .50615 .76471 .46958 .7737 .42226 .77166 .45694 Mtetra
.092 0 .32 r
.77166 .45694 .7737 .42226 .78529 .40905 .78171 .42251 Mtetra
0 0 0 r
.78171 .42251 .78529 .40905 .79958 .42609 .79166 .38928 Mtetra
.363 .294 .645 r
.79166 .38928 .79958 .42609 .81516 .45446 .80625 .40823 Mtetra
.305 .238 .615 r
.80625 .40823 .81516 .45446 .83032 .47521 .8221 .43769 Mtetra
.115 .128 .595 r
.8221 .43769 .83032 .47521 .84532 .49166 .8391 .47522 Mtetra
.739 .626 .734 r
.8391 .47522 .84532 .49166 .85603 .46567 .85135 .46347 Mtetra
.991 .861 .611 r
.85135 .46347 .85603 .46567 .86186 .39672 .86143 .43188 Mtetra
0 0 .284 r
.86143 .43188 .86186 .39672 .87304 .37861 .86937 .38305 Mtetra
.314 0 0 r
.86937 .38305 .87304 .37861 .89076 .41572 .88269 .38262 Mtetra
.667 .668 .841 r
.30553 .56815 .31208 .5773 .32381 .55452 .31609 .56433 Mtetra
.849 .532 .451 r
.31609 .56433 .32381 .55452 .33215 .58766 .3241 .60283 Mtetra
.715 .38 .409 r
.3241 .60283 .33215 .58766 .34016 .63182 .33381 .61759 Mtetra
.815 .659 .689 r
.33381 .61759 .34016 .63182 .35159 .61756 .34569 .59551 Mtetra
.746 .585 .675 r
.34569 .59551 .35159 .61756 .36317 .59966 .35726 .57793 Mtetra
.86 .649 .615 r
.35726 .57793 .36317 .59966 .3757 .55998 .37069 .52073 Mtetra
.652 .48 .638 r
.37069 .52073 .3757 .55998 .38775 .52714 .38175 .50937 Mtetra
0 0 .497 r
.38175 .50937 .38775 .52714 .39857 .52169 .39149 .52972 Mtetra
.889 .576 .45 r
.39149 .52972 .39857 .52169 .40763 .56585 .40003 .58711 Mtetra
.756 .441 .453 r
.40003 .58711 .40763 .56585 .41779 .58763 .41009 .61368 Mtetra
.42 .123 .351 r
.41009 .61368 .41779 .58763 .42799 .61533 .42145 .60692 Mtetra
.777 .726 .805 r
.42145 .60692 .42799 .61533 .4389 .62585 .43291 .59725 Mtetra
.786 .591 .637 r
.43291 .59725 .4389 .62585 .45114 .58328 .44495 .56431 Mtetra
.849 .652 .636 r
.44495 .56431 .45114 .58328 .46264 .56792 .45697 .52474 Mtetra
.715 .52 .624 r
.45697 .52474 .46264 .56792 .47468 .51596 .46856 .49864 Mtetra
.831 .65 .657 r
.46856 .49864 .47468 .51596 .48605 .4953 .48008 .4692 Mtetra
.688 .534 .672 r
.48008 .4692 .48605 .4953 .49742 .46524 .49127 .45758 Mtetra
0 .276 .776 r
.49127 .45758 .49742 .46524 .50851 .466 .50233 .46569 Mtetra
.246 .757 .856 r
.50233 .46569 .50851 .466 .51968 .4611 .51354 .46407 Mtetra
.745 .28 .144 r
.51354 .46407 .51968 .4611 .53087 .44844 .52483 .47564 Mtetra
.485 .188 .387 r
.52483 .47564 .53087 .44844 .54226 .47208 .53621 .4722 Mtetra
.895 .501 .266 r
.53621 .4722 .54226 .47208 .55372 .47659 .54791 .50297 Mtetra
.458 .161 .372 r
.54791 .50297 .55372 .47659 .56522 .47677 .5595 .49792 Mtetra
.375 .065 .306 r
.5595 .49792 .56522 .47677 .57664 .46746 .5711 .49029 Mtetra
.616 .292 .399 r
.5711 .49029 .57664 .46746 .58821 .46466 .58301 .4979 Mtetra
.112 0 .289 r
.58301 .4979 .58821 .46466 .59943 .44545 .59426 .47041 Mtetra
.464 .161 .366 r
.59426 .47041 .59943 .44545 .61083 .43481 .60599 .466 Mtetra
.565 .269 .424 r
.60599 .466 .61083 .43481 .62305 .44994 .61799 .46915 Mtetra
0 0 .115 r
.61799 .46915 .62305 .44994 .63369 .41529 .62928 .448 Mtetra
0 0 .229 r
.62928 .448 .63369 .41529 .64605 .42881 .63992 .41208 Mtetra
.666 .575 .743 r
.63992 .41208 .64605 .42881 .65766 .42098 .65162 .40612 Mtetra
.565 .539 .785 r
.65162 .40612 .65766 .42098 .66909 .40869 .66362 .40597 Mtetra
.605 .049 0 r
.66362 .40597 .66909 .40869 .68169 .4196 .67626 .417 Mtetra
.736 .925 .954 r
.67626 .417 .68169 .4196 .69545 .44838 .68813 .41044 Mtetra
.288 .236 .624 r
.68813 .41044 .69545 .44838 .71023 .48906 .70176 .43394 Mtetra
.167 .125 .562 r
.70176 .43394 .71023 .48906 .72477 .51943 .71702 .47936 Mtetra
.236 .199 .612 r
.71702 .47936 .72477 .51943 .739 .54023 .73164 .50816 Mtetra
.621 .479 .667 r
.73164 .50816 .739 .54023 .74961 .50665 .74417 .50234 Mtetra
.122 .566 .921 r
.74417 .50234 .74961 .50665 .76253 .50615 .75743 .50571 Mtetra
.992 .863 .604 r
.75743 .50571 .76253 .50615 .77166 .45694 .76793 .47225 Mtetra
.788 .74 .216 r
.76793 .47225 .77166 .45694 .78171 .42251 .77713 .42519 Mtetra
.989 .875 .534 r
.77713 .42519 .78171 .42251 .79166 .38928 .78703 .38976 Mtetra
.677 .129 0 r
.78703 .38976 .79166 .38928 .80625 .40823 .801 .40153 Mtetra
0 0 .438 r
.801 .40153 .80625 .40823 .8221 .43769 .81584 .42043 Mtetra
0 0 .515 r
.81584 .42043 .8221 .43769 .8391 .47522 .83218 .45175 Mtetra
.303 .312 .704 r
.83218 .45175 .8391 .47522 .85135 .46347 .84719 .46681 Mtetra
.972 .874 .489 r
.84719 .46681 .85135 .46347 .86143 .43188 .85694 .43088 Mtetra
.999 .797 .482 r
.85694 .43088 .86143 .43188 .86937 .38305 .86432 .37588 Mtetra
.219 .511 .911 r
.86432 .37588 .86937 .38305 .88269 .38262 .87835 .38115 Mtetra
.213 .226 .656 r
.29997 .54425 .30553 .56815 .31609 .56433 .30933 .55796 Mtetra
.939 .587 .325 r
.30933 .55796 .31609 .56433 .3241 .60283 .31738 .59469 Mtetra
.942 .579 .273 r
.31738 .59469 .3241 .60283 .33381 .61759 .32586 .62943 Mtetra
.995 .843 .575 r
.32586 .62943 .33381 .61759 .34569 .59551 .33959 .57714 Mtetra
.821 .64 .657 r
.33959 .57714 .34569 .59551 .35726 .57793 .35187 .54672 Mtetra
.767 .573 .636 r
.35187 .54672 .35726 .57793 .37069 .52073 .36404 .51586 Mtetra
0 .246 .687 r
.36404 .51586 .37069 .52073 .38175 .50937 .37432 .52209 Mtetra
.823 .497 .439 r
.37432 .52209 .38175 .50937 .39149 .52972 .38354 .55541 Mtetra
.805 .507 .485 r
.38354 .55541 .39149 .52972 .40003 .58711 .39244 .60368 Mtetra
.746 .413 .42 r
.39244 .60368 .40003 .58711 .41009 .61368 .40277 .62414 Mtetra
.763 .894 .492 r
.40277 .62414 .41009 .61368 .42145 .60692 .41469 .60346 Mtetra
.936 .776 .658 r
.41469 .60346 .42145 .60692 .43291 .59725 .42697 .56853 Mtetra
.836 .622 .612 r
.42697 .56853 .43291 .59725 .44495 .56431 .43957 .51468 Mtetra
.666 .477 .62 r
.43957 .51468 .44495 .56431 .45697 .52474 .45105 .49699 Mtetra
.784 .59 .638 r
.45105 .49699 .45697 .52474 .46856 .49864 .46273 .46587 Mtetra
.675 .507 .651 r
.46273 .46587 .46856 .49864 .48008 .4692 .47397 .45303 Mtetra
.676 .581 .741 r
.47397 .45303 .48008 .4692 .49127 .45758 .48512 .4467 Mtetra
.82 .421 0 r
.48512 .4467 .49127 .45758 .50233 .46569 .496 .47347 Mtetra
.593 .158 .185 r
.496 .47347 .50233 .46569 .51354 .46407 .50726 .47821 Mtetra
.51 .141 .275 r
.50726 .47821 .51354 .46407 .52483 .47564 .51864 .47882 Mtetra
.896 .532 .344 r
.51864 .47882 .52483 .47564 .53621 .4722 .53018 .51757 Mtetra
.529 .261 .452 r
.53018 .51757 .53621 .4722 .54791 .50297 .54185 .51615 Mtetra
.715 .347 .35 r
.54185 .51615 .54791 .50297 .5595 .49792 .55374 .5306 Mtetra
.509 .221 .412 r
.55374 .5306 .5595 .49792 .5711 .49029 .5656 .52832 Mtetra
.508 .231 .429 r
.5656 .52832 .5711 .49029 .58301 .4979 .5775 .52523 Mtetra
.234 0 .297 r
.5775 .52523 .58301 .4979 .59426 .47041 .58917 .50795 Mtetra
.403 .142 .4 r
.58917 .50795 .59426 .47041 .60599 .466 .60091 .4953 Mtetra
.29 .028 .332 r
.60091 .4953 .60599 .466 .61799 .46915 .61253 .47926 Mtetra
.046 0 0 r
.61253 .47926 .61799 .46915 .62928 .448 .62433 .46998 Mtetra
.099 0 .212 r
.62433 .46998 .62928 .448 .63992 .41208 .6358 .45105 Mtetra
0 0 .254 r
.6358 .45105 .63992 .41208 .65162 .40612 .64625 .40838 Mtetra
.93 .97 .701 r
.64625 .40838 .65162 .40612 .66362 .40597 .65751 .38996 Mtetra
.343 .394 .77 r
.65751 .38996 .66362 .40597 .67626 .417 .66998 .39787 Mtetra
.68 .566 .72 r
.66998 .39787 .67626 .417 .68813 .41044 .68177 .38994 Mtetra
.258 .295 .71 r
.68177 .38994 .68813 .41044 .70176 .43394 .69478 .40345 Mtetra
.098 .13 .606 r
.69478 .40345 .70176 .43394 .71702 .47936 .70887 .43159 Mtetra
.05 .054 .541 r
.70887 .43159 .71702 .47936 .73164 .50816 .72454 .47955 Mtetra
.206 .217 .65 r
.72454 .47955 .73164 .50816 .74417 .50234 .73892 .50149 Mtetra
.806 .316 0 r
.73892 .50149 .74417 .50234 .75743 .50571 .75348 .52206 Mtetra
.75 .725 .197 r
.75348 .52206 .75743 .50571 .76793 .47225 .76324 .4764 Mtetra
.995 .835 .48 r
.76324 .4764 .76793 .47225 .77713 .42519 .77248 .42792 Mtetra
.991 .869 .528 r
.77248 .42792 .77713 .42519 .78703 .38976 .78236 .39072 Mtetra
.678 .974 .802 r
.78236 .39072 .78703 .38976 .801 .40153 .7945 .3813 Mtetra
.255 .3 .717 r
.7945 .3813 .801 .40153 .81584 .42043 .80889 .39574 Mtetra
0 0 .456 r
.80889 .39574 .81584 .42043 .83218 .45175 .82644 .44032 Mtetra
0 0 .473 r
.82644 .44032 .83218 .45175 .84719 .46681 .84258 .4664 Mtetra
.999 .838 .53 r
.84258 .4664 .84719 .46681 .85694 .43088 .85179 .42428 Mtetra
.978 .786 .578 r
.85179 .42428 .85694 .43088 .86432 .37588 .86073 .38223 Mtetra
.698 .816 .363 r
.86073 .38223 .86432 .37588 .87835 .38115 .87166 .35969 Mtetra
.941 .582 .191 r
.2936 .53177 .29997 .54425 .30933 .55796 .30155 .56547 Mtetra
.868 .551 .447 r
.30155 .56547 .30933 .55796 .31738 .59469 .30919 .60828 Mtetra
.567 .198 .302 r
.30919 .60828 .31738 .59469 .32586 .62943 .31965 .61143 Mtetra
.838 .65 .648 r
.31965 .61143 .32586 .62943 .33959 .57714 .33251 .57544 Mtetra
.944 .745 .605 r
.33251 .57544 .33959 .57714 .35187 .54672 .34656 .51508 Mtetra
.703 .529 .65 r
.34656 .51508 .35187 .54672 .36404 .51586 .35798 .49839 Mtetra
.769 .442 0 r
.35798 .49839 .36404 .51586 .37432 .52209 .36706 .52851 Mtetra
.866 .528 .411 r
.36706 .52851 .37432 .52209 .38354 .55541 .37614 .56458 Mtetra
.872 .551 .441 r
.37614 .56458 .38354 .55541 .39244 .60368 .38504 .61235 Mtetra
.411 0 .088 r
.38504 .61235 .39244 .60368 .40277 .62414 .39623 .61159 Mtetra
.859 .69 .67 r
.39623 .61159 .40277 .62414 .41469 .60346 .40851 .58198 Mtetra
.86 .65 .618 r
.40851 .58198 .41469 .60346 .42697 .56853 .42137 .53018 Mtetra
.751 .551 .625 r
.42137 .53018 .42697 .56853 .43957 .51468 .43339 .49776 Mtetra
.779 .629 .693 r
.43339 .49776 .43957 .51468 .45105 .49699 .44489 .47992 Mtetra
.767 .621 .698 r
.44489 .47992 .45105 .49699 .46273 .46587 .4563 .46385 Mtetra
.906 .879 .798 r
.4563 .46385 .46273 .46587 .47397 .45303 .46764 .44881 Mtetra
.832 .36 0 r
.46764 .44881 .47397 .45303 .48512 .4467 .47848 .46679 Mtetra
.68 .349 .407 r
.47848 .46679 .48512 .4467 .496 .47347 .48957 .48039 Mtetra
.842 .473 .353 r
.48957 .48039 .496 .47347 .50726 .47821 .50073 .50832 Mtetra
.442 .155 .38 r
.50073 .50832 .50726 .47821 .51864 .47882 .5123 .5016 Mtetra
.792 .472 .448 r
.5123 .5016 .51864 .47882 .53018 .51757 .52389 .5395 Mtetra
.173 0 .221 r
.52389 .5395 .53018 .51757 .54185 .51615 .53565 .52437 Mtetra
.749 .346 .287 r
.53565 .52437 .54185 .51615 .55374 .5306 .54759 .53941 Mtetra
.055 0 0 r
.54759 .53941 .55374 .5306 .5656 .52832 .55948 .53194 Mtetra
.034 0 0 r
.55948 .53194 .5656 .52832 .5775 .52523 .57146 .52886 Mtetra
.481 0 0 r
.57146 .52886 .5775 .52523 .58917 .50795 .58362 .53203 Mtetra
.337 .042 .308 r
.58362 .53203 .58917 .50795 .60091 .4953 .59557 .52144 Mtetra
.395 .101 .343 r
.59557 .52144 .60091 .4953 .61253 .47926 .60758 .51286 Mtetra
0 0 .21 r
.60758 .51286 .61253 .47926 .62433 .46998 .61875 .47597 Mtetra
0 0 0 r
.61875 .47597 .62433 .46998 .6358 .45105 .63068 .46726 Mtetra
.63068 .46726 .6358 .45105 .64625 .40838 .64204 .44324 Mtetra
.248 .013 .347 r
.64204 .44324 .64625 .40838 .65751 .38996 .65338 .421 Mtetra
.04 0 .261 r
.65338 .421 .65751 .38996 .66998 .39787 .66426 .39098 Mtetra
.91 .787 .713 r
.66426 .39098 .66998 .39787 .68177 .38994 .67539 .36896 Mtetra
0 .087 .616 r
.67539 .36896 .68177 .38994 .69478 .40345 .68888 .39219 Mtetra
.158 .36 .813 r
.68888 .39219 .69478 .40345 .70887 .43159 .70182 .4012 Mtetra
0 0 .538 r
.70182 .4012 .70887 .43159 .72454 .47955 .71666 .43804 Mtetra
.221 .186 .604 r
.71666 .43804 .72454 .47955 .73892 .50149 .73147 .46847 Mtetra
.022 .074 .577 r
.73147 .46847 .73892 .50149 .75348 .52206 .74694 .50341 Mtetra
.839 .658 .657 r
.74694 .50341 .75348 .52206 .76324 .4764 .75804 .47489 Mtetra
.904 .961 .816 r
.75804 .47489 .76324 .4764 .77248 .42792 .77011 .46036 Mtetra
0 0 .164 r
.77011 .46036 .77248 .42792 .78236 .39072 .77905 .40863 Mtetra
0 0 0 r
.77905 .40863 .78236 .39072 .7945 .3813 .78844 .36599 Mtetra
.149 .283 .747 r
.78844 .36599 .7945 .3813 .80889 .39574 .80273 .37963 Mtetra
0 0 .484 r
.80273 .37963 .80889 .39574 .82644 .44032 .81893 .41083 Mtetra
0 0 .501 r
.81893 .41083 .82644 .44032 .84258 .4664 .837 .45696 Mtetra
.895 .772 .718 r
.837 .45696 .84258 .4664 .85179 .42428 .84846 .43539 Mtetra
0 0 0 r
.84846 .43539 .85179 .42428 .86073 .38223 .85886 .40494 Mtetra
0 0 .168 r
.85886 .40494 .86073 .38223 .87166 .35969 .86848 .36915 Mtetra
.843 .525 .451 r
.28551 .54217 .2936 .53177 .30155 .56547 .29319 .57958 Mtetra
.795 .473 .443 r
.29319 .57958 .30155 .56547 .30919 .60828 .30181 .60766 Mtetra
.701 .947 .957 r
.30181 .60766 .30919 .60828 .31965 .61143 .31288 .60179 Mtetra
.909 .704 .613 r
.31288 .60179 .31965 .61143 .33251 .57544 .32733 .54133 Mtetra
.721 .537 .641 r
.32733 .54133 .33251 .57544 .34656 .51508 .3392 .51965 Mtetra
.976 .892 .674 r
.3392 .51965 .34656 .51508 .35798 .49839 .3513 .49228 Mtetra
.946 .616 .37 r
.3513 .49228 .35798 .49839 .36706 .52851 .35924 .5438 Mtetra
.84 .528 .461 r
.35924 .5438 .36706 .52851 .37614 .56458 .36786 .58967 Mtetra
.586 .272 .404 r
.36786 .58967 .37614 .56458 .38504 .61235 .37869 .59464 Mtetra
.498 .471 .758 r
.37869 .59464 .38504 .61235 .39623 .61159 .38972 .59727 Mtetra
.884 .684 .628 r
.38972 .59727 .39623 .61159 .40851 .58198 .40272 .55026 Mtetra
.752 .563 .639 r
.40272 .55026 .40851 .58198 .42137 .53018 .41477 .52346 Mtetra
.934 .726 .599 r
.41477 .52346 .42137 .53018 .43339 .49776 .42774 .46305 Mtetra
.655 .489 .648 r
.42774 .46305 .43339 .49776 .44489 .47992 .439 .45237 Mtetra
.691 .531 .665 r
.439 .45237 .44489 .47992 .4563 .46385 .45032 .43963 Mtetra
.476 .406 .698 r
.45032 .43963 .4563 .46385 .46764 .44881 .46125 .44459 Mtetra
.904 .493 .18 r
.46125 .44459 .46764 .44881 .47848 .46679 .47193 .47199 Mtetra
.878 .52 .367 r
.47193 .47199 .47848 .46679 .48957 .48039 .48277 .50831 Mtetra
.609 .299 .42 r
.48277 .50831 .48957 .48039 .50073 .50832 .49421 .51614 Mtetra
.55 .105 .145 r
.49421 .51614 .50073 .50832 .5123 .5016 .5058 .51959 Mtetra
.731 .389 .401 r
.5058 .51959 .5123 .5016 .52389 .5395 .51748 .53913 Mtetra
.887 .478 .232 r
.51748 .53913 .52389 .5395 .53565 .52437 .52939 .56746 Mtetra
.361 .112 .394 r
.52939 .56746 .53565 .52437 .54759 .53941 .54134 .55015 Mtetra
.515 .102 .195 r
.54134 .55015 .54759 .53941 .55948 .53194 .55343 .55195 Mtetra
.579 .238 .355 r
.55343 .55195 .55948 .53194 .57146 .52886 .56565 .55657 Mtetra
.418 .123 .354 r
.56565 .55657 .57146 .52886 .58362 .53203 .57778 .54906 Mtetra
.4 .052 .254 r
.57778 .54906 .58362 .53203 .59557 .52144 .59 .54457 Mtetra
.055 0 .189 r
.59 .54457 .59557 .52144 .60758 .51286 .60188 .52397 Mtetra
.877 .868 .424 r
.60188 .52397 .60758 .51286 .61875 .47597 .61332 .49068 Mtetra
0 0 0 r
.61332 .49068 .61875 .47597 .63068 .46726 .62483 .46496 Mtetra
.9 .918 .824 r
.62483 .46496 .63068 .46726 .64204 .44324 .63665 .45091 Mtetra
.976 .873 .496 r
.63665 .45091 .64204 .44324 .65338 .421 .64741 .41124 Mtetra
.909 .74 .661 r
.64741 .41124 .65338 .421 .66426 .39098 .65836 .38109 Mtetra
.711 .694 .832 r
.65836 .38109 .66426 .39098 .67539 .36896 .67031 .37476 Mtetra
.337 0 0 r
.67031 .37476 .67539 .36896 .68888 .39219 .68259 .37393 Mtetra
.469 .451 .756 r
.68259 .37393 .68888 .39219 .70182 .4012 .69524 .37825 Mtetra
0 0 .364 r
.69524 .37825 .70182 .4012 .71666 .43804 .71033 .42083 Mtetra
0 0 .413 r
.71033 .42083 .71666 .43804 .73147 .46847 .72522 .45349 Mtetra
.773 .42 0 r
.72522 .45349 .73147 .46847 .74694 .50341 .74146 .5003 Mtetra
.973 .852 .661 r
.74146 .5003 .74694 .50341 .75804 .47489 .75265 .47152 Mtetra
.933 .896 .768 r
.75265 .47152 .75804 .47489 .77011 .46036 .76451 .45331 Mtetra
.976 .756 .54 r
.76451 .45331 .77011 .46036 .77905 .40863 .77298 .39437 Mtetra
.897 .706 .637 r
.77298 .39437 .77905 .40863 .78844 .36599 .7832 .36049 Mtetra
.49 .739 .982 r
.7832 .36049 .78844 .36599 .80273 .37963 .79622 .35974 Mtetra
0 0 .345 r
.79622 .35974 .80273 .37963 .81893 .41083 .81373 .40547 Mtetra
.795 .346 0 r
.81373 .40547 .81893 .41083 .837 .45696 .83025 .43614 Mtetra
.494 .454 .742 r
.83025 .43614 .837 .45696 .84846 .43539 .84437 .4401 Mtetra
.982 .814 .412 r
.84437 .4401 .84846 .43539 .85886 .40494 .85236 .38595 Mtetra
.79 .634 .688 r
.85236 .38595 .85886 .40494 .86848 .36915 .86387 .36658 Mtetra
.747 .387 .372 r
.2773 .55234 .28551 .54217 .29319 .57958 .2866 .56751 Mtetra
.954 .606 .259 r
.2866 .56751 .29319 .57958 .30181 .60766 .29436 .60681 Mtetra
.913 .873 .784 r
.29436 .60681 .30181 .60766 .31288 .60179 .30621 .59012 Mtetra
.907 .694 .603 r
.30621 .59012 .31288 .60179 .32733 .54133 .32146 .51929 Mtetra
.733 .577 .68 r
.32146 .51929 .32733 .54133 .3392 .51965 .33297 .50385 Mtetra
.411 .434 .774 r
.33297 .50385 .3392 .51965 .3513 .49228 .34329 .50856 Mtetra
.788 .465 .442 r
.34329 .50856 .3513 .49228 .35924 .5438 .35242 .5374 Mtetra
.936 .571 .283 r
.35242 .5374 .35924 .5438 .36786 .58967 .36145 .57354 Mtetra
.852 .5 0 r
.36145 .57354 .36786 .58967 .37869 .59464 .37094 .60656 Mtetra
.988 .887 .56 r
.37094 .60656 .37869 .59464 .38972 .59727 .38396 .56534 Mtetra
.712 .536 .649 r
.38396 .56534 .38972 .59727 .40272 .55026 .39585 .54686 Mtetra
.942 .764 .632 r
.39585 .54686 .40272 .55026 .41477 .52346 .40857 .50413 Mtetra
.847 .65 .636 r
.40857 .50413 .41477 .52346 .42774 .46305 .42095 .4651 Mtetra
.976 .849 .652 r
.42095 .4651 .42774 .46305 .439 .45237 .43292 .43306 Mtetra
.088 .185 .671 r
.43292 .43306 .439 .45237 .45032 .43963 .44353 .44762 Mtetra
.745 .348 .3 r
.44353 .44762 .45032 .43963 .46125 .44459 .45433 .46156 Mtetra
.685 .339 .382 r
.45433 .46156 .46125 .44459 .47193 .47199 .46533 .47444 Mtetra
.898 .538 .349 r
.46533 .47444 .47193 .47199 .48277 .50831 .47611 .51339 Mtetra
.852 .472 .327 r
.47611 .51339 .48277 .50831 .49421 .51614 .48737 .54102 Mtetra
.606 .285 .4 r
.48737 .54102 .49421 .51614 .5058 .51959 .49908 .54835 Mtetra
.529 .223 .393 r
.49908 .54835 .5058 .51959 .51748 .53913 .51094 .54875 Mtetra
.673 .263 .261 r
.51094 .54875 .51748 .53913 .52939 .56746 .52289 .55832 Mtetra
.485 .616 .905 r
.52289 .55832 .52939 .56746 .54134 .55015 .53497 .55921 Mtetra
.646 .224 .227 r
.53497 .55921 .54134 .55015 .55343 .55195 .54718 .56718 Mtetra
.536 .163 .281 r
.54718 .56718 .55343 .55195 .56565 .55657 .55948 .56935 Mtetra
0 0 0 r
.55948 .56935 .56565 .55657 .57778 .54906 .57155 .54977 Mtetra
.543 0 0 r
.57155 .54977 .57778 .54906 .59 .54457 .58404 .55608 Mtetra
.829 .86 .409 r
.58404 .55608 .59 .54457 .60188 .52397 .59584 .52566 Mtetra
.908 .983 .76 r
.59584 .52566 .60188 .52397 .61332 .49068 .60786 .50933 Mtetra
.083 0 .15 r
.60786 .50933 .61332 .49068 .62483 .46496 .61985 .49343 Mtetra
0 0 .031 r
.61985 .49343 .62483 .46496 .63665 .45091 .63082 .44904 Mtetra
.837 .952 .891 r
.63082 .44904 .63665 .45091 .64741 .41124 .64284 .43874 Mtetra
0 0 .14 r
.64284 .43874 .64741 .41124 .65836 .38109 .65382 .40395 Mtetra
0 0 .177 r
.65382 .40395 .65836 .38109 .67031 .37476 .66513 .38026 Mtetra
.143 0 0 r
.66513 .38026 .67031 .37476 .68259 .37393 .67735 .37656 Mtetra
.353 .798 .645 r
.67735 .37656 .68259 .37393 .69524 .37825 .68947 .37007 Mtetra
.721 .285 0 r
.68947 .37007 .69524 .37825 .71033 .42083 .70348 .39506 Mtetra
0 0 .409 r
.70348 .39506 .71033 .42083 .72522 .45349 .71896 .4386 Mtetra
0 0 .475 r
.71896 .4386 .72522 .45349 .74146 .5003 .7338 .46569 Mtetra
.098 .122 .597 r
.7338 .46569 .74146 .5003 .75265 .47152 .74932 .49788 Mtetra
0 0 .183 r
.74932 .49788 .75265 .47152 .76451 .45331 .76023 .46436 Mtetra
.925 .812 .349 r
.76023 .46436 .76451 .45331 .77298 .39437 .76957 .41345 Mtetra
.81 .719 .186 r
.76957 .41345 .77298 .39437 .7832 .36049 .77767 .352 Mtetra
.226 .481 .89 r
.77767 .352 .7832 .36049 .79622 .35974 .7913 .35778 Mtetra
.562 0 0 r
.7913 .35778 .79622 .35974 .81373 .40547 .80558 .36897 Mtetra
0 0 .519 r
.80558 .36897 .81373 .40547 .83025 .43614 .82378 .41821 Mtetra
0 0 .546 r
.82378 .41821 .83025 .43614 .84437 .4401 .84059 .44853 Mtetra
.852 .817 .335 r
.84059 .44853 .84437 .4401 .85236 .38595 .85056 .41123 Mtetra
0 0 .083 r
.85056 .41123 .85236 .38595 .86387 .36658 .8586 .35857 Mtetra
.953 .614 .327 r
.27052 .54271 .2773 .55234 .2866 .56751 .27773 .58503 Mtetra
.769 .45 .446 r
.27773 .58503 .2866 .56751 .29436 .60681 .28647 .61096 Mtetra
.969 .801 .62 r
.28647 .61096 .29436 .60681 .30621 .59012 .30061 .56253 Mtetra
.831 .621 .62 r
.30061 .56253 .30621 .59012 .32146 .51929 .31466 .51145 Mtetra
.889 .727 .675 r
.31466 .51145 .32146 .51929 .33297 .50385 .32713 .48143 Mtetra
0 .077 .599 r
.32713 .48143 .33297 .50385 .34329 .50856 .33663 .49936 Mtetra
.957 .634 .368 r
.33663 .49936 .34329 .50856 .35242 .5374 .34403 .55813 Mtetra
.705 .381 .425 r
.34403 .55813 .35242 .5374 .36145 .57354 .35409 .57528 Mtetra
.734 .254 .105 r
.35409 .57528 .36145 .57354 .37094 .60656 .36467 .5857 Mtetra
.767 .605 .677 r
.36467 .5857 .37094 .60656 .38396 .56534 .37676 .56595 Mtetra
.963 .78 .608 r
.37676 .56595 .38396 .56534 .39585 .54686 .39012 .51474 Mtetra
.788 .585 .626 r
.39012 .51474 .39585 .54686 .40857 .50413 .40266 .47746 Mtetra
.768 .583 .648 r
.40266 .47746 .40857 .50413 .42095 .4651 .41461 .45175 Mtetra
.707 .627 .766 r
.41461 .45175 .42095 .4651 .43292 .43306 .42587 .44432 Mtetra
.458 .054 .185 r
.42587 .44432 .43292 .43306 .44353 .44762 .43695 .44399 Mtetra
.85 .39 .062 r
.43695 .44399 .44353 .44762 .45433 .46156 .44763 .46297 Mtetra
.805 .354 .168 r
.44763 .46297 .45433 .46156 .46533 .47444 .4586 .47866 Mtetra
.886 .527 .36 r
.4586 .47866 .46533 .47444 .47611 .51339 .46937 .51661 Mtetra
.824 .405 .247 r
.46937 .51661 .47611 .51339 .48737 .54102 .48075 .53642 Mtetra
.903 .489 .163 r
.48075 .53642 .48737 .54102 .49908 .54835 .49226 .56592 Mtetra
.334 0 .223 r
.49226 .56592 .49908 .54835 .51094 .54875 .50428 .55925 Mtetra
.604 .192 .235 r
.50428 .55925 .51094 .54875 .52289 .55832 .51632 .56507 Mtetra
.478 0 .041 r
.51632 .56507 .52289 .55832 .53497 .55921 .52847 .567 Mtetra
.745 .33 .262 r
.52847 .567 .53497 .55921 .54718 .56718 .54079 .58189 Mtetra
.72 .795 .316 r
.54079 .58189 .54718 .56718 .55948 .56935 .55289 .55156 Mtetra
.412 .428 .767 r
.55289 .55156 .55948 .56935 .57155 .54977 .56532 .55734 Mtetra
.007 0 0 r
.56532 .55734 .57155 .54977 .58404 .55608 .57767 .55034 Mtetra
.287 .628 .962 r
.57767 .55034 .58404 .55608 .59584 .52566 .59024 .55251 Mtetra
0 0 .076 r
.59024 .55251 .59584 .52566 .60786 .50933 .60199 .51746 Mtetra
.183 0 0 r
.60199 .51746 .60786 .50933 .61985 .49343 .61442 .51253 Mtetra
0 0 0 r
.61442 .51253 .61985 .49343 .63082 .44904 .6261 .48317 Mtetra
.005 0 .246 r
.6261 .48317 .63082 .44904 .64284 .43874 .63749 .44979 Mtetra
.936 .855 .422 r
.63749 .44979 .64284 .43874 .65382 .40395 .64835 .40771 Mtetra
.999 .838 .529 r
.64835 .40771 .65382 .40395 .66513 .38026 .65875 .36103 Mtetra
.402 .402 .744 r
.65875 .36103 .66513 .38026 .67735 .37656 .67148 .36809 Mtetra
.796 .757 .817 r
.67148 .36809 .67735 .37656 .68947 .37007 .68343 .35759 Mtetra
0 0 .369 r
.68343 .35759 .68947 .37007 .70348 .39506 .69752 .38453 Mtetra
.857 .471 0 r
.69752 .38453 .70348 .39506 .71896 .4386 .71299 .42876 Mtetra
0 0 .418 r
.71299 .42876 .71896 .4386 .7338 .46569 .72749 .45108 Mtetra
0 .085 .641 r
.72749 .45108 .7338 .46569 .74932 .49788 .74209 .47069 Mtetra
.766 .584 .651 r
.74209 .47069 .74932 .49788 .76023 .46436 .75373 .44676 Mtetra
.849 .67 .659 r
.75373 .44676 .76023 .46436 .76957 .41345 .76491 .41844 Mtetra
.991 .824 .449 r
.76491 .41844 .76957 .41345 .77767 .352 .77388 .3651 Mtetra
.692 .721 .202 r
.77388 .3651 .77767 .352 .7913 .35778 .784 .3292 Mtetra
.274 .263 .665 r
.784 .3292 .7913 .35778 .80558 .36897 .7989 .34792 Mtetra
0 0 .361 r
.7989 .34792 .80558 .36897 .82378 .41821 .81676 .39455 Mtetra
0 0 .431 r
.81676 .39455 .82378 .41821 .84059 .44853 .83503 .44026 Mtetra
.948 .791 .652 r
.83503 .44026 .84059 .44853 .85056 .41123 .84579 .40945 Mtetra
.998 .775 .456 r
.84579 .40945 .85056 .41123 .8586 .35857 .85236 .34201 Mtetra
.963 .646 .253 r
.26446 .52363 .27052 .54271 .27773 .58503 .27098 .57321 Mtetra
0 0 .356 r
.27098 .57321 .27773 .58503 .28647 .61096 .28038 .58957 Mtetra
.799 .619 .658 r
.28038 .58957 .28647 .61096 .30061 .56253 .29314 .56142 Mtetra
.944 .771 .637 r
.29314 .56142 .30061 .56253 .31466 .51145 .30685 .51778 Mtetra
.983 .835 .618 r
.30685 .51778 .31466 .51145 .32713 .48143 .32028 .47491 Mtetra
.939 .581 .304 r
.32028 .47491 .32713 .48143 .33663 .49936 .32858 .51189 Mtetra
.853 .537 .453 r
.32858 .51189 .33663 .49936 .34403 .55813 .33667 .55806 Mtetra
.831 .391 .19 r
.33667 .55806 .34403 .55813 .35409 .57528 .34675 .57488 Mtetra
.732 .221 .001 r
.34675 .57488 .35409 .57528 .36467 .5857 .35734 .58535 Mtetra
.95 .839 .698 r
.35734 .58535 .36467 .5857 .37676 .56595 .36987 .55837 Mtetra
.927 .722 .606 r
.36987 .55837 .37676 .56595 .39012 .51474 .38369 .49975 Mtetra
.886 .682 .621 r
.38369 .49975 .39012 .51474 .40266 .47746 .39679 .45063 Mtetra
.641 .502 .677 r
.39679 .45063 .40266 .47746 .41461 .45175 .40803 .44386 Mtetra
.728 .731 .852 r
.40803 .44386 .41461 .45175 .42587 .44432 .41929 .43752 Mtetra
0 .316 .792 r
.41929 .43752 .42587 .44432 .43695 .44399 .43018 .44427 Mtetra
.908 .545 .334 r
.43018 .44427 .43695 .44399 .44763 .46297 .44037 .48234 Mtetra
.658 .318 .384 r
.44037 .48234 .44763 .46297 .4586 .47866 .45152 .49357 Mtetra
.804 .463 .411 r
.45152 .49357 .4586 .47866 .46937 .51661 .46245 .5246 Mtetra
.836 .467 .356 r
.46245 .5246 .46937 .51661 .48075 .53642 .47373 .55329 Mtetra
.345 0 .215 r
.47373 .55329 .48075 .53642 .49226 .56592 .48571 .54745 Mtetra
.26 .322 .738 r
.48571 .54745 .49226 .56592 .50428 .55925 .49759 .55767 Mtetra
.885 .466 .194 r
.49759 .55767 .50428 .55925 .51632 .56507 .50957 .58514 Mtetra
0 0 0 r
.50957 .58514 .51632 .56507 .52847 .567 .52186 .56028 Mtetra
.618 .75 .94 r
.52186 .56028 .52847 .567 .54079 .58189 .53412 .55739 Mtetra
.608 .498 .704 r
.53412 .55739 .54079 .58189 .55289 .55156 .54645 .55389 Mtetra
.398 0 0 r
.54645 .55389 .55289 .55156 .56532 .55734 .55889 .55654 Mtetra
.947 .91 .749 r
.55889 .55654 .56532 .55734 .57767 .55034 .57111 .53643 Mtetra
0 0 .52 r
.57111 .53643 .57767 .55034 .59024 .55251 .58403 .55697 Mtetra
.995 .867 .571 r
.58403 .55697 .59024 .55251 .60199 .51746 .59582 .51695 Mtetra
.896 .966 .825 r
.59582 .51695 .60199 .51746 .61442 .51253 .60807 .50282 Mtetra
.887 .746 .701 r
.60807 .50282 .61442 .51253 .6261 .48317 .61999 .47866 Mtetra
.968 .781 .598 r
.61999 .47866 .6261 .48317 .63749 .44979 .63109 .43386 Mtetra
.898 .691 .615 r
.63109 .43386 .63749 .44979 .64835 .40771 .64196 .39018 Mtetra
.706 .596 .732 r
.64196 .39018 .64835 .40771 .65875 .36103 .65403 .38077 Mtetra
0 0 0 r
.65403 .38077 .65875 .36103 .67148 .36809 .66465 .34012 Mtetra
.651 .507 .674 r
.66465 .34012 .67148 .36809 .68343 .35759 .67667 .33165 Mtetra
.105 .158 .634 r
.67667 .33165 .68343 .35759 .69752 .38453 .69043 .35427 Mtetra
0 0 .3 r
.69043 .35427 .69752 .38453 .71299 .42876 .70659 .41235 Mtetra
0 .132 .666 r
.70659 .41235 .71299 .42876 .72749 .45108 .72083 .43114 Mtetra
0 .118 .643 r
.72083 .43114 .72749 .45108 .74209 .47069 .73554 .45314 Mtetra
.257 .337 .755 r
.73554 .45314 .74209 .47069 .75373 .44676 .74977 .46448 Mtetra
.86 .754 .242 r
.74977 .46448 .75373 .44676 .76491 .41844 .75857 .40247 Mtetra
.917 .702 .596 r
.75857 .40247 .76491 .41844 .77388 .3651 .76818 .35605 Mtetra
.914 .773 .691 r
.76818 .35605 .77388 .3651 .784 .3292 .77934 .33125 Mtetra
.839 .378 .1 r
.77934 .33125 .784 .3292 .7989 .34792 .79494 .3571 Mtetra
.876 .479 .276 r
.79494 .3571 .7989 .34792 .81676 .39455 .81257 .40089 Mtetra
.724 .249 .121 r
.81257 .40089 .81676 .39455 .83503 .44026 .82779 .41535 Mtetra
.698 .554 .688 r
.82779 .41535 .83503 .44026 .84579 .40945 .84046 .40289 Mtetra
.988 .766 .513 r
.84046 .40289 .84579 .40945 .85236 .34201 .84812 .3441 Mtetra
.787 .475 .46 r
.25526 .54202 .26446 .52363 .27098 .57321 .26321 .57366 Mtetra
.727 .972 .929 r
.26321 .57366 .27098 .57321 .28038 .58957 .27441 .56665 Mtetra
.803 .616 .649 r
.27441 .56665 .28038 .58957 .29314 .56142 .28743 .53551 Mtetra
.819 .617 .63 r
.28743 .53551 .29314 .56142 .30685 .51778 .30105 .49388 Mtetra
.768 .591 .659 r
.30105 .49388 .30685 .51778 .32028 .47491 .31322 .47071 Mtetra
.935 .599 .373 r
.31322 .47071 .32028 .47491 .32858 .51189 .32087 .51687 Mtetra
.838 .469 .354 r
.32087 .51687 .32858 .51189 .33667 .55806 .33023 .54114 Mtetra
.929 .589 .145 r
.33023 .54114 .33667 .55806 .34675 .57488 .33882 .58306 Mtetra
.546 .105 .152 r
.33882 .58306 .34675 .57488 .35734 .58535 .34985 .58633 Mtetra
.964 .817 .648 r
.34985 .58633 .35734 .58535 .36987 .55837 .363 .54919 Mtetra
.923 .712 .6 r
.363 .54919 .36987 .55837 .38369 .49975 .37724 .48484 Mtetra
.873 .679 .638 r
.37724 .48484 .38369 .49975 .39679 .45063 .39006 .44453 Mtetra
.741 .782 .886 r
.39006 .44453 .39679 .45063 .40803 .44386 .40132 .43817 Mtetra
.875 .788 .76 r
.40132 .43817 .40803 .44386 .41929 .43752 .413 .42135 Mtetra
0 .04 .603 r
.413 .42135 .41929 .43752 .43018 .44427 .42355 .43772 Mtetra
.917 .519 .174 r
.42355 .43772 .43018 .44427 .44037 .48234 .43388 .46857 Mtetra
.928 .572 .144 r
.43388 .46857 .44037 .48234 .45152 .49357 .4442 .5122 Mtetra
.547 .197 .326 r
.4442 .5122 .45152 .49357 .46245 .5246 .45579 .51485 Mtetra
.939 .571 .203 r
.45579 .51485 .46245 .5246 .47373 .55329 .46675 .55876 Mtetra
.709 .945 .649 r
.46675 .55876 .47373 .55329 .48571 .54745 .47892 .54521 Mtetra
.851 .395 .1 r
.47892 .54521 .48571 .54745 .49759 .55767 .49072 .56624 Mtetra
.734 .324 .271 r
.49072 .56624 .49759 .55767 .50957 .58514 .50281 .58053 Mtetra
.915 .822 .74 r
.50281 .58053 .50957 .58514 .52186 .56028 .51518 .55935 Mtetra
.499 .892 .95 r
.51518 .55935 .52186 .56028 .53412 .55739 .5275 .55545 Mtetra
.834 .941 .895 r
.5275 .55545 .53412 .55739 .54645 .55389 .53985 .5451 Mtetra
.715 .728 .861 r
.53985 .5451 .54645 .55389 .55889 .55654 .55223 .53878 Mtetra
.643 .565 .752 r
.55223 .53878 .55889 .55654 .57111 .53643 .56468 .53392 Mtetra
.774 .267 0 r
.56468 .53392 .57111 .53643 .58403 .55697 .57754 .55056 Mtetra
.949 .768 .624 r
.57754 .55056 .58403 .55697 .59582 .51695 .58941 .50932 Mtetra
.73 .765 .881 r
.58941 .50932 .59582 .51695 .60807 .50282 .60191 .50264 Mtetra
.936 .947 .768 r
.60191 .50264 .60807 .50282 .61999 .47866 .61412 .48474 Mtetra
.987 .88 .537 r
.61412 .48474 .61999 .47866 .63109 .43386 .62559 .44591 Mtetra
.965 .839 .422 r
.62559 .44591 .63109 .43386 .64196 .39018 .63634 .39386 Mtetra
.995 .871 .56 r
.63634 .39386 .64196 .39018 .65403 .38077 .64736 .35625 Mtetra
.772 .593 .656 r
.64736 .35625 .65403 .38077 .66465 .34012 .65882 .33345 Mtetra
.163 .507 .912 r
.65882 .33345 .66465 .34012 .67667 .33165 .67154 .33808 Mtetra
.579 .098 .076 r
.67154 .33808 .67667 .33165 .69043 .35427 .68443 .34363 Mtetra
.88 .499 .028 r
.68443 .34363 .69043 .35427 .70659 .41235 .69997 .39229 Mtetra
0 0 .236 r
.69997 .39229 .70659 .41235 .72083 .43114 .71593 .43974 Mtetra
.706 .264 .199 r
.71593 .43974 .72083 .43114 .73554 .45314 .73012 .45283 Mtetra
.755 .992 .877 r
.73012 .45283 .73554 .45314 .74977 .46448 .74291 .44304 Mtetra
.818 .636 .656 r
.74291 .44304 .74977 .46448 .75857 .40247 .7544 .41577 Mtetra
.865 .786 .289 r
.7544 .41577 .75857 .40247 .76818 .35605 .76401 .36659 Mtetra
0 0 0 r
.76401 .36659 .76818 .35605 .77934 .33125 .77512 .33934 Mtetra
.21 0 0 r
.77512 .33934 .77934 .33125 .79494 .3571 .78807 .33442 Mtetra
0 .066 .603 r
.78807 .33442 .79494 .3571 .81257 .40089 .80416 .36264 Mtetra
.055 .086 .575 r
.80416 .36264 .81257 .40089 .82779 .41535 .82173 .40248 Mtetra
.653 .638 .823 r
.82173 .40248 .82779 .41535 .84046 .40289 .83524 .39783 Mtetra
.991 .796 .544 r
.83524 .39783 .84046 .40289 .84812 .3441 .84426 .35048 Mtetra
.927 .552 .152 r
.24849 .53021 .25526 .54202 .26321 .57366 .25652 .55982 Mtetra
.874 .498 .018 r
.25652 .55982 .26321 .57366 .27441 .56665 .26502 .58696 Mtetra
.992 .866 .526 r
.26502 .58696 .27441 .56665 .28743 .53551 .28018 .53011 Mtetra
.919 .739 .642 r
.28018 .53011 .28743 .53551 .30105 .49388 .294 .48742 Mtetra
.877 .755 .725 r
.294 .48742 .30105 .49388 .31322 .47071 .30608 .46662 Mtetra
.931 .588 .358 r
.30608 .46662 .31322 .47071 .32087 .51687 .31392 .50861 Mtetra
.944 .584 .28 r
.31392 .50861 .32087 .51687 .33023 .54114 .32237 .54677 Mtetra
.736 .314 .246 r
.32237 .54677 .33023 .54114 .33882 .58306 .33271 .55868 Mtetra
.252 .26 .674 r
.33271 .55868 .33882 .58306 .34985 .58633 .34317 .57116 Mtetra
.89 .683 .617 r
.34317 .57116 .34985 .58633 .363 .54919 .35731 .51669 Mtetra
.8 .593 .622 r
.35731 .51669 .363 .54919 .37724 .48484 .37052 .47478 Mtetra
.884 .715 .667 r
.37052 .47478 .37724 .48484 .39006 .44453 .38303 .4436 Mtetra
.957 .801 .647 r
.38303 .4436 .39006 .44453 .40132 .43817 .3956 .40747 Mtetra
.483 .382 .664 r
.3956 .40747 .40132 .43817 .413 .42135 .40641 .41256 Mtetra
.74 .291 0 r
.40641 .41256 .413 .42135 .42355 .43772 .41688 .43074 Mtetra
.948 .598 .303 r
.41688 .43074 .42355 .43772 .43388 .46857 .42658 .48044 Mtetra
.733 .358 .341 r
.42658 .48044 .43388 .46857 .4442 .5122 .43765 .4961 Mtetra
.833 .479 0 r
.43765 .4961 .4442 .5122 .45579 .51485 .44845 .53187 Mtetra
.476 .113 .27 r
.44845 .53187 .45579 .51485 .46675 .55876 .46031 .53119 Mtetra
.326 .297 .673 r
.46031 .53119 .46675 .55876 .47892 .54521 .47205 .54353 Mtetra
.749 .23 0 r
.47205 .54353 .47892 .54521 .49072 .56624 .48395 .55686 Mtetra
0 0 .503 r
.48395 .55686 .49072 .56624 .50281 .58053 .49602 .57174 Mtetra
.873 .753 .727 r
.49602 .57174 .50281 .58053 .51518 .55935 .50846 .55078 Mtetra
.265 .523 .911 r
.50846 .55078 .51518 .55935 .5275 .55545 .5208 .5549 Mtetra
.813 .978 .895 r
.5208 .5549 .5275 .55545 .53985 .5451 .53322 .54479 Mtetra
.148 0 0 r
.53322 .54479 .53985 .5451 .55223 .53878 .54573 .54648 Mtetra
.361 0 0 r
.54573 .54648 .55223 .53878 .56468 .53392 .55832 .54554 Mtetra
.016 0 0 r
.55832 .54554 .56468 .53392 .57754 .55056 .57085 .53517 Mtetra
.758 .647 .738 r
.57085 .53517 .57754 .55056 .58941 .50932 .58334 .52219 Mtetra
0 0 0 r
.58334 .52219 .58941 .50932 .60191 .50264 .59556 .49779 Mtetra
.915 .84 .757 r
.59556 .49779 .60191 .50264 .61412 .48474 .60781 .47846 Mtetra
.962 .76 .584 r
.60781 .47846 .61412 .48474 .62559 .44591 .619 .42685 Mtetra
.722 .597 .715 r
.619 .42685 .62559 .44591 .63634 .39386 .63125 .41503 Mtetra
.877 .776 .277 r
.63125 .41503 .63634 .39386 .64736 .35625 .6415 .35232 Mtetra
.63 .86 .986 r
.6415 .35232 .64736 .35625 .65882 .33345 .65386 .34826 Mtetra
0 0 0 r
.65386 .34826 .65882 .33345 .67154 .33808 .66557 .32916 Mtetra
0 .319 .807 r
.66557 .32916 .67154 .33808 .68443 .34363 .67867 .33822 Mtetra
.898 .489 .089 r
.67867 .33822 .68443 .34363 .69997 .39229 .69373 .3792 Mtetra
.717 .345 0 r
.69373 .3792 .69997 .39229 .71593 .43974 .70892 .41508 Mtetra
.258 .276 .689 r
.70892 .41508 .71593 .43974 .73012 .45283 .72322 .43063 Mtetra
0 .02 .576 r
.72322 .43063 .73012 .45283 .74291 .44304 .73863 .45897 Mtetra
.891 .777 .282 r
.73863 .45897 .74291 .44304 .7544 .41577 .74785 .39827 Mtetra
.878 .683 .635 r
.74785 .39827 .7544 .41577 .76401 .36659 .75867 .36353 Mtetra
.991 .82 .574 r
.75867 .36353 .76401 .36659 .77512 .33934 .76877 .32269 Mtetra
.721 .618 .743 r
.76877 .32269 .77512 .33934 .78807 .33442 .78127 .3125 Mtetra
.717 .415 0 r
.78127 .3125 .78807 .33442 .80416 .36264 .80079 .37905 Mtetra
.612 .225 .286 r
.80079 .37905 .80416 .36264 .82173 .40248 .81542 .38724 Mtetra
.522 .533 .808 r
.81542 .38724 .82173 .40248 .83524 .39783 .82952 .38831 Mtetra
.969 .761 .568 r
.82952 .38831 .83524 .39783 .84426 .35048 .83865 .34095 Mtetra
.918 .588 .4 r
.24081 .52822 .24849 .53021 .25652 .55982 .2476 .57189 Mtetra
0 0 0 r
.2476 .57189 .25652 .55982 .26502 .58696 .25957 .55691 Mtetra
.796 .596 .631 r
.25957 .55691 .26502 .58696 .28018 .53011 .27338 .51825 Mtetra
.894 .695 .626 r
.27338 .51825 .28018 .53011 .294 .48742 .28791 .46748 Mtetra
.452 .419 .732 r
.28791 .46748 .294 .48742 .30608 .46662 .2982 .47168 Mtetra
.867 .523 .397 r
.2982 .47168 .30608 .46662 .31392 .50861 .30658 .50533 Mtetra
.887 .471 .206 r
.30658 .50533 .31392 .50861 .32237 .54677 .31599 .52783 Mtetra
0 0 .353 r
.31599 .52783 .32237 .54677 .33271 .55868 .32553 .55184 Mtetra
0 .309 .78 r
.32553 .55184 .33271 .55868 .34317 .57116 .33633 .55837 Mtetra
.889 .695 .634 r
.33633 .55837 .34317 .57116 .35731 .51669 .35004 .51399 Mtetra
.942 .782 .654 r
.35004 .51399 .35731 .51669 .37052 .47478 .36311 .47748 Mtetra
.974 .799 .603 r
.36311 .47748 .37052 .47478 .38303 .4436 .37664 .42756 Mtetra
.784 .639 .701 r
.37664 .42756 .38303 .4436 .3956 .40747 .38845 .41027 Mtetra
.731 .26 .13 r
.38845 .41027 .3956 .40747 .40641 .41256 .39908 .42097 Mtetra
.547 .107 .155 r
.39908 .42097 .40641 .41256 .41688 .43074 .41012 .42436 Mtetra
.912 .508 .162 r
.41012 .42436 .41688 .43074 .42658 .48044 .42041 .45388 Mtetra
0 0 .528 r
.42041 .45388 .42658 .48044 .43765 .4961 .43111 .47937 Mtetra
.863 .514 .006 r
.43111 .47937 .43765 .4961 .44845 .53187 .44172 .51864 Mtetra
0 .002 .578 r
.44172 .51864 .44845 .53187 .46031 .53119 .45323 .53461 Mtetra
.812 .384 .226 r
.45323 .53461 .46031 .53119 .47205 .54353 .46488 .55362 Mtetra
.366 0 .072 r
.46488 .55362 .47205 .54353 .48395 .55686 .47706 .55175 Mtetra
.751 .248 0 r
.47706 .55175 .48395 .55686 .49602 .57174 .48912 .56815 Mtetra
.881 .875 .825 r
.48912 .56815 .49602 .57174 .50846 .55078 .5016 .55398 Mtetra
.118 0 0 r
.5016 .55398 .50846 .55078 .5208 .5549 .51402 .55244 Mtetra
.844 .925 .885 r
.51402 .55244 .5208 .5549 .53322 .54479 .52651 .54148 Mtetra
.751 .236 0 r
.52651 .54148 .53322 .54479 .54573 .54648 .53913 .55717 Mtetra
0 0 0 r
.53913 .55717 .54573 .54648 .55832 .54554 .55174 .54732 Mtetra
.763 .995 .818 r
.55174 .54732 .55832 .54554 .57085 .53517 .56435 .53618 Mtetra
.988 .856 .619 r
.56435 .53618 .57085 .53517 .58334 .52219 .57655 .49989 Mtetra
.524 .462 .729 r
.57655 .49989 .58334 .52219 .59556 .49779 .58933 .50162 Mtetra
.998 .848 .557 r
.58933 .50162 .59556 .49779 .60781 .47846 .60106 .45689 Mtetra
.747 .596 .689 r
.60106 .45689 .60781 .47846 .619 .42685 .61335 .44052 Mtetra
.964 .83 .407 r
.61335 .44052 .619 .42685 .63125 .41503 .62424 .38341 Mtetra
.811 .597 .613 r
.62424 .38341 .63125 .41503 .6415 .35232 .63538 .34308 Mtetra
.836 .753 .772 r
.63538 .34308 .6415 .35232 .65386 .34826 .64734 .32849 Mtetra
.731 .595 .704 r
.64734 .32849 .65386 .34826 .66557 .32916 .65934 .31536 Mtetra
.22 .36 .793 r
.65934 .31536 .66557 .32916 .67867 .33822 .67243 .32438 Mtetra
0 0 .428 r
.67243 .32438 .67867 .33822 .69373 .3792 .68662 .35061 Mtetra
0 0 .426 r
.68662 .35061 .69373 .3792 .70892 .41508 .7022 .39498 Mtetra
.71 .397 0 r
.7022 .39498 .70892 .41508 .72322 .43063 .71875 .44721 Mtetra
.306 0 .195 r
.71875 .44721 .72322 .43063 .73863 .45897 .73184 .43962 Mtetra
.889 .678 .612 r
.73184 .43962 .73863 .45897 .74785 .39827 .74245 .39692 Mtetra
.996 .783 .494 r
.74245 .39692 .74785 .39827 .75867 .36353 .7512 .33335 Mtetra
.622 .484 .673 r
.7512 .33335 .75867 .36353 .76877 .32269 .7641 .3271 Mtetra
.828 .927 .545 r
.7641 .3271 .76877 .32269 .78127 .3125 .77581 .30631 Mtetra
.873 .464 .017 r
.77581 .30631 .78127 .3125 .80079 .37905 .79344 .35247 Mtetra
0 0 .515 r
.79344 .35247 .80079 .37905 .81542 .38724 .811 .39228 Mtetra
.869 .899 .481 r
.811 .39228 .81542 .38724 .82952 .38831 .82244 .36544 Mtetra
.777 .609 .672 r
.82244 .36544 .82952 .38831 .83865 .34095 .83436 .34449 Mtetra
.961 .625 .303 r
.23402 .51553 .24081 .52822 .2476 .57189 .24069 .55931 Mtetra
0 .105 .66 r
.24069 .55931 .2476 .57189 .25957 .55691 .25047 .57062 Mtetra
.982 .903 .581 r
.25047 .57062 .25957 .55691 .27338 .51825 .26444 .53211 Mtetra
.996 .863 .574 r
.26444 .53211 .27338 .51825 .28791 .46748 .27907 .48274 Mtetra
.897 .91 .508 r
.27907 .48274 .28791 .46748 .2982 .47168 .29205 .45207 Mtetra
.915 .59 .116 r
.29205 .45207 .2982 .47168 .30658 .50533 .29976 .49359 Mtetra
.956 .611 .277 r
.29976 .49359 .30658 .50533 .31599 .52783 .30764 .53785 Mtetra
.727 .345 .325 r
.30764 .53785 .31599 .52783 .32553 .55184 .31787 .55155 Mtetra
.902 .923 .823 r
.31787 .55155 .32553 .55184 .33633 .55837 .32996 .53718 Mtetra
.831 .638 .642 r
.32996 .53718 .33633 .55837 .35004 .51399 .34329 .50079 Mtetra
.811 .675 .713 r
.34329 .50079 .35004 .51399 .36311 .47748 .35547 .48248 Mtetra
.979 .787 .575 r
.35547 .48248 .36311 .47748 .37664 .42756 .36988 .41858 Mtetra
.529 .636 .9 r
.36988 .41858 .37664 .42756 .38845 .41027 .38095 .41832 Mtetra
.664 .893 .544 r
.38095 .41832 .38845 .41027 .39908 .42097 .39272 .4035 Mtetra
0 0 .548 r
.39272 .4035 .39908 .42097 .41012 .42436 .40315 .42205 Mtetra
.776 .27 0 r
.40315 .42205 .41012 .42436 .42041 .45388 .41397 .43568 Mtetra
.892 .555 .065 r
.41397 .43568 .42041 .45388 .43111 .47937 .424 .48013 Mtetra
.9 .526 .315 r
.424 .48013 .43111 .47937 .44172 .51864 .43466 .51634 Mtetra
.737 .212 0 r
.43466 .51634 .44172 .51864 .45323 .53461 .44625 .52916 Mtetra
.77 .275 0 r
.44625 .52916 .45323 .53461 .46488 .55362 .45793 .54611 Mtetra
.783 .773 .844 r
.45793 .54611 .46488 .55362 .47706 .55175 .47027 .53667 Mtetra
0 .047 .614 r
.47027 .53667 .47706 .55175 .48912 .56815 .48228 .55336 Mtetra
.691 .622 .774 r
.48228 .55336 .48912 .56815 .5016 .55398 .49473 .54622 Mtetra
.665 .744 .909 r
.49473 .54622 .5016 .55398 .51402 .55244 .5072 .54191 Mtetra
.539 .622 .883 r
.5072 .54191 .51402 .55244 .52651 .54148 .51972 .54152 Mtetra
.498 .904 .904 r
.51972 .54152 .52651 .54148 .53913 .55717 .53231 .53661 Mtetra
.677 .565 .722 r
.53231 .53661 .53913 .55717 .55174 .54732 .54493 .52827 Mtetra
.719 .599 .721 r
.54493 .52827 .55174 .54732 .56435 .53618 .55755 .51681 Mtetra
.727 .601 .716 r
.55755 .51681 .56435 .53618 .57655 .49989 .57015 .50435 Mtetra
.979 .914 .606 r
.57015 .50435 .57655 .49989 .58933 .50162 .5824 .47372 Mtetra
.759 .578 .652 r
.5824 .47372 .58933 .50162 .60106 .45689 .59466 .45014 Mtetra
.953 .768 .615 r
.59466 .45014 .60106 .45689 .61335 .44052 .60632 .40803 Mtetra
.766 .568 .631 r
.60632 .40803 .61335 .44052 .62424 .38341 .61813 .37907 Mtetra
.915 .862 .774 r
.61813 .37907 .62424 .38341 .63538 .34308 .63019 .36141 Mtetra
.705 .725 .205 r
.63019 .36141 .63538 .34308 .64734 .32849 .64129 .32068 Mtetra
.323 .574 .931 r
.64129 .32068 .64734 .32849 .65934 .31536 .65405 .32368 Mtetra
.491 .029 .083 r
.65405 .32368 .65934 .31536 .67243 .32438 .6669 .32597 Mtetra
.859 .417 .151 r
.6669 .32597 .67243 .32438 .68662 .35061 .68119 .35347 Mtetra
.909 .517 .25 r
.68119 .35347 .68662 .35061 .7022 .39498 .69697 .4014 Mtetra
.785 .339 .188 r
.69697 .4014 .7022 .39498 .71875 .44721 .71156 .42138 Mtetra
.236 .257 .68 r
.71156 .42138 .71875 .44721 .73184 .43962 .72623 .43834 Mtetra
.991 .86 .606 r
.72623 .43834 .73184 .43962 .74245 .39692 .73754 .40354 Mtetra
.985 .825 .432 r
.73754 .40354 .74245 .39692 .7512 .33335 .74712 .34835 Mtetra
0 0 0 r
.74712 .34835 .7512 .33335 .7641 .3271 .75766 .31014 Mtetra
.392 .429 .78 r
.75766 .31014 .7641 .3271 .77581 .30631 .77167 .31646 Mtetra
.882 .49 .284 r
.77167 .31646 .77581 .30631 .79344 .35247 .78957 .3652 Mtetra
.772 .36 .27 r
.78957 .3652 .79344 .35247 .811 .39228 .8057 .38879 Mtetra
.968 .89 .696 r
.8057 .38879 .811 .39228 .82244 .36544 .81751 .36455 Mtetra
1 .828 .513 r
.81751 .36455 .82244 .36544 .83436 .34449 .82697 .31845 Mtetra
.931 .6 .389 r
.22642 .51115 .23402 .51553 .24069 .55931 .23288 .55619 Mtetra
.817 .867 .884 r
.23288 .55619 .24069 .55931 .25047 .57062 .24445 .54698 Mtetra
.737 .576 .675 r
.24445 .54698 .25047 .57062 .26444 .53211 .25668 .52994 Mtetra
.941 .747 .614 r
.25668 .52994 .26444 .53211 .27907 .48274 .27211 .47264 Mtetra
.883 .709 .662 r
.27211 .47264 .27907 .48274 .29205 .45207 .28541 .43877 Mtetra
.9 .527 .073 r
.28541 .43877 .29205 .45207 .29976 .49359 .29389 .46844 Mtetra
.881 .587 .072 r
.29389 .46844 .29976 .49359 .30764 .53785 .3014 .51584 Mtetra
.819 .513 0 r
.3014 .51584 .30764 .53785 .31787 .55155 .30994 .55377 Mtetra
0 0 0 r
.30994 .55377 .31787 .55155 .32996 .53718 .32134 .55189 Mtetra
.99 .878 .544 r
.32134 .55189 .32996 .53718 .34329 .50079 .33551 .5044 Mtetra
.978 .819 .617 r
.33551 .5044 .34329 .50079 .35547 .48248 .34927 .45969 Mtetra
.827 .63 .637 r
.34927 .45969 .35547 .48248 .36988 .41858 .36238 .42275 Mtetra
.979 .897 .667 r
.36238 .42275 .36988 .41858 .38095 .41832 .37487 .39463 Mtetra
.231 .248 .672 r
.37487 .39463 .38095 .41832 .39272 .4035 .3854 .40727 Mtetra
.799 .375 .241 r
.3854 .40727 .39272 .4035 .40315 .42205 .39592 .42404 Mtetra
.759 .287 .123 r
.39592 .42404 .40315 .42205 .41397 .43568 .40681 .43662 Mtetra
.892 .512 .306 r
.40681 .43662 .41397 .43568 .424 .48013 .41718 .46921 Mtetra
.714 .293 0 r
.41718 .46921 .424 .48013 .43466 .51634 .42824 .49013 Mtetra
.202 .22 .656 r
.42824 .49013 .43466 .51634 .44625 .52916 .43968 .5056 Mtetra
0 .059 .593 r
.43968 .5056 .44625 .52916 .45793 .54611 .4512 .52654 Mtetra
.332 .363 .743 r
.4512 .52654 .45793 .54611 .47027 .53667 .4632 .53469 Mtetra
.716 .181 0 r
.4632 .53469 .47027 .53667 .48228 .55336 .4753 .54713 Mtetra
.877 .806 .776 r
.4753 .54713 .48228 .55336 .49473 .54622 .4879 .53021 Mtetra
.58 .552 .788 r
.4879 .53021 .49473 .54622 .5072 .54191 .50035 .52878 Mtetra
.691 .645 .799 r
.50035 .52878 .5072 .54191 .51972 .54152 .5129 .52223 Mtetra
.657 .563 .738 r
.5129 .52223 .51972 .54152 .53231 .53661 .52548 .51589 Mtetra
.346 .364 .737 r
.52548 .51589 .53231 .53661 .54493 .52827 .53818 .52441 Mtetra
.909 .867 .786 r
.53818 .52441 .54493 .52827 .55755 .51681 .55081 .50699 Mtetra
.896 .748 .689 r
.55081 .50699 .55755 .51681 .57015 .50435 .56328 .48006 Mtetra
.697 .556 .69 r
.56328 .48006 .57015 .50435 .5824 .47372 .57587 .46803 Mtetra
.921 .818 .728 r
.57587 .46803 .5824 .47372 .59466 .45014 .58824 .44568 Mtetra
.957 .813 .659 r
.58824 .44568 .59466 .45014 .60632 .40803 .60029 .4139 Mtetra
.997 .848 .518 r
.60029 .4139 .60632 .40803 .61813 .37907 .61169 .36594 Mtetra
.866 .708 .684 r
.61169 .36594 .61813 .37907 .63019 .36141 .62355 .34078 Mtetra
.792 .623 .672 r
.62355 .34078 .63019 .36141 .64129 .32068 .63542 .31888 Mtetra
.569 .91 .972 r
.63542 .31888 .64129 .32068 .65405 .32368 .64792 .3144 Mtetra
0 0 .463 r
.64792 .3144 .65405 .32368 .6669 .32597 .66155 .33303 Mtetra
.734 .283 .179 r
.66155 .33303 .6669 .32597 .68119 .35347 .67523 .34774 Mtetra
.921 .533 .147 r
.67523 .34774 .68119 .35347 .69697 .4014 .69128 .40131 Mtetra
.765 .253 0 r
.69128 .40131 .69697 .4014 .71156 .42138 .70576 .41885 Mtetra
0 .327 .672 r
.70576 .41885 .71156 .42138 .72623 .43834 .71975 .42454 Mtetra
.938 .722 .585 r
.71975 .42454 .72623 .43834 .73754 .40354 .73006 .37398 Mtetra
.839 .618 .604 r
.73006 .37398 .73754 .40354 .74712 .34835 .74052 .33033 Mtetra
.903 .689 .603 r
.74052 .33033 .74712 .34835 .75766 .31014 .75069 .28648 Mtetra
0 0 .513 r
.75069 .28648 .75766 .31014 .77167 .31646 .767 .32158 Mtetra
.721 .229 .072 r
.767 .32158 .77167 .31646 .78957 .3652 .78195 .33583 Mtetra
0 0 .523 r
.78195 .33583 .78957 .3652 .8057 .38879 .79953 .37642 Mtetra
.836 .728 .745 r
.79953 .37642 .8057 .38879 .81751 .36455 .81207 .35916 Mtetra
.992 .785 .526 r
.81207 .35916 .81751 .36455 .82697 .31845 .821 .30642 Mtetra
.914 .608 .124 r
.22051 .48841 .22642 .51115 .23288 .55619 .22704 .53108 Mtetra
.291 .279 .673 r
.22704 .53108 .23288 .55619 .24445 .54698 .23682 .54161 Mtetra
.887 .774 .732 r
.23682 .54161 .24445 .54698 .25668 .52994 .24947 .52045 Mtetra
.906 .71 .627 r
.24947 .52045 .25668 .52994 .27211 .47264 .26454 .46935 Mtetra
.926 .777 .676 r
.26454 .46935 .27211 .47264 .28541 .43877 .27778 .43766 Mtetra
.876 .473 .26 r
.27778 .43766 .28541 .43877 .29389 .46844 .28676 .46018 Mtetra
.95 .613 .34 r
.28676 .46018 .29389 .46844 .3014 .51584 .29411 .50838 Mtetra
.802 .333 0 r
.29411 .50838 .3014 .51584 .30994 .55377 .30401 .52551 Mtetra
0 0 .408 r
.30401 .52551 .30994 .55377 .32134 .55189 .3133 .55499 Mtetra
.974 .858 .663 r
.3133 .55499 .32134 .55189 .33551 .5044 .32674 .5221 Mtetra
.982 .874 .51 r
.32674 .5221 .33551 .5044 .34927 .45969 .34108 .47128 Mtetra
.957 .919 .566 r
.34108 .47128 .34927 .45969 .36238 .42275 .35412 .43876 Mtetra
.984 .873 .513 r
.35412 .43876 .36238 .42275 .37487 .39463 .36785 .38971 Mtetra
.729 .826 .925 r
.36785 .38971 .37487 .39463 .3854 .40727 .37925 .38387 Mtetra
.449 .396 .706 r
.37925 .38387 .3854 .40727 .39592 .42404 .39022 .38886 Mtetra
0 0 .368 r
.39022 .38886 .39592 .42404 .40681 .43662 .3999 .42852 Mtetra
.894 .479 .082 r
.3999 .42852 .40681 .43662 .41718 .46921 .4104 .4564 Mtetra
0 0 .338 r
.4104 .4564 .41718 .46921 .42824 .49013 .42142 .47702 Mtetra
0 0 .487 r
.42142 .47702 .42824 .49013 .43968 .5056 .43276 .49469 Mtetra
0 0 .42 r
.43276 .49469 .43968 .5056 .4512 .52654 .44434 .512 Mtetra
0 .191 .714 r
.44434 .512 .4512 .52654 .4632 .53469 .45623 .52455 Mtetra
.507 .617 .896 r
.45623 .52455 .4632 .53469 .4753 .54713 .46852 .5248 Mtetra
.247 .285 .704 r
.46852 .5248 .4753 .54713 .4879 .53021 .48074 .53683 Mtetra
0 0 0 r
.48074 .53683 .4879 .53021 .50035 .52878 .49334 .52874 Mtetra
.929 .943 .783 r
.49334 .52874 .50035 .52878 .5129 .52223 .50603 .51114 Mtetra
.789 .713 .78 r
.50603 .51114 .5129 .52223 .52548 .51589 .51865 .49874 Mtetra
.354 .408 .779 r
.51865 .49874 .52548 .51589 .53818 .52441 .53131 .50534 Mtetra
.712 .596 .725 r
.53131 .50534 .53818 .52441 .55081 .50699 .54401 .49456 Mtetra
.809 .702 .748 r
.54401 .49456 .55081 .50699 .56328 .48006 .55667 .47895 Mtetra
.903 .951 .822 r
.55667 .47895 .56328 .48006 .57587 .46803 .5693 .46399 Mtetra
.97 .788 .602 r
.5693 .46399 .57587 .46803 .58824 .44568 .58134 .41916 Mtetra
.756 .58 .658 r
.58134 .41916 .58824 .44568 .60029 .4139 .59364 .39758 Mtetra
.91 .695 .599 r
.59364 .39758 .60029 .4139 .61169 .36594 .60508 .34726 Mtetra
.801 .64 .682 r
.60508 .34726 .61169 .36594 .62355 .34078 .6171 .32608 Mtetra
.879 .698 .652 r
.6171 .32608 .62355 .34078 .63542 .31888 .62868 .29485 Mtetra
.417 .379 .709 r
.62868 .29485 .63542 .31888 .64792 .3144 .64162 .30209 Mtetra
0 0 .387 r
.64162 .30209 .64792 .3144 .66155 .33303 .6555 .32694 Mtetra
.879 .459 .04 r
.6555 .32694 .66155 .33303 .67523 .34774 .67029 .36407 Mtetra
.825 .453 .351 r
.67029 .36407 .67523 .34774 .69128 .40131 .68558 .40255 Mtetra
.839 .377 .099 r
.68558 .40255 .69128 .40131 .70576 .41885 .70056 .42805 Mtetra
0 0 0 r
.70056 .42805 .70576 .41885 .71975 .42454 .71308 .40818 Mtetra
.929 .706 .579 r
.71308 .40818 .71975 .42454 .73006 .37398 .72327 .35443 Mtetra
.851 .663 .646 r
.72327 .35443 .73006 .37398 .74052 .33033 .73471 .32356 Mtetra
.979 .772 .554 r
.73471 .32356 .74052 .33033 .75069 .28648 .74443 .27224 Mtetra
0 .102 .654 r
.74443 .27224 .75069 .28648 .767 .32158 .75939 .291 Mtetra
0 0 .346 r
.75939 .291 .767 .32158 .78195 .33583 .77811 .35092 Mtetra
.691 .285 .274 r
.77811 .35092 .78195 .33583 .79953 .37642 .79352 .36614 Mtetra
.692 .715 .866 r
.79352 .36614 .79953 .37642 .81207 .35916 .80717 .36007 Mtetra
.996 .77 .419 r
.80717 .36007 .81207 .35916 .821 .30642 .81379 .28216 Mtetra
.886 .469 .203 r
.21276 .48439 .22051 .48841 .22704 .53108 .2213 .50523 Mtetra
.69 .438 0 r
.2213 .50523 .22704 .53108 .23682 .54161 .22884 .53916 Mtetra
.919 .811 .723 r
.22884 .53916 .23682 .54161 .24947 .52045 .24181 .51539 Mtetra
.923 .743 .64 r
.24181 .51539 .24947 .52045 .26454 .46935 .25644 .47115 Mtetra
.961 .821 .658 r
.25644 .47115 .26454 .46935 .27778 .43766 .27014 .43549 Mtetra
.813 .338 .076 r
.27014 .43549 .27778 .43766 .28676 .46018 .27974 .4498 Mtetra
.955 .614 .311 r
.27974 .4498 .28676 .46018 .29411 .50838 .28712 .49609 Mtetra
.95 .596 .238 r
.28712 .49609 .29411 .50838 .30401 .52551 .29527 .5371 Mtetra
.092 0 0 r
.29527 .5371 .30401 .52551 .3133 .55499 .30707 .52993 Mtetra
.721 .563 .675 r
.30707 .52993 .3133 .55499 .32674 .5221 .31943 .51443 Mtetra
.921 .731 .63 r
.31943 .51443 .32674 .5221 .34108 .47128 .33365 .46776 Mtetra
.938 .78 .659 r
.33365 .46776 .34108 .47128 .35412 .43876 .34696 .43251 Mtetra
.93 .743 .627 r
.34696 .43251 .35412 .43876 .36785 .38971 .36064 .38712 Mtetra
.295 0 0 r
.36064 .38712 .36785 .38971 .37925 .38387 .37158 .39157 Mtetra
.418 0 .029 r
.37158 .39157 .37925 .38387 .39022 .38886 .38282 .39199 Mtetra
.83 .417 .259 r
.38282 .39199 .39022 .38886 .3999 .42852 .39328 .41251 Mtetra
.626 .568 .769 r
.39328 .41251 .3999 .42852 .4104 .4564 .40492 .40891 Mtetra
0 0 .413 r
.40492 .40891 .4104 .4564 .42142 .47702 .41485 .45559 Mtetra
0 0 .478 r
.41485 .45559 .42142 .47702 .43276 .49469 .42592 .48 Mtetra
.456 .498 .814 r
.42592 .48 .43276 .49469 .44434 .512 .43785 .48266 Mtetra
.441 .367 .678 r
.43785 .48266 .44434 .512 .45623 .52455 .44979 .48944 Mtetra
.463 .362 .654 r
.44979 .48944 .45623 .52455 .46852 .5248 .46187 .49607 Mtetra
.514 .42 .686 r
.46187 .49607 .46852 .5248 .48074 .53683 .47417 .49847 Mtetra
.623 .463 .645 r
.47417 .49847 .48074 .53683 .49334 .52874 .48669 .49026 Mtetra
.455 .348 .643 r
.48669 .49026 .49334 .52874 .50603 .51114 .49912 .49823 Mtetra
.827 .7 .724 r
.49912 .49823 .50603 .51114 .51865 .49874 .51181 .47941 Mtetra
.661 .566 .737 r
.51181 .47941 .51865 .49874 .53131 .50534 .52444 .47266 Mtetra
.518 .409 .669 r
.52444 .47266 .53131 .50534 .54401 .49456 .53714 .47513 Mtetra
.789 .633 .687 r
.53714 .47513 .54401 .49456 .55667 .47895 .54978 .45472 Mtetra
.844 .638 .624 r
.54978 .45472 .55667 .47895 .5693 .46399 .56209 .41461 Mtetra
.684 .487 .614 r
.56209 .41461 .5693 .46399 .58134 .41916 .57446 .39209 Mtetra
.754 .577 .656 r
.57446 .39209 .58134 .41916 .59364 .39758 .58675 .37043 Mtetra
.8 .603 .635 r
.58675 .37043 .59364 .39758 .60508 .34726 .59872 .33929 Mtetra
.954 .755 .596 r
.59872 .33929 .60508 .34726 .6171 .32608 .61007 .29267 Mtetra
.351 .291 .649 r
.61007 .29267 .6171 .32608 .62868 .29485 .62316 .30661 Mtetra
.423 .005 .138 r
.62316 .30661 .62868 .29485 .64162 .30209 .6359 .30585 Mtetra
.642 .123 0 r
.6359 .30585 .64162 .30209 .6555 .32694 .64914 .3148 Mtetra
.917 .555 .113 r
.64914 .3148 .6555 .32694 .67029 .36407 .66516 .37952 Mtetra
.659 .265 .286 r
.66516 .37952 .67029 .36407 .68558 .40255 .67916 .39143 Mtetra
.185 .411 .847 r
.67916 .39143 .68558 .40255 .70056 .42805 .69312 .39893 Mtetra
.515 .424 .69 r
.69312 .39893 .70056 .42805 .71308 .40818 .70697 .40151 Mtetra
.98 .763 .539 r
.70697 .40151 .71308 .40818 .72327 .35443 .71693 .34195 Mtetra
.953 .73 .564 r
.71693 .34195 .72327 .35443 .73471 .32356 .72675 .28657 Mtetra
.487 .376 .653 r
.72675 .28657 .73471 .32356 .74443 .27224 .74068 .29238 Mtetra
.746 .37 .342 r
.74068 .29238 .74443 .27224 .75939 .291 .75629 .31773 Mtetra
.766 .409 .378 r
.75629 .31773 .75939 .291 .77811 .35092 .7731 .35326 Mtetra
.692 .158 0 r
.7731 .35326 .77811 .35092 .79352 .36614 .78842 .36676 Mtetra
.96 .942 .642 r
.78842 .36676 .79352 .36614 .80717 .36007 .80045 .34209 Mtetra
.923 .7 .583 r
.80045 .34209 .80717 .36007 .81379 .28216 .81004 .29343 Mtetra
.938 .566 .244 r
.20546 .4752 .21276 .48439 .2213 .50523 .21295 .50621 Mtetra
.89 .54 .377 r
.21295 .50621 .2213 .50523 .22884 .53916 .22046 .54 Mtetra
.297 .794 .827 r
.22046 .54 .22884 .53916 .24181 .51539 .23162 .53721 Mtetra
.999 .842 .534 r
.23162 .53721 .24181 .51539 .25644 .47115 .2488 .46663 Mtetra
.894 .793 .742 r
.2488 .46663 .25644 .47115 .27014 .43549 .2613 .44648 Mtetra
.803 .931 .56 r
.2613 .44648 .27014 .43549 .27974 .4498 .27373 .42638 Mtetra
.835 .539 0 r
.27373 .42638 .27974 .4498 .28712 .49609 .28147 .46596 Mtetra
0 0 .421 r
.28147 .46596 .28712 .49609 .29527 .5371 .29034 .49511 Mtetra
0 0 .252 r
.29034 .49511 .29527 .5371 .30707 .52993 .29812 .54357 Mtetra
.785 .893 .482 r
.29812 .54357 .30707 .52993 .31943 .51443 .31121 .51925 Mtetra
.983 .855 .635 r
.31121 .51925 .31943 .51443 .33365 .46776 .32506 .48128 Mtetra
.986 .887 .551 r
.32506 .48128 .33365 .46776 .34696 .43251 .33905 .43775 Mtetra
.975 .918 .669 r
.33905 .43775 .34696 .43251 .36064 .38712 .35187 .41073 Mtetra
.856 .834 .364 r
.35187 .41073 .36064 .38712 .37158 .39157 .36554 .36544 Mtetra
.64 .505 .682 r
.36554 .36544 .37158 .39157 .38282 .39199 .37708 .35854 Mtetra
0 0 .486 r
.37708 .35854 .38282 .39199 .39328 .41251 .38699 .38858 Mtetra
.625 .507 .699 r
.38699 .38858 .39328 .41251 .40492 .40891 .39866 .38346 Mtetra
0 0 .538 r
.39866 .38346 .40492 .40891 .41485 .45559 .40931 .40687 Mtetra
.195 .135 .558 r
.40931 .40687 .41485 .45559 .42592 .48 .42006 .4349 Mtetra
.46 .333 .62 r
.42006 .4349 .42592 .48 .43785 .48266 .43169 .4433 Mtetra
.161 .136 .579 r
.43169 .4433 .43785 .48266 .44979 .48944 .44306 .46791 Mtetra
.102 .192 .673 r
.44306 .46791 .44979 .48944 .46187 .49607 .45492 .48295 Mtetra
.101 .314 .789 r
.45492 .48295 .46187 .49607 .47417 .49847 .46709 .4921 Mtetra
.906 .797 .729 r
.46709 .4921 .47417 .49847 .48669 .49026 .47987 .46972 Mtetra
0 0 .534 r
.47987 .46972 .48669 .49026 .49912 .49823 .49211 .49286 Mtetra
.948 .785 .647 r
.49211 .49286 .49912 .49823 .51181 .47941 .50498 .45637 Mtetra
.647 .533 .71 r
.50498 .45637 .51181 .47941 .52444 .47266 .51759 .44963 Mtetra
.433 .401 .724 r
.51759 .44963 .52444 .47266 .53714 .47513 .53027 .45532 Mtetra
.846 .657 .646 r
.53027 .45532 .53714 .47513 .54978 .45472 .54284 .42223 Mtetra
.78 .579 .627 r
.54284 .42223 .54978 .45472 .56209 .41461 .55525 .38981 Mtetra
.782 .602 .655 r
.55525 .38981 .56209 .41461 .57446 .39209 .5676 .36516 Mtetra
.764 .583 .653 r
.5676 .36516 .57446 .39209 .58675 .37043 .57986 .34195 Mtetra
.822 .611 .618 r
.57986 .34195 .58675 .37043 .59872 .33929 .59167 .3033 Mtetra
.701 .517 .636 r
.59167 .3033 .59872 .33929 .61007 .29267 .60378 .28439 Mtetra
.626 .719 .914 r
.60378 .28439 .61007 .29267 .62316 .30661 .61633 .28115 Mtetra
.015 .102 .611 r
.61633 .28115 .62316 .30661 .6359 .30585 .62989 .30435 Mtetra
.898 .48 .156 r
.62989 .30435 .6359 .30585 .64914 .3148 .64432 .34171 Mtetra
.739 .392 .394 r
.64432 .34171 .64914 .3148 .66516 .37952 .65881 .37092 Mtetra
.846 .431 0 r
.65881 .37092 .66516 .37952 .67916 .39143 .67408 .4084 Mtetra
.367 0 .2 r
.67408 .4084 .67916 .39143 .69312 .39893 .68753 .40371 Mtetra
.953 .912 .544 r
.68753 .40371 .69312 .39893 .70697 .40151 .6995 .37251 Mtetra
.858 .631 .593 r
.6995 .37251 .70697 .40151 .71693 .34195 .71015 .3229 Mtetra
.864 .671 .64 r
.71015 .3229 .71693 .34195 .72675 .28657 .72157 .29 Mtetra
.91 .947 .595 r
.72157 .29 .72675 .28657 .74068 .29238 .7335 .26686 Mtetra
0 0 .447 r
.7335 .26686 .74068 .29238 .75629 .31773 .75027 .30841 Mtetra
.864 .473 0 r
.75027 .30841 .75629 .31773 .7731 .35326 .76845 .36119 Mtetra
.001 0 0 r
.76845 .36119 .7731 .35326 .78842 .36676 .78199 .35286 Mtetra
.9 .728 .66 r
.78199 .35286 .78842 .36676 .80045 .34209 .79361 .32293 Mtetra
.925 .695 .57 r
.79361 .32293 .80045 .34209 .81004 .29343 .80284 .26974 Mtetra
.792 .506 0 r
.1996 .45163 .20546 .4752 .21295 .50621 .20667 .48565 Mtetra
.768 .459 0 r
.20667 .48565 .21295 .50621 .22046 .54 .21448 .51513 Mtetra
.346 .319 .686 r
.21448 .51513 .22046 .54 .23162 .53721 .22454 .52353 Mtetra
.865 .685 .656 r
.22454 .52353 .23162 .53721 .2488 .46663 .23873 .48791 Mtetra
.995 .86 .527 r
.23873 .48791 .2488 .46663 .2613 .44648 .25496 .42691 Mtetra
.642 .541 .725 r
.25496 .42691 .2613 .44648 .27373 .42638 .26618 .42165 Mtetra
.827 .351 .01 r
.26618 .42165 .27373 .42638 .28147 .46596 .27574 .43754 Mtetra
0 0 .144 r
.27574 .43754 .28147 .46596 .29034 .49511 .2837 .47674 Mtetra
.766 .433 0 r
.2837 .47674 .29034 .49511 .29812 .54357 .29275 .50598 Mtetra
.512 .384 .643 r
.29275 .50598 .29812 .54357 .31121 .51925 .30392 .50877 Mtetra
.865 .718 .698 r
.30392 .50877 .31121 .51925 .32506 .48128 .31701 .484 Mtetra
.95 .936 .742 r
.31701 .484 .32506 .48128 .33905 .43775 .32974 .46343 Mtetra
.925 .851 .409 r
.32974 .46343 .33905 .43775 .35187 .41073 .34444 .40788 Mtetra
.914 .848 .765 r
.34444 .40788 .35187 .41073 .36554 .36544 .35679 .38931 Mtetra
.705 .763 .267 r
.35679 .38931 .36554 .36544 .37708 .35854 .37005 .3517 Mtetra
.414 .66 .961 r
.37005 .3517 .37708 .35854 .38699 .38858 .3813 .35243 Mtetra
0 0 .483 r
.3813 .35243 .38699 .38858 .39866 .38346 .39129 .38419 Mtetra
.46 0 0 r
.39129 .38419 .39866 .38346 .40931 .40687 .40269 .38854 Mtetra
.142 .248 .714 r
.40269 .38854 .40931 .40687 .42006 .4349 .41395 .40003 Mtetra
.377 .299 .641 r
.41395 .40003 .42006 .4349 .43169 .4433 .42539 .4114 Mtetra
.331 .279 .648 r
.42539 .4114 .43169 .4433 .44306 .46791 .43697 .4241 Mtetra
.123 .097 .554 r
.43697 .4241 .44306 .46791 .45492 .48295 .44833 .45328 Mtetra
.423 .354 .676 r
.44833 .45328 .45492 .48295 .46709 .4921 .46046 .46085 Mtetra
.695 .528 .657 r
.46046 .46085 .46709 .4921 .47987 .46972 .4731 .44553 Mtetra
.175 .222 .671 r
.4731 .44553 .47987 .46972 .49211 .49286 .48535 .46051 Mtetra
.709 .535 .651 r
.48535 .46051 .49211 .49286 .50498 .45637 .49808 .44245 Mtetra
.768 .67 .755 r
.49808 .44245 .50498 .45637 .51759 .44963 .51073 .42981 Mtetra
.713 .591 .718 r
.51073 .42981 .51759 .44963 .53027 .45532 .52338 .41849 Mtetra
.755 .554 .624 r
.52338 .41849 .53027 .45532 .54284 .42223 .53596 .38828 Mtetra
.752 .557 .632 r
.53596 .38828 .54284 .42223 .55525 .38981 .5484 .36112 Mtetra
.73 .556 .657 r
.5484 .36112 .55525 .38981 .5676 .36516 .56081 .34217 Mtetra
.871 .654 .606 r
.56081 .34217 .5676 .36516 .57986 .34195 .57269 .2949 Mtetra
.626 .447 .62 r
.57269 .2949 .57986 .34195 .59167 .3033 .58502 .28371 Mtetra
.577 .512 .746 r
.58502 .28371 .59167 .3033 .60378 .28439 .59759 .28204 Mtetra
.596 .03 0 r
.59759 .28204 .60378 .28439 .61633 .28115 .61061 .29275 Mtetra
.744 .335 .274 r
.61061 .29275 .61633 .28115 .62989 .30435 .62407 .31096 Mtetra
.808 .375 .218 r
.62407 .31096 .62989 .30435 .64432 .34171 .63797 .33389 Mtetra
.922 .542 .141 r
.63797 .33389 .64432 .34171 .65881 .37092 .65362 .39065 Mtetra
.381 .03 .238 r
.65362 .39065 .65881 .37092 .67408 .4084 .66698 .38564 Mtetra
.701 .57 .704 r
.66698 .38564 .67408 .4084 .68753 .40371 .68004 .3739 Mtetra
.779 .585 .637 r
.68004 .3739 .68753 .40371 .6995 .37251 .69218 .34567 Mtetra
.892 .654 .571 r
.69218 .34567 .6995 .37251 .71015 .3229 .70219 .28471 Mtetra
.623 .462 .644 r
.70219 .28471 .71015 .3229 .72157 .29 .71516 .276 Mtetra
.078 .276 .763 r
.71516 .276 .72157 .29 .7335 .26686 .72962 .28827 Mtetra
.737 .363 .343 r
.72962 .28827 .7335 .26686 .75027 .30841 .74527 .31337 Mtetra
.791 .319 .113 r
.74527 .31337 .75027 .30841 .76845 .36119 .76097 .33481 Mtetra
.296 .299 .693 r
.76097 .33481 .76845 .36119 .78199 .35286 .77638 .34904 Mtetra
.995 .816 .554 r
.77638 .34904 .78199 .35286 .79361 .32293 .78681 .30427 Mtetra
.94 .7 .548 r
.78681 .30427 .79361 .32293 .80284 .26974 .79539 .24323 Mtetra
.487 0 0 r
.19127 .45137 .1996 .45163 .20667 .48565 .20134 .45585 Mtetra
.962 .679 .25 r
.20134 .45585 .20667 .48565 .21448 .51513 .20549 .52051 Mtetra
.742 .32 .246 r
.20549 .52051 .21448 .51513 .22454 .52353 .2152 .53294 Mtetra
.986 .893 .634 r
.2152 .53294 .22454 .52353 .23873 .48791 .22958 .49705 Mtetra
.987 .83 .601 r
.22958 .49705 .23873 .48791 .25496 .42691 .24524 .44502 Mtetra
0 0 0 r
.24524 .44502 .25496 .42691 .26618 .42165 .25771 .42666 Mtetra
.517 .886 .68 r
.25771 .42666 .26618 .42165 .27574 .43754 .26929 .4183 Mtetra
.945 .619 .191 r
.26929 .4183 .27574 .43754 .2837 .47674 .27652 .4652 Mtetra
.949 .592 .243 r
.27652 .4652 .2837 .47674 .29275 .50598 .28463 .50588 Mtetra
.725 .212 .002 r
.28463 .50588 .29275 .50598 .30392 .50877 .29528 .51654 Mtetra
0 0 0 r
.29528 .51654 .30392 .50877 .31701 .484 .30729 .50946 Mtetra
.872 .845 .383 r
.30729 .50946 .31701 .484 .32974 .46343 .32199 .46139 Mtetra
.945 .815 .685 r
.32199 .46139 .32974 .46343 .34444 .40788 .33531 .43148 Mtetra
.669 .752 .261 r
.33531 .43148 .34444 .40788 .35679 .38931 .34879 .39636 Mtetra
.933 .96 .655 r
.34879 .39636 .35679 .38931 .37005 .3517 .36142 .37362 Mtetra
0 0 0 r
.36142 .37362 .37005 .3517 .3813 .35243 .37446 .34097 Mtetra
0 0 .492 r
.37446 .34097 .3813 .35243 .39129 .38419 .38514 .35605 Mtetra
.616 .483 .677 r
.38514 .35605 .39129 .38419 .40269 .38854 .39689 .35065 Mtetra
.437 .33 .634 r
.39689 .35065 .40269 .38854 .41395 .40003 .40815 .35894 Mtetra
.078 .067 .542 r
.40815 .35894 .41395 .40003 .42539 .4114 .41886 .38759 Mtetra
.348 .335 .702 r
.41886 .38759 .42539 .4114 .43697 .4241 .43049 .39627 Mtetra
.354 .315 .676 r
.43049 .39627 .43697 .4241 .44833 .45328 .44224 .40626 Mtetra
.498 .357 .62 r
.44224 .40626 .44833 .45328 .46046 .46085 .45428 .411 Mtetra
.472 .334 .612 r
.45428 .411 .46046 .46085 .4731 .44553 .4664 .41876 Mtetra
.486 .411 .697 r
.4664 .41876 .4731 .44553 .48535 .46051 .47873 .42225 Mtetra
.749 .547 .623 r
.47873 .42225 .48535 .46051 .49808 .44245 .49153 .39222 Mtetra
.554 .393 .617 r
.49153 .39222 .49808 .44245 .51073 .42981 .504 .39071 Mtetra
.665 .489 .636 r
.504 .39071 .51073 .42981 .52338 .41849 .51658 .37611 Mtetra
.755 .544 .61 r
.51658 .37611 .52338 .41849 .53596 .38828 .5291 .34109 Mtetra
.619 .442 .621 r
.5291 .34109 .53596 .38828 .5484 .36112 .54157 .33099 Mtetra
.713 .541 .655 r
.54157 .33099 .5484 .36112 .56081 .34217 .55398 .31367 Mtetra
.781 .587 .638 r
.55398 .31367 .56081 .34217 .57269 .2949 .56618 .28566 Mtetra
.761 .744 .837 r
.56618 .28566 .57269 .2949 .58502 .28371 .57861 .27684 Mtetra
0 .315 .788 r
.57861 .27684 .58502 .28371 .59759 .28204 .59143 .28452 Mtetra
.501 0 0 r
.59143 .28452 .59759 .28204 .61061 .29275 .60435 .28968 Mtetra
.921 .526 .19 r
.60435 .28968 .61061 .29275 .62407 .31096 .61876 .33703 Mtetra
.753 .403 .39 r
.61876 .33703 .62407 .31096 .63797 .33389 .63311 .36861 Mtetra
.589 .267 .391 r
.63311 .36861 .63797 .33389 .65362 .39065 .64694 .37784 Mtetra
0 0 .388 r
.64694 .37784 .65362 .39065 .66698 .38564 .66172 .40388 Mtetra
0 0 0 r
.66172 .40388 .66698 .38564 .68004 .3739 .67439 .38045 Mtetra
.997 .793 .436 r
.67439 .38045 .68004 .3739 .69218 .34567 .68412 .30464 Mtetra
.693 .503 .625 r
.68412 .30464 .69218 .34567 .70219 .28471 .69652 .28436 Mtetra
.994 .868 .59 r
.69652 .28436 .70219 .28471 .71516 .276 .70791 .24925 Mtetra
0 0 .431 r
.70791 .24925 .71516 .276 .72962 .28827 .72437 .29194 Mtetra
.81 .339 .1 r
.72437 .29194 .72962 .28827 .74527 .31337 .73994 .31524 Mtetra
.806 .32 .037 r
.73994 .31524 .74527 .31337 .76097 .33481 .75583 .33837 Mtetra
.851 .949 .594 r
.75583 .33837 .76097 .33481 .77638 .34904 .76842 .31739 Mtetra
.864 .627 .578 r
.76842 .31739 .77638 .34904 .78681 .30427 .77807 .26363 Mtetra
.723 .522 .618 r
.77807 .26363 .78681 .30427 .79539 .24323 .78991 .23805 Mtetra
.694 .759 .902 r
.18355 .44461 .19127 .45137 .20134 .45585 .19461 .4398 Mtetra
.967 .643 .303 r
.19461 .4398 .20134 .45585 .20549 .52051 .20018 .48879 Mtetra
0 0 .456 r
.20018 .48879 .20549 .52051 .2152 .53294 .20843 .51496 Mtetra
.632 .554 .749 r
.20843 .51496 .2152 .53294 .22958 .49705 .21986 .51061 Mtetra
.994 .84 .578 r
.21986 .51061 .22958 .49705 .24524 .44502 .23625 .4531 Mtetra
.984 .897 .643 r
.23625 .4531 .24524 .44502 .25771 .42666 .25015 .41994 Mtetra
.696 .767 .906 r
.25015 .41994 .25771 .42666 .26929 .4183 .26148 .41498 Mtetra
.841 .379 .09 r
.26148 .41498 .26929 .4183 .27652 .4652 .27107 .43195 Mtetra
.716 .49 0 r
.27107 .43195 .27652 .4652 .28463 .50588 .27852 .47875 Mtetra
.478 .399 .688 r
.27852 .47875 .28463 .50588 .29528 .51654 .28961 .48235 Mtetra
.362 .289 .639 r
.28961 .48235 .29528 .51654 .30729 .50946 .30029 .49327 Mtetra
.699 .609 .753 r
.30029 .49327 .30729 .50946 .32199 .46139 .31242 .48503 Mtetra
.69 .771 .285 r
.31242 .48503 .32199 .46139 .33531 .43148 .3263 .44967 Mtetra
.937 .886 .476 r
.3263 .44967 .33531 .43148 .34879 .39636 .34044 .40693 Mtetra
.979 .907 .579 r
.34044 .40693 .34879 .39636 .36142 .37362 .35396 .37098 Mtetra
.947 .805 .671 r
.35396 .37098 .36142 .37362 .37446 .34097 .36707 .33927 Mtetra
.717 .185 0 r
.36707 .33927 .37446 .34097 .38514 .35605 .37795 .35045 Mtetra
.877 .81 .779 r
.37795 .35045 .38514 .35605 .39689 .35065 .39021 .33434 Mtetra
.528 .513 .783 r
.39021 .33434 .39689 .35065 .40815 .35894 .40176 .33473 Mtetra
.226 .247 .674 r
.40176 .33473 .40815 .35894 .41886 .38759 .41295 .34732 Mtetra
.501 .37 .634 r
.41295 .34732 .41886 .38759 .43049 .39627 .42462 .35101 Mtetra
.196 .143 .567 r
.42462 .35101 .43049 .39627 .44224 .40626 .43578 .37656 Mtetra
.555 .44 .677 r
.43578 .37656 .44224 .40626 .45428 .411 .44788 .3757 Mtetra
.574 .434 .654 r
.44788 .3757 .45428 .411 .4664 .41876 .46011 .37296 Mtetra
.637 .457 .623 r
.46011 .37296 .4664 .41876 .47873 .42225 .47258 .36041 Mtetra
.583 .4 .599 r
.47258 .36041 .47873 .42225 .49153 .39222 .48497 .35333 Mtetra
.612 .452 .641 r
.48497 .35333 .49153 .39222 .504 .39071 .49739 .34596 Mtetra
.578 .417 .627 r
.49739 .34596 .504 .39071 .51658 .37611 .50984 .34168 Mtetra
.731 .541 .635 r
.50984 .34168 .51658 .37611 .5291 .34109 .52235 .31857 Mtetra
.792 .616 .662 r
.52235 .31857 .5291 .34109 .54157 .33099 .53476 .29458 Mtetra
.622 .463 .646 r
.53476 .29458 .54157 .33099 .55398 .31367 .54719 .28652 Mtetra
.737 .565 .66 r
.54719 .28652 .55398 .31367 .56618 .28566 .55952 .26767 Mtetra
.461 .46 .771 r
.55952 .26767 .56618 .28566 .57861 .27684 .57215 .27081 Mtetra
.839 .391 0 r
.57215 .27081 .57861 .27684 .59143 .28452 .5854 .298 Mtetra
.785 .395 .316 r
.5854 .298 .59143 .28452 .60435 .28968 .59896 .3238 Mtetra
.586 .263 .389 r
.59896 .3238 .60435 .28968 .61876 .33703 .61234 .33253 Mtetra
.918 .522 .161 r
.61234 .33253 .61876 .33703 .63311 .36861 .62725 .3809 Mtetra
.517 .087 .162 r
.62725 .3809 .63311 .36861 .64694 .37784 .64097 .38422 Mtetra
.211 0 0 r
.64097 .38422 .64694 .37784 .66172 .40388 .65457 .38172 Mtetra
.893 .67 .594 r
.65457 .38172 .66172 .40388 .67439 .38045 .66598 .33143 Mtetra
.784 .552 .585 r
.66598 .33143 .67439 .38045 .68412 .30464 .6771 .28218 Mtetra
.731 .587 .694 r
.6771 .28218 .68412 .30464 .69652 .28436 .68983 .26749 Mtetra
.536 .525 .79 r
.68983 .26749 .69652 .28436 .70791 .24925 .70345 .26754 Mtetra
.601 .215 .282 r
.70345 .26754 .70791 .24925 .72437 .29194 .71773 .2759 Mtetra
.831 .479 0 r
.71773 .2759 .72437 .29194 .73994 .31524 .73602 .33823 Mtetra
.55 .189 .307 r
.73602 .33823 .73994 .31524 .75583 .33837 .75068 .34314 Mtetra
.984 .837 .448 r
.75068 .34314 .75583 .33837 .76842 .31739 .76104 .29256 Mtetra
.89 .659 .583 r
.76104 .29256 .76842 .31739 .77807 .26363 .77104 .24222 Mtetra
.741 .601 .701 r
.77104 .24222 .77807 .26363 .78991 .23805 .78387 .22725 Mtetra
.761 .711 .805 r
.17606 .43521 .18355 .44461 .19461 .4398 .18761 .42608 Mtetra
.697 .312 0 r
.18761 .42608 .19461 .4398 .20018 .48879 .19624 .44467 Mtetra
0 0 .096 r
.19624 .44467 .20018 .48879 .20843 .51496 .20147 .49863 Mtetra
0 0 .432 r
.20147 .49863 .20843 .51496 .21986 .51061 .21072 .51628 Mtetra
.978 .872 .661 r
.21072 .51628 .21986 .51061 .23625 .4531 .22509 .48234 Mtetra
.961 .865 .459 r
.22509 .48234 .23625 .4531 .25015 .41994 .24189 .42011 Mtetra
.952 .831 .688 r
.24189 .42011 .25015 .41994 .26148 .41498 .25545 .39048 Mtetra
0 0 .525 r
.25545 .39048 .26148 .41498 .27107 .43195 .26466 .4108 Mtetra
.033 .14 .645 r
.26466 .4108 .27107 .43195 .27852 .47875 .2746 .42484 Mtetra
0 0 .432 r
.2746 .42484 .27852 .47875 .28961 .48235 .28259 .46656 Mtetra
.067 .242 .734 r
.28259 .46656 .28961 .48235 .30029 .49327 .29329 .47667 Mtetra
.568 .538 .781 r
.29329 .47667 .30029 .49327 .31242 .48503 .30494 .47545 Mtetra
.704 .71 .853 r
.30494 .47545 .31242 .48503 .3263 .44967 .31699 .46938 Mtetra
.94 .88 .468 r
.31699 .46938 .3263 .44967 .34044 .40693 .33156 .4234 Mtetra
.735 .84 .393 r
.33156 .4234 .34044 .40693 .35396 .37098 .34479 .39592 Mtetra
.679 .75 .253 r
.34479 .39592 .35396 .37098 .36707 .33927 .35845 .35824 Mtetra
.815 .845 .384 r
.35845 .35824 .36707 .33927 .37795 .35045 .37179 .32287 Mtetra
.546 .439 .684 r
.37179 .32287 .37795 .35045 .39021 .33434 .38329 .32264 Mtetra
.741 .68 .792 r
.38329 .32264 .39021 .33434 .40176 .33473 .39525 .3137 Mtetra
0 .116 .634 r
.39525 .3137 .40176 .33473 .41295 .34732 .40624 .32988 Mtetra
.631 .561 .757 r
.40624 .32988 .41295 .34732 .42462 .35101 .41818 .32553 Mtetra
.594 .482 .696 r
.41818 .32553 .42462 .35101 .43578 .37656 .43013 .3221 Mtetra
.332 .224 .578 r
.43013 .3221 .43578 .37656 .44788 .3757 .44149 .34275 Mtetra
.749 .557 .635 r
.44149 .34275 .44788 .3757 .46011 .37296 .45419 .31693 Mtetra
.552 .382 .604 r
.45419 .31693 .46011 .37296 .47258 .36041 .46631 .31506 Mtetra
.368 .266 .606 r
.46631 .31506 .47258 .36041 .48497 .35333 .47825 .33013 Mtetra
.727 .577 .685 r
.47825 .33013 .48497 .35333 .49739 .34596 .49074 .31525 Mtetra
.639 .491 .666 r
.49074 .31525 .49739 .34596 .50984 .34168 .50316 .30674 Mtetra
.655 .49 .647 r
.50316 .30674 .50984 .34168 .52235 .31857 .51561 .29496 Mtetra
.818 .625 .642 r
.51561 .29496 .52235 .31857 .53476 .29458 .52803 .26437 Mtetra
.538 .427 .675 r
.52803 .26437 .53476 .29458 .54719 .28652 .54046 .26462 Mtetra
.308 .326 .717 r
.54046 .26462 .54719 .28652 .55952 .26767 .55308 .27426 Mtetra
.666 .193 .119 r
.55308 .27426 .55952 .26767 .57215 .27081 .5659 .28432 Mtetra
.692 .287 .275 r
.5659 .28432 .57215 .27081 .5854 .298 .57897 .29836 Mtetra
.881 .455 .173 r
.57897 .29836 .5854 .298 .59896 .3238 .5927 .33091 Mtetra
.834 .417 .248 r
.5927 .33091 .59896 .3238 .61234 .33253 .60672 .35958 Mtetra
.658 .308 .368 r
.60672 .35958 .61234 .33253 .62725 .3809 .62069 .37583 Mtetra
.769 .881 .927 r
.62069 .37583 .62725 .3809 .64097 .38422 .63403 .3675 Mtetra
.875 .693 .652 r
.63403 .3675 .64097 .38422 .65457 .38172 .64643 .33565 Mtetra
.732 .521 .607 r
.64643 .33565 .65457 .38172 .66598 .33143 .65868 .30433 Mtetra
.861 .638 .598 r
.65868 .30433 .66598 .33143 .6771 .28218 .66998 .25777 Mtetra
.758 .591 .67 r
.66998 .25777 .6771 .28218 .68983 .26749 .68245 .23831 Mtetra
.136 .17 .633 r
.68245 .23831 .68983 .26749 .70345 .26754 .69732 .26039 Mtetra
.884 .48 .042 r
.69732 .26039 .70345 .26754 .71773 .2759 .7142 .30875 Mtetra
.709 .361 .387 r
.7142 .30875 .71773 .2759 .73602 .33823 .73025 .33687 Mtetra
.962 .936 .707 r
.73025 .33687 .73602 .33823 .75068 .34314 .74294 .3141 Mtetra
.84 .621 .607 r
.74294 .3141 .75068 .34314 .76104 .29256 .75412 .27346 Mtetra
.918 .694 .584 r
.75412 .27346 .76104 .29256 .77104 .24222 .76435 .22477 Mtetra
0 .162 .684 r
.76435 .22477 .77104 .24222 .78387 .22725 .78016 .24333 Mtetra
.782 .834 .37 r
.16438 .46164 .17606 .43521 .18761 .42608 .17923 .42432 Mtetra
.871 .462 .247 r
.17923 .42432 .18761 .42608 .19624 .44467 .18758 .4454 Mtetra
.845 .436 .265 r
.18758 .4454 .19624 .44467 .20147 .49863 .19628 .46517 Mtetra
.209 .179 .603 r
.19628 .46517 .20147 .49863 .21072 .51628 .20561 .48092 Mtetra
.656 .49 .647 r
.20561 .48092 .21072 .51628 .22509 .48234 .21781 .46923 Mtetra
.876 .693 .651 r
.21781 .46923 .22509 .48234 .24189 .42011 .23248 .43126 Mtetra
.975 .92 .613 r
.23248 .43126 .24189 .42011 .25545 .39048 .24651 .3983 Mtetra
.745 .953 .646 r
.24651 .3983 .25545 .39048 .26466 .4108 .25879 .38358 Mtetra
0 0 .472 r
.25879 .38358 .26466 .4108 .2746 .42484 .26781 .40753 Mtetra
.912 .565 .101 r
.26781 .40753 .2746 .42484 .28259 .46656 .27599 .44531 Mtetra
.78 .467 0 r
.27599 .44531 .28259 .46656 .29329 .47667 .28482 .4791 Mtetra
.569 .03 0 r
.28482 .4791 .29329 .47667 .30494 .47545 .29603 .48484 Mtetra
0 0 0 r
.29603 .48484 .30494 .47545 .31699 .46938 .30861 .47234 Mtetra
.978 .853 .65 r
.30861 .47234 .31699 .46938 .33156 .4234 .3227 .43658 Mtetra
.895 .92 .528 r
.3227 .43658 .33156 .4234 .34479 .39592 .33624 .40684 Mtetra
.839 .93 .549 r
.33624 .40684 .34479 .39592 .35845 .35824 .34927 .38346 Mtetra
.002 0 .101 r
.34927 .38346 .35845 .35824 .37179 .32287 .36195 .36495 Mtetra
.071 0 .231 r
.36195 .36495 .37179 .32287 .38329 .32264 .37505 .33686 Mtetra
.861 .892 .468 r
.37505 .33686 .38329 .32264 .39525 .3137 .38814 .30612 Mtetra
0 .309 .789 r
.38814 .30612 .39525 .3137 .40624 .32988 .39949 .31306 Mtetra
.357 .409 .778 r
.39949 .31306 .40624 .32988 .41818 .32553 .41105 .31852 Mtetra
.453 .685 .965 r
.41105 .31852 .41818 .32553 .43013 .3221 .42293 .31852 Mtetra
.905 .865 .79 r
.42293 .31852 .43013 .3221 .44149 .34275 .43539 .30186 Mtetra
.657 .477 .629 r
.43539 .30186 .44149 .34275 .45419 .31693 .44774 .28771 Mtetra
.579 .456 .676 r
.44774 .28771 .45419 .31693 .46631 .31506 .45983 .28486 Mtetra
.368 .312 .662 r
.45983 .28486 .46631 .31506 .47825 .33013 .47176 .29475 Mtetra
.512 .391 .652 r
.47176 .29475 .47825 .33013 .49074 .31525 .48397 .29697 Mtetra
.712 .6 .73 r
.48397 .29697 .49074 .31525 .50316 .30674 .49641 .28657 Mtetra
.78 .621 .684 r
.49641 .28657 .50316 .30674 .51561 .29496 .5089 .26725 Mtetra
.657 .513 .676 r
.5089 .26725 .51561 .29496 .52803 .26437 .52132 .25782 Mtetra
.825 .371 0 r
.52132 .25782 .52803 .26437 .54046 .26462 .53387 .28252 Mtetra
.665 .285 .316 r
.53387 .28252 .54046 .26462 .55308 .27426 .54664 .29569 Mtetra
.678 .313 .347 r
.54664 .29569 .55308 .27426 .5659 .28432 .55967 .3118 Mtetra
.742 .395 .394 r
.55967 .3118 .5659 .28432 .57897 .29836 .57317 .34227 Mtetra
.662 .345 .426 r
.57317 .34227 .57897 .29836 .5927 .33091 .58691 .36623 Mtetra
.579 .255 .384 r
.58691 .36623 .5927 .33091 .60672 .35958 .60058 .37473 Mtetra
.052 0 .02 r
.60058 .37473 .60672 .35958 .62069 .37583 .61381 .36252 Mtetra
.708 .668 .809 r
.61381 .36252 .62069 .37583 .63403 .3675 .6272 .35468 Mtetra
.939 .731 .595 r
.6272 .35468 .63403 .3675 .64643 .33565 .63905 .30645 Mtetra
.765 .578 .645 r
.63905 .30645 .64643 .33565 .65868 .30433 .65159 .2817 Mtetra
.86 .653 .622 r
.65159 .2817 .65868 .30433 .66998 .25777 .66338 .24396 Mtetra
.5 .551 .84 r
.66338 .24396 .66998 .25777 .68245 .23831 .67698 .24478 Mtetra
.78 .321 .154 r
.67698 .24478 .68245 .23831 .69732 .26039 .69182 .26525 Mtetra
.874 .451 .199 r
.69182 .26525 .69732 .26039 .7142 .30875 .70808 .3036 Mtetra
.738 .253 0 r
.70808 .3036 .7142 .30875 .73025 .33687 .72385 .32733 Mtetra
.935 .788 .673 r
.72385 .32733 .73025 .33687 .74294 .3141 .73616 .29818 Mtetra
.931 .717 .592 r
.73616 .29818 .74294 .3141 .75412 .27346 .74702 .25232 Mtetra
.746 .608 .704 r
.74702 .25232 .75412 .27346 .76435 .22477 .76006 .23704 Mtetra
.458 .023 .123 r
.76006 .23704 .76435 .22477 .78016 .24333 .77449 .23829 Mtetra
.997 .852 .564 r
.1532 .48156 .16438 .46164 .17923 .42432 .17116 .41902 Mtetra
0 .224 .648 r
.17116 .41902 .17923 .42432 .18758 .4454 .18115 .42496 Mtetra
.239 .286 .71 r
.18115 .42496 .18758 .4454 .19628 .46517 .19095 .43371 Mtetra
.73 .498 0 r
.19095 .43371 .19628 .46517 .20561 .48092 .19752 .47486 Mtetra
.651 .12 0 r
.19752 .47486 .20561 .48092 .21781 .46923 .2075 .48573 Mtetra
.941 .919 .547 r
.2075 .48573 .21781 .46923 .23248 .43126 .22215 .45013 Mtetra
.99 .877 .541 r
.22215 .45013 .23248 .43126 .24651 .3983 .23822 .39748 Mtetra
.749 .954 .941 r
.23822 .39748 .24651 .3983 .25879 .38358 .24992 .39013 Mtetra
.889 .984 .71 r
.24992 .39013 .25879 .38358 .26781 .40753 .26255 .37223 Mtetra
0 0 .386 r
.26255 .37223 .26781 .40753 .27599 .44531 .27093 .40526 Mtetra
0 0 .29 r
.27093 .40526 .27599 .44531 .28482 .4791 .27888 .44789 Mtetra
.262 .232 .636 r
.27888 .44789 .28482 .4791 .29603 .48484 .28942 .46133 Mtetra
.416 .384 .715 r
.28942 .46133 .29603 .48484 .30861 .47234 .30073 .46663 Mtetra
.645 .111 0 r
.30073 .46663 .30861 .47234 .3227 .43658 .31173 .47841 Mtetra
0 0 .095 r
.31173 .47841 .3227 .43658 .33624 .40684 .32605 .44096 Mtetra
.009 0 .157 r
.32605 .44096 .33624 .40684 .34927 .38346 .33938 .41667 Mtetra
.679 .719 .202 r
.33938 .41667 .34927 .38346 .36195 .36495 .354 .36756 Mtetra
.951 .944 .735 r
.354 .36756 .36195 .36495 .37505 .33686 .36685 .3468 Mtetra
0 0 0 r
.36685 .3468 .37505 .33686 .38814 .30612 .37898 .33928 Mtetra
.37898 .33928 .38814 .30612 .39949 .31306 .39245 .30246 Mtetra
.038 .331 .813 r
.39245 .30246 .39949 .31306 .41105 .31852 .40392 .30995 Mtetra
.871 .761 .738 r
.40392 .30995 .41105 .31852 .42293 .31852 .41652 .29056 Mtetra
.383 .332 .676 r
.41652 .29056 .42293 .31852 .43539 .30186 .42817 .29873 Mtetra
.922 .868 .768 r
.42817 .29873 .43539 .30186 .44774 .28771 .44073 .28004 Mtetra
.801 .783 .836 r
.44073 .28004 .44774 .28771 .45983 .28486 .45303 .26962 Mtetra
0 .161 .692 r
.45303 .26962 .45983 .28486 .47176 .29475 .46487 .28267 Mtetra
.858 .717 .705 r
.46487 .28267 .47176 .29475 .48397 .29697 .47747 .26058 Mtetra
.074 .084 .564 r
.47747 .26058 .48397 .29697 .49641 .28657 .48941 .28663 Mtetra
.942 .942 .759 r
.48941 .28663 .49641 .28657 .5089 .26725 .50201 .26768 Mtetra
.501 0 0 r
.50201 .26768 .5089 .26725 .52132 .25782 .51447 .27376 Mtetra
.736 .352 .326 r
.51447 .27376 .52132 .25782 .53387 .28252 .52709 .29395 Mtetra
.745 .335 .272 r
.52709 .29395 .53387 .28252 .54664 .29569 .53998 .31243 Mtetra
.641 .25 .287 r
.53998 .31243 .54664 .29569 .55967 .3118 .55306 .32341 Mtetra
.837 .45 .318 r
.55306 .32341 .55967 .3118 .57317 .34227 .56669 .35889 Mtetra
.513 .117 .227 r
.56669 .35889 .57317 .34227 .58691 .36623 .58012 .36168 Mtetra
.38 .75 .991 r
.58012 .36168 .58691 .36623 .60058 .37473 .59361 .36113 Mtetra
.85 .715 .714 r
.59361 .36113 .60058 .37473 .61381 .36252 .60663 .33973 Mtetra
.782 .615 .674 r
.60663 .33973 .61381 .36252 .6272 .35468 .61956 .31815 Mtetra
.845 .609 .581 r
.61956 .31815 .6272 .35468 .63905 .30645 .63111 .26146 Mtetra
.66 .473 .62 r
.63111 .26146 .63905 .30645 .65159 .2817 .64391 .24491 Mtetra
.672 .497 .64 r
.64391 .24491 .65159 .2817 .66338 .24396 .65674 .22984 Mtetra
0 .124 .672 r
.65674 .22984 .66338 .24396 .67698 .24478 .67113 .24613 Mtetra
.91 .507 .199 r
.67113 .24613 .67698 .24478 .69182 .26525 .68772 .29725 Mtetra
.738 .385 .383 r
.68772 .29725 .69182 .26525 .70808 .3036 .70388 .33118 Mtetra
0 0 .059 r
.70388 .33118 .70808 .3036 .72385 .32733 .71558 .28993 Mtetra
.702 .516 .635 r
.71558 .28993 .72385 .32733 .73616 .29818 .72851 .27017 Mtetra
.839 .624 .612 r
.72851 .27017 .73616 .29818 .74702 .25232 .73996 .23163 Mtetra
.822 .648 .667 r
.73996 .23163 .74702 .25232 .76006 .23704 .75226 .20692 Mtetra
0 0 .475 r
.75226 .20692 .76006 .23704 .77449 .23829 .77027 .2511 Mtetra
.981 .81 .598 r
.1429 .49238 .1532 .48156 .17116 .41902 .16106 .43022 Mtetra
.927 .957 .637 r
.16106 .43022 .17116 .41902 .18115 .42496 .17461 .40548 Mtetra
.242 .299 .722 r
.17461 .40548 .18115 .42496 .19095 .43371 .18443 .41363 Mtetra
.878 .55 .043 r
.18443 .41363 .19095 .43371 .19752 .47486 .1916 .44774 Mtetra
.713 .458 0 r
.1916 .44774 .19752 .47486 .2075 .48573 .19899 .48288 Mtetra
.7 .897 .968 r
.19899 .48288 .2075 .48573 .22215 .45013 .21078 .47724 Mtetra
.972 .87 .482 r
.21078 .47724 .22215 .45013 .23822 .39748 .22795 .41618 Mtetra
.719 .837 .394 r
.22795 .41618 .23822 .39748 .24992 .39013 .24161 .38904 Mtetra
.921 .878 .776 r
.24161 .38904 .24992 .39013 .26255 .37223 .25437 .37072 Mtetra
.878 .91 .847 r
.25437 .37072 .26255 .37223 .27093 .40526 .26661 .35788 Mtetra
.18 .117 .545 r
.26661 .35788 .27093 .40526 .27888 .44789 .27583 .38195 Mtetra
0 0 .376 r
.27583 .38195 .27888 .44789 .28942 .46133 .28297 .43612 Mtetra
0 0 .486 r
.28297 .43612 .28942 .46133 .30073 .46663 .29289 .45927 Mtetra
0 .033 .523 r
.29289 .45927 .30073 .46663 .31173 .47841 .30399 .46958 Mtetra
.802 .754 .808 r
.30399 .46958 .31173 .47841 .32605 .44096 .31672 .45774 Mtetra
0 0 0 r
.31672 .45774 .32605 .44096 .33938 .41667 .33 .43701 Mtetra
.11 0 .085 r
.33 .43701 .33938 .41667 .354 .36756 .3427 .42503 Mtetra
.099 0 .273 r
.3427 .42503 .354 .36756 .36685 .3468 .35671 .38922 Mtetra
0 0 .061 r
.35671 .38922 .36685 .3468 .37898 .33928 .37089 .34623 Mtetra
.889 .968 .651 r
.37089 .34623 .37898 .33928 .39245 .30246 .38377 .32558 Mtetra
0 0 .071 r
.38377 .32558 .39245 .30246 .40392 .30995 .39645 .30787 Mtetra
.772 .942 .936 r
.39645 .30787 .40392 .30995 .41652 .29056 .40871 .29977 Mtetra
.626 .183 .178 r
.40871 .29977 .41652 .29056 .42817 .29873 .42044 .30761 Mtetra
0 0 0 r
.42044 .30761 .42817 .29873 .44073 .28004 .43279 .3004 Mtetra
.066 0 .087 r
.43279 .3004 .44073 .28004 .45303 .26962 .44535 .28637 Mtetra
0 0 .001 r
.44535 .28637 .45303 .26962 .46487 .28267 .45788 .27317 Mtetra
.813 .382 0 r
.45788 .27317 .46487 .28267 .47747 .26058 .46968 .29888 Mtetra
.519 .209 .381 r
.46968 .29888 .47747 .26058 .48941 .28663 .48212 .30099 Mtetra
.113 0 .013 r
.48212 .30099 .48941 .28663 .50201 .26768 .49479 .29187 Mtetra
.617 .261 .345 r
.49479 .29187 .50201 .26768 .51447 .27376 .50738 .30236 Mtetra
.607 .265 .365 r
.50738 .30236 .51447 .27376 .52709 .29395 .52015 .31291 Mtetra
.761 .39 .353 r
.52015 .31291 .52709 .29395 .53998 .31243 .53317 .33976 Mtetra
.687 .336 .376 r
.53317 .33976 .53998 .31243 .55306 .32341 .54649 .36026 Mtetra
.686 .354 .408 r
.54649 .36026 .55306 .32341 .56669 .35889 .56015 .38587 Mtetra
.369 .042 .273 r
.56015 .38587 .56669 .35889 .58012 .36168 .57361 .37889 Mtetra
0 0 0 r
.57361 .37889 .58012 .36168 .59361 .36113 .58672 .35293 Mtetra
.923 .795 .7 r
.58672 .35293 .59361 .36113 .60663 .33973 .59971 .3268 Mtetra
.947 .727 .574 r
.59971 .3268 .60663 .33973 .61956 .31815 .61165 .27035 Mtetra
.728 .514 .602 r
.61165 .27035 .61956 .31815 .63111 .26146 .62405 .23885 Mtetra
.65 .541 .717 r
.62405 .23885 .63111 .26146 .64391 .24491 .63722 .23154 Mtetra
0 .082 .643 r
.63722 .23154 .64391 .24491 .65674 .22984 .6515 .24834 Mtetra
.719 .328 .307 r
.6515 .24834 .65674 .22984 .67113 .24613 .66624 .26906 Mtetra
.775 .402 .348 r
.66624 .26906 .67113 .24613 .68772 .29725 .68202 .30341 Mtetra
.14 0 0 r
.68202 .30341 .68772 .29725 .70388 .33118 .69604 .29997 Mtetra
.773 .578 .635 r
.69604 .29997 .70388 .33118 .71558 .28993 .70863 .27249 Mtetra
.9 .701 .624 r
.70863 .27249 .71558 .28993 .72851 .27017 .72039 .23494 Mtetra
.803 .583 .604 r
.72039 .23494 .72851 .27017 .73996 .23163 .73186 .19674 Mtetra
0 0 .457 r
.73186 .19674 .73996 .23163 .75226 .20692 .74988 .24604 Mtetra
.56 .237 .378 r
.74988 .24604 .75226 .20692 .77027 .2511 .76505 .25355 Mtetra
.581 .471 .693 r
.13697 .46643 .1429 .49238 .16106 .43022 .14811 .46373 Mtetra
0 0 0 r
.14811 .46373 .16106 .43022 .17461 .40548 .16365 .42386 Mtetra
.645 .813 .383 r
.16365 .42386 .17461 .40548 .18443 .41363 .1771 .40061 Mtetra
.286 .432 .834 r
.1771 .40061 .18443 .41363 .1916 .44774 .18742 .40518 Mtetra
0 0 .318 r
.18742 .40518 .1916 .44774 .19899 .48288 .19419 .44411 Mtetra
.236 .18 .588 r
.19419 .44411 .19899 .48288 .21078 .47724 .20362 .46073 Mtetra
.773 .641 .715 r
.20362 .46073 .21078 .47724 .22795 .41618 .21647 .44485 Mtetra
.768 .81 .331 r
.21647 .44485 .22795 .41618 .24161 .38904 .23176 .40299 Mtetra
.99 .888 .576 r
.23176 .40299 .24161 .38904 .25437 .37072 .24701 .35905 Mtetra
.819 .701 .734 r
.24701 .35905 .25437 .37072 .26661 .35788 .25966 .34209 Mtetra
.769 .405 0 r
.25966 .34209 .26661 .35788 .27583 .38195 .26871 .36716 Mtetra
0 .158 .694 r
.26871 .36716 .27583 .38195 .28297 .43612 .27915 .37834 Mtetra
.355 .23 .569 r
.27915 .37834 .28297 .43612 .29289 .45927 .28929 .39571 Mtetra
0 0 .425 r
.28929 .39571 .29289 .45927 .30399 .46958 .29746 .44303 Mtetra
.021 .097 .603 r
.29746 .44303 .30399 .46958 .31672 .45774 .30812 .46093 Mtetra
.502 .9 .769 r
.30812 .46093 .31672 .45774 .33 .43701 .32065 .45367 Mtetra
.861 .89 .463 r
.32065 .45367 .33 .43701 .3427 .42503 .33483 .41997 Mtetra
.795 .852 .893 r
.33483 .41997 .3427 .42503 .35671 .38922 .34743 .41083 Mtetra
0 0 0 r
.34743 .41083 .35671 .38922 .37089 .34623 .36087 .38638 Mtetra
.195 0 .265 r
.36087 .38638 .37089 .34623 .38377 .32558 .37401 .36605 Mtetra
.377 .085 .337 r
.37401 .36605 .38377 .32558 .39645 .30787 .38659 .35624 Mtetra
.345 .072 .349 r
.38659 .35624 .39645 .30787 .40871 .29977 .3994 .34153 Mtetra
.196 0 .276 r
.3994 .34153 .40871 .29977 .42044 .30761 .41243 .31989 Mtetra
.531 .105 .176 r
.41243 .31989 .42044 .30761 .43279 .3004 .42454 .3237 Mtetra
.056 0 .109 r
.42454 .3237 .43279 .3004 .44535 .28637 .43736 .30754 Mtetra
.615 .249 .326 r
.43736 .30754 .44535 .28637 .45788 .27317 .4495 .31716 Mtetra
.401 .115 .359 r
.4495 .31716 .45788 .27317 .46968 .29888 .4622 .3079 Mtetra
.82 .423 .298 r
.4622 .3079 .46968 .29888 .48212 .30099 .47432 .33555 Mtetra
.555 .231 .373 r
.47432 .33555 .48212 .30099 .49479 .29187 .48704 .34156 Mtetra
.41 .13 .375 r
.48704 .34156 .49479 .29187 .50738 .30236 .50004 .33149 Mtetra
.677 .332 .382 r
.50004 .33149 .50738 .30236 .52015 .31291 .51295 .35135 Mtetra
.596 .273 .393 r
.51295 .35135 .52015 .31291 .53317 .33976 .52613 .36281 Mtetra
.485 .125 .279 r
.52613 .36281 .53317 .33976 .54649 .36026 .53947 .36357 Mtetra
.737 .242 .057 r
.53947 .36357 .54649 .36026 .56015 .38587 .55305 .3785 Mtetra
.96 .774 .607 r
.55305 .3785 .56015 .38587 .57361 .37889 .56603 .33372 Mtetra
.688 .493 .618 r
.56603 .33372 .57361 .37889 .58672 .35293 .57916 .3122 Mtetra
.8 .574 .595 r
.57916 .3122 .58672 .35293 .59971 .3268 .59164 .2669 Mtetra
.665 .457 .594 r
.59164 .2669 .59971 .3268 .61165 .27035 .60443 .24324 Mtetra
.806 .608 .634 r
.60443 .24324 .61165 .27035 .62405 .23885 .61688 .21279 Mtetra
0 0 .499 r
.61688 .21279 .62405 .23885 .63722 .23154 .63149 .24494 Mtetra
.597 .168 .199 r
.63149 .24494 .63722 .23154 .6515 .24834 .6455 .25288 Mtetra
.91 .518 .248 r
.6455 .25288 .6515 .24834 .66624 .26906 .66194 .30884 Mtetra
.454 .15 .359 r
.66194 .30884 .66624 .26906 .68202 .30341 .67595 .30472 Mtetra
.989 .89 .579 r
.67595 .30472 .68202 .30341 .69604 .29997 .68829 .26964 Mtetra
.825 .61 .611 r
.68829 .26964 .69604 .29997 .70863 .27249 .70021 .23135 Mtetra
.771 .552 .601 r
.70021 .23135 .70863 .27249 .72039 .23494 .71202 .19508 Mtetra
.517 .388 .644 r
.71202 .19508 .72039 .23494 .73186 .19674 .72628 .19676 Mtetra
.893 .47 .12 r
.72628 .19676 .73186 .19674 .74988 .24604 .74412 .24375 Mtetra
.544 0 0 r
.74412 .24375 .74988 .24604 .76505 .25355 .75974 .25599 Mtetra
.591 .685 .907 r
.12891 .4575 .13697 .46643 .14811 .46373 .14 .4553 Mtetra
.861 .74 .727 r
.14 .4553 .14811 .46373 .16365 .42386 .1534 .43437 Mtetra
.987 .838 .608 r
.1534 .43437 .16365 .42386 .1771 .40061 .17026 .38309 Mtetra
0 .149 .673 r
.17026 .38309 .1771 .40061 .18742 .40518 .17978 .39444 Mtetra
.946 .586 .26 r
.17978 .39444 .18742 .40518 .19419 .44411 .18669 .43107 Mtetra
.847 .446 0 r
.18669 .43107 .19419 .44411 .20362 .46073 .19533 .45464 Mtetra
.606 .779 .964 r
.19533 .45464 .20362 .46073 .21647 .44485 .20693 .45163 Mtetra
.967 .934 .686 r
.20693 .45163 .21647 .44485 .23176 .40299 .2209 .42515 Mtetra
0 0 0 r
.2209 .42515 .23176 .40299 .24701 .35905 .23397 .40707 Mtetra
.23397 .40707 .24701 .35905 .25966 .34209 .2508 .34692 Mtetra
.2508 .34692 .25966 .34209 .26871 .36716 .26235 .3433 Mtetra
.015 .106 .615 r
.26235 .3433 .26871 .36716 .27915 .37834 .27235 .35894 Mtetra
.354 .38 .749 r
.27235 .35894 .27915 .37834 .28929 .39571 .28334 .36465 Mtetra
.058 .089 .578 r
.28334 .36465 .28929 .39571 .29746 .44303 .29342 .3841 Mtetra
.368 .239 .571 r
.29342 .3841 .29746 .44303 .30812 .46093 .30396 .40056 Mtetra
.241 .145 .54 r
.30396 .40056 .30812 .46093 .32065 .45367 .31401 .42729 Mtetra
.599 .487 .697 r
.31401 .42729 .32065 .45367 .33483 .41997 .32635 .42307 Mtetra
.167 0 0 r
.32635 .42307 .33483 .41997 .34743 .41083 .33851 .42263 Mtetra
0 0 0 r
.33851 .42263 .34743 .41083 .36087 .38638 .35128 .41322 Mtetra
.099 0 .142 r
.35128 .41322 .36087 .38638 .37401 .36605 .36442 .39694 Mtetra
.367 .049 .287 r
.36442 .39694 .37401 .36605 .38659 .35624 .37709 .3896 Mtetra
.362 .052 .299 r
.37709 .3896 .38659 .35624 .3994 .34153 .38985 .38121 Mtetra
.396 .098 .337 r
.38985 .38121 .3994 .34153 .41243 .31989 .40262 .37318 Mtetra
.375 .102 .366 r
.40262 .37318 .41243 .31989 .42454 .3237 .41561 .35966 Mtetra
.267 0 .277 r
.41561 .35966 .42454 .3237 .43736 .30754 .42864 .34478 Mtetra
.626 .302 .402 r
.42864 .34478 .43736 .30754 .4495 .31716 .44082 .35995 Mtetra
.542 .232 .393 r
.44082 .35995 .4495 .31716 .4622 .3079 .45346 .36507 Mtetra
.377 .11 .376 r
.45346 .36507 .4622 .3079 .47432 .33555 .46662 .3503 Mtetra
.773 .387 .325 r
.46662 .3503 .47432 .33555 .48704 .34156 .47917 .37557 Mtetra
.178 0 .237 r
.47917 .37557 .48704 .34156 .50004 .33149 .4925 .35657 Mtetra
.703 .345 .366 r
.4925 .35657 .50004 .33149 .51295 .35135 .50553 .37842 Mtetra
.23 0 .214 r
.50553 .37842 .51295 .35135 .52613 .36281 .51891 .3654 Mtetra
.959 .946 .678 r
.51891 .3654 .52613 .36281 .53947 .36357 .53225 .34066 Mtetra
.62 .525 .725 r
.53225 .34066 .53947 .36357 .55305 .3785 .54562 .33545 Mtetra
.811 .579 .587 r
.54562 .33545 .55305 .3785 .56603 .33372 .5585 .28291 Mtetra
.658 .463 .609 r
.5585 .28291 .56603 .33372 .57916 .3122 .57156 .26431 Mtetra
.648 .459 .615 r
.57156 .26431 .57916 .3122 .59164 .2669 .58462 .24855 Mtetra
.897 .689 .613 r
.58462 .24855 .59164 .2669 .60443 .24324 .59697 .2061 Mtetra
.447 .345 .647 r
.59697 .2061 .60443 .24324 .61688 .21279 .61053 .21298 Mtetra
.922 .532 .223 r
.61053 .21298 .61688 .21279 .63149 .24494 .62599 .26931 Mtetra
.667 .296 .333 r
.62599 .26931 .63149 .24494 .6455 .25288 .64055 .28658 Mtetra
.702 .352 .381 r
.64055 .28658 .6455 .25288 .66194 .30884 .65585 .31421 Mtetra
.96 .898 .521 r
.65585 .31421 .66194 .30884 .67595 .30472 .66841 .27841 Mtetra
.875 .649 .594 r
.66841 .27841 .67595 .30472 .68829 .26964 .6801 .23072 Mtetra
.628 .464 .641 r
.6801 .23072 .68829 .26964 .70021 .23135 .69366 .22049 Mtetra
.836 .765 .784 r
.69366 .22049 .70021 .23135 .71202 .19508 .70692 .20537 Mtetra
.794 .357 .208 r
.70692 .20537 .71202 .19508 .72628 .19676 .72302 .23177 Mtetra
.743 .386 .376 r
.72302 .23177 .72628 .19676 .74412 .24375 .7404 .27003 Mtetra
0 0 .158 r
.7404 .27003 .74412 .24375 .75974 .25599 .75315 .24343 Mtetra
.82 .548 0 r
.12319 .43 .12891 .4575 .14 .4553 .12919 .46775 Mtetra
0 0 0 r
.12919 .46775 .14 .4553 .1534 .43437 .14182 .45423 Mtetra
.997 .845 .563 r
.14182 .45423 .1534 .43437 .17026 .38309 .16075 .38778 Mtetra
.964 .912 .713 r
.16075 .38778 .17026 .38309 .17978 .39444 .17449 .3628 Mtetra
.072 .088 .569 r
.17449 .3628 .17978 .39444 .18669 .43107 .18334 .38064 Mtetra
0 0 .276 r
.18334 .38064 .18669 .43107 .19533 .45464 .18926 .42737 Mtetra
0 0 .355 r
.18926 .42737 .19533 .45464 .20693 .45163 .19768 .45428 Mtetra
.608 .954 .844 r
.19768 .45428 .20693 .45163 .2209 .42515 .20986 .44676 Mtetra
.923 .894 .485 r
.20986 .44676 .2209 .42515 .23397 .40707 .22549 .40417 Mtetra
.882 .871 .822 r
.22549 .40417 .23397 .40707 .2508 .34692 .23825 .38968 Mtetra
0 0 0 r
.23825 .38968 .2508 .34692 .26235 .3433 .254 .34171 Mtetra
.923 .873 .77 r
.254 .34171 .26235 .3433 .27235 .35894 .26698 .32267 Mtetra
.471 .356 .64 r
.26698 .32267 .27235 .35894 .28334 .36465 .278 .32683 Mtetra
.346 .263 .618 r
.278 .32683 .28334 .36465 .29342 .3841 .28855 .33837 Mtetra
.215 .148 .562 r
.28855 .33837 .29342 .3841 .30396 .40056 .29856 .35959 Mtetra
.148 .115 .561 r
.29856 .35959 .30396 .40056 .31401 .42729 .30876 .38168 Mtetra
.138 .096 .544 r
.30876 .38168 .31401 .42729 .32635 .42307 .31901 .40692 Mtetra
.351 .43 .803 r
.31901 .40692 .32635 .42307 .33851 .42263 .33085 .41164 Mtetra
.627 .188 0 r
.33085 .41164 .33851 .42263 .35128 .41322 .34208 .42891 Mtetra
0 0 0 r
.34208 .42891 .35128 .41322 .36442 .39694 .35536 .41304 Mtetra
.523 .122 .222 r
.35536 .41304 .36442 .39694 .37709 .3896 .36762 .41648 Mtetra
.019 0 .104 r
.36762 .41648 .37709 .3896 .38985 .38121 .38106 .39762 Mtetra
.36 0 .142 r
.38106 .39762 .38985 .38121 .40262 .37318 .39376 .39468 Mtetra
0 0 0 r
.39376 .39468 .40262 .37318 .41561 .35966 .40716 .37545 Mtetra
.641 .243 .275 r
.40716 .37545 .41561 .35966 .42864 .34478 .41948 .38614 Mtetra
.426 .125 .349 r
.41948 .38614 .42864 .34478 .44082 .35995 .43249 .38019 Mtetra
.334 0 .183 r
.43249 .38019 .44082 .35995 .45346 .36507 .44553 .37487 Mtetra
0 0 0 r
.44553 .37487 .45346 .36507 .46662 .3503 .4588 .36191 Mtetra
.734 .319 .262 r
.4588 .36191 .46662 .3503 .47917 .37557 .47153 .37961 Mtetra
.962 .942 .657 r
.47153 .37961 .47917 .37557 .4925 .35657 .48509 .3531 Mtetra
.746 .229 0 r
.48509 .3531 .4925 .35657 .50553 .37842 .49816 .36995 Mtetra
.949 .763 .617 r
.49816 .36995 .50553 .37842 .51891 .3654 .51173 .32604 Mtetra
.535 .4 .644 r
.51173 .32604 .51891 .3654 .53225 .34066 .52504 .32564 Mtetra
.892 .71 .649 r
.52504 .32564 .53225 .34066 .54562 .33545 .53828 .29144 Mtetra
.754 .538 .604 r
.53828 .29144 .54562 .33545 .5585 .28291 .55132 .25642 Mtetra
.784 .599 .65 r
.55132 .25642 .5585 .28291 .57156 .26431 .56429 .23098 Mtetra
.56 .434 .665 r
.56429 .23098 .57156 .26431 .58462 .24855 .57756 .22865 Mtetra
.443 .442 .762 r
.57756 .22865 .58462 .24855 .59697 .2061 .59106 .23219 Mtetra
.678 .314 .349 r
.59106 .23219 .59697 .2061 .61053 .21298 .60514 .25148 Mtetra
.634 .3 .388 r
.60514 .25148 .61053 .21298 .62599 .26931 .61948 .26943 Mtetra
.854 .399 .087 r
.61948 .26943 .62599 .26931 .64055 .28658 .63457 .29951 Mtetra
0 0 0 r
.63457 .29951 .64055 .28658 .65585 .31421 .64781 .2765 Mtetra
.785 .569 .607 r
.64781 .2765 .65585 .31421 .66841 .27841 .66031 .23992 Mtetra
.781 .564 .605 r
.66031 .23992 .66841 .27841 .6801 .23072 .6726 .20366 Mtetra
.618 .5 .696 r
.6726 .20366 .6801 .23072 .69366 .22049 .68636 .19744 Mtetra
.571 .497 .732 r
.68636 .19744 .69366 .22049 .70692 .20537 .70042 .1951 Mtetra
.737 .323 0 r
.70042 .1951 .70692 .20537 .72302 .23177 .71703 .22935 Mtetra
.504 0 0 r
.71703 .22935 .72302 .23177 .7404 .27003 .73244 .24036 Mtetra
.634 .501 .683 r
.73244 .24036 .7404 .27003 .75315 .24343 .7466 .232 Mtetra
.898 .569 .081 r
.11654 .40979 .12319 .43 .12919 .46775 .12295 .44328 Mtetra
.456 .4 .706 r
.12295 .44328 .12919 .46775 .14182 .45423 .13348 .44644 Mtetra
.838 .759 .776 r
.13348 .44644 .14182 .45423 .16075 .38778 .14636 .43122 Mtetra
0 0 .064 r
.14636 .43122 .16075 .38778 .17449 .3628 .16132 .39828 Mtetra
.783 .808 .323 r
.16132 .39828 .17449 .3628 .18334 .38064 .17796 .34931 Mtetra
.036 .064 .56 r
.17796 .34931 .18334 .38064 .18926 .42737 .18681 .36782 Mtetra
.101 .032 .484 r
.18681 .36782 .18926 .42737 .19768 .45428 .19443 .39981 Mtetra
0 0 .335 r
.19443 .39981 .19768 .45428 .20986 .44676 .20093 .44562 Mtetra
0 .504 .705 r
.20093 .44562 .20986 .44676 .22549 .40417 .21231 .44703 Mtetra
0 0 .058 r
.21231 .44703 .22549 .40417 .23825 .38968 .22733 .41171 Mtetra
.957 .886 .495 r
.22733 .41171 .23825 .38968 .254 .34171 .24349 .36221 Mtetra
.241 0 .135 r
.24349 .36221 .254 .34171 .26698 .32267 .25564 .35457 Mtetra
.757 .786 .292 r
.25564 .35457 .26698 .32267 .278 .32683 .27119 .30733 Mtetra
.21 .286 .724 r
.27119 .30733 .278 .32683 .28855 .33837 .2819 .31625 Mtetra
.449 .415 .728 r
.2819 .31625 .28855 .33837 .29856 .35959 .2932 .31952 Mtetra
.016 .021 .518 r
.2932 .31952 .29856 .35959 .30876 .38168 .30292 .34592 Mtetra
.2 .17 .598 r
.30292 .34592 .30876 .38168 .31901 .40692 .31357 .36312 Mtetra
.548 .395 .626 r
.31357 .36312 .31901 .40692 .33085 .41164 .32571 .36114 Mtetra
.104 .062 .52 r
.32571 .36114 .33085 .41164 .34208 .42891 .33598 .39088 Mtetra
.695 .512 .635 r
.33598 .39088 .34208 .42891 .35536 .41304 .34939 .37187 Mtetra
0 0 .48 r
.34939 .37187 .35536 .41304 .36762 .41648 .35997 .40454 Mtetra
.732 .696 .816 r
.35997 .40454 .36762 .41648 .38106 .39762 .37296 .39589 Mtetra
.269 0 0 r
.37296 .39589 .38106 .39762 .39376 .39468 .38541 .39986 Mtetra
.96 .945 .665 r
.38541 .39986 .39376 .39468 .40716 .37545 .39924 .37352 Mtetra
.737 .213 0 r
.39924 .37352 .40716 .37545 .41948 .38614 .41145 .38772 Mtetra
.35 .824 .787 r
.41145 .38772 .41948 .38614 .43249 .38019 .42451 .38297 Mtetra
.955 .95 .707 r
.42451 .38297 .43249 .38019 .44553 .37487 .43815 .35961 Mtetra
.744 .658 .765 r
.43815 .35961 .44553 .37487 .4588 .36191 .45141 .34831 Mtetra
.61 .621 .838 r
.45141 .34831 .4588 .36191 .47153 .37961 .46452 .34501 Mtetra
.613 .466 .658 r
.46452 .34501 .47153 .37961 .48509 .3531 .47777 .33765 Mtetra
.889 .705 .647 r
.47777 .33765 .48509 .3531 .49816 .36995 .49137 .30258 Mtetra
.672 .457 .585 r
.49137 .30258 .49816 .36995 .51173 .32604 .50472 .27393 Mtetra
.708 .496 .599 r
.50472 .27393 .51173 .32604 .52504 .32564 .51792 .24442 Mtetra
.632 .418 .573 r
.51792 .24442 .52504 .32564 .53828 .29144 .53098 .22067 Mtetra
.55 .364 .582 r
.53098 .22067 .53828 .29144 .55132 .25642 .54407 .21641 Mtetra
.522 .387 .639 r
.54407 .21641 .55132 .25642 .56429 .23098 .55729 .21704 Mtetra
0 0 .557 r
.55729 .21704 .56429 .23098 .57756 .22865 .57092 .23582 Mtetra
.762 .306 .166 r
.57092 .23582 .57756 .22865 .59106 .23219 .58485 .25469 Mtetra
.624 .245 .306 r
.58485 .25469 .59106 .23219 .60514 .25148 .59888 .26661 Mtetra
.721 .308 .264 r
.59888 .26661 .60514 .25148 .61948 .26943 .61337 .28587 Mtetra
0 0 0 r
.61337 .28587 .61948 .26943 .63457 .29951 .6269 .26913 Mtetra
.637 .498 .677 r
.6269 .26913 .63457 .29951 .64781 .2765 .6407 .26033 Mtetra
.935 .716 .582 r
.6407 .26033 .64781 .2765 .66031 .23992 .65263 .20907 Mtetra
.683 .523 .663 r
.65263 .20907 .66031 .23992 .6726 .20366 .66604 .1952 Mtetra
.556 .722 .951 r
.66604 .1952 .6726 .20366 .68636 .19744 .68008 .19296 Mtetra
.811 .346 0 r
.68008 .19296 .68636 .19744 .70042 .1951 .69614 .22287 Mtetra
.764 .39 .347 r
.69614 .22287 .70042 .1951 .71703 .22935 .7131 .25999 Mtetra
0 0 .136 r
.7131 .25999 .71703 .22935 .73244 .24036 .72544 .22385 Mtetra
.922 .719 .611 r
.72544 .22385 .73244 .24036 .7466 .232 .73722 .18354 Mtetra
0 0 .247 r
.11161 .37698 .11654 .40979 .12295 .44328 .11803 .40899 Mtetra
0 0 .116 r
.11803 .40899 .12295 .44328 .13348 .44644 .12384 .44811 Mtetra
.449 0 0 r
.12384 .44811 .13348 .44644 .14636 .43122 .13446 .45169 Mtetra
.985 .891 .556 r
.13446 .45169 .14636 .43122 .16132 .39828 .1517 .40172 Mtetra
.952 .921 .742 r
.1517 .40172 .16132 .39828 .17796 .34931 .16537 .37963 Mtetra
.1 0 .14 r
.16537 .37963 .17796 .34931 .18681 .36782 .17825 .3638 Mtetra
.311 .723 .976 r
.17825 .3638 .18681 .36782 .19443 .39981 .18934 .36376 Mtetra
.078 .075 .551 r
.18934 .36376 .19443 .39981 .20093 .44562 .19837 .38382 Mtetra
.327 .2 .55 r
.19837 .38382 .20093 .44562 .21231 .44703 .20777 .40262 Mtetra
.03 .015 .503 r
.20777 .40262 .21231 .44703 .22733 .41171 .21659 .42951 Mtetra
0 0 0 r
.21659 .42951 .22733 .41171 .24349 .36221 .23039 .40731 Mtetra
0 0 .163 r
.23039 .40731 .24349 .36221 .25564 .35457 .24481 .37755 Mtetra
.695 .799 .332 r
.24481 .37755 .25564 .35457 .27119 .30733 .25933 .3452 Mtetra
0 0 .018 r
.25933 .3452 .27119 .30733 .2819 .31625 .27382 .31115 Mtetra
.903 .812 .747 r
.27382 .31115 .2819 .31625 .2932 .31952 .28705 .29064 Mtetra
.472 .386 .678 r
.28705 .29064 .2932 .31952 .30292 .34592 .29841 .29375 Mtetra
.473 .324 .597 r
.29841 .29375 .30292 .34592 .31357 .36312 .30973 .29895 Mtetra
.305 .184 .546 r
.30973 .29895 .31357 .36312 .32571 .36114 .32 .32147 Mtetra
.269 .206 .599 r
.32 .32147 .32571 .36114 .33598 .39088 .33097 .33738 Mtetra
.553 .383 .604 r
.33097 .33738 .33598 .39088 .34939 .37187 .34332 .33395 Mtetra
.462 .349 .639 r
.34332 .33395 .34939 .37187 .35997 .40454 .35529 .3387 Mtetra
.434 .281 .573 r
.35529 .3387 .35997 .40454 .37296 .39589 .36707 .34975 Mtetra
.674 .481 .617 r
.36707 .34975 .37296 .39589 .38541 .39986 .38049 .33038 Mtetra
.479 .312 .576 r
.38049 .33038 .38541 .39986 .39924 .37352 .39274 .33653 Mtetra
.304 .245 .624 r
.39274 .33653 .39924 .37352 .41145 .38772 .40484 .35033 Mtetra
.694 .512 .637 r
.40484 .35033 .41145 .38772 .42451 .38297 .4183 .33177 Mtetra
.515 .36 .609 r
.4183 .33177 .42451 .38297 .43815 .35961 .43109 .33288 Mtetra
.755 .583 .663 r
.43109 .33288 .43815 .35961 .45141 .34831 .44459 .31189 Mtetra
.738 .543 .629 r
.44459 .31189 .45141 .34831 .46452 .34501 .45811 .28628 Mtetra
.645 .444 .596 r
.45811 .28628 .46452 .34501 .47777 .33765 .4714 .26717 Mtetra
.635 .426 .583 r
.4714 .26717 .47777 .33765 .49137 .30258 .48465 .24613 Mtetra
.592 .408 .601 r
.48465 .24613 .49137 .30258 .50472 .27393 .49772 .23664 Mtetra
.637 .472 .643 r
.49772 .23664 .50472 .27393 .51792 .24442 .51081 .22577 Mtetra
.734 .618 .729 r
.51081 .22577 .51792 .24442 .53098 .22067 .52392 .21335 Mtetra
.766 .816 .892 r
.52392 .21335 .53098 .22067 .54407 .21641 .53704 .20481 Mtetra
.753 .343 0 r
.53704 .20481 .54407 .21641 .55729 .21704 .55054 .23403 Mtetra
.799 .413 .324 r
.55054 .23403 .55729 .21704 .57092 .23582 .56449 .26733 Mtetra
.575 .228 .344 r
.56449 .26733 .57092 .23582 .58485 .25469 .57841 .27622 Mtetra
.683 .297 .311 r
.57841 .27622 .58485 .25469 .59888 .26661 .59274 .29435 Mtetra
0 0 .122 r
.59274 .29435 .59888 .26661 .61337 .28587 .60615 .26932 Mtetra
.841 .692 .698 r
.60615 .26932 .61337 .28587 .6269 .26913 .61952 .24655 Mtetra
.887 .67 .602 r
.61952 .24655 .6269 .26913 .6407 .26033 .63195 .20158 Mtetra
.601 .412 .597 r
.63195 .20158 .6407 .26033 .65263 .20907 .64548 .18987 Mtetra
.767 .636 .716 r
.64548 .18987 .65263 .20907 .66604 .1952 .65881 .17397 Mtetra
0 0 .24 r
.65881 .17397 .66604 .1952 .68008 .19296 .67549 .22202 Mtetra
.593 .232 .325 r
.67549 .22202 .68008 .19296 .69614 .22287 .69063 .23291 Mtetra
.478 0 .037 r
.69063 .23291 .69614 .22287 .7131 .25999 .70554 .2364 Mtetra
.912 .677 .569 r
.70554 .2364 .7131 .25999 .72544 .22385 .71663 .18128 Mtetra
.633 .459 .629 r
.71663 .18128 .72544 .22385 .73722 .18354 .73041 .16894 Mtetra
.67 .85 .443 r
.09977 .39442 .11161 .37698 .11803 .40899 .11345 .37281 Mtetra
0 0 .157 r
.11345 .37281 .11803 .40899 .12384 .44811 .11913 .41127 Mtetra
0 0 .471 r
.11913 .41127 .12384 .44811 .13446 .45169 .12695 .4359 Mtetra
.841 .672 .674 r
.12695 .4359 .13446 .45169 .1517 .40172 .14166 .4073 Mtetra
.971 .9 .692 r
.14166 .4073 .1517 .40172 .16537 .37963 .15627 .37853 Mtetra
.935 .839 .724 r
.15627 .37853 .16537 .37963 .17825 .3638 .1703 .35363 Mtetra
.82 .725 .759 r
.1703 .35363 .17825 .3638 .18934 .36376 .18314 .33837 Mtetra
.015 .093 .602 r
.18314 .33837 .18934 .36376 .19837 .38382 .19258 .35364 Mtetra
.14 .149 .607 r
.19258 .35364 .19837 .38382 .20777 .40262 .20225 .36866 Mtetra
0 0 .424 r
.20225 .36866 .20777 .40262 .21659 .42951 .2108 .39666 Mtetra
.419 .334 .654 r
.2108 .39666 .21659 .42951 .23039 .40731 .22181 .4027 Mtetra
.893 .827 .776 r
.22181 .4027 .23039 .40731 .24481 .37755 .23525 .38445 Mtetra
.302 0 0 r
.23525 .38445 .24481 .37755 .25933 .3452 .24703 .38402 Mtetra
0 0 0 r
.24703 .38402 .25933 .3452 .27382 .31115 .26198 .34817 Mtetra
.26198 .34817 .27382 .31115 .28705 .29064 .27714 .30748 Mtetra
.368 0 .149 r
.27714 .30748 .28705 .29064 .29841 .29375 .28905 .30505 Mtetra
.901 .941 .578 r
.28905 .30505 .29841 .29375 .30973 .29895 .30285 .27828 Mtetra
.609 .526 .736 r
.30285 .27828 .30973 .29895 .32 .32147 .31493 .27417 Mtetra
.603 .426 .615 r
.31493 .27417 .32 .32147 .33097 .33738 .32739 .26513 Mtetra
.404 .25 .556 r
.32739 .26513 .33097 .33738 .34332 .33395 .33836 .28009 Mtetra
.357 .238 .577 r
.33836 .28009 .34332 .33395 .35529 .3387 .34953 .29527 Mtetra
.663 .477 .622 r
.34953 .29527 .35529 .3387 .36707 .34975 .36267 .27875 Mtetra
.451 .288 .568 r
.36267 .27875 .36707 .34975 .38049 .33038 .37445 .28824 Mtetra
.481 .351 .626 r
.37445 .28824 .38049 .33038 .39274 .33653 .38668 .2919 Mtetra
.6 .43 .624 r
.38668 .2919 .39274 .33653 .40484 .35033 .39954 .28368 Mtetra
.651 .441 .586 r
.39954 .28368 .40484 .35033 .4183 .33177 .41301 .26037 Mtetra
.512 .334 .576 r
.41301 .26037 .4183 .33177 .43109 .33288 .42555 .26166 Mtetra
.569 .376 .58 r
.42555 .26166 .43109 .33288 .44459 .31189 .43847 .25372 Mtetra
.668 .46 .594 r
.43847 .25372 .44459 .31189 .45811 .28628 .45183 .22999 Mtetra
.507 .345 .596 r
.45183 .22999 .45811 .28628 .4714 .26717 .46455 .23185 Mtetra
.5 .385 .654 r
.46455 .23185 .4714 .26717 .48465 .24613 .4774 .23375 Mtetra
.885 .733 .687 r
.4774 .23375 .48465 .24613 .49772 .23664 .4907 .20722 Mtetra
.439 .369 .682 r
.4907 .20722 .49772 .23664 .51081 .22577 .50365 .21228 Mtetra
.706 .316 0 r
.50365 .21228 .51081 .22577 .52392 .21335 .5167 .2405 Mtetra
.433 .087 .277 r
.5167 .2405 .52392 .21335 .53704 .20481 .53006 .23827 Mtetra
.767 .419 .396 r
.53006 .23827 .53704 .20481 .55054 .23403 .54381 .28104 Mtetra
.615 .292 .4 r
.54381 .28104 .55054 .23403 .56449 .26733 .55779 .29886 Mtetra
.09 0 .187 r
.55779 .29886 .56449 .26733 .57841 .27622 .57142 .27714 Mtetra
.835 .999 .803 r
.57142 .27714 .57841 .27622 .59274 .29435 .58511 .26279 Mtetra
.828 .61 .607 r
.58511 .26279 .59274 .29435 .60615 .26932 .5981 .2219 Mtetra
.756 .533 .593 r
.5981 .2219 .60615 .26932 .61952 .24655 .61091 .18396 Mtetra
.503 .338 .59 r
.61091 .18396 .61952 .24655 .63195 .20158 .62491 .18661 Mtetra
.731 .666 .785 r
.62491 .18661 .63195 .20158 .64548 .18987 .63855 .17653 Mtetra
0 0 .525 r
.63855 .17653 .64548 .18987 .65881 .17397 .65363 .19778 Mtetra
.799 .418 .334 r
.65363 .19778 .65881 .17397 .67549 .22202 .6701 .23962 Mtetra
.102 0 .063 r
.6701 .23962 .67549 .22202 .69063 .23291 .68409 .22708 Mtetra
.891 .895 .825 r
.68409 .22708 .69063 .23291 .70554 .2364 .69788 .21128 Mtetra
.859 .648 .616 r
.69788 .21128 .70554 .2364 .71663 .18128 .71018 .17331 Mtetra
.837 .843 .85 r
.71018 .17331 .71663 .18128 .73041 .16894 .72402 .16054 Mtetra
.962 .916 .566 r
.08733 .41435 .09977 .39442 .11345 .37281 .10382 .37378 Mtetra
.858 .964 .87 r
.10382 .37378 .11345 .37281 .11913 .41127 .1162 .36202 Mtetra
.098 .044 .501 r
.1162 .36202 .11913 .41127 .12695 .4359 .12378 .38682 Mtetra
0 0 .321 r
.12378 .38682 .12695 .4359 .14166 .4073 .12972 .42653 Mtetra
0 0 0 r
.12972 .42653 .14166 .4073 .15627 .37853 .14254 .41379 Mtetra
.69 .765 .275 r
.14254 .41379 .15627 .37853 .1703 .35363 .15903 .37051 Mtetra
.901 .927 .544 r
.15903 .37051 .1703 .35363 .18314 .33837 .17391 .33904 Mtetra
.92 .925 .799 r
.17391 .33904 .18314 .33837 .19258 .35364 .187 .32205 Mtetra
0 0 .483 r
.187 .32205 .19258 .35364 .20225 .36866 .19567 .34521 Mtetra
.082 .161 .648 r
.19567 .34521 .20225 .36866 .2108 .39666 .20569 .35801 Mtetra
0 0 .408 r
.20569 .35801 .2108 .39666 .22181 .4027 .214 .38937 Mtetra
.621 .623 .831 r
.214 .38937 .22181 .4027 .23525 .38445 .22607 .38578 Mtetra
.492 0 0 r
.22607 .38578 .23525 .38445 .24703 .38402 .2374 .39068 Mtetra
.964 .941 .679 r
.2374 .39068 .24703 .38402 .26198 .34817 .25171 .36396 Mtetra
.766 .882 .466 r
.25171 .36396 .26198 .34817 .27714 .30748 .26584 .33798 Mtetra
.275 0 .226 r
.26584 .33798 .27714 .30748 .28905 .30505 .27856 .32776 Mtetra
0 0 0 r
.27856 .32776 .28905 .30505 .30285 .27828 .29258 .30115 Mtetra
.392 .029 .225 r
.29258 .30115 .30285 .27828 .31493 .27417 .30472 .29812 Mtetra
.69 .778 .298 r
.30472 .29812 .31493 .27417 .32739 .26513 .3192 .26283 Mtetra
.762 .937 .941 r
.3192 .26283 .32739 .26513 .33836 .28009 .33169 .25486 Mtetra
.381 .351 .7 r
.33169 .25486 .33836 .28009 .34953 .29527 .34333 .26103 Mtetra
.439 .343 .651 r
.34333 .26103 .34953 .29527 .36267 .27875 .35516 .26642 Mtetra
.893 .722 .662 r
.35516 .26642 .36267 .27875 .37445 .28824 .36916 .23411 Mtetra
.396 .266 .584 r
.36916 .23411 .37445 .28824 .38668 .2919 .38079 .24615 Mtetra
.58 .413 .619 r
.38079 .24615 .38668 .2919 .39954 .28368 .39345 .23998 Mtetra
.507 .365 .623 r
.39345 .23998 .39954 .28368 .41301 .26037 .40585 .24139 Mtetra
.658 .574 .749 r
.40585 .24139 .41301 .26037 .42555 .26166 .41866 .23459 Mtetra
.778 .593 .649 r
.41866 .23459 .42555 .26166 .43847 .25372 .43211 .2094 Mtetra
.309 .225 .596 r
.43211 .2094 .43847 .25372 .45183 .22999 .4443 .22542 Mtetra
.913 .866 .78 r
.4443 .22542 .45183 .22999 .46455 .23185 .45753 .20715 Mtetra
0 .094 .614 r
.45753 .20715 .46455 .23185 .4774 .23375 .47002 .22594 Mtetra
.644 .158 0 r
.47002 .22594 .4774 .23375 .4907 .20722 .48281 .24289 Mtetra
.64 .299 .379 r
.48281 .24289 .4907 .20722 .50365 .21228 .49586 .26078 Mtetra
.473 .17 .371 r
.49586 .26078 .50365 .21228 .5167 .2405 .50928 .25927 Mtetra
.584 .185 .253 r
.50928 .25927 .5167 .2405 .53006 .23827 .52279 .26736 Mtetra
.718 .358 .366 r
.52279 .26736 .53006 .23827 .54381 .28104 .53659 .29524 Mtetra
.182 0 .004 r
.53659 .29524 .54381 .28104 .55779 .29886 .55045 .28829 Mtetra
.945 .76 .622 r
.55045 .28829 .55779 .29886 .57142 .27714 .56389 .24729 Mtetra
.813 .606 .623 r
.56389 .24729 .57142 .27714 .58511 .26279 .57718 .21265 Mtetra
.732 .513 .594 r
.57718 .21265 .58511 .26279 .5981 .2219 .59027 .17866 Mtetra
.55 .4 .63 r
.59027 .17866 .5981 .2219 .61091 .18396 .60403 .17595 Mtetra
.673 .787 .935 r
.60403 .17595 .61091 .18396 .62491 .18661 .6178 .17047 Mtetra
.765 .405 0 r
.6178 .17047 .62491 .18661 .63855 .17653 .63356 .21509 Mtetra
.652 .305 .372 r
.63356 .21509 .63855 .17653 .65363 .19778 .64891 .23707 Mtetra
.444 .128 .333 r
.64891 .23707 .65363 .19778 .6701 .23962 .66338 .23372 Mtetra
.96 .857 .694 r
.66338 .23372 .6701 .23962 .68409 .22708 .67669 .20671 Mtetra
.935 .697 .555 r
.67669 .20671 .68409 .22708 .69788 .21128 .68792 .14681 Mtetra
.42 .28 .583 r
.68792 .14681 .69788 .21128 .71018 .17331 .70336 .1605 Mtetra
0 .154 .696 r
.70336 .1605 .71018 .17331 .72402 .16054 .71919 .17581 Mtetra
.966 .805 .631 r
.07678 .41953 .08733 .41435 .10382 .37378 .09484 .36914 Mtetra
.759 .847 .917 r
.09484 .36914 .10382 .37378 .1162 .36202 .10667 .36189 Mtetra
.725 .218 .022 r
.10667 .36189 .1162 .36202 .12378 .38682 .11616 .3722 Mtetra
0 0 .46 r
.11616 .3722 .12378 .38682 .12972 .42653 .12526 .38666 Mtetra
.354 .259 .608 r
.12526 .38666 .12972 .42653 .14254 .41379 .13512 .3967 Mtetra
.621 .569 .774 r
.13512 .3967 .14254 .41379 .15903 .37051 .14689 .39259 Mtetra
0 0 0 r
.14689 .39259 .15903 .37051 .17391 .33904 .16065 .3723 Mtetra
.826 .836 .367 r
.16065 .3723 .17391 .33904 .187 .32205 .17769 .32315 Mtetra
.602 .055 0 r
.17769 .32315 .187 .32205 .19567 .34521 .18817 .33002 Mtetra
.71 .631 .768 r
.18817 .33002 .19567 .34521 .20569 .35801 .20046 .32137 Mtetra
.428 .324 .634 r
.20046 .32137 .20569 .35801 .214 .38937 .21126 .32724 Mtetra
.263 .15 .532 r
.21126 .32724 .214 .38937 .22607 .38578 .22048 .35001 Mtetra
0 0 .329 r
.22048 .35001 .22607 .38578 .2374 .39068 .22884 .38449 Mtetra
.286 .652 .969 r
.22884 .38449 .2374 .39068 .25171 .36396 .24067 .38562 Mtetra
.213 0 .113 r
.24067 .38562 .25171 .36396 .26584 .33798 .25345 .37718 Mtetra
.403 .09 .316 r
.25345 .37718 .26584 .33798 .27856 .32776 .26602 .37155 Mtetra
.242 0 .266 r
.26602 .37155 .27856 .32776 .29258 .30115 .27955 .35468 Mtetra
.143 0 .254 r
.27955 .35468 .29258 .30115 .30472 .29812 .29385 .32741 Mtetra
0 0 0 r
.29385 .32741 .30472 .29812 .3192 .26283 .30868 .29108 Mtetra
.571 .222 .338 r
.30868 .29108 .3192 .26283 .33169 .25486 .32028 .29874 Mtetra
0 0 .149 r
.32028 .29874 .33169 .25486 .34333 .26103 .33459 .26699 Mtetra
.68 .946 .677 r
.33459 .26699 .34333 .26103 .35516 .26642 .34761 .254 Mtetra
.172 .397 .84 r
.34761 .254 .35516 .26642 .36916 .23411 .35954 .26 Mtetra
.471 .115 .28 r
.35954 .26 .36916 .23411 .38079 .24615 .37191 .26059 Mtetra
.638 .812 .385 r
.37191 .26059 .38079 .24615 .39345 .23998 .38551 .23759 Mtetra
.772 .263 0 r
.38551 .23759 .39345 .23998 .40585 .24139 .39732 .25372 Mtetra
0 0 0 r
.39732 .25372 .40585 .24139 .41866 .23459 .41054 .23992 Mtetra
.41054 .23992 .41866 .23459 .43211 .2094 .42342 .23573 Mtetra
.407 .057 .256 r
.42342 .23573 .43211 .2094 .4443 .22542 .43632 .23265 Mtetra
.797 .367 .226 r
.43632 .23265 .4443 .22542 .45753 .20715 .44865 .25527 Mtetra
.518 .208 .38 r
.44865 .25527 .45753 .20715 .47002 .22594 .46169 .25929 Mtetra
.567 .224 .347 r
.46169 .25929 .47002 .22594 .48281 .24289 .4748 .26778 Mtetra
.436 .074 .251 r
.4748 .26778 .48281 .24289 .49586 .26078 .48821 .2666 Mtetra
.434 0 0 r
.48821 .2666 .49586 .26078 .50928 .25927 .5017 .26975 Mtetra
.206 0 0 r
.5017 .26975 .50928 .25927 .52279 .26736 .51536 .26571 Mtetra
0 .517 .748 r
.51536 .26571 .52279 .26736 .53659 .29524 .5291 .26769 Mtetra
.843 .631 .615 r
.5291 .26769 .53659 .29524 .55045 .28829 .54271 .22765 Mtetra
.702 .481 .584 r
.54271 .22765 .55045 .28829 .56389 .24729 .55613 .19431 Mtetra
.696 .484 .596 r
.55613 .19431 .56389 .24729 .57718 .21265 .56944 .16677 Mtetra
.597 .426 .62 r
.56944 .16677 .57718 .21265 .59027 .17866 .58301 .15811 Mtetra
.151 .254 .716 r
.58301 .15811 .59027 .17866 .60403 .17595 .59716 .17069 Mtetra
.693 .186 0 r
.59716 .17069 .60403 .17595 .6178 .17047 .61176 .18984 Mtetra
.766 .368 .3 r
.61176 .18984 .6178 .17047 .63356 .21509 .62706 .21961 Mtetra
.317 0 0 r
.62706 .21961 .63356 .21509 .64891 .23707 .64164 .22113 Mtetra
.929 .724 .604 r
.64164 .22113 .64891 .23707 .66338 .23372 .65427 .17743 Mtetra
.696 .479 .589 r
.65427 .17743 .66338 .23372 .67669 .20671 .66732 .14798 Mtetra
.526 .359 .597 r
.66732 .14798 .67669 .20671 .68792 .14681 .68179 .14694 Mtetra
.738 .213 0 r
.68179 .14694 .68792 .14681 .70336 .1605 .69763 .16611 Mtetra
.525 0 0 r
.69763 .16611 .70336 .1605 .71919 .17581 .71298 .17289 Mtetra
.978 .858 .652 r
.06566 .42741 .07678 .41953 .09484 .36914 .08243 .38749 Mtetra
.136 0 .015 r
.08243 .38749 .09484 .36914 .10667 .36189 .09447 .37962 Mtetra
.977 .911 .586 r
.09447 .37962 .10667 .36189 .11616 .3722 .11115 .33824 Mtetra
.598 .451 .652 r
.11115 .33824 .11616 .3722 .12526 .38666 .12285 .33239 Mtetra
.144 .068 .504 r
.12285 .33239 .12526 .38666 .13512 .3967 .1306 .35716 Mtetra
.02 .018 .512 r
.1306 .35716 .13512 .3967 .14689 .39259 .13893 .37944 Mtetra
.842 .434 0 r
.13893 .37944 .14689 .39259 .16065 .3723 .14745 .40222 Mtetra
0 0 0 r
.14745 .40222 .16065 .3723 .17769 .32315 .16199 .37671 Mtetra
0 0 .106 r
.16199 .37671 .17769 .32315 .18817 .33002 .1779 .33841 Mtetra
.987 .879 .632 r
.1779 .33841 .18817 .33002 .20046 .32137 .1937 .29936 Mtetra
.661 .547 .714 r
.1937 .29936 .20046 .32137 .21126 .32724 .20592 .29146 Mtetra
.457 .347 .641 r
.20592 .29146 .21126 .32724 .22048 .35001 .21695 .29538 Mtetra
.358 .231 .568 r
.21695 .29538 .22048 .35001 .22884 .38449 .22712 .30904 Mtetra
.327 .185 .53 r
.22712 .30904 .22884 .38449 .24067 .38562 .23672 .33068 Mtetra
.145 .076 .514 r
.23672 .33068 .24067 .38562 .25345 .37718 .2461 .35767 Mtetra
.57 .522 .762 r
.2461 .35767 .25345 .37718 .26602 .37155 .25836 .35548 Mtetra
.636 .597 .793 r
.25836 .35548 .26602 .37155 .27955 .35468 .27092 .35065 Mtetra
.88 .87 .824 r
.27092 .35065 .27955 .35468 .29385 .32741 .28435 .33563 Mtetra
.08 0 0 r
.28435 .33563 .29385 .32741 .30868 .29108 .29695 .33138 Mtetra
.278 0 .268 r
.29695 .33138 .30868 .29108 .32028 .29874 .31027 .31781 Mtetra
.566 .176 .261 r
.31027 .31781 .32028 .29874 .33459 .26699 .32223 .32433 Mtetra
.331 .055 .335 r
.32223 .32433 .33459 .26699 .34761 .254 .33576 .30849 Mtetra
.467 .17 .377 r
.33576 .30849 .34761 .254 .35954 .26 .34844 .30649 Mtetra
.394 .094 .334 r
.34844 .30649 .35954 .26 .37191 .26059 .36153 .29861 Mtetra
.349 .038 .29 r
.36153 .29861 .37191 .26059 .38551 .23759 .37471 .28961 Mtetra
.272 .001 .306 r
.37471 .28961 .38551 .23759 .39732 .25372 .38839 .2705 Mtetra
.214 0 .054 r
.38839 .2705 .39732 .25372 .41054 .23992 .40149 .26382 Mtetra
.679 .31 .34 r
.40149 .26382 .41054 .23992 .42342 .23573 .41371 .28214 Mtetra
.475 .165 .36 r
.41371 .28214 .42342 .23573 .43632 .23265 .42681 .28164 Mtetra
.586 .268 .396 r
.42681 .28164 .43632 .23265 .44865 .25527 .43962 .29532 Mtetra
.447 .128 .331 r
.43962 .29532 .44865 .25527 .46169 .25929 .45305 .29284 Mtetra
.347 .025 .27 r
.45305 .29284 .46169 .25929 .4748 .26778 .46668 .2847 Mtetra
0 0 0 r
.46668 .2847 .4748 .26778 .48821 .2666 .48045 .27029 Mtetra
.811 .988 .726 r
.48045 .27029 .48821 .2666 .5017 .26975 .49422 .2543 Mtetra
.845 .702 .704 r
.49422 .2543 .5017 .26975 .51536 .26571 .50798 .2318 Mtetra
.707 .529 .645 r
.50798 .2318 .51536 .26571 .5291 .26769 .52166 .21317 Mtetra
.733 .508 .587 r
.52166 .21317 .5291 .26769 .54271 .22765 .53519 .17589 Mtetra
.605 .421 .606 r
.53519 .17589 .54271 .22765 .55613 .19431 .54873 .16469 Mtetra
.56 .451 .686 r
.54873 .16469 .55613 .19431 .56944 .16677 .56239 .16199 Mtetra
.862 .419 .022 r
.56239 .16199 .56944 .16677 .58301 .15811 .57681 .19543 Mtetra
.569 .227 .35 r
.57681 .19543 .58301 .15811 .59716 .17069 .59114 .20534 Mtetra
.539 .194 .331 r
.59114 .20534 .59716 .17069 .61176 .18984 .6056 .21186 Mtetra
.673 .278 .288 r
.6056 .21186 .61176 .18984 .62706 .21961 .62063 .22993 Mtetra
.966 .833 .414 r
.62063 .22993 .62706 .21961 .64164 .22113 .63306 .17244 Mtetra
.744 .521 .591 r
.63306 .17244 .64164 .22113 .65427 .17743 .646 .13703 Mtetra
.358 .28 .63 r
.646 .13703 .65427 .17743 .66732 .14798 .66106 .14966 Mtetra
.746 .228 0 r
.66106 .14966 .66732 .14798 .68179 .14694 .67672 .16865 Mtetra
.672 .269 .272 r
.67672 .16865 .68179 .14694 .69763 .16611 .69268 .18691 Mtetra
0 0 .067 r
.69268 .18691 .69763 .16611 .71298 .17289 .70657 .16811 Mtetra
.569 .437 .66 r
.06048 .39489 .06566 .42741 .08243 .38749 .07189 .3915 Mtetra
.645 .154 .07 r
.07189 .3915 .08243 .38749 .09447 .37962 .08175 .39924 Mtetra
.983 .901 .577 r
.08175 .39924 .09447 .37962 .11115 .33824 .09939 .35283 Mtetra
.892 .949 .597 r
.09939 .35283 .11115 .33824 .12285 .33239 .11403 .3264 Mtetra
0 .243 .672 r
.11403 .3264 .12285 .33239 .1306 .35716 .12424 .33229 Mtetra
0 0 .194 r
.12424 .33229 .1306 .35716 .13893 .37944 .13168 .36045 Mtetra
0 0 .331 r
.13168 .36045 .13893 .37944 .14745 .40222 .14041 .38077 Mtetra
.564 .497 .739 r
.14041 .38077 .14745 .40222 .16199 .37671 .15212 .37873 Mtetra
.963 .856 .687 r
.15212 .37873 .16199 .37671 .1779 .33841 .16742 .34706 Mtetra
.692 .939 .644 r
.16742 .34706 .1779 .33841 .1937 .29936 .18058 .33276 Mtetra
.004 0 .096 r
.18058 .33276 .1937 .29936 .20592 .29146 .19434 .3128 Mtetra
0 0 0 r
.19434 .3128 .20592 .29146 .21695 .29538 .20826 .29073 Mtetra
.897 .828 .77 r
.20826 .29073 .21695 .29538 .22712 .30904 .22176 .27206 Mtetra
.432 .326 .633 r
.22176 .27206 .22712 .30904 .23672 .33068 .23281 .27745 Mtetra
.328 .212 .566 r
.23281 .27745 .23672 .33068 .2461 .35767 .24306 .29264 Mtetra
.381 .236 .556 r
.24306 .29264 .2461 .35767 .25836 .35548 .25365 .30661 Mtetra
0 0 .462 r
.25365 .30661 .25836 .35548 .27092 .35065 .26281 .33929 Mtetra
.233 .472 .882 r
.26281 .33929 .27092 .35065 .28435 .33563 .27471 .34349 Mtetra
.834 .973 .663 r
.27471 .34349 .28435 .33563 .29695 .33138 .28857 .32447 Mtetra
.822 .351 0 r
.28857 .32447 .29695 .33138 .31027 .31781 .29942 .34488 Mtetra
0 0 .007 r
.29942 .34488 .31027 .31781 .32223 .32433 .31347 .32389 Mtetra
.262 .768 .861 r
.31347 .32389 .32223 .32433 .33576 .30849 .3262 .3217 Mtetra
.221 0 0 r
.3262 .3217 .33576 .30849 .34844 .30649 .33916 .3172 Mtetra
.231 0 0 r
.33916 .3172 .34844 .30649 .36153 .29861 .3521 .31407 Mtetra
.627 .215 .241 r
.3521 .31407 .36153 .29861 .37471 .28961 .36441 .32444 Mtetra
.401 .072 .29 r
.36441 .32444 .37471 .28961 .38839 .2705 .37765 .31976 Mtetra
.084 0 .223 r
.37765 .31976 .38839 .2705 .40149 .26382 .39207 .29021 Mtetra
.307 0 .202 r
.39207 .29021 .40149 .26382 .41371 .28214 .40545 .28282 Mtetra
.808 .332 .084 r
.40545 .28282 .41371 .28214 .42681 .28164 .41788 .30309 Mtetra
.257 0 .132 r
.41788 .30309 .42681 .28164 .43962 .29532 .43148 .29561 Mtetra
.789 .995 .872 r
.43148 .29561 .43962 .29532 .45305 .29284 .44523 .28419 Mtetra
.892 .798 .749 r
.44523 .28419 .45305 .29284 .46668 .2847 .4592 .26341 Mtetra
.828 .651 .663 r
.4592 .26341 .46668 .2847 .48045 .27029 .47321 .23596 Mtetra
.697 .521 .646 r
.47321 .23596 .48045 .27029 .49422 .2543 .48695 .2185 Mtetra
.707 .523 .638 r
.48695 .2185 .49422 .2543 .50798 .2318 .50066 .19881 Mtetra
.798 .588 .617 r
.50066 .19881 .50798 .2318 .52166 .21317 .51435 .16424 Mtetra
.381 .269 .6 r
.51435 .16424 .52166 .21317 .53519 .17589 .52791 .17643 Mtetra
.878 .992 .796 r
.52791 .17643 .53519 .17589 .54873 .16469 .54152 .1607 Mtetra
.863 .417 .038 r
.54152 .1607 .54873 .16469 .56239 .16199 .55564 .19302 Mtetra
.731 .366 .359 r
.55564 .19302 .56239 .16199 .57681 .19543 .5702 .22537 Mtetra
.489 .133 .29 r
.5702 .22537 .57681 .19543 .59114 .20534 .58458 .22757 Mtetra
.357 0 .186 r
.58458 .22757 .59114 .20534 .6056 .21186 .59893 .2233 Mtetra
.968 .828 .41 r
.59893 .2233 .6056 .21186 .62063 .22993 .6116 .16215 Mtetra
.645 .431 .578 r
.6116 .16215 .62063 .22993 .63306 .17244 .62514 .13851 Mtetra
.679 .51 .651 r
.62514 .13851 .63306 .17244 .646 .13703 .63892 .12354 Mtetra
0 .147 .691 r
.63892 .12354 .646 .13703 .66106 .14966 .65408 .13839 Mtetra
.761 .353 0 r
.65408 .13839 .66106 .14966 .67672 .16865 .67068 .17565 Mtetra
.544 .018 0 r
.67068 .17565 .67672 .16865 .69268 .18691 .68611 .18296 Mtetra
.974 .894 .682 r
.68611 .18296 .69268 .18691 .70657 .16811 .69958 .15562 Mtetra
.111 .033 .48 r
.0592 .3377 .06048 .39489 .07189 .3915 .06598 .36383 Mtetra
0 0 .331 r
.06598 .36383 .07189 .3915 .08175 .39924 .0733 .38816 Mtetra
.433 .583 .902 r
.0733 .38816 .08175 .39924 .09939 .35283 .08428 .38898 Mtetra
.874 .863 .414 r
.08428 .38898 .09939 .35283 .11403 .3264 .10297 .33555 Mtetra
.164 0 0 r
.10297 .33555 .11403 .3264 .12424 .33229 .11446 .33249 Mtetra
.948 .841 .704 r
.11446 .33249 .12424 .33229 .13168 .36045 .12943 .30378 Mtetra
0 0 .343 r
.12943 .30378 .13168 .36045 .14041 .38077 .13518 .34536 Mtetra
.169 .144 .585 r
.13518 .34536 .14041 .38077 .15212 .37873 .14463 .36066 Mtetra
0 .12 .661 r
.14463 .36066 .15212 .37873 .16742 .34706 .15472 .37242 Mtetra
0 0 0 r
.15472 .37242 .16742 .34706 .18058 .33276 .16979 .34346 Mtetra
.243 0 0 r
.16979 .34346 .18058 .33276 .19434 .3128 .18172 .34086 Mtetra
0 0 0 r
.18172 .34086 .19434 .3128 .20826 .29073 .19703 .30829 Mtetra
.773 .884 .466 r
.19703 .30829 .20826 .29073 .22176 .27206 .2116 .28114 Mtetra
.089 0 0 r
.2116 .28114 .22176 .27206 .23281 .27745 .22371 .27682 Mtetra
.938 .89 .757 r
.22371 .27682 .23281 .27745 .24306 .29264 .23754 .25569 Mtetra
.151 .128 .575 r
.23754 .25569 .24306 .29264 .25365 .30661 .24764 .27325 Mtetra
.531 .409 .659 r
.24764 .27325 .25365 .30661 .26281 .33929 .25966 .27227 Mtetra
.425 .267 .562 r
.25966 .27227 .26281 .33929 .27471 .34349 .27083 .28218 Mtetra
.212 .116 .523 r
.27083 .28218 .27471 .34349 .28857 .32447 .28088 .30798 Mtetra
.745 .645 .75 r
.28088 .30798 .28857 .32447 .29942 .34488 .29419 .29585 Mtetra
.603 .424 .612 r
.29419 .29585 .29942 .34488 .31347 .32389 .30735 .28581 Mtetra
0 0 .5 r
.30735 .28581 .31347 .32389 .3262 .3217 .31794 .31301 Mtetra
.791 .784 .846 r
.31794 .31301 .3262 .3217 .33916 .3172 .33134 .30228 Mtetra
.781 .68 .752 r
.33134 .30228 .33916 .3172 .3521 .31407 .34498 .2879 Mtetra
.344 .33 .699 r
.34498 .2879 .3521 .31407 .36441 .32444 .35738 .29519 Mtetra
.607 .483 .685 r
.35738 .29519 .36441 .32444 .37765 .31976 .37065 .28905 Mtetra
.696 .534 .663 r
.37065 .28905 .37765 .31976 .39207 .29021 .38441 .27365 Mtetra
.755 .655 .751 r
.38441 .27365 .39207 .29021 .40545 .28282 .39804 .2607 Mtetra
.378 .387 .744 r
.39804 .2607 .40545 .28282 .41788 .30309 .41097 .26587 Mtetra
.796 .579 .607 r
.41097 .26587 .41788 .30309 .43148 .29561 .42558 .22624 Mtetra
.53 .346 .577 r
.42558 .22624 .43148 .29561 .44523 .28419 .43887 .2234 Mtetra
.677 .462 .587 r
.43887 .2234 .44523 .28419 .4592 .26341 .45284 .19611 Mtetra
.592 .394 .581 r
.45284 .19611 .4592 .26341 .47321 .23596 .46639 .18332 Mtetra
.548 .378 .604 r
.46639 .18332 .47321 .23596 .48695 .2185 .4798 .17934 Mtetra
.62 .456 .638 r
.4798 .17934 .48695 .2185 .50066 .19881 .49335 .16938 Mtetra
.389 .34 .683 r
.49335 .16938 .50066 .19881 .51435 .16424 .50683 .17617 Mtetra
.733 .298 .218 r
.50683 .17617 .51435 .16424 .52791 .17643 .52047 .19523 Mtetra
.471 .065 .188 r
.52047 .19523 .52791 .17643 .54152 .1607 .53437 .19735 Mtetra
.668 .315 .365 r
.53437 .19735 .54152 .1607 .55564 .19302 .54859 .22139 Mtetra
.375 .027 .241 r
.54859 .22139 .55564 .19302 .5702 .22537 .56279 .21652 Mtetra
.949 .795 .656 r
.56279 .21652 .5702 .22537 .58458 .22757 .57654 .18311 Mtetra
.581 .419 .627 r
.57654 .18311 .58458 .22757 .59893 .2233 .59071 .17623 Mtetra
.733 .516 .598 r
.59071 .17623 .59893 .2233 .6116 .16215 .60422 .14447 Mtetra
.834 .685 .698 r
.60422 .14447 .6116 .16215 .62514 .13851 .61787 .12235 Mtetra
.677 .319 0 r
.61787 .12235 .62514 .13851 .63892 .12354 .63374 .15966 Mtetra
.673 .311 .35 r
.63374 .15966 .63892 .12354 .65408 .13839 .64961 .18499 Mtetra
.474 .156 .347 r
.64961 .18499 .65408 .13839 .67068 .17565 .66462 .18505 Mtetra
.918 .852 .407 r
.66462 .18505 .67068 .17565 .68611 .18296 .67734 .14058 Mtetra
.777 .552 .594 r
.67734 .14058 .68611 .18296 .69958 .15562 .69013 .10304 Mtetra
0 0 0 r
.04798 .34473 .0592 .3377 .06598 .36383 .05961 .33942 Mtetra
.797 .505 0 r
.05961 .33942 .06598 .36383 .0733 .38816 .06588 .36983 Mtetra
0 0 .541 r
.06588 .36983 .0733 .38816 .08428 .38898 .07486 .38397 Mtetra
.583 .819 .989 r
.07486 .38397 .08428 .38898 .10297 .33555 .08652 .38079 Mtetra
0 0 .013 r
.08652 .38079 .10297 .33555 .11446 .33249 .10244 .34769 Mtetra
.975 .918 .605 r
.10244 .34769 .11446 .33249 .12943 .30378 .11888 .30964 Mtetra
.528 .023 0 r
.11888 .30964 .12943 .30378 .13518 .34536 .12947 .31415 Mtetra
.612 .471 .666 r
.12947 .31415 .13518 .34536 .14463 .36066 .14164 .30743 Mtetra
.273 .168 .547 r
.14164 .30743 .14463 .36066 .15472 .37242 .15084 .32466 Mtetra
.256 .168 .559 r
.15084 .32466 .15472 .37242 .16979 .34346 .16036 .34115 Mtetra
.663 .109 0 r
.16036 .34115 .16979 .34346 .18172 .34086 .1709 .35085 Mtetra
.072 0 0 r
.1709 .35085 .18172 .34086 .19703 .30829 .18326 .34597 Mtetra
0 0 0 r
.18326 .34597 .19703 .30829 .2116 .28114 .20016 .30016 Mtetra
.20016 .30016 .2116 .28114 .22371 .27682 .21443 .27668 Mtetra
.914 .931 .808 r
.21443 .27668 .22371 .27682 .23754 .25569 .22792 .25997 Mtetra
.284 0 0 r
.22792 .25997 .23754 .25569 .24764 .27325 .23968 .2607 Mtetra
.876 .717 .682 r
.23968 .2607 .24764 .27325 .25966 .27227 .25426 .23224 Mtetra
.438 .321 .623 r
.25426 .23224 .25966 .27227 .27083 .28218 .26571 .2374 Mtetra
.615 .438 .619 r
.26571 .2374 .27083 .28218 .28088 .30798 .27865 .22674 Mtetra
.343 .192 .527 r
.27865 .22674 .28088 .30798 .29419 .29585 .28905 .24762 Mtetra
.58 .407 .612 r
.28905 .24762 .29419 .29585 .30735 .28581 .30187 .2405 Mtetra
.542 .385 .618 r
.30187 .2405 .30735 .28581 .31794 .31301 .31442 .23771 Mtetra
.514 .327 .565 r
.31442 .23771 .31794 .31301 .33134 .30228 .32692 .23678 Mtetra
.368 .228 .556 r
.32692 .23678 .33134 .30228 .34498 .2879 .33849 .25204 Mtetra
.754 .554 .626 r
.33849 .25204 .34498 .2879 .35738 .29519 .35287 .22395 Mtetra
.369 .224 .549 r
.35287 .22395 .35738 .29519 .37065 .28905 .36466 .24052 Mtetra
.724 .511 .601 r
.36466 .24052 .37065 .28905 .38441 .27365 .37911 .20951 Mtetra
.362 .227 .559 r
.37911 .20951 .38441 .27365 .39804 .2607 .39124 .22536 Mtetra
.688 .512 .643 r
.39124 .22536 .39804 .2607 .41097 .26587 .40496 .20864 Mtetra
.715 .493 .587 r
.40496 .20864 .41097 .26587 .42558 .22624 .41931 .17404 Mtetra
.386 .263 .587 r
.41931 .17404 .42558 .22624 .43887 .2234 .43198 .18542 Mtetra
.737 .537 .622 r
.43198 .18542 .43887 .2234 .45284 .19611 .4459 .15914 Mtetra
.515 .39 .648 r
.4459 .15914 .45284 .19611 .46639 .18332 .45909 .15899 Mtetra
.158 .221 .68 r
.45909 .15899 .46639 .18332 .4798 .17934 .47216 .17196 Mtetra
0 .425 .856 r
.47216 .17196 .4798 .17934 .49335 .16938 .48557 .17746 Mtetra
.727 .262 .146 r
.48557 .17746 .49335 .16938 .50683 .17617 .49906 .19403 Mtetra
.662 .249 .252 r
.49906 .19403 .50683 .17617 .52047 .19523 .51284 .20897 Mtetra
.724 .294 .229 r
.51284 .20897 .52047 .19523 .53437 .19735 .52689 .22851 Mtetra
0 0 .023 r
.52689 .22851 .53437 .19735 .54859 .22139 .54094 .19397 Mtetra
.517 .441 .709 r
.54094 .19397 .54859 .22139 .56279 .21652 .55515 .19376 Mtetra
.877 .669 .617 r
.55515 .19376 .56279 .21652 .57654 .18311 .56885 .15344 Mtetra
.816 .609 .622 r
.56885 .15344 .57654 .18311 .59071 .17623 .5824 .11957 Mtetra
.416 .281 .589 r
.5824 .11957 .59071 .17623 .60422 .14447 .5969 .12999 Mtetra
.659 .28 0 r
.5969 .12999 .60422 .14447 .61787 .12235 .61232 .16198 Mtetra
.56 .215 .341 r
.61232 .16198 .61787 .12235 .63374 .15966 .62741 .17217 Mtetra
.529 .062 .089 r
.62741 .17217 .63374 .15966 .64961 .18499 .64257 .17827 Mtetra
.989 .788 .54 r
.64257 .17827 .64961 .18499 .66462 .18505 .65507 .12377 Mtetra
.572 .385 .59 r
.65507 .12377 .66462 .18505 .67734 .14058 .66952 .11482 Mtetra
.749 .59 .679 r
.66952 .11482 .67734 .14058 .69013 .10304 .68347 .09642 Mtetra
P
p
P
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.10634 .2493 m
.11082 .25363 L
s
P
[(-10)] .09737 .24064 1 .96527 Mshowa
p
.002 w
.22558 .20261 m
.22987 .20713 L
s
P
[(-5)] .217 .19356 .94911 1 Mshowa
p
.002 w
.35089 .15354 m
.35496 .15826 L
s
P
[(0)] .34275 .1441 .86223 1 Mshowa
p
.002 w
.48274 .10191 m
.48656 .10684 L
s
P
[(5)] .4751 .09206 .77536 1 Mshowa
p
.002 w
.62165 .04752 m
.62519 .05265 L
s
P
[(10)] .61458 .03725 .68849 1 Mshowa
p
.001 w
.12972 .24014 m
.13239 .24276 L
s
P
p
.001 w
.15334 .2309 m
.15598 .23354 L
s
P
p
.001 w
.17718 .22156 m
.17981 .22422 L
s
P
p
.001 w
.20126 .21213 m
.20386 .21482 L
s
P
p
.001 w
.25014 .19299 m
.25269 .19573 L
s
P
p
.001 w
.27495 .18327 m
.27748 .18604 L
s
P
p
.001 w
.30001 .17346 m
.30251 .17625 L
s
P
p
.001 w
.32532 .16355 m
.32779 .16636 L
s
P
p
.001 w
.37672 .14343 m
.37914 .14628 L
s
P
p
.001 w
.40282 .13321 m
.4052 .13609 L
s
P
p
.001 w
.42918 .12288 m
.43154 .12579 L
s
P
p
.001 w
.45582 .11245 m
.45815 .11538 L
s
P
p
.001 w
.50994 .09126 m
.5122 .09424 L
s
P
p
.001 w
.53743 .0805 m
.53965 .0835 L
s
P
p
.001 w
.5652 .06962 m
.5674 .07265 L
s
P
p
.001 w
.59328 .05863 m
.59543 .06168 L
s
P
p
.001 w
.08318 .25837 m
.08589 .26094 L
s
P
p
.001 w
.65033 .03629 m
.65242 .03939 L
s
P
[(x)] .30204 .09689 .86223 1 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{501, 411.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007e0001Va000`40O003h00OogoomWoo003oOoof
Ool00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00
ogoomWoo003oOoofOol00?moooIoo`00ogoo:goo0`0017oo0P00`Woo003oOol/Ool00`00Oomoo`02
Ool01000Oomoo`007Woo0P00XGoo003oOol/Ool00`00Oomoo`02Ool01000Oomoo`006goo0`0000=o
o`00Ool0X7oo003oOol/Ool00`00Oomoo`02Ool01000Oomoo`006Goo0P001Goo00<007ooOol0WWoo
003oOol/Ool00`00Oomoo`02Ool01000Oomoo`005Woo0`0027oo00<007ooOol0WGoo003oOol[Ool2
0005Ool2000EOol2000;Ool00`00Oomoo`2MOol00?moodIoo`<000ioo`03001oogoo09aoo`00ogoo
@goo10004Goo00<007ooOol0Vgoo003oOom1Ool20004Ool00`00Oomoo`0>Ool00`00Oomoo`2KOol0
0?moocioo`<001Qoo`03001oogoo09Yoo`00ogoo?7oo0P0077oo00<007ooOol0VGoo003oOoliOol3
000NOol2002JOol00?moocMoo`80021oo`03001oo`0009Yoo`00ogoo=7oo100097oo00<007ooOol0
Ugoo003oOolbOol20004Ool00`00Oomoo`0QOol00`00Oomoo`2GOol00?moobmoo`<000Moo`03001o
ogoo025oo`03001oogoo00ioo`<000Aoo`8007moo`00ogoo;7oo0`00;Woo00<007ooOol03goo00<0
07ooOol00Woo00@007ooOol007ioo`00ogoo:Woo0P00<Woo00<007ooOol01goo1@000Woo00<007oo
Ool00Woo00@007ooOol007ioo`00ogoo9goo0`00=Goo00<007ooOol03Goo00<007ooOol00Woo00@0
07ooOol007ioo`00ogoo9Goo0P000goo00<007ooOol0<Woo00<007ooOol03Goo00<007ooOol00Woo
00@007ooOol007ioo`00ogoo8Woo0`00>goo00<007ooOol02goo0P001Goo0P00Ogoo003oOolPOol2
000oOol00`00Oomoo`2BOol00?mooaeoo`<0045oo`8009=oo`00ogoo6goo0P00@Woo0P0000=oo`00
Ool0TWoo003oOolHOol40017Ool00`00Oomoo`2@Ool00?mooaEoo`<000Aoo`03001oogoo04Aoo`03
001oogoo091oo`00ogoo4goo0P00Cgoo00<007ooOol0Sgoo003YOol3000SOol3001BOol00`00Oomo
o`2>Ool00>aoo`03001oogoo01ioo`8005Eoo`03001oogoo08ioo`00k7oo00<007ooOol06goo0`00
F7oo00<007ooOol0SGoo002AOol200000goo0000001COol3000LOol20003Ool00`00Oomoo`1FOol0
0`00Oomoo`2<Ool0099oo`03001oo`0005Aoo`03001oogoo01Uoo`<005ioo`03001oogoo08aoo`00
Tgoo00<007ooOol0Dgoo10005Woo0P00H7oo0`00SGoo002BOol00`00Ool0001[Ool3001UOol00`00
Oomoo`2:Ool0095oo`800003Ool0000006Moo`<006Qoo`03001oogoo08Yoo`00ngoo0P000Woo00<0
07ooOol0Igoo00<007ooOol0RGoo003hOol30005Ool00`00Oomoo`1VOol00`00Oomoo`29Ool00?Io
o`80079oo`03001oogoo08Qoo`00lgoo0`00Ggoo0UiE57oo00<007ooOol0Qgoo003aOol2001ROol3
GUDCOol00`00Oomoo`27Ool00>ioo`@0069oo`ENEA=oo`03001oogoo08Ioo`00k7oo0P0017oo00<0
07ooOol0GWoo1UiE57oo0P00QWoo003YOol30007Ool00`00Oomoo`1LOol7GUDCOol20027Ool00>Io
o`<006Qoo`MNE@03HS=oogoo01=oo`03001oogoo08Aoo`00i7oo0P00Jgoo1eiE0V8c5Goo00<007oo
Ool0Pgoo003QOol4001[Ool8GUD2HS<EOol00`00Oomoo`23Ool00=moo`8000Aoo`03001oogoo06Mo
o`QNE@=R<aIoo`03001oogoo089oo`00g7oo0`00KWoo00=9TUiEGUD01eiE0f8c5goo00<007ooOol0
PGoo003JOol2001_Ool3BI89GUD3HS<GOol00`00Oomoo`21Ool00=Moo`<004Uoo`8e4REoo`E9TPMN
E@AR<aQoo`03001oogoo081oo`00eGoo0P00C7oo0cDB8Woo1dVB1eiE168c6Goo00<007ooOol0Ogoo
003BOol30002Ool00`00Oomoo`18Ool00fYc=A8e4P03=A8GOol00eD[Oomoo`05Ool8BI86GUD6HS<H
Ool20020Ool00<moo`<0051oo`03JW<e4SDB00@e4P]oo`03A<Yoogoo00Qoo`9E:`Ioo`U9TPENE@IR
<aMoo`03001oo`00081oo`00Ygoo0P0097oo0P00Dgoo0VYc1SDB2Goo00=E04C:Ool027oo00AE@5D[
EB]E:`Eoo`U9TPENE@IR<aYoo`03001oogoo07eoo`00YWoo00@007ooOol0021oo`<005Aoo`=ZL`He
4PUoo`03E@14bTC:00Moo`9E@0AE:`=oo`9o<@Q9TPANE@MR<aYoo`03001oogoo07eoo`00YWoo00@0
07ooOol001ioo`8005Moo`=ZL`Le4PMoo`9E0094bPIoo`9E@0IE:`9oo`9o<@U9TP=NE@MR<a]oo`03
001oogoo07aoo`00YWoo00@007ooOol001]oo`<0009oo`03001oogoo05=oo`AZL`Le4PMoo`9E0094
bP03ED1oogoo009oo`=E@0ME:`03Oomo<Gla00U9TP=NE@MR<aaoo`03001oogoo07]oo`00YWoo00@0
07ooOol001Uoo`8005]oo`AZL`Pe4PEoo`9E00A4bP=oo`AE@0QE:`9o<@U9TP9NE@UR<a]oo`03001o
ogoo07]oo`00Ygoo0P005goo0`00G7oo1FYc23DB17oo0eD014C:00=E@7ooED0015E025D[0Wla2TVB
00=NEF8cHS<01f8c77oo00<007ooOol0NWoo002nOol2001OOol5JW<9=A83Ool3E@05A<X6ED07EB/3
Oc4:BI800eiEHS=R<`07HS<LOol00`00Oomoo`1jOol00;]oo`<0065oo`IZL`Pe4P9oo`AE00E4bPIE
@0ME:`Ao<@U9TPYR<aeoo`03001oogoo07Uoo`00^7oo0`0000=oo`00Ool0H7oo1fYc2CDB00=ooeD0
E@000UD01TC:15E025D[17la2DVB2V8c77oo0`00NWoo002fOol20005Ool00`00Oomoo`1NOol7JW<9
=A85E@06A<X4ED08EB/4Oc49BI800gM]HS=R<`07HS<NOol00`00Oomoo`1hOol00;=oo`<006Moo`QZ
L`Te4P03GQ=E05D0009E00M4bP=E@0QE:`Ao<@Q9TP9gK@UR<amoo`03001oogoo07Moo`00/Goo0P00
JWoo26Yc23DB0UhC15D01dC:0eE01eD[1Gla24VB0WM]2V8c7goo00<007ooOol03Woo0`00IGoo002^
Ool3001/Ool8JW<8=A82GQ<016ZfE@1E05D01dC:0eE01eD[1Gla24VB0WM]2V8c7goo00<007ooOol0
4Goo00<007ooOol0HWoo002/Ool200000goo001oo`1[Ool9JW<7=A84GQ<2E@09A<X2ED07EB/6Oc46
BI84Mfd9HS<POol00`00Oomoo`07Ool50004Ool00`00Oomoo`1ROol00:Uoo`<000Aoo`03001oogoo
06Uoo`YZL`He4PAN4`03J[IE04C:00Q4bP03ED1E:eD[00IE:`Io<@I9TPAgK@UR<b5oo`03001oogoo
00aoo`<006Eoo`00Ygoo0P0027oo00<007ooOol0Igoo0W:c2FYc1SDB15hC00=Z]UD0A<X02DC:1eD[
1gla1TVB17M]2F8c00=oUGooOol07Woo00<007ooOol037oo00<007ooOol0IGoo002TOol3000gOol7
@I@25?DdOol2L[<9JW<5=A86GQ<00fZfA<Y4bP08A<X7EB/7Oc46BI84Mfd8HS<3OiDPOol00`00Oomo
o`0;Ool4001TOol00:9oo`8003Yoo`Q1U08DmBIoo`9]X@Moo`9]X@04KJ1oog:cL[<9JW<5=A86GQ<3
DK88A<X00d0REB]E:`04EB/7Oc45BI86Mfd7HS<3OiD2@008Ool00f]KOomoo`0COol2001dOol009mo
o`@003Yoo`9N<`M1U0<DmBEoo`04ED]]XFfQKJ42Ool5KJ4015e[L[=b/g:c2FYc13DB1ehC156b1TC:
0d0R1ED[1gla1DVB1WM]1V8c1GnE0T001Woo00<0UV]KJe/04Woo0P0000=oo`00Ool0Lgoo002LOol3
0004Ool00`00Oomoo`0gOol2GS<7@I@45?DGOol00edVOomoo`09Ool00ca6ED]]X@09KJ400ee[L[=b
/`02L[<8JW<4=A87GQ<6DK84A<X3@285EB/7Oc45BI86Mfd6HS<6OiD2@004Ool209H3Je/EOol00`00
Oomoo`1aOol009Yoo`80041oo`=N<`Q1U0@DmAIoo`9M9PUoo`8lAP9EB`Q]X@9MJ`Ab/`QZL`<e4PQN
4`03NdeA/U6b00AA/P94bPE08P=E:`Uo<@A9TPIgK@IR<`IoU@0300900400009oo`80UPE[FaEoo`03
001oogoo071oo`00Ugoo0`00@Woo0ehc246D1ACe2Goo00<1^ed4G@@027oo15dV1goo0Sa60eE;26fQ
00=MJg:cL[<00g:c2FYc0SDB1ehC0W]=1e6b00=4bT0R@2800d0R0eD[2Gla0dVB1gM]1F8c1gnE00@e
4P02@01000<0UPA[F`03DMAoogoo01=oo`03001oogoo071oo`00UGoo0P00A7oo15hc246D1ACe0P6k
1Woo00<1^ed4G@@015d417oo1UdV1Goo0ca60eE;26fQ00=MJg:cL[<017:c26Yc0SDB1ehC0W]=2E6b
1D0R0UD[2Gla0dVB27M]168c1WnE0cDB00<0UT00@0000P2F0f]K0e7D5Goo00<007ooOol0Kgoo002B
Ool300000goo001oo`0iOol2<A88Ool5GS<8@I@55?D30K/2Ool20K/9G@@00gooGBIM9P06GBH3Ool4
?4H4ED/7KJ400ee[L[=b/`04L[<8JW<00cDBGQ=N4`06GQ<2Ndd:DK800ehB@2908P02@2800eD[Oc5o
<@07Oc43BI88Mfd3HS<6OiD4=A87Je/4DM@FOol00`00Oomoo`1^Ool0091oo`8000Eoo`03001oogoo
03Moo`<a4PMoo`EN<`Q1U0HDm@<1^`03CM@1^ed400UM10YM9P03OollASa600<lAPAEB`I]X@03GF]b
/g:c00Eb/`QZL`03=A9N4ehC00IN4`9kC@YA/P=N4P908P03EB]o<Gla00Mo<@99TP9gK@91L`EgK@=R
<`IoU@@e4P03KY=[Ff]K00=[F`IAe1Eoo`03001oogoo06ioo`00Igoo0`008goo0`00@7oo00=IlS4B
<A800S4B1Goo1Uhc246D1aCe00<1^dgDCM@02ed400=Dj5dVGBH01edV1Sa61EE;1FfQ00=MJg:cL[<0
1G:c1fYc00=9]5hCGQ<01ehC0W]=2U6b1EhB2Wla0TVB0WM]00AIlT5c@G=1L`=gK@9R<`IoU@@e4P=^
T`=[F`MAe1Ioo`03001oogoo06eoo`00JWoo00<007ooOol07Woo0P00@goo00=IlS4B<A800c4B17oo
1Uhc2D6D1ACe00=5TdgDCM@00TgD2Ed40eCX25dV1Sa61EE;1FfQ00=MJg:cL[<01W:c0fYc14Vd25hC
0g]=2E6b0W]=1EhB2Wla00A9TWM]FO9IlPA1L`04M]5gKGM]HS<5OiD5=A84KY<00f]KDMAAe006DM@F
Ool2001^Ool0065oo`D000Aoo`03001oogoo01]oo`<004Eoo`9IlPDa4P9oo`QN<`Q1U08Dm@A5T`E=
e0QM10=Dj0MM9PHlAPMEB`A]X@Ub/`03JW=9]4Vd00A9]0QN4`AkC@QA/P9kC@IN4PUo<@04BI9IlUWb
FO84@G<3M]400f8cOiEoU@02OiD6=A84KY<:DM@DOol00`00Ool0001^Ool006Moo`<001]oo`<0009o
o`03001oogoo049oo`=IlPHa4P03OomN<ehc00IN<`M1U003BI95TdFC00E5T`E=e0IM10EDj0IM9PHl
APMEB`=]X@03GF]b/g:c00Mb/`Q9]0MN4`AkC@QA/P9kC@MN4PQo<@04MfeIlUWbFO84@G<5M]43OiD5
=A85KY<:DM@GOol00`00Oomoo`1[Ool006Moo`03001oogoo01Uoo`8004Yoo`=IlPHa4PUN<`I1U099
TPM5T`I=e0EM10IDj0EM9PHlAPMEB`=]X@03GF]b/g:c00Mb/`Q9]0MN4`AkC@QA/P9kC@UN4P9fl`QI
lPA1L`Ifd@03OiDe4SDB00@e4PE^T`YAe1Moo`03001oogoo06]oo`00Igoo10005Goo0`00Bgoo15Wb
1S4B2Ehc1D6D0dVB1dFC1dgD15d41eCX0edV1ca625E;0VfQ2G:c00=k=4VdBK@01TVd1ehC17]=256b
0W]=2EhB0WKc25Wb145c1WKA1cDB16jC0WJb2E7D00=flgooOol05Goo00<007ooOol0JWoo001nOol2
001>Ool4FO86<A89GS<4@I@4BI87AI<8CM@2G@@8E>P3GBH7?4H8ED/2KJ49L[<2Nc@7BK@6GQ<5Ndd7
DK83Ndd8GQ83M_<9FO83@G<6M]46=A85KY<2M[88DM@2M_<HOol00`00Oomoo`1YOol007]oo`<0051o
o`AIlPLa4PUN<`91U0I9TPI5T`U=e003G@ADj5CX00MDj09M9PLlAPUEB`03GF]b/g:c00Mb/`9k=0M9
]0IN4`EkC@MA/PAkC@MN4P=fl`UIlP91L`Qfd@De4PE^T`9f/PQAe09flaQoo`03001oogoo06Uoo`00
NGoo0P000goo00<007ooOol0C7oo1EWb1c4B2Ehc00=1U4VBBI801DVB1dFC24gD2eCX1ca60eE;1d7F
2G:c0g/d1dVd1UhC1G]=1e6b17]=1ehB0gKc2EWb0T5c27KA13DB1VjC0WJb257D0WKc6Goo00<007oo
Ool0J7oo001fOol3001DOol5FO87<A89GS<8BI87AI<9CM@:E>P5GBL2?4H3ED/8@MH8L[<3Nc@8BK@5
GQ<6Ndd6DK84Ndd6GQ84M_<9FO82@G<8M]44=A86KY<2M[87DM@3M_<JOol00`00Oomoo`1WOol007Ao
o`8005Moo`EIlPLa4PUN<`Q9TPM5T`U=e003<EEDj5CX00MDj0MM9`9EB`8000M1ePMb/`Ak=0Q9]0EN
4`IkC@IA/PAkC@IN4PEfl`QIlP91L`Qfd@@e4PE^T`Af/PIAe0AflaQoo`<006Qoo`00LGoo0`00F7oo
1eWb1S4B25hc00=EdTVBBI801TVB1dFC2DgD0VIC1eCX25dW00@005E;000000M1ePMb/`Ek=0M9]0AN
4`MkC@EA/PEkC@IN4PEfl`QIlP91L`Qfd@<e4PI^T`Af/PIAe0AflaYoo`03001oogoo06Ioo`00KWoo
1000FWoo1eWb1S4B25hc00=EdTVBBI801TVB1dFC2DgD0fIC1UCX25dW00@005E;000000Q1ePEb/`Ik
=0M9]0AN4`MkC@EA/PEkC@EN4PIfl`UIlP03@G=fdGKA00Ifd@<e4PI^T`Af/PEAe0Efla]oo`03001o
ogoo06Eoo`00K7oo0P0017oo00<007ooOol0EWoo25Wb1c4B1Uhc0UGB24VB24FC1dgD00=J56ICIU<0
0VIC15CX25dW0P0000AN4P00000000M1ePEb/`Ik=0M9]0AN4`MkC@EA/PIkC@AN4PIfl`UIlPUfd@<e
4PI^T`Af/PEAe0Efla]oo`03001oogoo06Eoo`00JGoo0`001goo00<007ooOol0EGoo25Wb1c4B1Uhc
0UGB24VB24FC1TgD0eXD16IC0UCX2EdW0P0000AN4Tfc000000M1ePEb/`Ik=0Q9]0=N4`MkC@EA/PIk
C@AN4PIfl`UIlPYfd@03=A9^TfjC00E^T`Af/PEAe0Eflaaoo`03001oogoo06Aoo`00Igoo0P00HWoo
25Wb1c4B1Ehc15GB1dVB24FC1TgD0eXD1FIC00=Dj5dWGBL01edW00@005hBGQ9N4P8000Q1eP=b/`Mk
=0Q9]0=N4`MkC@AA/PMkC@=N4PMfl`UIlPYfd@03=A9^TfjC00A^T`If/PAAe0Iflaaoo`03001oogoo
06=oo`00I7oo0`00Hgoo2EWb1c4B1Ehc15GB24VB1dFC1DgD15XD1FIC2UdW00H005hBGQ9N4Tfc0008
@MH3L[<7Nc@8BK@2GQ<9Ndd3DK87Ndd3GQ87M_<9FO8:M]400cDBKY=^T`04KY<6M[83DM@7M_<5Ool0
0dC/Oomoo`0DOol00`00Oomoo`1SOol0069oo`800003Ool007oo05Ioo`03;?5oogoo00Yoo`UIlPLa
4PAN<`EEdPQ9TPM5T`A=e0EJ50IVD`QM9`8000=N4P03CK<0000000M1eP9b/`Uk=0M9]09N4`UkC@=A
/PMkC@=N4PQfl`MIlP9kMPUfd@M^T`If/P=Ae0Mfl`Aoo`0300i4k7oo01Ioo`03001oogoo069oo`00
Ggoo0`0017oo00<007ooOol0Dgoo00=N4bca;?402Woo00=J55WbFO801eWb1c4B15hc1EGB24VB24FC
0TgD1UXD1fIC1edW00<005hBGQ800UhB0Tfc00<0047F@MH01T7F00=b/g/dNc@01g/d1dVd0UhC0W]=
00=R<W]=Ndd017]=0e6b1g]=0UhB2GKc1eWb0W]f2GKA1fjC1WJb0e7D1gKc17oo00<03TC/Ool05goo
00<007ooOol0;7oo0`00<Woo001MOol2001MOol015hC;?4/lBca27oo0UXD2EWb1c4B0ehc1UGB24VB
24FC0TgD1eXD1VIC1edW00<005hBGQ800UhB0dfc247F00=b/g/dNc@01g/d1dVd0UhC00AkCF8bHS9R
<PEkC@=A/PQkC@03GQ9flgKc00Mfl`IIlP=kMPQfd@9cVPE^T`Mf/P9Ae0Qfl`=oo`803P94k1Ioo`<0
02ioo`03001oogoo035oo`00FWoo0`00GWoo0UhC0bca1goo0eXD2UWb1c4B0Uhc1UGB24VB24FC00==
e5XDFQ@01UXD1fIC1UdW00<005hBGQ800UhB0dfc00<0047F@MH00d7F0eWc2G/d24Vd00=N4g]=HS80
0f8b17]=0U6b2G]=00=N4WKcM_<01gKc1UWb17]f1WKA0g>J1FjC27Jb00=Ae7KcM_<01gKc00Aoo`0>
00h03P94k1Qoo`03001oogoo02eoo`03001oogoo031oo`00Egoo0`00HGoo0ehC0bca1Goo1EXD2EWb
1c4B00=N<eGBEM801EGB24VB24FC2EXD1VIC0UXD15dW00<005hBGQ800ehB0dfc00=IlT7F@MH00eWb
15Wc27/d24Vd00=kCF8bHS80168b0g]=0U6b0W]=17:c00==/g]=Ndd02WKc1EWb1G]f1GKA17>J1FjC
27Jb00=Ae7KcM_<01gKc00=oo`0>00h014C/67oo00<007ooOol0;7oo00<007ooOol0<7oo001EOol2
0002Ool00`00Oomoo`1OOol3GQ<4;?43Ool6FQ@9FO87<A800ehcEM9EdP05EM88BI88AI<9FQ@5IU<4
FQ@3GBL00`00GQ9N4P04GQ82CK<7FO84FO<8Nc@7BK@00g]=HS9R<P05HS82Ndd2DK82Ndd4L[<2CK<0
0bP0M_=fl`08M_<4FO86NgH4M]46LiX4KY<8M[8:M_<300h4A>`HOol00`00Oomoo`0[Ool00`00Ool0
000aOol0059oo`<006Eoo`AN4`D/l@03OomJ55XD00EJ50UIlP@a4P=1LPQEdPQ9TPM5T`YJ50AVD`EJ
50=M9`MN4P03CK=IlUWb00IIlPEIl`Mk=0E9]09N4`UR<P9kC@03DK9kCG:c00Ab/`9=/`8X00Ufl`AI
lPMkMP9fd@McVPA^T`Qf/PYfl`<03PA4k1Uoo`03001oogoo02Yoo`03001oo`00035oo`009Goo0`00
17oo0P008Woo0P00GWoo00</lGooOol01goo15hC1Bca25XD2EWb1d5b25GB24VB1TFC35XD0fIC1EXD
00=N4UdWGBL01ehB00==/eWbFO801UWb1UWc0fYc00=N4g/dNc@00TVd15hC00=ZLf8bHS801f8b00A1
DW]=DK91DPEb/`==/`03:01flgKc00Qfl`9IlPQkMP03M]5cVW>J00IcVP=^T`Uf/P0300AflgKc00Mf
l`<03PE4k1Uoo`03001oogoo02Qoo`800003Ool00000031oo`009Woo00<007ooOol00Woo00@007oo
Ool001ioo`<003Yoo`03CM=oogoo029oo`03HS@/lBca00Moo`EN4`D/l@QJ50UIlPM1LPQEdPU9TPA5
T`eJ509VD`IJ509N4P03001N4UhB00EN4PUIlPEIl`AZL`UN4`9ZL`QR<P91DP03Nde1DW:c00Ab/`A=
/`03:01flgKc00Mfl`9IlPQkMP03COIAe7>J00McVP9^T`Qf/P8010Yfl`803PE4k09oo`03>0=oogoo
01Aoo`03001oogoo05eoo`007goo1@000Woo00<007ooOol00Woo00@007ooOol001aoo`<003]oo`9=
d`03:=1oogoo025oo`03HS@/lBca00Moo`EN4`H/l@MJ50QIlP03IU=1LT5b00E1LPUEdPQ9TP=5T`iJ
5003IU=J55XD00EJ50YN4PUIlPEIl`AZL`UN4`9ZL`QR<P=1DPIb/`A=/`03:01flgKc00Mfl`03FO9k
MW]f00IkMP04COIAe57DDM@7LiX2KY<8M[8300@9M_<200h6A>`3>0<7Ool00eifOomoo`0<Ool00`00
Oomoo`1LOol002Ioo`03001oogoo009oo`04001oogoo000IOol30003Ool00`00Oomoo`0^Ool2>E<6
Ool4CM<00bS@Oomoo`0POol2HS@3;?45Ool6GQ<6;?47FQ@8FO800fIC@G91LP05@G89EM88BI82AI<G
FQ@9GQ800fZCFO9IlP07FO84FO<6JW<7GQ<3JW<8HS83@E87L[<4CK<00bP0M_=fl`06M_<00eWbNgIk
MP05NgH00f9CDMAAe003DM@6LiX2KY<8M[8300@8M_<00e8E00h03P06A>`4>0<5Ool00`2eGWINMP0=
Ool2001MOol002Ioo`03001oogoo009oo`04001oogoo000GOol2000gOol4>E<3Ool5CM<2:=0QOol2
HS@4;?44Ool6GQ<6;?47FQ@8FO800fIC@G91LP06@G88EM88BI800dFCFQAJ500GFQ@8GQ800fZCFO9I
lP07FO84FO<6JW<7GQ<3JW<8HS83@E87L[<5CK<6M_<2EQD2HU<5NgH2HU<8DM@4LiX00fjCM[9f/P05
M[82IU<200@7M_<3DQD00`0>A>a4k005A>`4>0<3Ool20;D2GWH=Ool2001MOol002Eoo`8000Eoo`80
01Eoo`<003Qoo`03L]DiDcUC00<iD`03Oom=ddgC00A=d`8Xd21oo`=R=0@/l@Aoo`IN4`H/l@MJ50MI
lP9VD`Q1LPQEdPQ9TQ1J509^ePQJ50QN4P9ZT`QIlPAIl`IZL`MN4`=ZL`QR<P=1DPMb/`E=/`03M]9f
lgKc00AfdP04EQERDf9CHU<3NgH3HU<00fjCDMAAe007DM@00f8cLiYf/P07M[82IU<2@0000`04M_=f
l`02M_<5DQD00`0>A>a4k005A>`5>0<017oo0;D0]@2e0eif3Woo00<007ooOol0FWoo0010Ool3000k
Ool00g;E>E<iD`03>E<7CM<3:=0=Ool2AI<6@E8:Ool3HS@5;?42Ool7GQ<6;?48FQ@6FO83IU<7@G88
EM88BI8@FQ@2K]H8FQ@7GQ83JY<8FO83FO<7JW<6GQ<4JW<8HS82@E88L[<5CK<7M]85HU<017]fHU=R
Df9C0VjC257D0VYc00<l0GJbM[801WJb0fIC0T000gKc1e8E1dC/0P0?13P30P2e15if00=N4gooOol0
2goo00<007ooOol02Woo0P00CWoo000nOol200000goo001oo`0jOol2L]D5>E<7CM<3:=0:Ool5AI<6
@E800bcaOomoo`06Ool4HS@6;?400gooGQ=N4`05GQ<7;?47FQ@6FO83IU<7@G88EM87BI82JYD>FQ@3
K]H8FQ@7GQ83JY<9FO82FO<7JW<6GQ<5JW<8HS800d5BL[=b/`06L[<5CK<7M]89HU<2KY<8DM@2JW<0
0f8c?05f/P05M[80168cL]=VDfIC0d0000=fle8EDQD01U8E24C/100?0Uif00<0]EifGWH00Uif0UhC
3Goo00<007ooOol027oo00@007ooOol004eoo`00>goo0`0017oo00<007ooOol0>7oo0g;E13UC1dgC
12S@1Woo00=9/dFCAI<01DFC1T5B0Rca1goo1F8d1Bca2EhC1Rca1eXD1EWb16IC1d5b25GB1dVB0VZE
3UXD0fkF25XD1ehB0fZC2EWb00=IlfYcJW<01VYc1UhC1FYc268b00=1DW:cL[<01W:c14fc27KB2F9C
0VjC257D0VYc00=R<c`1M[801GJb0W;C0fIC0T002U8E1dC/100?1Uif15hC3Goo00<007ooOol01goo
00@007ooOol004eoo`00>Goo0P00@Goo17;E13UC1dgC12S@17oo0dVc1dFC1T5B0bca1Goo1V8d1Bca
2EhC1Rca1eXD1EWb16IC1d5b25GB1TVB0fZE3EXD1FkF1eXD1UhB16ZC2EWb00=IlfYcJW<01VYc1EhC
1VYc268b00=1DW:cL[<01g:c0dfc1gKB0VIC269C0VjC1e7D0fYc0V8c1WJb0W;C0fIC0T002U8E24C/
0P0?1eif15hC3Goo00<007ooOol01goo00@007ooOol004eoo`00=Woo0`00@goo17;E1CUC1TgC1BS@
00=oodVcBK<00dVc1dFC1T5B12ca17oo1V8d1Bca2EhC1Rca1eXD1EWb16IC1d5b25GB1TVB0fZE3EXD
1FkF1eXD1UhB16ZC2EWb00=IlfYcJW<01fYc15hC1VYc268b2W:c0dfc1gKB0VIC1f9C16jC1U7D0fYc
0V8c00<l0GJbM[800WJb00=R<g;CL]<016IC0T002E8E00<01DC/A>`01DC/0P0?1Uif1EhC3Woo00<0
07ooOol01Woo00@007ooOol004eoo`00=7oo0P00AGoo1G;E1CUC1TgC1BS@1TVc1dFC1T5B1Bca0Woo
1f8d1Bca2EhC1bca1UXD15Wb1FIC1d5b25GB1DVB16ZE35XD1VkF25XD1EhB16ZC2EWb2VYc15hC1VYc
268b2W:c0dfc1gKB0VIC1f9C16jC1U7D16Yc0V8c17Jb17;C0fIC0T00258E0P0500=404C/A>`014C/
0P0?1Uif1EhC00=jdGooOol037oo00<007ooOol01Woo0P00CWoo000aOol30002Ool00`00Oomoo`11
Ool6L]D5>E<6CM<5:=07BK<6AI<6@E86;?400gooHSAR=005HS@6;?48GQ<7;?46FQ@4FO85IU<7@G88
EM85BI85JYD;FQ@6K]H8FQ@4GQ85JY<9FO8:JW<3GQ<7JW<8HS800f[FL[=b/`07L[<2CK<7M]83IU<7
HU<4KY<5DM@5JW<2HS<4M[84L]<4IU<00d00DQEB5@06DQD2GWH00`05A0140005A>`00g:bGWINMP03
GWH6GQ<00g[AOomoo`0<Ool2001GOol002moo`8000Ioo`03001oogoo041oo`Ibe@DiD`I=d`DXd0M9
/`I5T`I1DPH/l@QR=0H/l@QN4`L/l@IJ50AIlPEVD`M1LPUEdP=9TPIZU@YJ50M^ePQJ50AN4PIZT`QI
lP03Na=ZLfYc00MZL`=N4`QZL`IR<P9ZePUb/`9=/`MfdP=VD`MRD`A^T`EAe0EZL`9R<`04?05f/WJb
HS<4L]<4IU<2@006DQD4GWH4A002A>`3L[84GWH6GQ<00g[AOomoo`0:Ool200000goo001oo`1FOol0
02aoo`<004Yoo`Mbe@DiD`I=d`DXd0M9/`I5T`M1DPD/l@QR=0H/l@QN4`L/l@IJ50=IlPIVD`Q1LPQE
dP=9TPIZU@YJ50Q^ePMJ50AN4PIZT`MIlP9k4`UZL`=N4`QZL`IR<P9ZePUb/`9=/`MfdPAVD`ERD`E^
T`EAe0EZL`=R<`9f/PEbd`AVD`9000IB5@ENMP9400=fdP=b/PANMPEN4`=jd@moo`03001oogoo05Ao
o`00:Goo0`00BGoo00@T07ooOomoo`Mbe@DiD`I=d`HXd0I9/`M5T`I1DPD/l@QR=0H/l@QN4`L/l@MJ
509IlPIVD`Q1LPQEdP99TPMZU@UJ50U^ePMJ50=N4PMZT`MIlP9k4`UZL`9N4`UZL`ER<PAZePUb/`03
CK=fdWKB00AfdPEVD`ERD`I^T`=Ae0IZL`=R<`9f/PEbd`AVD`03JW=0058E00AB5@ENMPIfdP=b/P=N
MPIN4`=jd@moo`03001oogoo05Aoo`009goo1000B7oo12@000=oog;EL]D01W;E1CUC1TgC1RS@1TVc
1dFC1T5B1Rca1f8d1Rca25hC22ca1UXD0UWb1VIC245b25GB0TVB26ZE25XD00=WmfkFK]H01VkF1eXD
0ehB1fZC1eWb0W/C2VYc00=N4fYcJW<01fYc1F8b16[F2G:c00==/gKBM]8017KB1FIC1F9C1VjC0e7D
1fYc168c1W;C0fIC00=ZLd00DQD0158E00=fdUifGWH00Uif1WKB0g:b0eif1UhC0g[A47oo00<007oo
Ool0Dgoo000TOol30004Ool00`00Oomoo`14Ool3MkT00g^H901oo`08L]D6>E<5CM<6:=06BK<7AI<6
@E86;?47HS@6;?48GQ<8;?46FQ@00eWbIU=VD`06IU<7@G88EM800dVBJYEZU@07JYD7FQ@2IoL8K]H7
FQ@3GQ87JY<6FO84Na<9JW<00ehCJW=ZL`07JW<4HS85J]H9L[<6M]86IU<5HU<6KY<3DM@7JW<3HS<7
L]<2IU<3JW<00d00DQEB5@02DQD00gKBGWINMP02GWH5M]85L[800eifGQ=N4`05GQ<4N]4@Ool00`00
Oomoo`1BOol0029oo`8004ioo`9g^@=kV0Ube@HiD`E=d`HXd0I9/`M5T`I1DPH/l@MR=0H/l@QN4`L/
l@04HYPaUc6G<IL3FQ@00eWbIU=VD`06IU<7@G88EM800dVBJYEZU@07JYD6FQ@4IoL8K]H7FQ@00ehB
JY=ZT`06JY<6FO84Na<CJW<3HS87J]H7L[<00e7eM]9fdP04M]86IU<4HU<7KY<2DM@8JW<3HS<7L]<2
IU<3JW<01400DQEB5E8E0WKB15if1GKB1G:b00=NMUhCGQ<01EhC17[A47oo00<007ooOol0DWoo000O
Ool3001?Ool3MkT3NiP00a2BL]Ebe@07L]D5>E<5CM<6:=07BK<6AI<6@E86;?47HS@6;?49GQ<5;?42
HYP6<IL00eWbIU=VD`06IU<7@G88EM8:JYD5FQ@5IoL8K]H7FQ@00ehBJY=ZT`06JY<6FO84Na<DJW<2
HS87J]H5L[<4DOD5M]87IU<3HU<7KY<2DM@8JW<3HS<7L]<2IU<4JW<3DQD3M]82GWH6M]85L[88GQ<4
N]4AOol00`00Oomoo`1AOol001ioo`03001oogoo04moo`=g^@AkV08@TPQbe@DiD`E=d`HXd0M9/`I5
T`I1DPH/l@MR=0L/l@QN4`@/l@ARV0DaU`UVD`M1LPQEdP03LcMZUFZE00MZU@AJ50IWm`I^ePAIl`03
DK825`8G009J5003GQ9ZTfZC00MZT`EIlPEk4`MZL`03JoUZLfYc00UZL`03HS9ZeV[F00IZePAb/`EA
m@AfdPQVD`=RD`Q^T`03DMAZLfYc00IZL`9R<`Ubd`03IU=ZLfYc009ZL`03@01B5FYc00=fdP9NMPIf
dPEb/PQN4`EjdA5oo`03001oogoo051oo`00Kgoo0gNi1G^H0Q2B27;E1CUC1TgC1BS@1dVc1TFC1T5B
1Rca1f8d1bca25hC0bca1F:H1C6G2FIC1d5b1eGB0W<g2VZE0UXD00=WmdVcBK<00dVc0VOg0VkF00=A
m5WcFO<015Wc0U6b0`8G2VZC15Wb1W/C1VYc0f_i2VYc00=R<V[FJ]H01f[F00=b/e7eDOD01E7e17KB
26IC0f9C26jC2VYc00=R<g;CL]<01g;C1VYc00=B5FYcM]800WKB0Uif1WKB1G:b00=^TUhCGQ<015hC
1W[A47oo0P00DWoo001^Ool4MkT5NiP34987L]D5>E<6CM<5:=07BK<6AI<6@E87;?46HS@7;?48GQ<2
;?46HYP5<IL9IU<7@G86EM83LcL:JYD00eXDDK9A/P09BK<00e7dFO=Il`04FO<3DK820QL:JY<4FO86
Na<5JW<4JoT:JW<:J]H9DOD3M]88IU<2HU<9KY<:JW<00f8cL]=bd`07L]<7JW<5M]800eifM]9fdP03
M]86L[800fjBGQ=N4`04GQ<6N]4BOol00`00Oomoo`1?Ool006ioo`=g^@IkV0@@TPIbe@DiD`I=d`HX
d0I9/`I5T`I1DPL/l@IR=0L/l@QN4`03;?5RV6:H00IRV0DaU`QVD`M1LPIEdPAc=`UZU@=A/PU9/`03
DOAIleWc00AIl`=A/P<25`UZT`AIlPIk4`AZL`E[n@YZL`0300=ZeV[F00MZePUAm@9fdPUVD`9RD`U^
T`YZL`Ybd`MZL`]fdPEb/P9^TPIN4`IjdA=oo`03001oogoo04ioo`00KGoo17Ni1g^H0a2B1T6e0SDA
13UC1DgC1RS@1TVc1TFC1T5B1bca1V8d1bca25hC2F:H1C6G26IC245b15GB1G<g26ZE1E6b24Vc1eWc
156b0P8G2FZC0eWb27/C0VYc1V_i2FYc0P0326[F0P00257e0WKB2VIC00=RDfjCKY<01VjC0WnB2FYc
2G;C0UXD1VYc2gKB1G:b0VjB1UhC1W[A00=fdWooOol047oo00<007ooOol0CWoo001/Ool4MkT8NiP3
4986@KD3=A43>E<5CM<6:=06BK<6AI<6@E87;?46HS@7;?48GQ<00eXeHYQRV006HYP5<IL8IU<8@G83
EM86LcL7JYD6DK88BK<8FO<3DK820QL9JY<3FO88Na<016YcJoUAde7C1F_i26Yc00=Ed`03J]H01V[F
0`002E7e00=fdVICIU<026IC00=RDfjCKY<01VjC0WnB2FYc00=RE7;CL]<01G;C0eXD1VYc1GKB00=Z
LgKBM]800gKB1G:b0fjB1EhC1W[A00=fdWooOol04Goo00<007ooOol0CGoo001[Ool300000g=H=E@e
E003=E@4NiP34986@KD5=A400cUCCM==d`03CM<6:=07BK<5AI<6@E87;?47HS@6;?47GQ<2FSD8HYP5
<IL8IU<8@G82EM88LcL5JYD7DK87BK<00eGBFO=Il`06FO<4DK820QL8JY<3FO88Na<00eGCDM=Ad`02
DM<4JoT7JW<2EM<200<5J]H015hC000000002E7e2fIC2FjC0WnB26Yc0V9D1g;C0eXD1FYc1WKB00=Z
LgKBM]800gKB1G:b0fjB1EhC1G[A0WKB4goo00<007ooOol0CGoo001ZOol00`P0HhicF002LeP5=E@0
12SBNiQkV7^H112B1D6e1SDA1DgC1RS@1dVc1DFC1T5B1bca1f8d1Rca1UhC15Xe26:H136G26IC245b
0UGB27<g16ZE256b1dVc00=EdUWcFO<01UWc156b0P8G26ZC0eWb27/C00=Ede7CDM<00e7C0f_i1fYc
0eGC00<00f[FJ]H00V[F0ehC0P002E7e2fIC26jC0gnB26Yc0V9D1W;C1EXD16Yc1GKB0VYc17KB1W:b
0fjB1EhC1G[A0WKB57oo00<007ooOol0C7oo001YOol00`00HhicF003LeP5=E@2:=82NiP44985@KD6
=A45CM<6:=07BK<5AI<6@E88;?46HS@7;?44GQ<5FSD8HYP4<IL8IU<8@G800eGBLcMc=`07LcL3JYD0
0e7CDK9A/P06DK86BK<3EM87FO<5DK800`8GJY=ZT`07JY<00eWbNa=k4`06Na<2EM<5DM<3JoT6JW<4
EM<017[bJ]IZeV[F15hC0`001e7e0P002VIC26jC0gnB1fYc169D17;C1UXD16Yc1GKB0fYc0gKB1W:b
0fjB1EhC1G[A0gKB57oo0P00C7oo001YOol2Hhh4LeP5=E@2:=82NiP44985@KD6=A400aQ`CM==d`02
CM<6:=07BK<5AI<6@E88;?46HS@7;?43GQ<7FSD6HYP00e7B<ILaU`03<IL8IU<6@G800fOkLcMc=`09
LcL00fZEDM=Ad`08DK86BK<3EM87FO<5DK800`8GJY=ZT`07JY<00eWbNa=k4`05Na<4EM<5DM<3JoT4
JW<5EM<2N_800f[FGQ=N4`04GQ<20007DOD20009IU<2Ni06KY<5Oi86JW<4HU@3L]<7FQ@4JW<5M]83
JW<3M]86L[84KY83GQ<6N]43M]8COol2001=Ool006Qoo`03001SSW=H00AcF0DeE0<XdP03NiP@TQ2B
008@TPE1]@He4@03671=ddgC009=d`HXd0I9/`03CK=5TdFC00=5T`M1DPL/l@IR=0L/l@9N4`QJ=@AR
V0AAdP@aU`QVD`E1LP=Wn`Uc=`AAd`QA/PE9/`AEdPMIl`IA/P030QMZTfZC00IZT`03FO9k4g/C00Ek
4`AEd`IAd`9[n@AZL`EEd`9jlPMN4`03KW80057e00EAm@<000UVD`9kT0I^T`EoTPEZL`ERE0=bd`MJ
50=ZL`IfdPAZL`9fdPEb/PE^TP=N4`Ijd@=fdP9oo`03M]9o3Goo011oo`03001oogoo04Yoo`00J7oo
00=SSW=HLeP017=H1CED0bSB0W^H0a2B1D6e1SDA00<HL4gCCM<00TgC1bS@14Vc0Tfc00<03dFCAI<0
0TFC1d5B1bca0ReF168d1bca00=N4eXeFSD025Xe00=RV4fcCK<01E7B0c6G26IC145b1FOk1W<g1U7C
256b1DVc15GB1eWc1U6b00<25fZCJY<01VZC1g/C1EGC1E7C0VIC00A[nFYcJW=ZL`EEd`=jlPIN4`9^
LP8000EAm@<000UVD`9kT0I^T`EoTPAZL`MRE003L]=J55XD00MJ509ZL`EfdPEZL`9fdPEb/PE^TP=N
4`Ejd@AfdP9oo`03M]9o3Goo015oo`03001oogoo04Uoo`00Igoo0V>>1g=H13ED12SB00=kV12B4980
0Q2B1D6e1CDA0QQ`0dgC1bS@0dVc0dfc00<03dFCAI<00TFC1d5B1Rca00AR^2eF;EH]EP=R=0H/l@03
COEJ=EXe00UJ=@==/`EAdP<aU`QVD`=1LPMWn`Ac=`MAd`QA/PA9/`EEdPMIl`MA/PMZT`03HS=k4g/C
00Ak4`IEd`EAd`9VD`04JoUZLfYcJW<5EM<4N_85GQ<3KW800`00DOEAm@02DOD015Gc0000000026IC
0g^@1FjC1WnB16Yc1f9D2UXD0VYc1GKB1FYc00=fdW:bL[8017:b1FjB0ehC1G[A1GKB00=oogKBO`d0
4Woo00<007ooOol0BGoo001VOol01000HhhiM0001W=H1CED12SB112B1D6e1CDA0QQ`0dgC1bS@0TVc
1Dfc00@03dFCAI=5T`M1DPD/l@=R^0@]EP04HS@/lBca;?44COD;FSD3CK<6DM82<IL8IU<2@G89Io/0
0g<gEM=N=007DM<8DK84BK<5EM87FO<7DK80108GJY=ZTfZC168c00<D07/CNa<00g/C1UGC1E7C0fIC
00=[nFYcEM<01EGC17[b1EhC0fib00@0057eDOEAm@9El`@000MVD`AkT0A^T`IoTP=ZL`QRE0YJ509Z
L`EfdPIZL`Ib/PI^TP9N4`Ejd@MfdP9o3A9oo`03001oogoo04Qoo`00I7oo0P030V>>13Ud17=H1CED
12SB112B1D6e1CDA0aQ`0TgC1bS@00=9/dfcCK<014fc00<03dFCAI<00TFC1T5B12ca16:h1BeF00</
lDgeCOD01Dge2EXe14fc1U7B0S6G26IC00=1LVOkIo/01FOk1EGC00=N=57CDM<01E7C2E6b0dVc1EGB
1eWc256b00=ZTf8cHS<01F8c00@D07/CNa=k4`QEd`AAd`AVD`03JW=EdeGC00AEd`AjlPEN4`A^LP=A
m@=El`<000IVD`EkT0A^T`MoTP9ZL`QRE003005J55XD00QJ5003JW=fdWKB00=fdPIZL`Ib/PI^TP9N
4`Ejd@MfdP9o3A=oo`03001oogoo04Moo`00Hgoo0P0300<006>>>G@013Ud17=H1CED12SB00@`lA2B
498@TPE1]@De4@<HL09=d`HXd003GYM=/dfc00E=/`0300m5TdFC0095T`I1DP</l@ER^0D]EPQ=m@UJ
=@E=/`IAdP03<IMVDfIC00EVD`M9TPIEd`9N=0MAd`UA/P99/`IEdPQIl`MA/P03L]AR<f8c00IR<`=k
4`QEd`=Ad`IVD`IEd`AjlPAN4`E^LP03001AmEGc00=El`<000IVD`EkT0=^T`QoTP03JW=RE69D00IR
E0800@YJ50EfdPMZL`03Odib/W:b00=b/PI^TP9N4`Ejd@IfdP=o3A=oo`03001oogoo04Moo`00HGoo
100300=SSUHf>G@013Ud00@/lW=HLeQcF0DeE0@XdP8`l@8@TPE1]@He4@8HL09=d`DXd09NU`M=/`80
3`=5T`I1DP8/l@MR^0@]EPQ=m@QJ=@I=/`MAdP03<IMVDfIC009VD`91DPM9TPEEd`AN=0IAd`UA/P99
/`IEdPQIl`MA/P03L]AR<f8c00IR<`03IU9k4fIB00QEd`=Ad`IVD`EEd`EjlPAN4`I^LP03DOEEleGc
009El`03HU@0000000EVD`IkT0=^T`QoTP03JW=RE69D00IRE0800@YJ50EfdPMZL`03Odib/W:b00=b
/PI^TP03GQ=jdG[A00=jd@MfdPAo3A=oo`8004Moo`00H7oo100300@006>>ESIF=P@iM08/lP9cF0De
E0@XdP<`l@034991]D6e00=1]@He4@<HL003CM<Xd2S@008Xd0=NU`M=/`803`=5T`I1DP03;?5R^6:h
00IR^0D]EPM=m@QJ=@I=/`MAdP04<IMVDfICIU<3@E87BI85EM<4GS@6DM<9DK800dVcEM9EdP06EM87
FO<7DK82L]@7HS<3IU88EM<3DM<6IU<5EM<6N_83GQ<7KW83EO<3HU@20004IU<6Ni02KY<7Oi824009
HU@2004:FQ@00gLeM]9fdP02M]86JW<2Odh4L[88KY85N]47M]84O`dBOol00`00Ool00017Ool0061o
o`@00`04HhiF=UHfESH4>G@3;?800g=H=E@eE003=E@4:=83<?424984@KD6=A43670014gC:=0Xd2S@
15jG1dfc0`0?0TFC1T5B2F:h1BeF1dge1eXe00<mM4fcCK<014fc257B00=VDd5B@E800d5B24VB0eGC
1Ehd1e7C256b00=9/eGBEM801UGB1eWc1U6b0g;D1f8c0fIB25GC0U7C1fIC1EGC1W[b0ehC26ib0UGc
0f9D0P0016IC1g^@00=^TgnBOi800WnB00=NEUXC40000Q00269D0`012EXD0WLe17KB1VYc0gm>0g:b
26jB1G[A1gKB17l=57oo00<007ooOol0AGoo000oOol00d00Oomoo`0MOol400<00`00ESIF=P02ESH4
>G@3;?82LeP4=E@4:=84<?400a2B@KE1]@02@KD6=A4367000dgC:=0Xd005GYL8CK<200l2AI<5@E82
Ic/9H[P4;EH8COD6FSD00cedCK==/`04CK<8DM86@E88BI83EM<5GS@7DM<8DK89EM87FO<6DK83L]@6
HS<4IU88EM<2DM<7IU<5EM<6N_83GQ<8KW800eGcHUARE003HU@01000IU=VDfIC27^@00=^TgnBIS80
0VHb00=NEUXCFQ<00a001f9D100125XD0WLe0gKB1fYc0gm>0g:b26jB1G[A1gKB1Gl=57oo00<007oo
Ool0A7oo000mOol3@00OOol400<00f>>ESIF=P02ESH4>G@4;?800g=H=E@eE002=E@4:=85<?44@KD6
=A4467000bS@GYMNU`04GYL8CK<300l00dFC@E91DP02@E83Ic/9H[P4;EH8COD5FSD2?G@6CK<8DM86
@E88BI82EM<6GS@7DM<8DK89EM87FO<5DK84L]@6HS<4IU89EM<00e7CIU=VD`06IU<3EM<7N_82GQ<9
KW800eGcHUARE003HU@01000IU=VDfIC1W^@1fHb0eXC0a001f9D10011eXD17Le0WKB1fYc0gm>0g:b
26jB1G[A1gKB1Gl=5Goo00<007ooOol0@goo000lOol4@005Ool00dgeOomoo`0GOol400<5ESH4>G@5
;?84=E@4:=85<?44@KD6=A446708GYL7CK<300l014FC@E91DT5B1FLk26:h1BeF1dge15Xe0ced1Tfc
257B1T5B24VB00=EdehdGS@01Ehd1e7C1e6b00=be5GBEM801eGB1eWc1E6b17;D1V8c1FIB25GC00=A
dfICIU<01VIC0eGC1g[b0UhC2Fib1f9D0VIC17^@0fjC1fHb15XC0Q001f9D10011eXD17Le0WKB1fYc
17m>0W:b26jB00=oDG[AN]400W[A1gKB1Gl=5Goo00<007ooOol0@goo000kOol2Ok<4@002Ool3COD0
0b2aOomoo`0EOol400<00`00ESIF=P03ESH5>G@4;?84=E@5:=84<?44@KD6=A456707GYL7CK<300l0
0dFC@E91DP06Ic/9H[P4;EH7COD4FSD3?G@6CK<8DM86@E88BI800eGCGSAN=005GS@7DM<7DK800g;D
EM9EdP07EM87FO<4DK85L]@6HS<5IU88EM<9IU<3EM<7N_82GQ<9KW87HU@01000IU=kT5hC1FjC1fHb
00Ao;EXCFQ=J4`8@00IRE003CM@00@0100800@IJ50Eg=@9fdPIZL`EoCP9b/PM^TP9oD@=jd@QfdPEo
3@03Oc1oogoo01=oo`03001oogoo049oo`00>goo0gnc0W]F00=004geCOD00dge00<P/GooOol05Goo
10031UHf1CUd12cb00@X/3ED=E@eE0DXdP@`l@0400i1]D6e@KD6=A456707GYL7CK<400l00d5BIc]W
>`06Ic/8H[P4;EH7COD3FSD4?G@6CK<8DM86@E88BI88GS@7DM<7DK82L]@8EM87FO<4DK85L]@5HS<6
IU88EM<9IU<3EM<8N_800ehCKW9^LP07KW800g[cHUARE005HU@00fICGQ=N4`05KY<7IS800gl]FQ=J
4`02FQ<24005HU@2CM@30046FQ@6McD7JW<5Odh2L[87KY82Oe43N]48M]85O`d00gl`Oomoo`0DOol0
0`00Oomoo`11Ool003Yoo`Ao/`9kEPI=m@8P/AIoo`<00`9oU0EF=PDiM0@/lP04:;0eE3ED=E@5:=84
<?40100>@KE1]D6e1SDA1QQ`1UjG1dfc1@0?26Lk1V:h00</lUGcEO<012eF1dge0UXe1Ced1Dfc257B
1T5B24VB25hd1e7C1U6b0g;D25GB1eWc156b1W;D168c1VIB25GC2FIC0eGC27[b00=N4fibKW801Vib
0W[c269D0UhC16jC26Hb00=o;EXCFQ<00UXC0Q001F9D0dgD0`0115XD1gLe1fYc1Wm>26jB0gmA0W[A
27KB1Gl=0Wl`5Goo0P00@Woo000jOol3Ok<3NeH6COD38;4DOol400<2Oi@5ESH5>G@4;?82:;02=E@5
:=85<?43@KD6=A466706GYL7CK<600l8Ic/2H[P4;?83EO<3;EH7COD00eXe?G@mM004?G@5CK<8DM86
@E87BI800f9EGSAN=007GS@6DM<6DK83L]@8EM88FO<2DK87L]@4HS<6IU87EM<00eWcIU=VD`07IU<2
EM<9N_89KW82N_<7HU@3GQ<4KY<7IS82Obd4FQ<24004HU@017:BCMA=e6jd0`0115XD1gLe1fYc1Wm>
26jB0gmA0W[A27KB17l=0gl`57oo00<007oo0000@Woo000jOol3Ok<3NeH6COD38;4DOol300<00`P0
OiAoU006ESH4>G@4;?82:;03=E@4:=85<?400`0>@KE1]@06=A466706GYL8CK<600l6Ic/2<?46;?83
EO<2;EH7COD00eXe?G@mM004?G@6CK<7DM86@E86BI83HUD8GS@6DM<5DK84L]@9EM87FO<2DK87L]@4
HS<6IU86EM<3FO<8IU<2EM<9N_89KW83N_<6HU@4GQ<3KY<7IS82Obd5FQ<00a00HUARE002HU@00g:B
CMA=e002K[@20044FQ@6McD2NkH6JW<6Odh8KY83Oe42N]48M]84O`d4Oc0FOol00`00Oomoo`08Ool3
000dOol003Uoo`=o/`AkEP0300Y=mDge00==m@@P/A=oo`800`03701oU7nD009oU0EF=P@iM0@/lP<X
/08eE0@XdPD`l@0300i1]D6e00He4@LHL0ENU`Q=/`L03`9W>`H`l@D/lPAEl`03;EI=mDge00A=m@8i
<PHmM0I=/`QAdPE1DPI9TP=RE@QN=0IAd`EA/PAbe0UEdPMIl`03DK9be7;D00Ibe0=R<`MVDPIEd`=I
l`UVD`03EM=jlW[b00MjlPU^LP=jl`ERE0EN4`=^T`MV<P=o;@AJ4`8@00=RE09bTP05CMA^]6jdK[@0
0@03FQ@7McD2NkH5JW<7Odh7KY85Oe49M]84O`d4Oc0FOol00`00Oomoo`0;Ool00`00Oomoo`0aOol0
03Uoo`=o/`AkEP0300Y=mDge00A=m@<P/A5oo`05C2000`0300<80003Oi@00eZH=E@eE003ESH4>G@4
;?83:;02=E@4:=85<?400`0>@KE1]@06=A476705GYL8CK<400l38a/2CK<6<?45;?85EO<012eFCOE=
mDge13Tb1Sed1Tfc257B1T5B14VB169E25hd1U7C156b1G;D2EGB1eWc00=A/W;DL]@01W;D0f8c1fIB
1EGC15Wc2FIC00=Edg[bN_801W[b0VIe1fib17[c1F9D1EhC0VjC26Hb0gl]15XC00=bTQ00HU@00V9D
0W:B16jd00@00EXDFQAJ50Ig=@=k]PEZL`IoCP9_d`I^TPEoD@QfdPEo3@Ao<1Moo`03001oogoo00Yo
o`03001oogoo035oo`00>7oo17nc17]F00<02TgeCOD014ge122a3Goo0P030T`P0P0300@L07nDOiAo
U09JV0@eE003ESHiM3Ud008iM0@/lP<X/08eE0@XdPD`l@803P91]@De4@PHL0ANU`Q=/`@T/@8S6`==
/`H`l@D/lPIEl`03CODi<STb00Di<PDmM0I=/`QAdPI1DP=9TPERE@QN=0IAd`AA/PEbe0UEdPMIl`03
DK9be7;D00Ibe0=R<`MVDPAEd`EIl`UVD`03EM=jlW[b00IjlP9VM@M^LPAjl`ERE0EN4`9^T`QV<P=o
;@AJ4`04LY8@069DHU@3LY85K[@00`01FQAg=@06McD3NkH5JW<5Odh3Km<6KY85Oe48M]85O`d4Oc00
0gm@Oomoo`0DOol00`00Oomoo`07Ool3000dOol003Qoo`=o/`EkEP0300Y=mDge00A=m@@P/@eoo`D0
0`03700807nD00AJV0DeE0@iM0@/lP@X/003=E@XdRSB008XdPD`l@803P91]@De4@PHL0ANU`Q=/`@T
/@8Pd`==/`H`l@D/lPIEl`Pi<PDmM0I=/`QAdPI1DP=9TPERE@QN=0MAd`=A/PEbe0UEdPM5U0Ube09R
<`UVDP=Ed`EIl`UVD`QjlP=VM@M^LPEjl`=RE0IN4`9^T`QV<P=o;@AJ4`9bTP9RE0=bTP03KY9^]6jd
009^]003N_9J57Le00Eg=@Ek]PAZL`EoCP=_d`I^TPEoD@03L_EfdWKB00EfdPAo3@Ao<09oD1Moo`03
001oogoo00Ioo`03001oogoo03Aoo`00=goo17nc1G]F00<02TgeCOD014ge1B2a2goo00<0000300<0
0P030Q`000<805ZHFYP00eZH1CED13Ud12cb12R`00<eE2SB:=800RSB1C3a0P0>0T6e1SDA1aQ`00A[
mEjGGYMNU`M=/`DT/@8Pd`==/`H`l@D/lPIEl`Pi<PDmM0I=/`QAdPI1DP99TPIRE@QN=0MAd`9A/PMb
e0QEdPQ5U0Ube003HS=VDVIB00MVDP9Ed`MIl`QVD`QjlP=VM@M^LPEjl`=RE0MN4`03KY=V<VHb00IV
<P=o;@AJ4`9bTP03401RE7:B009bTP04KY9^]6jdK[@2N_87McD5NkH4JW<4Odh4Km<5KY85Oe42L_D7
M]84O`d4Oc02Oe0HOol00`00Oomoo`05Ool4000cOol003Moo`=o/`IkEP802PE=m@HP/@Yoo`D00`03
700805ZH00IJV0@eE004894iM3Ud>G@4;?85:;04:=85<?4300h00d6e=A4e4@04=A466702JoD3GYL6
CK<00ceC9;4T/@039;438=<2CK<6<?45;?86EO<8>C86?G@5CK<8DM86@E82BI87HUD7GS@7DM<2DK87
L]@8EM800g/CAIA5U005AI@9L]@00f8cIU9VDP07IU82EM<7FO<8IU<00gLfN_9jlP04N_84IWD6KW86
N_<2HU@8GQ<8IS85Obd2FQ<7LY82KY83K[@3N_85McD6NkH3JW<4Odh6Km<4KY85Oe43L_D6M]84O`d4
Oc03Oe0GOol2000mOol003Eoo`8D00=o/`9kEP03Lm<0mG]F009kEP0300Y=mDge00==m@HP/@Yoo`@0
0`8L000320003eZH00EJV0@eE004894iM3Ud>G@4;?85:;04:=86<?4200h00d6e=A4e4@04=A456704
JoD2GYL6CK<00ceC9;4T/@049;428=<2CK<6<?46;?86EO<7>C82?C84?G@5CK<8DM84@G<2@E800dVB
HUERE@06HUD7GS@7DM<00e6bL]Abe006L]@7EM82Na<8AI@8L]@00f8cIU9VDP07IU800eGCFO=Il`06
FO<7IU<3McH4N_86IWD5KW87N_<00f9DGQ=N4`06GQ<8IS85Obd2FQ<7LY83KY82K[@4N_84McD7NkH2
JW<4Odh6Km<4KY85Oe43L_D6M]84O`d4Oc03Oe0EOol200000goo001oo`0lOol003Aoo`8D00=o/`=c
d`03CM@0mG]F009kEP0300Y=mDge00==m@LP/@Qoo`0300000`0300<L0088000300mJV5ZH00AJV0@e
E08PT@8iM0@/lPDX/004450XdRSB:=86<?4200h00d6e=A4e4@04=A446703JoD00g=j>KMNU`02GYL4
CK<2?E<69;438=<00dfc<?4`l@03<?400dFC>G@iM004;?86EO<7>C84?C82?G@5CK<8DM86@G<9HUD7
GS@7DM<00e6bL]Abe006L]@7EM82Na<8AI@8L]@:IU89FO<7IU<3McH4N_86IWD5KW87N_<00f9DGQ=N
4`06GQ<8IS85Obd2FQ<7LY83KY82K[@5N_82McD8NkH2JW<3Odh7Km<4KY84Oe44L_D6M]84O`d4Oc03
Oe0IOol00`00Oomoo`0jOol003=oo`<000=o/`A=e0054500mG]FNeH02P05COD78;48Ool00`0000<L
000370000`P0MkT03`06FYP4=E@28943>G@3;?85:;00111@:=8XdRSB1S3a0`0>1SDA0aQ`00A[mAgl
LgYcNP<i]`9NU`==/`<mD`HT/@@Pd`8`l@A5T`@iM08/lPIEl`Hi<P03EO<m<Sdb00@m<PE=/`MAdP03
FQA1Ld5c00A1L`URE@QN=0IAd`03DK9be7;D00Ibe0MEdP9k4`U5U0Ibe003CQMVDVIB00QVDPUIl`IV
D`Eg=P9jlPMVM@E^LPMjl`UN4`03L[=V<VHb00EV<PEo;@9J4`MbTP=^TP9^]0IjlP03McEk]W^f00Ik
]P9ZL`=oCP03CODU=RDf00A_d`A^TPAoD@Ebm@EfdP=o3@Ao<0EoD1Qoo`03001oogoo03Yoo`0077oo
00<007ooOol057oo0P000gnc1DgD00D@D03eNeIkEP0:00E=m@PP/@Moo`0300<L01`0008L0088009g
^@0300mJV5ZH00=JV0@eE0<PT@8iM0</lPDX/004450XdRSB:=86<?4300h6=A4367027O`2LgX3>KL2
GYL3CK<3?E<69;448=<6AI<6>G@6EO<5>C82EO<6?C85CK<6DM82FQ@7@G<8HUD8GS@5DM<00dgEL]Ab
e007L]@6EM83Na<9AI@4L]@3CQL:IU8:FO<5IU<6McH00g[bIWEVM@05IWD4KW88N_<8GQ<2L[<7IS85
Obd2FQ<6LY85KY87N_84K[@5NkH2JW<2Odh2COD39CH4Km<2KY84Oe46L_D5M]83O`d4Oc05Oe0IOol0
0`00Oomoo`0iOol001]oo`03001oogoo01Aoo`<0009o/`I=e0044500mG]FNeH200X4COD98;45Ool0
0`00700L000370001@P0MkUg^GNi00l01EZH13ED0b2A0SUd0bcb1BR`0Q1@0RSB1S3a0`0>0agl0cDA
0QQ`0Qgl0W=j00<]4cVg>KL00SVg00=NUdfcCK<013eC1RBa123C1dFC1CUd0SDB15Gc13Tb0eGc1Sdb
00<TldfcCK<00dfc1E7B0eXD1T5c269E25hd157C0dgE27;D1UGB17/C2DFD00=be4hGCQL00dhG2FIB
0W/C2EWc16IC1gLf26Ie16ib1g[c00=^e5hCGQ<01UhC0W:c1fHb1Wl]00=J4g:BLY8017:B1FjB1W[b
1Fjd0fYc0g^f0Wm>0dge00AU@bDf9CHU=P=_d`9^TPAoD@Mbm@AfdP=o3@Ao<0EoD1Yoo`03001oogoo
03Qoo`007Goo00=V07ooOol04Woo0P000Wnc00=o/TgDCM@014gD0Q1@0W]F0P0:14ge2R2a0UAP0Woo
0Q`00eAP0PP00gNi00<03eZHFYP00eZH13ED0b2A0SUd0bcb1BR`0Q1@0bSB1C3a100>1Agl00<HL1gl
7O`00g=j00<]4aRA>KL00SVg00=NUdfcCK<013eC1RBa123C1dFC1CUd0cDB0eGc0cTb15Gc1Sdb0RCc
14fc157B15XD1T5c269E25hd0U7C1DgE27;D1UGB17/C2DFD1dhG26IB0W/C2EWc16IC1gLf2FIe0fib
1g[c0VkD1ehC0W:c1fHb1Wl]1g:B1FjB1W[b1Fjd0fYc0W;C00=oCGm>COD014ge12Df0VoC0VjB17mA
1g;e17KB0gl=17l`1Wm@27oo00=o47ooOol03Woo00<007ooOol0>7oo000MOol00``_Oomoo`0BOol2
000017ncOi9o/Wnb1DgD0Q1@0W]F0P0:14ge2b2a1eAP0`P000<0DgNiMkT00P0?15ZH1CED0b2A00@i
M2cb;?8/lPDX/0<@D08XdPD`l@D03PHMo0=cNP8]4`07694i]cVg>KL044fc010013eC1RBa123C1dFC
1CUd13DB0UGc0cTb15Gc1cdb0RCc0dfc0e7B1EXD1d5c269E1ehd00=AddgECMD01DgE1g;D1UGB17/C
2DFD1dhG26IB0W/C2EWc16IC1WLf0VkF26Ie0fib1W[c0fkD1ehC0W:c1fHb1Wl]1g:B1FjB00=o4G[b
N_800W[b1Fjd16Yc0W;C0Wl_1Dge1BDf00=_dfjBKY800gmA27;e00Ake7KBM]9fdP=o3@=o<0MoD003
OomRMGlB00=oo`=o4003O`ioogoo00ioo`03001oogoo03Moo`007Goo00<<;gooOol04Goo0`000WnB
0Wnb1DgD0Q1@00@0mG]F00X02PA=m@`P/@EDH088009Zn080D`03MkT03`0?00AJV0DeE0<PT@04>G@/
lRcb;?86:;024502:=85<?4500h57O`4LgX2;A<26942>KL30104?E<69;458=<6AI<5>G@5=A800eGc
>C8i<P05EO<7?C839?<2CK<2DM86FQ@7@G<8HUD5GS@2CWX8CMD8L]@4EM85Na<8AI@2NmD6CQL8IU82
Na<9FO<3IU<6McH3K]H8IWD2KW87N_<3K]@7GQ<3L[<5IS87Obd6LY86KY800glAN_9jlP02N_85K[@5
JW<017;CObmo;gl_14ge00=U@bDf9CH00bDf00=_dfjBOe400WmA1g;e0W_D0gKB0Wl=17l`1gm@0V9e
0WlB0Woo0gl@00=o3WooOol03Goo0`00>7oo000MOol00``_IP1oo`0AOol200000g?COi9o/P02Ok85
CM@3450017]F00X02QBB14ge2b2a00EkMEAPE61DH0P000AZn080D`9g^@803`AJV0@eE0@PT@@/lPDX
/08@D08XdPH`l@D03P<Mo0AcNP<]4`8HT@8i]`<040036;<mDceC008mD`DT/@DPd`I5T`DiM0He4P03
>C9EleGc00EEl`Hm<P@Tl`03CK=AdU7B00IJ50M1L`QRE@9N=0E>NPU=e@Mbe0AEdPEk4`Q5U09ke@I>
5`MVDP=k4`YIl`9VD`Ig=P=^ePQVM@9^LPMjl`=^e0IN4`Ab/`EV<PMo;@IbTPI^TP9o4@=jlPE^]0EZ
L`04Odeo;gl_Obl4COD00gmB9CHU=P049CH3Oe48L_D2Nm@2M]83O`d4Oc07Oe00169eOa9o4WlB0Woo
0gl@00=o3WooOol03goo00<007ooOol0=Woo000MOol00``_IP1oo`0AOol20002Oi83Ok85CM@34500
0g]F00X02P025983COD;8;42NgD00eAPNgEZn004J_P305<017Ni00l03`Rd0eZH13ED122A12cb1BR`
0a1@00<XdS3a<?40133a1P0>00<Mo7=jLgX00g=j12dC0QRA00Di]`0@010041Rc00@mD`DT/@DPd`I5
T`HiM0De4PQEl`Hm<PDTl`03DM9J55XD00EJ50Q1L`IRE@03G[Q>NTij00E>NPU=e@Mbe0AEdPIk4`I5
U0=ke@I>5`MVDP=k4`YIl`03IU=g=WLf00Ag=PA^ePQVM@9^LPIjl`A^e0IN4`Ab/`EV<PIo;@9RE0Eb
TPE^TP=o4@9jlPI^]0EZL`04Odeo;gl_Obl4COD00gmB9CHU=P059CH2Oe47L_D4Nm@017KBO`eo3Gl=
17l`1Wm@0V9e17lB00Ao<Gl@Oa1o409o3Q5oo`03001oogoo03Eoo`007Goo0P`_4Goo0P000gnB0gnb
1DgD0a1@00EkEP0:00X02QBB00==m@XP/@EkM@IZn0<0D`803`88]09JV0@eE0@PT@@/lPDX/0<@D003
:=8`lC3a00@`l@D03P=BN@=cNPD]4`8HT@03>KL0400@008040046;<mDceC?E<69;448=<7AI<5>G@5
=A88EO<6?C859?<8FQ@8@G<5HUD3G[P7CWX9CMD6L]@4EM86Na<5AI@5NmD6CQL6IU84Na<9FO<00fIC
McIg=P03McH6K]H8IWD00fibN_=jl`04N_<4K]@6GQ<4L[<5IS86Obd2HU@5LY85KY83Oa42N_85K[@6
JW<00gm=Obmo;`02Obl3COD00gmBID<U=P069CH00gmAL_Ebm@05L_D4Nm@017KBO`eo3Gl=17l`1Gm@
0f9e17lB00=o<Gl@Oa000gl>4Woo00<007ooOol0=7oo000MOol232l00fH0Oomoo`0>Ool20002Oi85
Ok84CM@3450017]F00X02P0:0QBB0Tge2R2a17]e1f[h0`1C0`0?0PRd00=JV3ED=E@00SED122A00@0
2Rcb;?8/lPDX/0<@D003:=8`lC3a00@`l@803PQBN@03LgX]4bdC00<]4`<HT@04>KL0400@01026;<2
?E<69;448=<7AI<5>G@5=A88EO<6?C859?<8FQ@8@G<4HUD5G[P6CWX9CMD6L]@3EM87Na<5AI@5NmD6
CQL6IU84Na<9FO<6McH6K]H8IWD6N_<6K]@5GQ<4L[<5IS85Obd3HU@5LY85KY84Oa400g[bK[A^]003
K[@6JW<00gm=Obmo;`02Obl2COD3Oe869CH00`00L_Ebm@05L_D5Nm@017KBO`eo3Gl=0gl`1Wm@0f9e
17lB00=o<Gl@Oa000gl>4Woo00<007ooOol0=7oo000MOol232l00fH0Oomoo`0>Ool01000Oi9oTWnB
1Gnb14gD111@0`0:0QBB0Tge2B2a1G]e1f[h0`1C00<@T`0?00l00`Rd13ED1B2A0bcb1BR`111@0c3a
0dXH2U9i0Sed12dC0aRA00@i]`0@0100408H/`8mD`HT/@@Pd`M5T`DiM0De4PQEl`Lm<P@Tl`QJ50U1
L`9RE@IN^0I>NPU=e@03NmEbe7;D00=be0=EdPMk4`A5U0Ike@I>5`EVDPEk4`UIl`03001g=WLf009g
=PM^ePMVM@03F[Ujlg[c00Ajl`I^e0EN4`Eb/`AV<PEo;@=RE0AbTPI^TPAo4@I^]0IZL`03Odeo;gl_
009o;`9=m@=oDPDU=P03I^D0000000Ibm@Ike09o3@Ao<0EoD0ARM@Ao4P=o40Ao3Q9oo`03001oogoo
03=oo`007Goo0``_3goo0P000WnB1Wnb14gD111@0`0:0aBB00==mB2a8;401b2a17]e0WMG1V[h101C
00<@T`0?2;@00PRd13ED1B2A0bcb1BR`111@1dXH2E9i0Sed12dC11RA0`0@0aRc00<mDbBa9;4012Ba
123C1dFC1CUd1SDB1eGc1cdb1BCc25XD245c00=REEjhG[P01Ujh1Dij24gE0g_E17;D0eGB1g/C14FD
1W_E1ThG1FIB1G/C25Wc0`000gLf1fkF1FIe15Zi17[c1fkD15hC1W:c16Hb17l]169D17:B1VjB17lA
00=fdVjdK[@00Vjd1VYc0Wm=17l_0Tge0gmB00EU@bDf9CIg5Wm>009Vi@03001bmG;e00Abm@Ike09o
3@Ao<0EoD0=RM@Ao4P04Oc5o47l@Oa04O`hCOol00`00Oomoo`0bOol001eoo`<<;`03IP1oogoo00ao
o`04001oTWnBOi86Ok85CM@3450300X459888;400`1eNgEkM@02NgD3MeL6J_P305<00a2C00l03`02
2;@4=E@58943;?85:;044507BQP8DWT3?G@4;A<4694301036;<00ceC9;4T/@049;448=<7AI<5>G@6
=A87EO<7?C859?<8FQ@8@G<:G[P4CWX8CMD4NmD3L]@2EM89Na<2AI@8NmD5CQL5IU85Na<8FO<40000
0gLfK]I^eP07K]H3IWD5F[T4N_<7K]@4GQ<6L[<4IS84Obd5HU@3LY86KY84Oa400gKBK[A^]002K[@6
JW<00gm=Obmo;`04Obl01TgeOe9oDWmBKbTU=P9g5P05OdiViFKUI^D00004L_D6Nm@3F]/016[gOc1o
<7l`17m@169e17lB00Ao<Gl@Oa1o40Ao3Q=oo`8003=oo`007Goo0``_00=V07ooOol037oo00@007nB
Oi9oTP9o/P04Hgeo/WnbOk85CM@3450300X459888;45NgD4MeL5J_P305<249<0100?2;@8]00=0cED
1B2A0bcb1BR`1A1@1dXH1U9i0bfG00<mM2dC;A<00RdC11RA00<@L@0@010011Rc0bBa0dFD123C1dFC
1CUd1SDB1eGc1cdb1BCc25XD245c00=keUjhG[P01ejh1Dij1TgE1G_E00E=e7;DL]Abe5GB00Uk4`03
AIAkeG_E00Mke@E>5`AVDPMk4`IIl`03HU@boc;o008bo`Y^eP03IWEJ^EZi00IJ^@=jl`M^e0AN4`Ib
/`=V<PAo;@IRE0=bTPE^TPEo4@03M]9^]6jd009^]0IZL`03Odeo;gl_00Ao;`=oDP03001fdgKC009g
5PAVi@03L]@007;e009bm@=ke0IJf`9Zm`9o<0=oD0ERM@Ao4P04Oc5o47l@Oa04O`h00`02Oomoo`03
Ool00e];Oomoo`09Ool00`00Ool0000cOol001eoo`<<;`03IP1oogoo00]oo`04001oTWnBOi83Ok82
Hgd2Ok85CM@34500100@00X02P0:11BB1b2a17]e1GMG00=W:PAA9_l00RKo0`1C0Q2C00@03`Rd2;@8
]0<eE0DPT@0300X/lRcb00DX/0D@D0M:60EBN@0307<]UbfG008]U`@]4`@HT@044740400@01036;<6
AI@00```8=<Pd`028=<6AI<5>G@6=A87EO<7?C859?<8FQ@7@G<2NmH8G[P2GS@4CWX6CMD4NmD3CM@2
L]@00eGBNa=k4`07Na<00dFDNmER<`04HS<3CM<6CQL3IU87Na<6FO<00f9DJW<bo`03<_l9K]H9F[T2
N_<9K]@3GQ<6L[<3IS84Obd6HU@2LY86KY84Oa43M]83K[@6JW<00gm=Obmo;`04Obl017:dOe9oDVlY
0gKC00=oCVKUI^D00VKU0W;D0W;e0W_D1e[K16[g17m@1F9e17lB00Ao<Gl@Oa1o40Ao3P03009oogoo
009oo`0300EKBgoo00eoo`03001oogoo031oo`007Woo0``_3Goo00@007nBOi9oTP9o/PASO@9o/PA=
e0<@D00401002P0:00X459800`1e8;4P/@038;45NgD5MeL01VLZ1544D@AA9_l8D@80D`<@T`0300l8
]0Rd00<eE0DPT@0300X/lRcb00DX/0D@D0Q:60ABN@0307<]UbfG008]U`@]4`DHT@034740400@00<H
/`I5U003330Pdb3C008Pd`M5T`@iM0He4PMEl`Lm<PDTl`QJ50M1L`9kePMN^0=N=004AI=>NTijCWX5
CMD4NmD5CM@00g;DEM9k4`08Na<00ehdHS=R<`04HS<4CM<5CQL3IU87Na<5FO<2HU@2JW<00fId<_lb
o`08K]H00fkE101J^@08F[T00g[cK]A^e007K]@3GQ<7L[<2IS83Obd7HU@2LY86KY84Oa43M]82K[@7
JW<00gm=Obmo;`04Obl2L[@00gmBKbUfd`02M]<00gm>I^EVi@02I^D3L]@00g;e011Jf`06F]/5J_L3
NiH5HWD5Oa8017laOa1o47l@17l>0P020goo0U];3Woo00<007ooOol0<7oo000NOol332l00fH0Oomo
o`0:Ool00`00Oi9oTP02Ok84Hgd2Km/00gnbCMA=e002CM@445000`0@00X02P0559800`1e8;4P/@02
8;44NgD5MeL2IbX315400bKo2540D`0205<349<22;@00`0==E@eE0068942;?85:;064507BQP3DWT2
07<4;IL010AB;A<]4bdC1ARA00<@L@0@01000aRc1TFD00<<<23C8=<00R3C1dFC13Ud1SDB1eGc23db
12Cc25XD1T5c17_F1Ejh15hd00A5TdijCWY>NPA=e@Ake@03BI==e4gD00A=e0Uk4`9N=0IR<`E=d`A>
5`=VDPMk4`AIl`ARE003JW=VM6Id008bo`I^eP04M]=oL6kE1007F[T00f>MK]A^e008K]@2GQ<8L[<2
IS83Obd7HU@2LY86KY84Oa43M]82K[@6JW<2Odd5Obl3L[@2KbT3M]<017m>I^EViFKU17;D00<0000@
01001U[K1F[g0g^F1F9e17lB0Wla0gl@0gl>0`020fJF0e];3Woo00<007ooOol0;goo000NOol332l0
0fH0Oomoo`09Ool01000Oi9oTWnB0Wnb0f=m16oK14gD111@00<0400:00X01ABB0P1e0R2a1G]e17MG
0PQB00AW:PAA1544D@8Vo`032540D`1C00<@T`88]00300deE3ED00HPT@8/lPDX/0H@D0Q:6003DWTD
L@1c0080L`@]U`<]4`DHT@8@L@04010H/aRc6;<7AI@010``8=<Pdb3C1dFC13Ud1SDB1eGc23db1BCc
1eXD1D5c1G_F15jh1Ehd0TFC0Tij14gE17_E00=9TdgDCM@014gD27/C0Uhd1f8c1TgC0dhG0VIB27/C
15Wc169D00=ZLfIdIW@00VId00<bofkFK]H00VkF0WKC00=oL6kEK]D01UZi0f>M2FkD0UhC27:c0VHb
0Wl]2F9D00=bTVjBKY8016jB17lA17KB00=^]6YcJW<016Yc0Wm=1Gl_0g:d0VlY0gKC00AoCVKUI^EV
i@Abe003000A=`0@00EJf`EZm`=kUP9_S`ARM@Ao4P9o<@9o40Ao3P<00P=VUP=KB`ioo`03001oogoo
02moo`007Woo10`_2goo00D007nBOi9oTWnb009k=003Hge_ffoK00=_f`A=e0@@D00301002P0:00DD
TP<0M@038;5kMG]e009kM@AgE`9k]P03259W:PAA0084D@0332lVo`QA0080D`<@T`88]00300deE3ED
00HPT@0300X/lRR`00DX/0D@D0M:609c^`045740]P1c07<4;IL010AB;A<]4bdC11RA0Q1a00<041Rc
6;<00QRc1TFD00@<<23C8=<Pd`M5T`DiM0He4PIEl`Pm<PDTl`MJ50E1L`EkeP=N^0IN=004AI=Ade7C
CWX3CMD4NmD3BI<6CM@6Na<2BK@00ehdHS=R<`05HS<6CM<00f8dCQM>5`02IU88Na<3FO<5HU@6IW@3
K]H2M]<3Og02K]D3F[T5Hid9K]@2GQ<8L[<2IS82Obd9HU@7KY84Oa44M]87JW<2Odd5Obl3L[@00flY
M]=fd`02M]<017m>I^EViFKU0g;D0P0000<A=`0@01000e[K1V[g0g^F0Vn?169e17lB0Wla0Wl@17l>
0P0216JF0e];3goo00<007ooOol0;Woo000NOol432l;Ool3Oi8017nbNcAk=7/d17^b0VoK00@<<4gD
CMA=e0@@D080400300XDTQBB00@DTP<0M@AkM@=gE`=k]P03259W:VLZ0084D@0532lVo`QA2540D`03
49<0100=2;@03@0=0SED1B2A00<02Rcb:;001BR`1Q1@0dXH0WNH0g>k0QAa00<0]P1c;IL00bfG0PAB
0RdC11RA0Q1a00<041Rc6;<00QRc1TFD0P``0R3C1dFC00<03cUd>G@00SUd1SDB1UGc23db1BCc1eXD
145c1g_F00=N^5hdGS@00Uhd0dVd0e7C0Tij0TgE0g_E14VC1dgD17/C0dVd00=N=68cHS<01F8c1DgC
0f8d0ThG00=VDW/CNa<01g/C0UWc1F9D1VId00=fdfkFM]<00WKC17m`0VkE00=J^F>MHid01F>M26kD
0UhC27:c0VHb00=o;F9DHU@0269D1VjB17lA1GKB1fYc0Wm=17l_17:d00A_:GKCM]=fd`9oCP9Vi@Ab
e0<000034CL045[K009Jf`EZm`=kUP=_S`ARM@Ao4P9o<@9o40Ao3P800PAVUPAKB`moo`8002ioo`00
7Woo10`_00<04GooOol01goo00D007nBOi9oTWnb00=k=0Ak/P9_f`04331=e4gDCM@44502010200X5
598207D5NgD2MeL016LZNkIk]W^f0PQB00EW:PAA154<;bKo0088D@0605<@Ta2C49<03@Rd0P0=0SED
1B2A00<02Rcb:;001BR`1Q1@00I:67NHMiQgV7?f00`2Lk/257420;H0101c;IL]UbfG0PAB0RdC11RA
0a1a00@041Rc6;<H/`I5U08<<08Pd`I5T`03FQ@03cUd00<iM0He4PIEl`Pm<P03NmDTlbCc008Tl`QJ
50=1L`IkeP95e@M9]0AAd`04CWY=eG_ENmD6BI<7CM@3Na<4BK@8HS<4CM<5HS@00dhGIU9k4`08Na<0
0eWcHUARE005HU@5IW@5M]<4Og03K]D7Hid9K]@00ehCL[=b/`07L[<2Obd:HU@6KY84Oa45M]87JW<0
0gm=Obmo;`03Obl3L[@2KbT3M]<2Odh2I^D4L]@300024CL00`0@F]]Zm`05J_L3NiH4Khl2HWD4Oa82
Oc43Oa04O`h00`02IYIVUP02IYH00ahMFd]KB`02Fd/>Ool2000_Ool001ioo`D<;`03015oogoo00Io
o`04KfeoTWnBOi83Nc@4Nk801EM^Km]_f```00h00TgD111@0`0@00<02QBB598011BB00<0MG]eNgD0
0TWg0WMG00=k]g^fNkH00W^f0PQB00EW:PAA154<;bKo00<8D@0405<@Ta2C49<22;@00`0==E@eE005
89400`0:;?8X/005:;054504MiP2LoH00`0<Lk]c^`0257430;H3;IL315800bdC694HT@0269434740
100@6;<H/aRc1TFD0P``0R3C1DFC0eXD13Ud1SDB1UGc1cdb0g_E0bCc25XD0T5c17_F1DGE1dVd1E7C
00==eE7CBI<01TVC1dgD00=9]7/CBK@014Vd268c14gC1V8d2W/C00=Ilf9DHU@01F9D1FId1GKC1Gm`
00=^eGMhMgP01f>M26kD2W:c00=o;EYFFUH0269D0W^a1FjB17lA1GKB00=jlVYcJW<00fYc0Wm=1Gl_
0g:d0VlY0gKC00AoCVKUI^EVi@Abe0<0008A=`03011Zmf[g00AZm`=kUPE_S`9RM@Ao4P9o<@=o40Ao
3PEVUP@N7@03Fd]oogoo00ioo`03001oogoo02aoo`007Woo1@`_00<04GooOol01Woo0gnB17/d0g^b
0eM^00=_f```33000TgD111@0`0@00@02QBB598DTPQ9m`03OiIk]g^g00Ak]P<8DP84D@8<;`<8D@06
05<@Ta2C49<03@Rd0P0=00<eE22A8940122A00</lRR`:;0012R`111@1GNH0g?f0W>k0aAa0P2f12fG
0PAB00<]4aRA69400aRA0a1a0aRc1TFD0```00<PddFCAI<00dFC0eXD00@03cUd>G@iM0He4PIEl`Lm
<PAke@8Tl`QJ5003@G=keW_F008HTPM5e@I9]0MAd`M9T`M=e0I9]003EOAR<f8c00MR<`9=d`MR=09N
=@Mk4`URE0AVM0Ifd`EoL09RE09gN0ISW@Q^e0Yb/`03ObeJEUYF00QRE09k/@E^TPAo4@EfdP03N_9Z
LfYc00=ZL`9oC@Ao;`Ab]09_:@=fd`03OdiViFKU00Ebe0@0008A=`03011Zmf[g00=Zm`=kUPE_S`9R
M@Ao4P9o<@=o40Ao3PEVUPHN7A1oo`03001oogoo02]oo`007Woo1@`_0P0A0goo0d]O00A_KGnBOi9o
TP=k=0Ak/P04Ool01eM^Km/233000`0>CM@@D0034504010:BOL2OiH00g^gNkIk]P03NkH325821542
32l012Ko2548D@QA0a2C00D03@Rd00d03CED00HPT@0300XX/2R`00@X/08@D09ke@AgV0AcmP9c^`<D
L@80]P04;?8]UbfG;IL31585694347436;<6AI@333028=<3AI<4FQ@0100?>G@iM3Ud1SDB1eGc1Cdb
17_E0SED0RCc1eXD00=1Ld5d69800aRB1TGE1dVd1U7C1dVC1dgD1DVd0UGd2F8c0TgC1f8d0ehe17/C
0fId269D16Id1GKC1Wm`0f9D1VIc0V>M16kD0aP02W:c0eYF269D0W^a1FjB17lA17KB0W[b1FYc0Wm=
17l_17:d00=_:GKCM]<00WKC00=oCVKUI^D017;D100000AGnB4f4CLA=`AZm`AkUPE_S`9RM@Ao4P9o
<@=o40=o3PEVUP9o;`LN7@ioo`03001oogoo02]oo`007Woo1@`_00@02P0A01404@A;G`=oTPAk=0=k
/P=oo`06Efi_f```33003TgD111@100@2DWg0WnF0W^g00=k]WmbNkH00W^f0`QB0PAA0P`_00@Vo`QA
2548D@<@T`0500d8]00=00deE00689400`0::;0X/004:;000a1@NmEoTP04MiP00g?fGmicmP02LoH0
0`0<Lk/DL@0257420;H2;?82;IL31585694447426;<6AI@43300123CAI=5TdFC15XD00@03cUd>G@i
M0He4PMEl`Dm<PAke@<eE0039?=J55XD00=J50A1M0@HTPI5e@M9]0IAd`M9T`M=e0A9]0AEm0QR<`03
CM=R=68d00IR=0=N=@03IWAk4fId00AVM0URE0=VM0Efd`EoL0ARE0IVL`03L`QoLGma00=oL@03FWLH
01P000Yb/`=JEPMRE0Ak/@A^TP=o4@EfdP9jlPEZL`9oC@Ao;`Ab]003KbUfdgKC009fd`03OdiViFKU
00Abe0<0009Gn@8Q=P034CL046[g009Zm`=kUPM_S`03HWEo4WlB009o4P9o<@=o40=o3PEVUP9o;`03
00Ukeg_G00@X00moo`03001oogoo02Yoo`007Woo1@`_00<02P0A01400`0A0T]O0WnB1G/d0W^b00EG
KWooOomooeM^009_f`8<<00300h@D11@008@D0@0400300Y9mdWg00I9m`04OiIk]g^gIbX2Og800gmC
NkIk]P032582154232l01BKo2548D@QA:=400Q2C00<03@Rd00d00P0=1B2A0dij00<02RJO9Yl00RJO
00=keGnBMiP017NH0UoN00D03g?fLoH037>k00<DL@80]P8/lP8]U`<4DP03;?8HTARA008HT@@@L@<H
/`I5U0<<<0038==5TdFC00EJ50803`8iM0He4PMEl`@m<PAke@03CODeE3ED008eE09J5088D@E1M0@H
TPI5e@M9]0IAd`Q9T`M=e0=9]0AEm0QR<`03CM=R=68d00MR=003GSEVM6Id00IVM0URE0=VM0Efd`Eo
L0ARE0EVL`9c20=oL@=JM`<H00Qb/`EJEPIRE0Ak/@=^TPAo4@EfdP=jlPAZL`9oC@=o;`Eb]003KbUf
dgKC009fd`03OdiViFKU00Abe08000AGn@8Q=P034CMZmf[g00AkUPM_S`Ao4P=o<@9o40Ao3PEVUP9o
;`=ke`0439<X02P0:00@Ool00`00Oomoo`0YOol001ioo`H<;`@fG0804@03KfeoTWnB00Ak=0=k/PAo
o`03Efi_ffoK008<<00300h]4a1@00<@D0@040M9m`9oUP9k]`9oLP9oD`0309Ek]W^f0088DP84D@<<
;`<8D@03:=4@Ta2C00D03@8PT@Q>NP8VW`03NmEoTWNH00AgV09OgP9Oe09cmP0300ac^aAa008DL@03
00`0]Rcb008/lP04;IL4DPAB1582;?83694447436;<6AI@333000b3CAI=J5005FQ@200l2>G@7=A86
EO<3?C84NmD00dhF>00eE003=E@42542;EH4@G@46985AMD7BK@6DM<8BI<7CM@2BK@5EO@8HS<:HS@0
0eheIWAVM007IW@8HU@2IW@6M]<4Og05HU@5IW<2L`P2Og44FWL00`0<600H0007L[<6FUH5HU@5Nk43
KY84Oa45M]83N_84JW<2Odd3Obl4L[@2KbT3M]<2Odh00fKUL]Abe003L]@00`00EoUGn@03EoT38CH0
0a4gJ_MkUP02NiH00fn?@SU2>@05@ST4Oa83Oc42Oa04O`h5IYH2Obl3NmL00`bC:00X0002:00?Ool0
0`00Oomoo`0YOol001ioo`H<;`0300XfG3IL00<fG09oTPEk=09k/PEoo`0300M_ffoK008<<00300h]
4bdC00<@D0@040I9m`9oUP=k]`9oLP9oD`0309Ek]W^f0088DP0300P4D@`_008<;`<8D@03:=4@Ta2C
00D03@U>NP9cF0039YmcNUm<00=OC0=OgP=Oe09cmP0300ac^aAa008DL@0300`0]Rcb008/lP8]U`84
DP8/lP<HT@D@L@8H/`I5U0@<<003AI=J55XD00AJ50803`8iM0Le4PIEl`<m<P=ke@9>5P03>00@mSED
00<eE0<8D@<]EP=1M0@HTPI5e@I9]0IAd`Q9T`M=e003BKAEm5Gd00AEm0QR<`YR=0YVM0QRE09VM0If
d`AoL0ARE09kC@AVL`9c2003Og5JMeYg00AJM`0300`H07:c00Ib/`IJEPERE0Ek/@=^TPAo4@EfdP=j
lP=ZL`=oC@=o;`Ab]09_:@=fd`9oCP03I^Ebe7;D009be004001oL7maOg43EoT48CH01Q4gA000Dg^F
159<j@M2>@=o4P=o<@9o40Ao3PAVUP=o;`=ke`8<T`<X00moo`<002Uoo`007Woo1@`_0TVe00<02SIL
=U`00SIL00=oTW/dNc@00g/d0g^b1Goo00<01eM^Km/00P``00@03RdC;A<]4`8@D0@0400300Y9mdWg
00=9m`04OiIk]g^gNkL3Og83Oe<01P2ENkH8DPQB00P4D@<<;`<8D@8Xd@0449<03@0=2;@300d7CWX4
LeP017nBGdaOC5m<0eoN00Qo/eoDGmAOe00?LoH037>k0aAa00<0302f;?800bcb00<]U`AB15800bcb
0QRA1A1a0QRc1TFD10``25XD0P0?00<iM3DB=A801CDB1UGc0Sdb17_E0ThF00<04CP04?H00cED10QA
12eF00=1M1RB69800QRB1TGE1TVd1e7C1dVC1dFC1eGd2F8c2F8d2VId269D0VId1GKC1Gm`169D0W]=
16Ic00Ac27maNdebd`EJM`03Oe0H01P000Eb/`QJEPARE0Ik/@9^TPAo4@AfdPEjlP9ZL`9oC@=o;`Eb
]003KbUfdgKC009fd`03OdiViFKU00Abe09oL09oL@04;CAGnEOiEoT48CH00`0?05<4DP021588@ST2
Oa83Oc42Oa04O`h4IYH2Obl5NmL010bC:00X02P04Goo00<007ooOol027oo0`0017oo0P005Woo000N
Ool232l6BKD3=U`00gnBOgAk=004Nc@2Nk87Ool01EM^Km/<<0``00X012dC00<@D00@01000`0@14Wg
0WnF0g^g0Wmb17mC0P2E0`QB00D4D@`_32l<;bKo0088D@8Xd@0349<03@0=00@03@I>NPAcF003LgYO
C5m<00AOgP9o/`05011Oe5oD00mcmP0200`017>k574DL@0<0P2f12cb0PAB12cb0QRA1A1a00<H/dFD
AI@014FD10``25XD0P0?0SUd1SDB1UGc0Sdb0g_E0dhF00@04CP04?H@mP8eE0@8D@D]EP@HTPI5e@I9
]0MAd`M9T`M5T`MEm0UR<`QR=09RE0UVM0URE003IWAfdgKC00=fd`AoL0ERE09kC@AVL`04L`QkCG]=
L]<5FWL2Oe000aP0L[=b/`02L[<00c07FUIJEP06FUH3HU@7Nk42KY83Oa45M]85N_82JW<2Odd3Obl5
L[@00flYM]=fd`02M]<00gm>I^Ebe004L]@2Og02Og401000;CAGnEOi1B4f00A400AB1584DPQ2>@9o
4P=o<@9o40=o3P03OdeVUVJF009VUP9o;`Eke`8<T`8X015oo`03001oogoo00Uoo`03001oogoo009o
o`04001oogoo000EOol001ioo`U9]@8fG003Oi9k=7/d00=k=09k/PQoo`05Efi_f```33002P05;A<2
0103CUP3BOL2OiH4NkL2Og84Oe<209D325800`AA32l<;`0232l22543:=400a2C00d03@0400d4CWX5
LeP00g=jGdaOgP03Gmh2Ok<2NeH2Gm@01@0?LoH0300<Lk/00QAa00<0302f0;H012cb0PAB12cb0QRA
1A1a00<H/dFDAI@014FD10``25XD0P0?0SUd1CDB15kJ0eGc00<m<W_ENmD01ThF00D04A3f4?H@mSED
00@8D@D]EP8]E@<HTPE5e@M9]0IAd`I9T`03GS=5TdFC00E5T`MEm0UR<`QR=09RE0QVM09El`QRE0If
d`AoL0ERE09kC@AVL`03L`QkCG;C009bd`=JM`=oD003601b/g:c009b/`03:IQJEUYF00IJEP=RE0Mk
/@9^TP=o4@EfdPEjlP9ZL`9oC@=o;`Eb]003KbUfdgKC009fd`03OdiViG;D00Abe003Og1oLGma0080
008]=003EoTQ=R4f00<Q=P03A004DPAB0084DPQ2>@=o<@=o40=o3P9oC@=VUP9o;`Eke`8<T`<X015o
o`03001oogoo00Qoo`03001oogoo009oo`04001oogoo000EOol001ioo`U9]@03Og@fG7md00Ek=09k
/PQoo`0600M_f```33002P0>12dC1DiH00<02TWgBOL00WnF0W^g00AoTGmbOg9oLPEoD`0409D8DPQB
2582154332l22543:=400a2C00d03@02=E@200d4CWX5LeP00em<Oi5oT@02Oi43Ok<2NeH01`0@GmAO
e00?LoH037>k00<DL@80]P@/lP<4DP@/lP03694@LA1a00<@L@036;=5U4FD00A5U0D<<0MJ50<03`03
>G@e4SDB008e4PINfP04GediUSdb00l7CQH00`0A>00@mP024?H42545;EH3;ED26986AMD6BK@6DM<6
BI<2GS<7AI<7EO@8HS<8HS@2HU@8IW@2EO<8HU@6M]<3Og06HU@2Ndd4IW<00g<8Ndebd`02L]<3FWL3
Oe0017KeL[=b/g:c0RVH00<`1eYFFUH01EYF0V9D2G^a17lA1GKB1G[b0VYc0Wm=0W:c1W:d00=_:GKC
M]<00WKC00=oCVKUOa400g;D0Wm`0Wma0P000bdd00=GnB4f8CH00R4f00<03P1C15800PAB1d8i0U:J
0Wla0gl@0gl>0Wm=0VJF0gl_1G_G0`bC0RP04Woo00<007ooOol01goo00<007ooOol00Woo00@007oo
Ool001Eoo`007Woo2DVe0gmd1G/d00=k/WooOol01goo00<01foK33000P``00<03RdC;A<00bdC1DiH
00=9mgnFOiH017nA0Wmb1WmC0P2E0PQB0PAA0``_0PQA0bSA00<@T`0=00d013ED0dij1G=H00=cNUm<
Oi400gnA0Wnc0g]F00L045oDGm@03g?f00ac^`0357420;H4;?831585;?8647400aRcAIA5U003AI@5
3307FQ@300l013Ud=A8e4SDB1ekJ00AOGCVF>IH03`M>5P804@<@mP03<C@8D@QA0088D@D]EP<]E@03
6995eDGE00A5e@I9]0IAd`I9T`9N<`M5T`MEm0UR<`IR=0ARE0IVM0=El`QRE003HUEfdgKC00=fd`=o
L0ERE0AkC@9VL`03L`QkCG]=00=bd`=JM`9oD09fm@03601b/g:c008YV003<0MJEUYF00IJEP03HUAk
/AFk00E1]P9k/@Ao4@EfdPIjlP9oC@04Og=b/g:cL`T4L[@2KbT4M]<00gm>I^Eo4@03L]@2Og02Og42
0004;C@58CH0100@1584DPAB148i1U:J00Ao<Gl@Oa1o40=o3P9oC@9VUP=o;`03039keg_G009ke`<<
T`8X019oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo000EOol001ioo`Q9]@=oM0Ek=003
Nk9oogoo00Qoo`0300M_f```008<<00300h]4bdC00<]4`E>F003F`QZ]GnA00=oT@=oLPIoD`8U^P88
DP84D@<<;`88D@@Xd@803@DeE003CWYcF7=H00AcF003LgYoKgnA009oT@=o/`=kEP804003Gm@03g?f
008030<DL@0300`0]Rcb00</lP0300d4DPAB00D/lPH@L@036;=5U4FD00=5U0D<<0MJ50<03`03>G@e
4SDB00MNfP037?EOGCVF008iUP0300m>5ThF00A>5P804@<@mP8a=0<8D@D]EP@]E@036995eDGE00=5
e@I9]0IAd`E9T`=N<`M5T`MEm0UR<`IR=0ARE0IVM0=El`MRE09RE@Afd`=oL0IRE0AkC@9VL`03L`Qk
CG]=00Abd`9JM`9oD0=fm@03L[<YV2VH008YV0QJEP03HU@E^aFk00Q1]P=o4@AfdPMjlP03OdeoLgmc
009b/`03L`Ub]7:d009b]003KbUfdgKC009fd`9oCP03Mb]o4GlA009be003Og1oLGma00<000@]=0DQ
=P03A00040AB0084DP03@SUBVU:J00MBVP=o40=o3P=oC@06IYIo;gl_ObmZi`0b17_G0`bC00<X07oo
Ool04Goo00<007ooOol01Goo0P001Goo0P005Woo000OOol7BKD3Og@5Nc@00g^bOomoo`09Ool01FoK
330<<0``00h01RdC14iH0VZe17nA0gmb1WmC00ICC2Fj2588DP08154332l22544:=4300d6=E@4LeP2
LgX4Oi43Ok<4NeH0100@Gm@03`0?0P0<0aAa00<0302f;?800bcb00<03@AB15801Bcb00<LTA1a4740
0a1a00<H/dFDAI@014FD10``1eXD100?00<e4UkJG]X01EkJ0ace00AOGCVF>IH03`I>5P804@04>00@
mQ3f4?H2<C@22545;EH5;ED5AMD6BK@6DM<5BI<3GS<7AI<7EO@9HS<6HS@4HU@5IW@4EO<7HU@3HUD3
M]<3Og06HU@4Ndd2IW<00g<8NdekC@04L]<2FWL00gm@M_Efm@02M_D00gOf:IPYV002:IP7FUH55K/8
@KH00glAM]9fdP03M]87N_82Og<3L[<2L`T3L[@00flYM]=fd`02M]<2Odh00gL[Oa5o4@02L]@00gm`
Og5oL@040004;C@48CH00`0>010040021589DYX00eXfOa1o4004O`h3Odd017lbObmo;g;W0V[W00@0
<W_GNmMke`<<T`8X019oo`8002Eoo`007goo1TVe17md17/d00=k/WooOol02Woo00D01```330<<00>
00H]4`A>F09Z]@AoT@9oLPIoD`8M=`05Dd`8DPQB00P4D@0332l22544:=400`0@00d03@09=E@00g=H
MhmoK`04Oi42Ok<5NeH2010200l200`357400`0<0;H/lP03;?800`0=1584DP05;?800abA474@L@04
4746AI@43308FQ@300l8G]X017nE7?DLmAce0SVF00<03dhFCQH01DhF0P0A0a3f0c4d00<8DBeF;EH0
0beF1BeE0Sec0dGE1TVd1U7C14VC15hc1dFC1eGd2F8c1F8d1V9D16Id1EGc1F9D169E0gKC0gm`1V9D
17]=0VIc00=NMW]=L]<01G;C00=oD7M]M_D00WKe14Xi0RVH00@`1eYFFUIJEPAFE`@E^`U1]PEfdPMj
lP9oL`=b/`9c2@=b]003KbU_1gKC009fd`9oCP=o4@9be003Og1oLGma00@000D]=0<Q=P0400h0400@
01021587DYX3FSH00gl@O`io3P02O`h3Odd017lbObmo;g;W0V[W0P0b0W_G10bC00<X07ooOol03Woo
0P0000=oo`00Ool097oo000OOol6BKD3Og@5Nc@00g^bOomoo`0:Ool01@07330<<0``00X01bdC0TiH
0VZe17nA0gmb1GmC00ACC1dg7CLM=`88DP0300P4D@`_008<;`0300X8DBSA00<Xd@0301003@0=00Te
E09gS`04OfmoTGnAOi43Ok<5NeH2010015oD00l0300<0aAa00<0302f;?800bcb00<03@AB15801Bcb
00<LTA1a4740111a0bfi0dFD10``25XD100?1UkJ0WnE0ace0cVF1dhF0P0A0a3f134d00<8DBeF;EH0
0ReF1BeE13ec0TGE1DVd1U7C14VC15hc1dFC1eGd2F8c1F8d1V9D0fId1UGc1F9D1F9E0WKC0Wm`1f9D
17]=0VIc0W]=1W;C0WM]0gKe1DXi0RVH00=JEUIGEUL015IG00@Q=QFk5K/E^`U1]PEfdPMjlP9oL`9b
/`=c2@=b]003JYA_1gKC009fd`03OdiViGlA00=o4@9oL003Og40000000<000D]=0@Q=P0500h0400@
00/4DP06DYX5FSH3O`h4Odd00glbObmo;`03J^L010Qb0380<W_G10bC00<X07ooOol04Woo00<007oo
Ool08Woo000OOol5BKD4Og@4Nc@00g^bOomoo`0;Ool01@07330<<0``00X01bdC0TiH0VZe17nA0gmb
1GmC0WOD0adg00<8DP0815400``_00<02PQA:=400bSA00<0400=00d02CED0WN?17nA0Wnc1W]F0`0@
00<03`0<00`00aAa00<0302f;?800bcb00<03@AB15801Bcb0QbA1Q1a1Bfi1@``1eXD100?1EkJ0gnE
11ce0SVF00<03dhFCQH00dhF00ABF00A014HT@8@mPDa=0D]EP@]E@HmL`E9]0IAd`A9T`AN<`Q5T`IE
m0YR<`=R=0MRE0=VM0IEl`ARE0IRE@9fd`03Og1kEF9D00ERE0IkC@03IW=kCG]=00Ibd`03MfefmGKe
009fm@E:>@03?G@YV2VH00MFE`@E^`Q1]P03001fdWKB009fdPIjlP9oL`=b/`Ac2@9b]003JYA_1gKC
009fd`03OdiViGlA00=o4@03Og1oLGma00D000H]=0<Q=P0600h03`0@01003@AB15:J1UXf0g/d0gm=
0Wlb0Wl_0f[W00D0000b0380<W_G00@<TaEoo`03001oogoo025oo`007goo1DVe17md17/d3Woo00D0
1```330<<00:00P]4`03CUQZ]FZe00=oT@=oLPEoD`03001ge7OD00<M=`03258020AA00<<;`0300X8
DBSA00@Xd@0301003CED00LeE09gS`04OfmoTGnAOi43Ok<7NeH2010200l200`257400`0<0;H/lP04
;?821585;?8279464745;KT53307FQ@500l3G]X4OiD47?D00d:L>IHiUP02CQH4DUP201400aRA4?H@
mP05<C@00bTD;EH]EP02;EH4;ED6?G<2?E<4BK@6DM<2BI<6GS<7AI<7EO@9HS<3HS@8HU@00fIdEO=E
l`05EO<3HU@8HUD00gm`NeEkE@06HU@6Ndd00g<8NdekC@06L]<017M]M_EfmGKe1DXi00A_FSed?G@Y
V0IFE`03GkhQ=QFk008E^`M1]P8000=fdPMjlP9oL`=b/`Ac2@03L[A_:Fl7009_1`9fd`03Odig:glA
00=o4@04Og1oLGmaGWH50005;C@01BCc8CHQ=P0>00l00P0@00<03EcSDYX00U:J1eXf0g/d0gm=00Ao
<Wl_Obmo;`9Zi`8000042780<P0b038439<00bP0Oomoo`0BOol00`00Oomoo`0QOol001moo`A9]@Ao
M0Ek=0ioo`0500L03```33002P08;A<2J[D4Oi43Og84Oe<015=<MmAge7OD0adg00<8DP0815400``_
00<02PQA254012SA00<0400=00d01SED0WN?0Wm_0gnA0Wnc27]F0P0@00@4U00?00`0308DL@0300`0
]Rcb00@/lP0300d4DRcb00@/lP<LT@H@L@D]^@@<<0MJ50=fm0803`=NfPEoU@8Lm@04@YaVUSVF>IH6
DUP0100=014HTARA0Q3f134d0RTD0beF1BeE1Cec0ceC0dVd1U7C0TVC1Uhc1dFC1eGd2F8c0f8d269D
00=VM5GcEO<01EGc0f9D269E0W]E0W/C1F9D1W]=00=NMW]=L]<01G;C0WM]0gKe14Xi0VmJ0ced15IG
0enn00@Tlb4f5K/E^`I1]P<000=fdPMjlP9oL`=b/`Ec2@04JYA_1fl7K`L2M]<00gm>Mb]o4@03Oa40
0gm`Og5oL@02GWH40006;C@02RCc8CH03P0>00l0400;00eLhe:J1eXf17/d0gm=00Ao<Wl_Obmo;`9Z
i`8000042780<P0b038539<EOol00`00Oomoo`0POol001moo`A9]@AoM0=k=15oo`0400l<<0``00X7
;A<3J[D3Oi44Og84Oe<5Mm@27CL00`QB00P4D@0332l00`0:2548D@04:=4201000`0==E@eE004=E@0
0gN?OfmoK`03Oi43Ok<7NeH01E/L0100400@19@00P0<0QAa0P0<1Bcb00<03@AB;?801Bcb0QbA1Q1a
1Rfi0```1eXD0gKd0gm`00=NfWnEOiD017nE00<LmD:LIYH00VJF0SVF1E9H00@03@0A014HT@8@mP@a
=0<Y508]EPD]E@DmL`DmD`03BKAAde7C00AAd`03BI=N<ehc00EN<`M5T`MEm0UR<`9R=0URE0UEl`03
HUAREF9E00MRE@9kE@9k4`ERE0IkC@03GWIkCG;C00Ebd`04MfeoKgKeM_D4BST4KeX3?G@00eIGGkiO
_P03Gkh012Cc8CHE^aFk1T6f10000WKB1W[b0gmc0g:c1G<900EZU6l7K`M_1gKC009oCP04Mb]o4GlA
Oa42Og000gmaGWINMP02GWH30006;C@01BCc8CH03P0>00l00P0@00<03EcSFSH01eXf17/d0Wm=0Wlb
0Wl_00=bif[WJ^L00P0000D8LP0b0380<P1B00@<TaEoo`03001oogoo021oo`007goo0dVe1Gmd57oo
00D01```33002P0>00D]4`AZ]@=oT@=oLPAoD`03001ge7OD00=ge0<M=`0300P4D@`_008<;`0300X8
D@QA00@Xd@80400300deE3ED00<eE004MhmS:Wm_Ofl3Oi43Ok<4NeH5Fa`201000`BD00`030025742
00`5;?800`0=158/lP05;?8279474745;KT33306FQ@4M_@2Og05OiD5@Y`3IYH2>IH6DUP201400aRA
4?H@mP05<C@3:A@00beF;ED]E@03;ED5?G<6?E<6DM<00dVCGS=N<`05GS<7AI<7EO@:HS<00f8dHUAR
E007HU@9EO<00f9DHUERE@06HUD3NeD2Na<5HU@5Ndd00eifNdekC@06L]<017M]OfmfmGKe0dXi1FmJ
1Ced1Enn00@Tlb4f5K/E^`A1]PD0009fdPIjlP9oL`Ab/`Ec2@03JYA_1fl7009_1`03Odi^]GL[00=o
4@03Og1oLGma00ENMP8000H]=08Tl`058CH03P0>00l0400200d00ecSFSIJ=P05FSH3Nc@3Odd2Oc82
Obl00g;WJ^L0000200022783038439<EOol3000POol0021oo`99]@=oM1Ioo`0500L03```00X03P04
;A<4J[D4Oi43Og84Oe<2Mm@2Og82Mm@37CL00`QB00P<;`0232l00`0:2548D@04:=4201000`0==E@e
E002=E@00`0@MhmRUP02Ofl3Oi42Ok<4Nfh7Fa`0100@19@4U00<0QAa0P0<1Bcb00<03@AB;?801Bcb
0abA1Q1a1Rfi0P``1EXD1GKd0Wm`00=oUFZDOc801T:L16JF00=k=3VFDUP01E9H0P0A0QRA00<@mS4d
<C@00c4d12TD00<]EReE;ED00ReE1Sec1CeC13ff0U7C00=9TehcGS<01Ehc1dFC1UGd00=JEV8cHS<0
268c00=R=69DHU@01V9D00=^TeGcEO<01eGc2F9E0W]E0g/C169D1G]=0Uif0W]=1G;C0WM]0Wm_00=f
mEIGBST01VmJ1Ced1Enn00@Tlb4f8CHE^`A1]P03014000000080009fdPIjlP9oL`Ab/`Ac2@9ZU0A_
1`9^]@Ao4@03Og1oLGma00ENMP0300h002dd00D]=08Tl`<03P0500l0400@00eLh`06FSH4Nc@3Odd2
Oc82Obl00g;WJ^L0000300001@Qb0380<P0b058010bC5Woo00<007ooOol07Woo000POol2BKD2Og@G
Ool00`0700l<<00200X3;A<5J[D3Oi44Og83Oe<00`00MmAo<`04Og801GOD7CLM=`QB00P00``_0P0:
00<8DBSA:=400RSA0`0@13ED00AgSf<ZOfmoK`=oT@=o/`AkKP03OiAK75/L00=K7007@iD0400@19@0
300957400P0<00<0]Rcb;?800Rcb00<03@AB;?801Bcb0abA1a1a1Rfi00<<<5XDFQ@00UXD00=o]GKd
M_@00WKd0gm`0VZD0Wlb14:L1FJF0W/d00<02e9HDUP00e9H0P0A0QRA0Q3f134d1BTD12eE1Sec1CeC
1Sff25hc1dFC1EGd0UYF2V8c2F9D00=^TeGcEO<01eGc2F9E0W]E0g/C169D17]=0eif00=kCG;CL]<0
17;C0WM]0Wm_00=FEf;jH_X01VmJ1Ced00<XlennGkh00Unn0RCc00<Q=QFk@KH00T6f00DENP0AFF0M
5@5E008000IjlP=oL`Ab/`Ac2@9ZU0A_1`03K[Eg:glA00=o4@03Og1oLEif00INMP0300h002dd00@]
=0<Tl`<03P0400l0400=00d6FSH4Nc@2Odd3Oc82Obl2J^L40002278203800`1B39<<T`0239<FOol0
0`00Oomoo`0NOol0021oo`03BKEoM7oo01Qoo`0500L03```33002P02;A<6J[D3Oi43Og83Oe<01000
MmAo<glc17mb00D0m1dg7CL8DP0800<<;`802P03254XdBSA008Xd@<0400600deE3ED011k]F<Z0Wm_
0gnA0Wnc00Abe7]^NfikKP=oU0=K70=B=`050104U00<00TDL@0200`00`2f;?8/lP02;?800`0=158/
lP05;?8379464744COH3Khh23303FQ@00gneM_Afm002M_@2Og03JY@3Oc83@Y`4IYH3Nc@00`0;DUQB
F003DUP00`0=014HT@0269400a3f<C@a=002<C@5:A@4;ED6?G<6?E<5?KH9GS<7AI<3EO@4FUH9HS<9
HU@2KY<8EO<00glcHUERE@05HUD3NeD4Na<3HU@3Ndd4GWH00g]=L]=bd`04L]<017M]OfmoKgm_16;j
1FmJ1Ced00<XlennGkh00Unn0bCc00DQ=QFk@KH<TaEj00804@8M5@81E@IjlP9oL`Ab/`Ac2@9ZU0A_
1`9^]@03Mb]o4GlA009o4@03Og5ViUif00INMP0300iQAbdd00@]=0<Tl`<03P0500l0400@00eLh`05
FSH4Nc@2Odd3Oc82Obl00f[W000000030002278203800`1B39<<T`0239<GOol00`00Oomoo`0MOol0
021oo`03BKEoogoo01Uoo`803`0433002RdC00X5J[D3Oi4016/HOg9oLWmb0gmC00=ge7lcOc<01Gmb
00EWBadf7CH8DP0800@<;`0300X8DBSA00@Xd@80400600deE3EDNkES:V:F0Wm_0WnA0Wnc00=be7]^
Nfh00W]^17nD00=K758gDSL00U8g00D040BD19@031Aa008030030;H/lRcb008/lP803@H/lP@LT@8@
L@M=mPA_SP04331J55XDOkD5M_@2Og02JY@5Oc800d:LIYIVUP03IYH4Nc@5DUP00`0=014HT@026940
0a3f<C@a=002<C@5:A@010aa;ED]EBeE1Sec1SeC1Cff2Ehc1dFC0UGd1EYF268c00=^]69DHU@01V9D
0fjC1eGc0Wlc1f9E0g]E17/C0f9D0W]=15if0W]=1W;C00=gKGm_Ofl01V;j16mJ1Sed00@XlennGkiO
_P<Tl`038CH<Td6f008<T`804@048AHM5AdE0ED6N_82Og<4L[<4L`T2JY@4K`L2K[D01GL[Oa5o4GlA
Odl00VKV1Uif00=NV00>00h01Rdd0RCc00@03P0@00h03`804003015LheXf00=J=PAk=0=oC@9o<P=o
;`03J^L0000000<000<8LP80<P04058<T`bC39<HOol00`00Oomoo`0LOol003aoo`803`0333002P0:
00IZ]@=oT@04JaQoLWmbOg82Oe<01000Oc=o<glc17mb0VM;0adf00<020`_32l00P`_00<02PQA:=40
12SA0`0@00@eE00@NkES:P=oK`9oT@03Ok=be7;D00AkKPAoU0IB=`040104U00<574200`00`2f;?8/
lP02;?8200d00`AB;?8/lP03;?847949COH4Khh017M]FQAo]Gne1GKd00AoL6ZDJYAZU0Eo<PIVUPEk
=0ABF00300d04ARA00<HT@Da=0@Y5004374]EBeE;ED6?G<6?E<6?KH8GS<7AI<00eGdFUIJEP04FUH8
HS<2K[@7HU@3KY<7EO<2Oc<7HUD2NeD5Na<3HU@00g]=GWINMP03GWH2Ndd5L]<2Mfd2Ofl5H_X00eHe
KeY_FP03KeX5?G@012ScGkiO_Unn12Cc00LQ=PbC39<<TaEj015IH0037AD00`5EN_9jlP03N_82Og<4
L[<4L`T2JY@3K`L3K[D01GL[Oa5o4GlAOdl00VKV1Eif0UjH00<0<@0>HDL01Bdd0bCc00L0400>00h0
46EP01403@04FSH4Nc@2Odd2Oe001WlbObmo;g;WJ^L@2`D00088LP80<P04058<T`bC39<HOol00`00
Oomoo`0LOol003aoo`0300<03```00802PIZ]@=oT@=oLP9oD`03K_Mo<glc009o<`AoLP9WB`040?@M
=Qdf00P432l00`0:254Xd@04:=45010017^eHYIoKgm_0gnA0g;D0g]^1GnD1e8g00<4U00<57400`0<
12cb0P0=00<4DRcb;?800bcb11bA24gf16n>0WM]0gne17Kd0Wm`0fZD1Glb00=o<fJFIYH00VJF1W/d
159H00<03@0A69400aRA1C4d12TD00<<LBeE;ED00ReE1Cec1SeC1Sff25hc1dFC1eYF268c0Vjd1f9D
0fjC1eGc0glc1F9E0g]E1G/C0V9D0W]=00=k4UifGWH00Uif0W]=1G;C0WM]00=oKf;jH_X00f;j0UHe
00<PdfmJKeX00VmJ1Ced0RSc0enn0bCc00<Q=PbC39<00PbC0P0A11dE00@1EG[bN_9jlP=oL`Ab/`=c
2@=ZU0=_1`=^]@06Mb]o4GlAOa5oCfKV0P020Uif1EjH0P0>1Bdd0bCc00P03P0@00h03`0@IF004EcS
0eXf17/d0Wm=0gm@0Wl_00Abif[W0KX1^P@000<8LP030380DP1B00<<TaQoo`03001oogoo01]oo`00
?7oo00@00`0?00l02PIZ]@=oT@05JaQoLWmbOg9oD`02K_L3Oc<5Og82Id/00f;I7CHM=P0200P332l0
0`0:254Xd@04:=4401000g^eHbYRUP02Ofl2Oi43L]@4Nfh4Oi@00gm`DSMB=`05DSL010BD00`02AAa
0P0<12cb0P0=00<4DRcb;?800bcb1AbA1dgf0fn>00=kEGM]Mfd00Wne1GKd00=oL7^bJY@00VZD1Glb
00=o<fJFIYH00VJF1g/d0e9H0P0=00D04ARA694HTA3f00@a=0DY5004374]EBeE;ED5?G<7?E<5?KH8
GS<7AI<7FUH7HS<3K[@6HU@4KY<6EO<4Oc<5HUD3NeD5Na<2HU@00g]=GWIk4P04GWH00g]=L]=bd`04
L]<00gM]OfmoK`04H_X3ESD00b3CKeY_FP02KeX5?G@2:?<3Gkh49?<439<201400b4F7ADM5@027AD3
N_82Og<5L[<3L`T3JY@3K`L3K[D017L[Oa5o4GlA0VKV0P0200=NMUjHGYP015jH00<0<@0>014012dd
12Cc00L0400>00h046EP01403@02FSH4Nc@00fm:OdeoC@03Oe02Ofl01G;W0KX1^P6j01000`000`Qb
00<0<P1B05800`bC6Goo00<007ooOol06Woo000lOol0100300l03`0:1VZe0gnA00A[67mbOg9oLP9^
m`04BOIo<glcOc<4Og82Id/2H]T37CH01P0832l<;``_00X8D@DXd@@04003NkES:V:F009oK`9oT@=b
e0=kKPAoU09oL0IB=`05Ik44U0BD00TDL@0200`4;?8200d00`AB;?8/lP03;?857946COH3Khh00g]E
MfegK@02OkD00gnANaEk5@03M_@00gm`JYAZU002JY@4Oc82Oc<4IYH7Nc@4DUP00`0=014HT@036944
<C@5:A@010aa;ED]EBeE1Cec1ceC1Cff25hc1TFC0V:h1eYF1V8c0fjd1V9D16jC1UGc17lc169E0g]E
1W/C0V9D00=kCG/BNa800eif0W]=1G;C0WM]00=oK`3GH_X00V;j1EHe00@PdfmJKeY_FPDmM0<Xl`9O
_P@Tl`@<T`0313404B4F00DM5@9jlP9oL`Eb/`9c2@AZU09_1`=^]@03Mb]o4GlA009o4@9ViP8ROPMN
V00303403V5700@]=0@Tl`80400500h0400@IF004@02FSH4Nc@00fm:OdeoD003Oe02Ofl01V[W0KX1
^P6j3;D0408000@8LP030380DP1B008<TcIoo`00?7oo00<01`0?00l01fZe0WnA0V/H0Wmb0fkg17lc
17mb00EWBf;IH]URf@3d008M=P0600P<;``_32l02PQA1BSA100@00Ak]F:FOfmoK`9oT@Abe0=kKPAo
U09oL0IB=`05Ik44U0BD00TDL@0200`4;?8200d00`AB;?8/lP03;?857946COH2Khh2NeD2Mfd3Oi43
NaD2M_@017^bJYAZU6ZD1Glb0glc0VJF27/d00HmUE9HDUQBF00=01446942>E<2<C@5:A@23742;ED6
?G<6?E<5?KH8GS<5AI<3H[P7FUH6HS<3K[@6HU@4KY<6EO<5Oc<3HUD3NeD7Na<00f9DGWIk4P02Na82
GWH2Ndd00g/CL]=bd`02L]<2Mfd30=L00f;jESEF=@04ESD0123CKeY_FVmJ1Ced0bSc0Unn12Cc00DD
L@bC39<<T`@a00804@HM5@=oL`Eb/`9c2@=ZU0=_1`=^]@07Mb]o4GlAOa5oCfKV6EP00b9n1UjH00@0
<@0>00h04@<]=0DTl`80400600l046EP?MMLheXf17/d0Wm=17m@0Wm_00=Ziacd0KX00P6j00<<]@0@
000010Qb00<0<P1B05800PbC=Woo000mOol300l5J[D2Oi42JaP3Og83K_L4Oc<4Og800fM;OomRf@02
H]T27CH0100800/<;``_0P0:1BSA0`0@00=k]F<ZHYH00Wm_0WnA17;D0W]^17nD00AoDgm`Og1oL0AB
=`9W/@04NeD4U009574200`0100?;?8/lRcb0`0=1Bcb1AbA1Dgf0Vn>00AgSg]ENeEgK@=oT@Ek5@03
Og1ZU6ZD009ZU0Eo<P=o<`9VUPMk=09O?0=BF00300d04ARA00<HT@<iD`8a=0@Y508<L@8]E@HmL`Hm
D`Dm]PUN<`=5T`AR^0MJEPER<`E^]0ARE0E^T`IEl`Eo<`=RE@=kE@Mk4`03HUANMW/B009k4P9NMP03
NdeoTG/C00Abd`03MfeoK`3G0080e`MF=@8Pd`=_FP@mM0<Xl`9O_P@Tl`03574<T`bC008<T`804@03
8AHM5AdE00DM5@Eb/`9c2@AZU09_1`A^]@08Mb]o4GlAOa5oCfKVHm8IF08ROPMNV00303403P0A00@]
=0@Tl`80400300h046EP008me`Ek=003Oddmegm@009oD09oK`04L^L42Qcd7?@20KX010be01004000
0`Qb00<0<P1B05800PbC=Woo000mOol300l5J[D2Oi42JaP2Og83K_L014WfOc=o<glc17mb00AWBgoo
Oomoo`9Rf@8M=P049KX02``_32l200X6:=4201000g^eHYIRUP02Ofl00gnANk5be002L]@3Nfh3Oi@2
Oe<3Og04DSL01VNaNeEkE@BD00`DL@<030</lP<03@D/lPHLT@A=mP9_SP04F`UkEG]EMfd3Oi45NaD0
0g^bJYAZU002JY@4Oc84Oc<2IYH6Nc@3Gc`3DUP00`0=014HT@036944>E<00c4d:A@Y5002:A@23742
;ED6?G<6?E<5?KH9GS<2AI<6H[P6FUH5HS<5K[@4HU@6KY<4EO<6Oc<2HUD4NeD7Na<00g]=GWIk4P02
Na82GWH00g]=Na=k4`04L]<00gM]AMDXl`030=L6ESD28=<3KeX5?G@3:?<00enn9?<Tl`039?<439<0
0`@a01404@067AD00b@6L[=b/`03L[<2L`T4JY@2K`L4K[D01gL[Oa5o4GlAOdmViV?B008IF08ROPIN
V00403403V570143;C@49?<00`bC0100400201000fEP?MMk=003Nc@00fm:?MMc5P03Oe02Ofl017;W
10XLm1cd0P6j0Pbe0P0@10Qb0`1B0PbC2goo00<82P03Ool09goo000mOol0100300l03`0?16Ze00Ao
TF/HJaQ[609oLP=^m`Ao<`AoLP04Id]oogooOol2H]T0103d7CHM=P080P`_0P0:1RSA00@047^eNkER
UP9oK`03Oi5k/G;D00=be0=kKP=oU003Oe=oL7m`009oL0=B=`04Ik5c=g]ENeD219@0100900`0300<
0bcb0`0=1Bcb1QbA14gf00I_SWN?NeEkEGM]NkL3Oi45NaD00g^bJYAZU002JY@4Oc85Oc<6Nc@5Gc`2
DUP200d46945>E<4:A@337400beE?G<mL`04?G<7?E<5?KH8GS<00dFCH[QR^005H[P7FUH4HS<5K[@4
HU@6KY<4EO<7Oc<0169ENeEkEG]E27/C00=NMW/BNa800g/B00=NMWnANa<00W/C0W;C0WM]00=5eBSc
0=L00P3G1UHe0b3C0VmJ1Ced0bSc00=O_RCc9?<00bCc00DDL@bC39<<T`@a00804@DM5@03018T1R@6
00Ab/`9c2@AZU003K`M^]Fje00=^]@05Mb]o4GlAOa5ViP03Hm826EP00b9nGYQNV004GYP203400`0>
01404@02;C@59?<201000`0>011UH002?ML3Nc@00fm:?MMoD003Oe02Ofl00g;W10XLm0027?@20KX2
3;D00`0@2788LP0227800`0b0580DP0239<;Ool00`P:00=oo`0WOol003eoo`04>IH03`0?00l3J[D2
Oi42JaP2Og84K_L4Oc<3Og800fM;Oomoo`03Ool01f;IFa`M=Qdf00P02``_00802PHXd@04011k]F<Z
HYH2Ofl00gnANk5be003L]@2Nfh3Oi@2Oe<5Og00158gIk5c=g<g0W]E0PBD00D02@0<00`0300?00</
lP803@D/lPHLT@==mP03KhikSWN?009kE@04MfeoTGnAOi45NaD00g^bJYAZU002JY@5Oc85Oc<3L]D2
Nc@6Gc`2DUP200d46945>E<4:A@337400beE?G<mL`04?G<7?E<5?KH8GS<8H[P7FUH3HS<6K[@3HU@7
KY<4EO<7Oc<0169ENeEkEG]E27/C00=NMW/BNa800g/B00=kCGnANa<00W/C0W;C00EgKDGEAME5eBSc
0080e`MF=@8Pd`9_FPDmM0@Xl`03GkhTlbCc008Tl`05574<T`bC39<4<@0301427AD28AH201800b@6
L[=b/`02L[<00g<9JYAZU003JY@00fl7K[E^]@03K[D01GL[Oa5o4GlAI^H00f?B0aUH1UjH0P0a00<0
3P0A01400Rdd1BCc00D<T`0@010046EP00<me`9k=003?MMc5Wm@009oD09oK`9bi`842P8Lm081^P8<
]@8040@8LP<0DP0339=oogoo00Uoo`0320X00goo02Moo`00?Goo00<iUP0?00l00P0?0VZe00EoTF/H
JaQ[67mb00A^m`04BOIo<glcOc<4Og800fM;Oomoo`05Ool27CH00`0:00/<;`0600X2:=40100@CaiR
UV:F0Wm_00=k/G;DL]@00W;D0g]^0WnD0gmC1Gm`00=B=g<gLcL00g]E0PBD00D02@0<00`0300?00</
lP803@0307</lRcb00</lPDLT@==mP03KhikSW]E009kE@04MfeoTGnAOi45NaD00g^bJYAZU002JY@5
Oc85Oc<4L]D00fjdGcaO?004Gc`0158EDUP03@0=1ARA13UC00<DTRTD:A@00RTD0`aa00<]ECec?G<0
0cec1ceC1Cff25hc00=J=6:hH[P01V:h1UYF0f8c1Vjd0f9D1fjC15Gc1glc0WMG0W]E1g/C0Uif1G/B
0WnA0g/C0W;C00AoKdGEAME5e@8Xl`80e`IF=@<Pd`03KeXmM3ed00<mM0@Xl`03GkhTlbCc008Tl`04
574<T`bC39<2134201400adE00d0U@028AH00`0B90Ib/`03L[<00g<9JYAZU003JY@00fl7K[E^]@03
K[D01GL[Oa5o4Gm?I^H00f?B11UH1EjH0`0a00@03P0A014]=0DTl`0339<0400@00804003IF0mecgG
009k=003?MMc5Wm@009oD09oK`9bi`842P<Lm0060KX<]@be3;D0403F0`Qb0QUi00<0DPbCOol02Goo
0PP:00<00gooOol09Woo000nOol2>IH200l2J[D4JaP00gmbK_M^m`02K_L014WfOc=o<glc17mb2Goo
00@M=P0:00/<;`H02P05NkE?7TlNCaiRUP02Ofl00gnANk5be003L]@2Nfh2Oi@00gmBOe=oD`06Og03
LcL3NeD219@00`0900`0300200`00`0?;?8/lP0300d00`1c;?8/lP02;?857942COH00fn>NhigS`02
NeD017M]NkMoTGnA1G/E0W^b16ZD17lb1Glc1G;E0Vjd0ell0e8E00ABF00=00d04@@HT@@iD`03598Y
52TD008Y50<<L@03;EDmLcec00<mL`LmD`035?Dm]Sff008m]PMN<`9J=0QR^0IJEP=R<`I^]0=RE0M^
T`=El`Qo<`=gE`Mk4`=NMPEk4P03Oi5k4g/C00=k4`03Mfe5eDGE0095e@8Xl`80e`IF=@<Pd`03KeXm
M3ed00<mM0DXl`@Tl`8DL@8<T`84<@804@057;<03@0=09DQ5P0201801R@6L[=b/g:cL`USo0AZU0E^
]@06Mb]o4GlAOa5oCfKV0Rjo0V?B0aUH0SUd15jH0P0a00@03P0A014]=0DTl`8<T`80400300mUH3gG
008me`03KdYc5W<F00=oD09oK`04L^LY50@:10X47?@43;D00`0@0=H8LP0227826GT00`1BOomoo`08
Ool010P:00<00`039goo000nOol5>IH00gnA>IHiUP02JaP5K_L4Oc<3Og800fM;Oomoo`07Ool011df
00X02`0;0`0:0doK0dlN0V:F0Wm_00=k/G;DL]@00g;D0W]^00=oU7mBOe800WmC1Wm`0W<g17]E00Ag
5@BD00dPm0<0300300l/lRcb00<03@0307</lRcb008/lPHLT@04COI_SW^>F`T2NeD017M]Oi5oTGnA
1G/E00=k/VZDJY@00fZD17lb1Glc17;E16jd00=O?58EDQD00e8E00=BF00=014011RA1CUC00@DTRTD
:A@Y50<<L@03;EDmLcec00<mL`HmD`9J5@045?Dm]Sff?KH6GS<4FS@6H[P00e8f=ILeU`04FUH2HS<8
K[@00f9DKY=^T`06KY<3EO<7Oc<4MeL6Na<4GWH5Na800gnANa=k4`03Na<00gm_AME5e@02AMD3:?<0
0`3GESEF=@04ESD48=<00fmJ?G@mM002?G@5:?<59?<01AAa39<<T`bC13400P0A0Qbc00<03`0=07@0
0P0B00@T1W:cL[=b/`9So0=ZU003K`MRE6je00=^]@05Mb]o4GlAOa5ViP05;[l36EP3>G@3GYP20340
1@0>01004@0A;C@01BCc00<<T`0@01000P0@0cgG0g<F0gm@00=oKgmcL^L00RTD00<42Qcd7?@00Qcd
00D1^Pbe3;D<]@0@0080eP88LP<IN@0339=oogoo00Eoo`0300=oo`P:00<00bMoo`00?Woo2CVF00=o
LVkgK_L00Vkg00A9mWlcOc=o<`AoLP03Id]oogoo00Qoo`047CH02P0;00X2Cm/00`0;Cai?7P02Cah3
HYH2Ofl00g^aL]Abe002L]@3Nfh2Oe83Oe<5Og03LcL4NeD00gLE19@03@028?@200`200l012cb00d0
3@0=0P1c0bcb1QbA00==mW^>Nhh00g]E00=k]gnAOi401W/E00=k/VZDJY@00fZD17lb1Glc17;E16jd
1U8E00=BF00=00d011RA1CUC00@DTRTD:A@Y50@<L@DmL`DmD`=J5@8Dm@8m]PEN<`EJ=0ER^0=B=P@e
U`9JEP03HS=^]6jd00I^]003HUA^TfjC00I^T`=El`Io<`EgE`03HUAk4g/C00=k4`=NMPEk4P9oT@Ek
4`03LkY5eDGE0095e@<Xl`80e`EF=@@Pd`03KeXmM3ed008mM0DXl`03698TlbCc008Tl`04574<T`bC
39<213401@0A7;<L/`0=00l00P1d00<04V?l90H00W:c0V?l0fZD00=_1f9DK[D00fje00Ig:glAOa5o
4FKVBOH4;[l0100?6EPIF1UH0cUd0UjH0`0a00@03P0A014]=0DTl`8<T`80400400lmecgG?ML3LaH2
Oe02Ofl01GmcL^LY52TD10X01Acd10be0`3F0PQb0QUi00<<TgooOol01Goo00<00`P:20X00`039goo
000nOol9>IH5K_L014WfOc=o<glc17mb2goo00@M=P0:00/02`I?7PARUP03Ofmk/G^a00Abe09kKP=o
DP=oD`AoL0Ac=`=kE@9g5@0319@03@09008Pm00400`03`0?;?8400d207<2;?85794014>HIaUkSU/9
0g]E00=k]gnAOi401G/E00=k/VZDJY@00fZD17lb1Glc1G;E16jd1U8E00=BF00=00d011RA1CUC0QBB
0RTD10aa0SEe13ec0ceC15XE0QCe0Sff15hc1UXd0f:h1E8f1SFG00=R<fjdK[@01Vjd00=RE6jCKY<0
1VjC0UGc1glc17MG0f9D0g/C15if1G/B0WnA1G/C00<mUDGEAMD00TGE12Sc00<0eeHeESD015He123C
1Ced12Sc00<HTRCc9?<00RCc0QAa0PbC0P@a0P0A0Qbc00<03`0=07@00P1d00<QF7:cL`T00f?l0VZD
0f9D0fje00Ig:glAOa5o4FKVBOH5;[l36EP4>G@01UjH0340<@0a00h040804@DTl`8<T`8040039CIU
H3gG00=c5P=oD09oK`03Og=bibTD008Y500310XLm1cd008Lm0D<]@<0eP05278INAUi6GT0DP06Ool0
0`0320X82P0400<VOol003moo`LiUP03B[e^mfkg00=^m`Ao<`=oLP03Id]oogoo00Yoo`802P037;9?
7TlN00=?7PARUP9oK`03Nk5be7;D00=be09kKP=oDP9oD`EoL0=c=`AkE@9g5@0319@03@09008Pm004
00`03`0?;?8400d207<2;?84794014>HIaUkSW^>0g]E00AgKGnAOi5oT@Ek5@03Nk9ZU6ZD00=ZU0Ao
<PEo<`Abe@E^]003L[=B5E8E00AB5@803@@HT@DiD`8DTP8Y50@<L@<eM@<mL`<mD`AJ5@<Dm@8m]P=N
<`MJ=003H[QB=U8f00AB=PHeU`U^]0Y^T`03EO=o<glc00Ao<`EgE`ARE003Na=NMUif00=NMPEk4P03
Oi5k4g/C00=k4`03LkXmUDGE00A5e@@Xl`IF=@@Pd`DmM0DXl`@Tl`8DL@8<T`84<@804@8L/`0300d0
3`1D00<0M003L[=c2F?l009So09ZU0=RE0=^]@04Mb]gV7lAOdl2BOH00bTD;[l^_`02;[l36EP5>G@0
1EjH0340<@0a01000P0A1RCc0PbC0P0@00<U=SgGLaH00W<F0gm@00AoKgmcL^Mbi`@Y50@Lm0034;@<
]@be008<]@@0ePDIN@Eoo`0400<82PP:0=L300<VOol003moo`HiUP=:_@=^m`03BOIo<glc009o<`=o
LPeoo`802P8L/P=?7PERUP03Ofmk/G^a00Ebe004NfioMGmBOe83Oe<4Og04LcL3NeD3MaD00`BD00d0
3@038?@00`0<00l03`0400d307<01Bcb794LTD>H07<00VLI00=kSU[KNeD00W]E00=k]gnAOi401G/E
0W^b1FZD17lb1Glc17;E16jd0W:c1U8E0P0=00@03aRA694HT@DiD`<DTP03:A@<L@aa00<<L@@eM@03
?G<mDceC00IJ5@<Dm@03?KIN<ehc00QJ=0QB=PDeU`U^]003IYE^TfjC00M^T`03EO=o<glc00=o<`Eg
E`ERE0INMPEk4P03Oi5k4g/C00=k4`8mU@E5e@@Xl`030=MF=EHe00=F=@@Pd`035?DmM3ed008mM0DX
l`04698TlbCc9?<2574239<313401P0A7;<L/abc00l03@<0M0<QF09So09ZU0ARE09^]@=gV004Odm9
mW_GNmL4;[l00`0?6EPIF006>G@30340100>01004Ace1BCc0PbC0P0@00<U=W<FLaH00W<F0gm@00Ao
KgmcL^MViP@Y50DLm0054;@<]@be3;D040040=H46GT4Ool0100320X82PP:0P3G0P039Woo000oOol5
>IH5B[d2K_L014WfOc=o<glc17mb3Goo0P0:0abb00=?7V:FHYH016:F00=oKg^aL]@017;D0W]^0gmB
0gmC17m`17<g0g]E0gLE00<4U00=00d0123d0`0?00@0<00=00d03@<0L`037940L`1c009W6@03OgAk
SU/900=kE@03NkMoTGnA00Ek5@03Nk9ZU6ZD00AZU0Ao<PAo<`Ebe@A^]09b/`IB5@03HU@03@0=00<H
T@DiD`<DTP8Y50@<L@DeM@03?E=J5EXE00EJ5@@Dm@03GS=J=5Xd00MJ=0QB=PHeU`M^]09VU@U^T`03
EO=o<glc00=o<`EgE`ERE0ENMPEk4P9oT@Ek4`8mU@E5e@DXl`EF=@DPd`045?DmM3ed?G@5:?<011RB
9?<TlbCc0aAa00D<T`@a1344<@0A00<L/`803`0305@0M01d00@QF003HoaZU6ZD00ARE003K[Eg:gNH
009gV005I^Ikeg_GNmLY5003;[l00`0?6EPIF006>G@40340100@01404Ace12Cc0PbC0P0@0RDf0g<F
0Wm@0Wm_00=oLg;WI^H012TD00<DeAcd7?@00Qcd00<@]0be3;D00Pbe103F11Ui17oo00@00`P:20X8
2P<0e`0300=oogoo02Aoo`00?goo13VF1dZm00=^mglcOc<00Wlc0gmb3goo00@02Qbb7;8L/PIRUP9o
K`03Nk5be7;D00=be003NfioMGmB009oDP=oD`=oL0Ac=`AkE@Ag5@803@@Pm08eUP803`0303003@0=
00D0L`=W6@03NhiJffm/009_K003MfeoTGnA00Ek5@9k/PIZU0=o<PEo<`Abe@E^]09b/`IB5@03HU@0
3@0=00<HT@DiD`@DTP03:A@<L@aa008<L@DeM@QJ5@@Dm@UJ=09k=0MB=PHeU`I^]0=VU@U^T`Eo<`Eg
E`IRE003Og5NMUif009NMPEk4P03Oi5k4g/C00=k4`=1L`03?IE5eDGE0095e@DXl`91U0=F=@DPd`04
5?DmM3ed?G@5:?<269839?<2574239<213401P0A7;<L/abc00d03`80E080M0@QF003Hoa_1f9D00AR
E005Mb]gV7NHMiQViP03NmL2:A@2;[l0100?6EPIF1UH1CUd00@H/`0a0340<@804003014LmAce00<T
l`<<T`04010U=RDf9CH2LaH2Oe001Gm_Og=oLg;WI^H01BTD00@DeAcd7?@Lm08@]0<<]@@0eP039?@I
NAUi008IN@=oo`0400<82PP:I^H40=L00`03Oomoo`0SOol0041oo`8iUP03Oom:_DZm00A:_@99mPAo
<`=oLPmoo`0300XL/Qbb008L/PERUP03Ofmk/G;D00Ebe004NfioMGmBOe83Oe<3Og05LcL3NeD5MaD2
00d00`098?@Pm0028?@3=IH00`0?03003@0407<4IaT00g^>F`U_K002Kf`00g^gOi5oT@05NaD00g^b
Og1oD`04JY@4Oc84Oc<5L]D4K[@4L[<4DQD3HU@0100=00lHTARA1SUC0aBB00<Y50aa37400Paa1CEe
25XE11Ce2EXd0W/d258f1CFG1Vjd16JE26jC0W?J0glc1GMG1F9D0Wma15if1G/B00=oTG/CNa<00g/C
145c14GE1BSc0d6D0eHe123C0QCe0Sed1BSc0QRB0bCc0QAa0PbC0`@a00@04Abc7;<L/`803`80E004
07@QF25H8EP8HU@3MiP00gm?Og=ke`02NmL2:A@3;[l00`0?6EPIF006>G@303400`0>01004@037?D3
9?<239<201029CH01G<FOe1oD7m@Ofl00UjG00=oU6KV:A@012TD00<DeAcd7?@00Qcd00D@]0be3;D<
]@0@00<0eP039?@INAUi008IN@=oo`<82P03JcXPl`3G00<0ebEoo`00@7oo00@iUWooOomoo`9:_@E9
mP=o<`=oLQ1oo`0300XL/Qbb008L/PERUP03Ofmk/G;D00Abe09kKP=oDP=oD`=oL0Ac=`AkE@Eg5@03
19@03@0900@Pm0DeUP0403003@1c07<4IaT00gmdF]]_K003Kf`00g^gOi5oT@05NaD00gm`Oe=oD`04
JY@4Oc84Oc<5L]D4K[@4L[<4DQD3HU@200d26946>E<459843746=GD8FQD45?D8FS@2Nc@8DSH6=IL4
K[@5IYD8KY<3LmX00glcMeMgE`03MeL6HU@2Og44GWH5Na800gnANa=k4`03Na<4@G<5AMD4:?<5@I@0
0eHe8=<Pd`038=<25?D00ced:?<Xl`03:?<269839?<357401@bC1344<@@a01400abc0P0?0P1D00@0
M25H8EPQF0QRE09gV09oC`Ake`<Y508^_`0300lIF1UH00HiM0056;<0<@0a0340400201427?D39?<3
39<0100@9CHU=RDf0Wm@00AoKejGGYMNU`=ViP@Y508De@<Lm08@]0<<]@@0eP049?@INAUi6GT3Ool3
20X00f/j8?<0e`030=LUOol004Aoo`M9mP=o<`9oLQ5oo`0300XL/Qbb00<L/PARUP9k/@Ebe003Nfio
MGmB009oDP=oD`9oL09oD@=c=`AkE@Ag5@04L]D4U00=00d48?@5=IH203000`1cIaUW6@03IaT00g^>
F]]_K002Kf`00g^gOi5oT@02M_@3NaD017^bOg1oDgmC16ZD17lb17lc17;E1Fjd17:c158E169D00@0
3@0?694HT@DiD`@DTPD<L@DeM@QJ5@@Dm@MJ=0Ak=0MB=PHeU`A^]0EVU@M^T`AcfP9J=PAgE`IRE0=o
L@9NMPEk4P9oT@Ak4`E1L`03>E=5eDGE0095e@DXl`E1U0DPd`8Dm@8mM0DXl`8HTP8Tl`<DL@0539<4
<@@a13404@047;<01P0?37<0E01D07@QF0QRE09gV003LmYoCgm?00Eke`8Y508^_`0300lIF1UH00Hi
M0046;<0<@0a03420100100A7?DLmAce0RCc0`bC00<042Df9CH00bDf15jG00<bgfKVI^H01BTD0QCE
0Qcd0a2d0Pbe00D0403F0=H0eRCd00<IN@=oo`<82P9[>P048?<0e`3G0=LUOol004Aoo`I9mPAo<`9o
LQ5oo`03FL0L/Qbb00<L/P=RUP03Ofmk/G;D00Ebe004NfioMGmBOe84Oe<2Og04Oe4017<gNeEfm7Kd
0W;D0gLE00Abe@BD00d03@DPm0DeUP03031W6FLI00=W6@9Jf`03F`U_K6m/009k]`9oT@Afm003NaEo
L7m`009oD`AZU0=o<PAo<`Ebe@E^]0Ab/`=B5@ERE00400d03aRA6945>E<459800`cE374<L@023745
=GD8FQD45?D7FS@4Nc@8DSH5=IL3K[@7IYD5KY<4LmX4FSH2MeL6HU@4Og42GWH5Na800gnANa=k4`03
Na<5@G<2>E<3AMD5:?<5@I@2@G@38=<35?D00ced:?<Xl`03:?<269829?<357400`bC1344<@021344
7;<200l305@00b5HHUARE006HU@2MiP00g?JOdmoL`05NmL3:A@00bjo00l03`026EP5>G@26;<20340
0`1C01004@047?D00bCc39<<T`0239<49CH4GYL01GnD<]lbgc;O<GD012TD0QCE0Qcd0a2d0Pbe00@0
403F0=H0eP8Tm0<IN@03Ool01`P:00882P9[>P038?<0e`3G0080ebAoo`00AGoo1DWf17lc00=oLWoo
Ool04Goo1Qbb0V:F0W^a00=Am7;DL]@00g;D0Wme0WmB0gmC0Wm`00=^]7mAOe400WmA17Kd17;D00=g
5G;E19@00P0=1B3d1SFF00<0<6LIIaT00VLI0U[K0fm/0W^g00=oTGmdM_@00gKd0Wm`17mC0VZD17lb
17lc1G;E16jd1G:c0e8E1V9D0P0?00<HTCUC>E<00cUC1ABB00@<e@aa374<L@DeM@QJ5@04LcLDmACe
5?D7FS@4Nc@8DSH6=IL00fjdIYEVU@06IYD4KY<4LmX6FSH00gMGHUARE004HU@4Og42GWH5Na800gnA
Na=k4`03Na<5@G<2>E<3AMD5:?<5@I@3@G@28=<45?D5:?<369800bCc574DL@02574413447;<200l0
0`ac05@0E009HU@01GNHLmYcfWm?Og<01G_G12TD0P0?0QUH1CUd0QRc0`0a0P0@00<04Ace7?D00Qce
00DTl`bC39<<T`0@008U=PENU`04Oi@bgc;O<]l2<GD3:A@35=D27?@34;@00`be0100eP020=H29?@3
6GT01@07Fd/82PP:I^H00V/j0R3c0`3G97oo0015Ool5BOH3Oc<2Og8COol00`0:7;8L/P037;82HYH0
17^aDOAAm57d0g;D00=kKWmeOe800WmB0gmC0Wm`1GmA17Kd17;D0g;E0P0=00<02B3d8?@00R3d1cFF
00<0<6LIIaT00e[K0Vm/0W^g0WnA1GKd0Wm`17mC0VZD17lb17lc17;E1Fjd1W:c00=B5F9DHU@01F9D
00<03@0?69401CUC1ABB0PcE0Paa1CEe1eXE0W<g11Ce1EXd1G/d1e8f00=FEd6e@KD00T6e0SFG00=^
]6JEIYD01VJE16jC0g?J1eXf1f9D17ma0Uif1G/B00=oTG/CNa<00g/C1T5c0SUC0TGE1BSc1D6D1D5d
00@PdaCe5?DDm@DXl`<HTP8Tl`<DL@0539<4<@@a13404@047;<0100?37<0E01D269D00=gV7?JLmX0
0Wm?00=oLbddNmL00g_G12TD00@^_`0?00lIF0HiM08H/`80<@0305<0400A00DLm@@<T`039CINUejG
00ANU`Dbg`8aM@<Y50<De@047?@@]12d4;@23;D00`0@0=H0eP039?@26GT01007Fd/82PP:0f/j0R3c
0`3G97oo0015Ool4BOH4Oc<00gmbOomoo`0BOol00`0:7;8L/P047;800gm_DOAAm002DO@3L]@2OgD3
Oe83Oe<00gm`K[AoD@03Oe44M_@5L]@00g[cL]Ebe@0300d58?@6=IH00e[KIaUW6@02F]/00eYhKfa_
K002NkL00gnAOgAfm004M_@2Og04Oe<2JY@3Oc82Oc<2Nc@5L]D5K[@6L[<00e8EHUARE005HU@00fjD
00lHT@05>E<559823=D23746=GD6FQD2LcL0100A5?DDmACe1EXd1W/d0e8f15IG1T6e2VJE0VjC0g?J
25Xf1f9D1Gma00=NMW/BNa800W/B0WnA17/C00=J4d5c@G<0145c0cUC00=5eBSc:?<00bSc1T6D1D5d
0aCe00<<TbSc:?<00RSc0aRB0RCc0aAa00<<T`@a13400P@a11bc00<03`ac37<00P1D1f9D0fZe00=o
CekVOg<00Rdd0g_G1BTD0P0?00<IF3Ud>G@013Ud0QRc0P0a00<0D`0@01001Ace10bC1UjG00=oU3;O
<]l00c;O0c5e0RTD0aCE00<Lm12d4;@00Q2d00<<]@0@0=H00P3F0bCd00<IN@07Fd/00PP:0f/j0b3c
0P3G97oo0015Ool4BOH4Oc<EOol00`0:7;8L/P037;800e^NNk5Am004DO@2L]@2OgD2Oe83Oe<2Og00
0fjdOe5oD@02Oe44M_@5L]@2N_<017;E00d03@0=1B3d1CFF00A:>5[KF]]W6@9Jf`9_K0=k]`9oM0Af
m09oL0EoD`9ZU09o<P03I[Ik=7/d009k=003IU=beG;E009be@A^]0Mb/`MRE09^U0803`HiD`DDTP8<
e@8<L@DeM@EJ5@Ac=`03014DmACe00EJ=0Ik=003DSIFEeIG00AFE`I1]@YVU@04KY=cfW?JLmX8FSH2
Ok<5HU@6Og45Na800gnANa=k4`03Na<00eXC@G=1L`04@G<3>E<2AMD4:?<6@I@5@G@45?D4:?<46980
0bCc574DL@02574413447;<200l00`ac05@0E007HU@3J[D01EkVOg=9]4Vd;C@017_G12TD0P0?00<I
F3Ud>G@013Ud0QRc0P0a0P1C00<0400A7?D011ce10bC1EjG00=oU2dd<]l00c;O135e00<Y51CE5=D0
0QCE00<Lm12d4;@00Q2d0P0@0P3F0bCd0QUi00=KB`P:20X016/j0b3c0P3G8goo0016Ool3BOH3Oc<0
0gmbOomoo`0DOol37;83Fih7DO@00g]^OgEoM@02Oe83Oe<00gm`K[A^]004Oe44M_@4L]@3N_<00g;E
?IHmUP02?IH0100=8?@Pm23d13FF0dXh0e[K00=JN6m/NkL00W^g00=oTGmdM_@017Kd0Wm`1WmC00AZ
U7lbI[IV]P=k=0=VD`9be@E^]0Mb/`MRE0=^U00400linSWj>OX3>E<559833=D00`aa=GDeM@03=GD5
FQD4LcL00`0A5?DDm@04FS@7Nc@8EUL6@KD9IYD3I]L9FSH2Ok<5HU@6Og42MeP3Na800gnAL_IbmP03
Na<00eXC@G=1L`04@G<4>E<00dGE:?<Xl`02:?<6@I@5@G@01CDc5?DDmACe39<00bSc11RB00<TlaAa
57400QAa10@a11bc00D0DP0?37<<L`1D00IRE0AZ]@04G^IoLdVdBK@2;C@3NmL4:A@012dC00l03aUH
1CUd0aRc0P0a00<0D`0@01001Ace00@8m`bC39<<T`ANU`9oU003;C@bgc;O008bg`DaM@03:A@DeACE
008De@@@]0043;D0403F0=H49?@011UiFd/82RCd16/j0b3c0P3G8goo0016Ool3BOH3Oc<GOol00abb
FiiKWP02Fih00g^aDOAAm005DO@2OgD3Oe83Oe<00gm`K[AoD@03Oe44M_@5L]@4N_<5?IH012dd2?LP
m23d0SFF1DXh0U[K00=JN6m/NkL00VkF0Wmd1GKd0Wm`1WmC00=o<VJfI[H017/d0fIC0W;E1Fjd1g:c
00=VE69DHU@0169D0fjD00=fl`0?>OX013Wj1ABB10cE1CEe15XE1W<g00<04ACe5?D00eXd1g/d00=Z
eeIGEUL01EIG1T6e2FJE0fKG00=bmUXfFSH01UXf0Wnc1F9D1Wma0gMH0W/B00=oTG;fL_H00W;f0UXC
1T5c1CUC1BSc1D6D1D5d00De<aCe5?DDm@bC00@Xl`@HTP@DL@057=<4<@@a134He0047;<00`0?37<<
L`0205@5HU@4J[D015kVOg=9]4Vd0bdd0W_G12TD00@]4`0?00lIF0DiM0<H/`80<@80D`03010YN2Uh
00<Lm@88m`8<T`ANU`9oU08]=0<bg`HaM@@De@D@]0030100eP3F00@Tm0046GUKB`P:I^H4JcX48?<0
0`3GOomoo`0QOol004Ioo`99mP=o<aQoo`<H/`9KWPQAm09oM@9oDPAoD`9^]0AoD@Afm0Ebe0Ajl`03
Og8mUSfF008mUP8]=088m`03=II:>4Xh00E:>003F]]_K6kF00=^eP9oM0Afm09oL0MoD`=V]PAk=0AV
D`03L]E^]6jd009^]0Mb/`9VE0ERE0A^U003M_<03cWj00@inP8iM@<DTP@<e@8=F@<eM@=J5@Mc=`03
014DmACe00=J=0Ik=09Ze`MFE`I1]@QVU@=Ve`9bmPMJ=P=o/`ERE0EoL@EgF003Oi5bmW;f00=bmP9J
4`I1L`DiD`DXl`E1U0E1M08e<`8Dm@8<T`<Xl`@HTP039?<DLAAa008DL@@4<@056=@L/abc7;<03`03
37<00`1DHUARE003HU@3J[D00ekVOg=oL`02BK@3;C@2NmL5:A@00bdC00lIF006>G@36;<00`0a05<0
D`020102:GP37?D22?L239<3GYL00gnD>KL]=002;C@3<]l5<GD45=D00b3C4;@@]0024;@201000`3F
9?@Tm0039?@00e];9?@Y5004JcX48?<20=LROol004Ioo`99mP9o<aUoo`<H/`UAm0=oM@9oDP=oD`03
Og1^]6jd00AoD@Afm0Abe0Ejl`03Og8mUSfF008mUP<]=0032?M:>4Xh00E:>09JN004Kfa^eVkFK]H3
Og@4M_@2Og07Oe<3I[H3Nc@5IU<5K[@7L[<2IU@5HU@4KY@2M_<00`0?>OXinP02>OX4>GD259843=D2
3ET3=GD2FQD7LcL201400aCeFSAJ=006Nc@3J]L7EUL7@KD6IYD4I]L2L_H7FSH3Ok<4HU@5Og46MeP0
0gOHL_IbmP03L_H3FQ<5@G<5>E<00c4c:?<Xl`02:?<5@I@6@G@013Dc5?DDmACe0PbC0RSc11RB00<T
laAa57400QAa00DLd`@a1344<ASD00<L/`05058<L`ac37<0E004HU@4J[D00ekVOg=oL`02BK@4;C@0
0g_G:A@Y5003:A@00bdC00l03`06>G@36;<01@0a05<0D`1C010012Uh00DLm@Sg2?L8m`bC009NU`9o
U004>KL]=2dd;C@3<]l5<GD00bCC5=DDe@025=D44;@012TD0100eP3F12Cd00<INBCd:A@016/j1B3c
00<0egooOol087oo0017Ool00dWfOc=oo`0IOol46;<8DO@2OgD3Oe83Oe<3K[@3Oe44M_@5L]@5N_<0
0gmb?IHmUP03?IH3;C@00`SgBSQ:>003BSP3FWP4K]H2Og@5M_@2Og06Oe<3I[H4Nc@5IU<00gKCK[A^
]002K[@7L[<2IU@5HU@4KY@2M_<00eTP>OXinP03>OX5>GD43=D43ET00cEeFQEc=`08LcL20142FS@6
Nc@4J]L6EUL7@KD5IYD4I]L4L_H5FSH5Ok<3HU@5Og46MeP00gOHL_IbmP02L_H4FQ<5@G<5>E<2<C<3
:?<6@I@5@G@2=C<25?D239<2:?<56984574011cC1344<@@a0QSD0Qbc00<0DP0?37<00Pac00@0E69D
HUARE0AZ]@03G^IoLgmc00=9]0<]=09ke`@Y5003;A<03`0?00HiM0@H/`<0D`03010YN2Uh00<YN0@8
m`9NU`9oU08i]`<]=08bg`DaM@039=<DeACE008De@038=<@]12d008@]003:A@0eP3F00@Tm09kE@8Y
50A[>P@Pl`030=Moogoo021oo`00Agoo00=o<gooOol06Goo11Rc257d0Wme0WmB0gmC00=oU6jdK[@0
17mA17Kd1G;D17[c0Wmb1CfF12dd0dXh15Yh00=_K6kFK]H00VkF0Wmd1GKd0Wm`1GmC16Jf17/d1FIC
00=fdfjdK[@00Vjd1W:c16ID0f9D16jD17Kc00<03cWj>OX00SWj1CUe0SUd0`cE10eI00=J5G<gLcL0
1W<g00E=e3Ud>G@DmEXd00Ek=0EZe`MFE`I1]@AVU@EVe`AbmPEJ=PEo/`=RE0AoL@IgF003MmQbmW;f
00=bmPAJ4`E1L`HiD`04<C<XlbSc:?<6@I@5@G@3=C<01ACe39<<T`bC:?<01ARB11Aa0QcC0P@a0aSD
0Qbc00D03`ac37<<L`1D00=RE0AZ]@9oL`A9]0@]=003NmLY52TD008Y508]4`0300lIF3Ud00@iM0@H
/`050340D`1C05<04005:GP42?L00ejGOiAoU002>KL4;C@00c;O<GDaM@04<GD45=D00b3C4;@@]002
4;@00bTD0100eP049?@2NeD3:A@3JcX58?<ROol006Aoo`<H/`MAm0=oM@9oDP9oD`04OiA^]6jdK[@4
Oe44M_@5L]@4N_<2Og800g;D?IHmUP02?IH5;C@00dXhFWQJN003FWP016m/K]I^eVkF0gmd17Kd0Wm`
1WmC16Jf0g/d1FIC0gKC0Vjd1g:c16ID0f9D16jD17Kc00<Hm3Wj>OX00SWj1CUe13Ud00<<e@eI3ET0
0`eI1g<g0TgD0cUd1G/d1f[G1UIG1d6e0VJE1VKG17;f1EXf1Gnc0V9D17ma1WMH0WOH1G;f15XC1T5c
1CUC0S4c0RSc1T6D1D5d0cDc0QCe0PbC00<XlaRB69800aRB00@4LaAa574DL@8Ld`84<@<He08L/`05
058<L`ac37=oM@02HU@5J[D2Og<4BK@5;C@4:A@2;A<200l5>G@56;<305<00`0@:GPYN004:GP27[h0
0cff2?L8m`03>KL4;C@00c;O<GDaM@04<GD012CC5=DDeACE0R3C0a2d0RTD00<0eRCd9?@00RCd0W]E
00=_n2TD:A@00f/j1B3c00<0egooOol00goo0bA^6Goo001TOol36;<7DO@3OgD2Oe800gmCOiAoU003
K[@3Oe44M_@5L]@5N_<2Og800g;D?IHmUP02?IH5;C@6FWP4K]H2Og@5M_@2Og05Oe<4I[H4Nc@5IU<3
M]<2K[@7L[<4IU@3HU@4KY@4M_<00eTP6?@inP03>OX5>GD5>G@53ET5LcL3CM@5>G@3Nc@7J]L6EUL7
@KD00fJEI]MVe`04I]L6L_H3FSH6Ok<2HU@4Og45MeP2MmP5L_H5FQ<6@G<5>E<2<C<2:?<6@I@5@G@4
=C<01ACe39<<T`bC:?<01ARB11Aa0QcC0P@a0aSD00@L/`1B37<<L`9oM@0305ARE6Ze00=Z]@03G^Io
Lgmc00A9]0D]=0@Y50<]4`0400lm]cfg?KL3>G@46;<0124f05<0D`1C1bUh00Ag53ff?KH8T`<i]`D]
=003<]laMC5e00<aM@049=<DeACE5=D28=<34;@3:A@39?@2NeD2KoP3:A@2JcX68?<2Ool696hIOol0
06Aoo`<H/`IAm0=oM@9oDP04Oe=oU7nDOi@3K[@3Oe44M_@5L]@4N_<3Og800g;D?IHmUP02?IH6;C@4
FWP00fm/K]I^eP02K]H2Og@5M_@2Og04Oe<5I[H4Nc@5IU<3M]<2K[@6L[<5IU@2HU@5KY@4M_<00eTP
6?@inP03>OX5>GD5>G@3@KD33ET3LcL5CM@5>G@00g/dJ]MZe`06J]L6EUL6@KD00eYgI]MVe`05I]L6
L_H3FSH6Ok<2HU@3Og45MeP3MmP5L_H5FQ<6@G<5>E<3<C<2:?<5@I@5@G@4=C<01ACe39<<T`bC:?<0
1ARB00@4LaAa574DL@8Ld`84<@<He0047;<0DP0?37<3OgD00f9DJ[EZ]@02J[D00ekVOg=oL`04BK@5
;C@0123B:A@Y52TD0bdC00<03cfg?KL013fg1ARc00@Q=P1C05<040DYN09g50<m]P0429<i]cVg>KL5
;C@5<GD29=<35=D28=<34;@2:A@00`3F9?@Tm002NeD2KoP4:A@00f/j8?<Pl`048?<2Ool696hIOol0
06Aoo`@H/`EAm0=oM@9oDP=oU0=^]0=oD@Efm0Ebe0Ajl`9oLP9be0@mUPH]=0AJN0A^eP=oM0Afm09o
L0EoD`EV]P=k=0IVD`Afd`Mb/`EVE09RE0E^U0Efl`8Hm0<inPDiM@DiM0I1]@033EUc=dgD00E=e0Di
M0YZe`EFE`E1]@=JM`EVe`MbmP9J=PQo/`04HUAoLD7G0005MeP2MmP5L_H6FQ<6@G<5>E<4<C<00bSc
@IA1U003@I@5@G@5=C<439<5698010Ac574DLAAa0acC00<4<ASD6=@00QSD00<L/`1B37<00gme1FZe
0gmc14Vd1Bdd00<PdRTD:A@00RTD0bdC00<03cfg?KL00cfg1ARc0R4f0P1C0RUh0e:J0WLD0cff00@8
TcVg>KLi]`D]=0DaM@8Td`<De@8Pd`<@]08Y50030=HTm7]E009kE@9_n0@Y509[>PDPl`9oo`HTKQUo
o`00I7oo11Rc157d17me0WmB0gnD0fjd0gmA1GKd17;D1G[c0Wmb0W;D1CfF1Bdd15Yh16kF0Wmd1GKd
0Wm`17mC1FJf17/d1VIC17KC1g:c1VID00=RE6jDKY@00VjD1WKc0QSd00<03cWj>OX01CUe1SUd1T6e
1dgD1SUd2F[G0Rfh15IG0d6e1EYg16KG27;f00=J=WncGWH0147G0Wnc00=oLD7G@ML00P000gMH0gOH
1G;f1UXC1T5c1CUC134c00<Xld6D@I@00d6D1D5d1CDc00@Dm@bC39<<T`DHTP84L`8DL@<Ld`03134H
e1SD00<He0<0DP9oM@EZ]@=oL`E9]0D]=0@Y50<]4`0300lm]cfg00<m]`03=E@H/aRc008H/`<Q=P03
05=BVU:J00=BVP9g50<m]P88T`8i]`D]=003014aMC5e008aM@8Td`<De@<Pd`8@]0<Y50049?AkEG]E
NeD2KoP5:A@00f/j8?<Pl`048?<00goo96hTKP0396hJOol006Eoo`<H/`AAm0AoM@04Oe9oU7nDOi@4
K[@3Oe44M_@5L]@5N_<2Og83L]@4?IH6;C@2FWP016m/K]I^eVkF0gmd1GKd0Wm`0WmC00=oTFJfI[H0
16Jf17/d1FIC1GKC00=flg:cL[<00g:c1fID1FjD1WKc00AI81Sd6?@03@8inP@iM@HiM0I1]@M=e0Hi
M0QZe`9Vf0<]^09FE`91]@IJM`=Ve`UbmP03FSINMUif00Q1e`@00003MeQgf7OH009gf0EbmPIJ4`I1
L`DiD`Da<`I1U0E1M0De<`<<T`03;C@HTQRB008HTP84L`8DL@@Ld`DHe0@0DP03OgEZ]FZe009Z]@03
G^IoLgmc00I9]0D]=0048=8Y52TD:A@4;A<6?KL00cED6;<H/`026;<38CH0101CDYYBVU:J0gLD0cff
0PRC0SVg1Rdd1C5e0RCC0QCE0b3C0Q2d12TD0g]E00<]=FohKoP01BTD1R3c00<<02A^96h00bA^6Woo
001UOol00`0=6;<H/`04DO@3OgD2Oe83Oi@3K[@3Oe45M_@5L]@4N_<2Og84L]@4?IH6;C@2FWP4K]H3
Og@5M_@00gm`Oe=oT@02Oi400fZDI[IV]P03I[H3Nc@6IU<5M]<00gKcL[=b/`03L[<7IU@5KY@6M_<0
15TP6?@Hm1Sd0SWj1CUe1CUd1T6e1dgD1cUd1V[G0fKH1Bfh00=1]EYgFWL01UYg0VKG2G;f0Uif0Wmc
1d7G0`001ElL1G;f00=5meXCFQ<01EXC1D5c1SUC134c1T6D1D5d1CDc10bC00<]=1RB69800QRB0PAc
0QAa0acC00@4<ASD6=@He09=m@<0DPEZ]@=oL`I9]0D]=0048=8Y52TD:A@4;A<00`0??KLm]`03?KL2
=E@36;<48CH00`1CDYYBVP02Ma@00cfE?KHm]P02?KH229<2>KL5;C@5<GD29=<35=D38=<00a2d:A@Y
5003:A@00g]E;CD]=@02KoP5:A@68?<00``096hTKP0396hJOol006Eoo`0300hH/aRc00=Am0AoM@03
Oe9B=gnD009oU0=^]0=oD@Efm0Ebe0Ajl`9oLPAbe0@mUPH]=09JN0A^eP=oM0Afm09oL0=oT@=ZU0=V
]PAk=0IVD`Afd`=fl`Ab/`MVE0E^U0Ifl`06HS<Hm1Sd6?@03CWj1CUe1CUd1d6e1TgD23Ud16[G16KH
1Bfh2UYg00=Veg;fL_H01W;f0eif0Wmc1T7G0P001UlL0W?J17;f00=5meXCFQ<01EXC1D5c1SUC134c
00<iDd6D@I@00d6D1D5d1CDc00DH/PbC39<<Tbdd00@HTP84L`8DL@@Ld`036=A=mDge00==m@<0DPAZ
]@03BQPU=TWf00I9]0D]=0048=8Y52TD:A@4;A<00`0??KLm]`03?KL3=E@26;<58CH2DYX2Ma@2?ID3
?KH229<2>KL5;C@00`0A<GDaM@02<GD39=<25=D38=<24;@4:A@01CaX;CD]=BdeKoP01BTD00<Y=B3c
8?<00b3c00<<02A^96h00bA^6Woo001UOol00`0>00dH/`03DO@4OgD0158gOiAoU7nD16jd0gmA17Kd
1G;D1G[c0Wmb1G;D0cfF1bdd00A_K6kFK]I^eP=oM0Efm09oL0=oT@=ZU0=V]PAk=0IVD`Afd`=fl`=b
/`QVE003NaA^U6jD009^U0Efl`9R<`@Hm00300dinSUe00<iM@HiM0I1]@I=e0PiM0=Ze`IVf0D]^0UJ
M`QbmPANMP9oL`I1e`MO70AcfP9bmP95m`MJ4`E1L`HiD`@a<`8iD`A1U0E1M0De<`046;8<T`bC39<2
;C@3698217<257447=<6COD30584J[D00dXH9CHU=P06BK@5;C@28=82:A@5;A<5?KL3=E@36;<58CH3
Ma@4?ID01Cff29<8T`RC>KL01Bdd00<04C5e<GD00S5e0bCC0QCE123C00H@]2TD:A@Y51cC?6P3;CD0
0foh:A@Y5004:A@00bTe8?<Pl`028?<00``096hTKP0396hJOol006Eoo`803P8H/`03DOAoMGme009o
M@03Oe9B=gnD009oU0A^]09oD@Efm0Ebe0Ajl`9oLPIbe003M_@mUSfF00H]=0E^eP=oM0Efm003Og1o
MGnA009oT@AZU09V]P=k=0IVD`Efd`Afl`9b/`MVE09k50=^U0Ifl`9R<`@Hm0803@@iM@HiM0I1]@M=
e0PiM003J]MVf6KH00EVf0D]^0UJM`03MgUbmW;f00AbmPANMPAoL`A1e`MO70EcfP9bmP95m`MJ4`I1
L`DiD`Da<`8iD`=1U0E1M0He<`<<T`<]=08HTP<4L`03574LdacC008Ld`M=m@80DP=Z]@04G^I:62Df
9CH2@KH5BK@4;C@28=83:A@4;A<00`0??KLm]`02?KL4=E@26;<58CH3Ma@5?ID013ff29<8TcVg1Rdd
00@04C5e<GDaM@@Td`035=DPdb3C008Pd`064;@Y52TD:A@LdcaX12de00=_n2TD:A@00bTD0RTe123c
12A^00=SOGooOol067oo001UOol200h00`0=6;=Am003OgD2DSL4Oi@3K[@3Oe45M_@5L]@4N_<2Og86
L]@2M_@2?IH4;C@2@I@4K]H3Og@5M_@017m`Oi5oTGnA1VZD17/d1VIC1GKC17Kc0W:c1fID0W/D0fjD
1WKc0f8c0aSd00<0<P0=>GD013Ue1CUd1T6e1dgD23Ud26KH1Bfh25Yg0gMi17;f1Eif17mc147G00=k
4elLGa`00elL1g?J00AbmTGgAOM5m`IJ4`I1L`DiD`Da<`<iD`91U0E1M0He<`036;8<T`bC00@]=005
6984L`Ac17<DL@057=<7COD20582J[D00dXH9CHU=P029CH4@KH2BK@4;C@28=83:A@5;A<5?KL4=E@0
0aRc8CHQ=P048CH2Ma@6?ID329<6;C@0100A<GDaMC5e12CC00<DeB3C8=<00b3C0bTD00<LdcaX;CD0
12de1BTD0bTe0b3c12A^00=SOGooOol067oo001VOol200h00`0=DOAB=`04DSL3Oi@4K[@3Oe44M_@5
L]@5N_<2Og86L]@2M_@0100=?IH]=2dd1D6D0VkF0gmd1GKd00=oL7meOi400WnA1VZD0W;D0W/d1VIC
17KC1WKc26ID0g/D0VjD1GKc168c11Sd0P0=13Ue1SUd1D6e1dgD23Ud00=gfFKHI]P01VKH1Bfh1UYg
17Mi0g;f1Uif17mc0d7G00=RUg/CNa<00elL1W?J00A=/bdC;A<]4`95m`IJ4`95U0A1L`DiD`Da<`@i
D`91U0A1M0He<`046;8<T`bC39<3;C@2698317<00aAa7=<Ld`027=<7COD01GnA059Z]FZeBQP012Df
1T6f1Bdd0R3B0RTD1BdC1Cfg1CED00<H/b4f8CH00b4f0WLD1SfE0`RC00<i]bdd;C@00bdd00<04C5e
<GD00S5e0bCC0QCE123C00<@]2TD7=<00QcC00<lJ2de;CD00Rde1BTD0bTe0b3c00D<02A^96hTKV=m
01Yoo`00IWoo0P0>1e8g0gnD16jd0WmA0WLg0gKd1G;D17[c0Wmb1W;D0gKd00<03@08;C@01T6D0VkF
0Wmd00=WSeiEGUD00gKd00=oL7meOi400WnA1VZD0g;D1fIC17KC1WKc1fID17/D0VjD1GKc168c11Sd
00<0<P0=0=H00cUe1SUd1D6e1dgD1cUd0gOI1VKH00=FEbeg;GL00bfh1UYg1GMi00=bmUifGWH015if
1Gmc0d7G17/C00=O77?JLmX00W?J00AcKDfcCK==/`<]4`95m`IJ4`A5U091L`HiD`@a<`DiD`03@IA1
M45d0091M0He<`8H/P8<T`@]=0056984L`Ac17<DL@047=<7COD01GnA059Z]FZeBQP012Df1T6f1Bdd
0R3B0RTD1BdC00<Tlcfg?KL00Sfg1SED1B4f00=g52YM?ID01CfE00@e<`RC29<8T`H]=004014aMC5e
<GD49=<00aCE8=<Pd`038=<01BTD7=<LdacC?6P01Bde1BTD0bTe0R3c00D<02A^96hTKV=m01Yoo`00
IWoo0`0>1E8g0gnD1Fjd0WmA0gLg0WKd1G;D17[c0Wmb1W;D0gKd00<03@08@I@01d6D00A^eVN?IhmW
S`=NE@9fm004OgEoTGnAOi47JY@3L]@7IU<4M]<6M_<7IU@4Na@2KY@4M_<6HS<36?@203820=H2>GD6
>G@6@KD6CM@6>G@4MmT4I]P4EUL2;GL3;KP4FWL5MgT00eigGWINMP05GWH6Og<00d7GHYMk4`03Na<3
Og800gOhLfe=/`03CK<4;A<00dGgFQ=J4`03FQ<00e7DAIA5U004AI@6>E<4<C<6>E<5@G@5=C<26;82
39<5;C@417<47=<7COD2Oi400`1BJ[E:60059CH5@KH00`0a;C@]=002;C@28=82:A@5;A<00bCc?KLm
]`02?KL6=E@3:Yh0134c8CHQ=RYM1SfE00@e<`RC29<8T`8e]`@]=004014aMC5e<GD49=<00aCE8=<P
d`028=<2LgT47=<5;CD00aTF:A@Y5002:A@4:CD0123c300TKRA^0V=m6Woo001VOol300h5DSL3Oi@4
K[@2Oe45McL6L]@4N_<2Og800fIdL]Abe003L]@3M_@00`0=00Q1U007@I@3Ihl5GUD00gm`OgEoT@02
Oi46JY@4L]@6IU<5M]<6M_<7IU@5Na@5M_<7HS<36?@01@0b00d0eP3F>GD01SUd1T6e1TgD1CUd1WOI
00=Vf5IGEUL015IG12eg00@]^5YgFWMJM`EgN@=NM`INMPIoL`03@MMRUg/C00=k4`=oLP03MoQ=/dfc
00A=/`<]4`03AOMJ4eXC009J4`=Ae0E5U0HiD`@a<`HiD`E1M0He<`8H/P0339<]=2dd00<]=0@4L`DL
d`E=m@AoT@9:6003?E<U=RDf008U=PI1]P@]=0<PdP03:A@]4bdC00@]4`049?<m]cfg?KL7=E@2:Yh2
<C<3:Ud6?ID00cDc29<8T`03=KL3;C@20142<GD59=<48=<00g=i7=<Ld`037=<5;CD26AH3:A@5:CD0
0b3c96hTKP02HgdJOol006Ioo`<03PEB=`=oU0A^]09oD@Eg=`03LaMbe7;D009be0Ejl`04Og9VM6Id
IW@3L]@4M_@00fYd00Q1U007@I@2Ihl6GUD2OgD3Oi46JY@4L]@6IU<4M]<6M_<00g/CIUAVE004IU@6
Na@5M_<6HS<016YcEO<Hm1Sd0P0b0`3F00<iMCUd>G@013Ud1D6e1TgD13Ud1WOI00=JVEIGEUL01EIG
1Beg0eYg17Mi15ig1Eif1gmc00=RUg/CNa<00g/C0gmb00=gn4fcCK<014fc12dC00=5meXCFQ<0157D
1DFD00<eDcUC>E<00cUC134c1SUC00<@]45d@G@00T5d1SDc0QRb00<<Tbdd;C@00bdd00D<]@Ac17<4
L`Be00@Ld`E=m@EoT@03?I@mDceC00<U=PI1]P@]=0<PdP8Y50D]4`039?<m]cfg008m]`LeE004:Yha
<c4c<C<2:Ud6?ID2=C<229<4=KL00bdd01404@02<GD59=<38=<2LgT57=<00caX;CD]=@03;CD26AH3
:A@5:CD296h2HgdJOol006Moo`<03P=B=`=oU0E^]003Oe5g=gLg00Ag=`9c5`=be0Ajl`9oLP=VM0=b
e0Afm003JW@0266P00I1U09WS`MNE@04OgEoTGnAOi47JY@3L]@2L[<5IU<4M]<6M_<2Na<5IU@6Na@0
169DM_=flgKc1f8c0VYc00AElaSd0380<P@0ePHiM0E1]@M=e0<iM0Egf@9JV@QFE`D]M`03FWMgNGMi
009gN@INM`ANMPMoL`03HYMk4g/C009k4`=oLP03Jfe9/dfc00E=/`@]4`03AOMJ4eXC00AAe0E5U08e
D`@iD`Da<`HiD`A1M0He<`8H/P8<T`D]=0053;D4L`Ac17<4]@037=<5COD5Oi42?I@2?E<39CH5@KH0
100a;C@]=2dd0b3B0RTD1BdC0RCc0cfg1cED00@mUC4c<C<a<`8ZG@HmU@8e<`88T`De]`04;C@04C5e
<GD59=<00aCE8=<Pd`02LgT00eig7=<Ld`037=<5;CD26AH3:A@5:CD296h00f=m801oo`0IOol006Qo
o`803P=B=`9oU08]E@A^]003Oe5g=gLg00=g=`Ac5`9be0Ajl`03Og9oTVId00=VM09be0Afm003JW@0
200800I1U003IhmNEEiE00ENE@9oM@=oT@IZU0Abe09b/`EVD`Afd`Ifl`9k4`EVE0Ik509RE09fl`MR
<`9ZL`9El`036?@0<P0b00<0ePI2O0037CI1]D6e0091]@M=e08iM0Agf@EJV@MFE`P]M`03MgUNMeig
00ENM`ANMPIoL`9RU`Ak4`=oLP03Jfe9/dfc00E=/`D]4`03FQ=Ae57D00=Ae0I5U08eD`<iD`Da<`Hi
D`044;A1M45d@G@6=C<36;800`bC;C@]=003;C@01@be17<4L`Ac1;D00acC14ge1GnA0cfD0ceC0RDf
1D6f00<0<Bdd;C@00Rdd0b3B00<Y52dC;A<00bdC0RCc0cfg1cED0SfE0c4c00<ZGCfE?ID013fE0cDc
00<8TcFg=KL013Fg0P0A0S5e1BCC00DPdg=iLgT]=Eig00DLd`8EVP@]=@8I5P8Y50HY=@03HgdP0200
01Yoo`00JGoo00<03U8gDSL00WnD0beE0fjd00=oDGLgMcL00gLg1W<G1G[c00=oTVIdIW@016Id17Kd
0VYd00<03@08@I@0146D00=WSeiEGUD01UiE0Wme0gnA1VZD17;D0W:c1FIC17KC1GKc0g/C16ID1W/D
169D00=flf8cHS<01F8c0VYc0eGc0P0b0RUg0P3F1D9l0Qdf0d6e1dgD00<iM7OIMmT00WOI1UZI1eIG
1beg00=FEeigGWL01Uig0eif1Wmc0f:G17/C0gmb0TVc1Tfc1BdC1U7D1TFD0cEC0SUC1C4c1SUC00@@
]45d@GA1M0He<`<H/P0339<]=2dd00<]=08<]@84L`84]@<Ld`==m@AoT@@mU0@mD`039CI1]T6f00=1
]P03034]=2dd008]=0<PdP03:A@]4bdC00<]4`<Tl`8m]`HeE0<mU@<a<`03:UdmUCfE00@mU@<e<`88
T`De]`91]@8aM@DTd`=cN@8]=@HLd`<EVP8]=@<I5P03:A@Y=BTe00DY=@8P01Yoo`00JWoo00<03U8g
Oi@01BeE0Vjd00=oDGLgMcL00gLg1W<G0eiE00=jlgmbOi801VId00AoL7KdM_Afm09ZM00300d0246D
00A1U0UNE@04OgEoTGnAOi47JY@4L]@2L[<4IU<4M]<6M_<3Na<4IU@6Na@4HU@8HS<2JW<3EO<30382
:GL20=H5@W`27CH2@KD6CM@5BST7FYT8EUL5;GL2EUL9GWL2GWH5Og<3HYL4Na<3Og800f]]BK=9/`06
CK<5;A<6DM@6AI@4=E<2>E<4<C<6>E<24;@2@G@6=C<46;86;C@23;D217<21;D27=<3COD3Oi45?I@5
?E<00bDf@KI1]P03@KH0100a;C@]=2dd0b3B00<Y52dC;A<012dC0RCc0Sfg1SED0cfE134c00<ZGCfE
?ID00cfE13Dc00<8TcFg=KL00cFg0T6e0S5e1RCC0W=i0Rde0dGF0acC11FJ00<]=ATF6AH00QTF00<Y
52Te:CD012Te00<P07ooOol06Goo001[Ool00e8gOol]E@04;ED2K[@00gmAMcMg=`02McL7LaL4GUD2
Oi86IW@2Og02M_@3JW@00`08@IA1U002@I@00fN?GUENE@06GUD2OgD3Oi46JY@4L]@3L[<4IU<4M]<6
M_<3Na<4IU@5Na@5HU@7HS<3JW<4EO<20384:GL5@W`37CH2@KD4CM@7BST7FYT7EUL4;GL4EUL8GWL2
GWH4Og<4HYL4Na<3Og83BK<7CK<4;A<7DM@5AI@5=E<00cUC<C<a<`02<C<7>E<24;@00d5d=C<e<`05
=C<36;86;C@33;D01@Ac1;D4]@Be7=<00Tge0gnA00=9mSfD?I@00cfD1SeC1D6f00@0<Bdd;C@]=0@P
dPH]4`<Tl`8m]`@eE0@mU@@a<`03:UdmUCfE00<mU@De<`He]`91]@03<GDTdbCC00DTd`<]=@I5eP03
7=<EVQFJ00<EVP<I5P03D_`Y=BTe00DY=A]oo`00KGoo1BeE0Vjd1GLg1W<G1EiE00=oTVIdIW@01FId
0gm`16Yd00<0246D@I@00T6D00=k50P0GUD01UiE0Wme0gnA1VZD17;D17:c0fIC17KC1WKc0g/C0fID
1W/D1F9D1f8c0fYc1EGc00<0<RUg:GL00bUg149l11df00=1]DgDCM@00W<h1dXi1eZI1eIG0beg1EIG
2Eig17mc1F:G17/C0gmb0dVc1dfc12dC1e7D1DFD1SEC134c1cUC0Q2d0T5d1SDc0aRb00<<Tbdd;C@0
0bdd0`be00D4L`Be1;D4]AcC009=m@9oT@99mPDmU0HmD`E1]P04034]=2dd;C@48=86;A<39?<2?KL4
=E@4?ID5<C<6?ID4=C<00`RC=KLe]`03=KL2@KD00c5e9=<Td`049=<5;CD6AMH2<MT35IX8D_`NOol0
06ioo`D]E@03Oe5g=gLg009g=`Ic5`ENE@9oTPIVM0AoL0AZM00700Q1U46D@IAWSg/D20001UiE0gme
0WnA1fZD17;D17:c0fIC17KC1GKc17/C0fID1G/D1F9D0VjC1V8c0fYc1EGc0P0b1BUg149l11df00==
e7<hLcP00W<h1dXi1UZI25IG00<]MeIGEUL015IG25ig0f?j00<006:GHYL00f:G17/C17mb0dVc1dfc
1BdC1U7D1DFD1SEC1C4c1SUC0a2d00=1M3Dc=C<013Dc11Rb1Bdd10be00P4L`Be1;D4]AcCCOEoTCeC
0TWf1CfD1SeC00<iDd6f@KH00T6f0P0a0Rdd123B00<Y52dC;A<00bdC12Cc00Dm]cED=E@eE7_E00Dm
U@@a<`HmU@De<`De]`=1]@DTd`03AOL]=Bde00<]=@M5eP<af@8EVPIBo1moo`00KWoo0beE0RLj17Lg
1g<G1EiE0WnB1VId17m`1VYd0T6D0W/D00<03EiEGUD015iE0Wme0gnA1VZD1G;D17:c0VIC1GKC1GKc
17/C0fID1G/D1F9D0VjC1V8c0fYc1UGc00<0<RUg:GL012Ug0d9l1Adf17<h1dXi1eZI1EIG0SnL25IG
1Uig0f?j00=BF000000016:G17/C0gmb14Vc1dfc1BdC1U7D1TFD1CEC1C4c1SUC0a2d00=1M3Dc=C<0
13Dc11Rb0d6f0bdd10be0PBe0U<M00=oTCeC?E<00TWf1SfD1CeC0SUC0d6f0P0a0Rdd1B3B1BdC12Cc
00Hm]cED=E@eE7_E<C<4?ID4<C<00bCd?IDmU@03?ID5=C<5=KL3@KD0135e9=<TdbCC0Woo00=5mbde
;CD00Rde1dGF137I00<EVU;lD_`00U;l8Goo001bOol39AD2McL6LaL6GUD00gnBIWAVM005IW@3Og02
IW@5JW@01D6DNaAk57/DID001EiE0gme0gnA1VZD17;D1G:c0VIC17KC1WKc1G/C00=VE7/DNa@017/D
1F9D0VjC1F8c1FYc1EGc00<0<RUg:GL00bUg0VLK0T9l11df1W<h1dXi1UZI0UIG1CnL25IG1Eig0f?j
0U9H0P0016:G17/C0gmb14Vc1dfc1BdC1U7D1TFD1CEC1C4c1SUC112d1SDc11Rb1T6f1@be0e<M00AA
mCeC?E<mD`99mPDmU0DmD`8iD`A1]P80<@8]=0@PdPD]4`DTl`<eE003AK@a<cfE00<mU@Da<`DmU@De
<`035=De]cFg00<e]`91]@03<GDTdbCC00Aoo`D]=@M5ePDaf@03D_aoogoo025oo`00LWoo1RDE17<G
1UiE0WnB1VId17m`0VId1FYd00I1U7/DNaAk56Yc2004GUD3OgD2Oi42LkX5JY@4L]@5L[<2IU<4M]<5
M_<6Na<00fIDNaAk5003Na@6HU@2KY<5HS<5JW<5EO<00fjD038YM`02:GL4Ia/0149l7CHM=Qdf1g<h
1TXi00=FoDIlAW`024Il13nL1eIG15ig0f?j0e9H00=k]`00HYL00f:G17/C0gmb1DVc1Tfc1BdC1U7D
1TFD1CEC1C4c1cUC0a2d0SgG1CDc11Rb246f0`be0U<M00=AmCeC?E<00SeC00=9mSfD?I@00cfD1SeC
0SUC0d6f0P0a0Rdd123B1RdC12Cc00@m]cEDNmE5]08a<`<mU@Da<`039?@mUCfE008mU@He<`035=De
]cFg008e]`=1]@039==oogoo00Aoo`@]=@M5eP@afBEoo`00Lgoo1RDE0g<G1UiE0WnB1VId17m`0VId
1FYd17/D00=ZL`0=GUD00eiE0Wme0WnA0g>j16ZD1G;D1W:c00=VDgKCM]<00WKC1GKc1W/C00=VE7/D
Na@00g/D1F9D0fjC1F8c1FYc15Gc0fjD00<YMfLKIa/01FLK00=2O1df7CH027<h0TXi1EKm24Il0Vnl
0cnL25IG0Uig0f?j0e9H0g^g00<006:GHYL017/C17mb1DVc1dfc12dC1e7D1DFD1SEC134c1cUC0a2d
1CgG0SDc11Rb246f0f[G00<<]E<MDOD01CeC1CfD1SeC0cUC0T6f0P0a0Rdd123B00<]EBdC;A<00bdC
1BCc00<eE2CcAK@00S4c0cfE1C4c00<Tm3fE?ID00SfE1SDc00<DeCFg=KL00SFg146e1goo0bde1dGF
0c7I9Woo001cOol79AD00g<GGUENE@05GUD00gnBIWAVM005IW@3Og03IW@5JW@4Na@00fYc00eNE@02
GUD3OgD00gnALkYc^P02LkX4JY@4L]@7L[<00fICM]=fd`02M]<5M_<6Na<5Na@6HU@3KY<5HS<5JW<4
EO<4KY@8Ia/00adfLcQc>006LcP00eYhE_eFo@06E_d6AW`4Kk`2?i`8EUL00eigHoYBF005DUP3NkL0
0`00HYMRU`04Na<3Og86BK<7CK<4;A<7DM@5AI@6=E<4<C<6>E<00eHe4;@@]0024;@6?ML46;88@KH0
17]fJ]MZef[G0U7e1CeC1CfD1SeC13UC00E1]P0a0340<Bdd00DPdP03;ED]4bdC008]4`LTl`04AK@a
<c4c<C<2?ID5<C<29?@4?ID5=C<25=D3=KL3@KD9Ool3;CD7AMH00c7IOomoo`0UOol007=oo`HU5@03
JgaNEEiE00ENE@9oTPMVM0=oL0AVM0=ZM0Ak509ZL`0400eNEEiEGUD3OgD00gnALkYc^P03LkX3JY@4
L]@7L[<4M]<6M_<6Na<3FS@2Na@6HU@3KY<5HS<5JW<4EO<5KY@7Ia/203<6LcP3FWP7E_d5AW`4Kk`2
Jo`2?i`6EUL4F_/4DUP5NkL2HYL4Na<3Og86BK<7CK<4;A<7DM@6AI@5=E<4<C<5>E<2ESD012de4;@@
]12d1SgG11Rb1d6f0g]f0V[G0U7e1CeC00<a<cfD?I@00SfD1SeC13UC00E1]P0a0340<Bdd00DPdP8]
E@<]4`HTl`95]0<a<`<mU@Da<`039?@mUCfE008mU@De<`<De@8e]`=1]@Yoo`8]=@I5eRUoo`00Lgoo
1BDE0V]l1eiE0WnB1VId17m`16Id0fYd17/D0fYc0UiE0gme00=oTG>jLkX017>j0VZD1G;D1g:c17KC
1GKc1g/C15Xd1f9D16jC0f8c1VYc0eGc1VjD00=J4fLKIa/01FLK0P0c0g<h1UYh1eKm0dIl16nl0f_l
0SnL1EIG1E[k159H1G^g00<007/CNa<00W/C17mb1TVc1dfc12dC1e7D1TFD1CEC1C4c0cUC0eHe0Rde
0Q2d1SgG00@M5ARb6;8H/PM1]P=kMP9Ze`9Am@DmD`03<C<mU3fD008mU0HmD`DiD`04@KH0<@0a;C@5
8=83;ED2;A<59?<3AK@3<C<3?ID5<C<29?@3?ID6=C<25=D3=KL2@KD;Ool00bdeAMI5eP03AMHZOol0
07Aoo`8U5@E[O0INE@03Oi9VM6Id00EVM0=oL0EVM0=ZM0Ak50=ZL`0400eNEGmeOgD4M]<0104hLkYc
^W>j0VZD1G;D1g:c00AkE7KCM]=fd`Efl`Ik4`EJ=0MRE0A^T`=R<`IZL`=El`I^U09J4`=W6`8Y=@05
M_<0<`0c03=c>008FWP7E_d00dIlKka__002Kk`3Jo`2Jm`00cnLEUMFE`02EUL00f_LF_]Jn`03F_/3
DUP5NkL3BI<3Na<3Og800f9DBK=9/`04BK<7CK<00bTC;A<]4`02;A<6DM@6AI@5=E<5<C<2>E<5ESD2
;CD24;@6?ML011dE6;8H/QRb1D6f1G]f157e1CeC00<a<cfD?I@00SfD1CeC1SUC0`0a1R3B0beE0RdC
0bCc00=cfTFdAK@00TFd0c4c0SfE1C4c0bCd0SfE1SDc0aCE0SFg0T6e37oo00<]=DGFAMH0;7oo001d
Ool00bDEJga[O004Jg`5GUD2Oi87IW@3Og05IW@2JW@4Na@5JW<00eiEM]=fd`05M]<20CP2LkX00fZD
L]Abe002L]@7L[<3Ne@2M]<5M_<6Na<5FS@6HU@5KY<3HS<6JW<3EO<6KY@2FQ<4:CD3M_<203<9FWP4
LgX00flG8QdR7@038Qd016nlJoa[o6_l16_L00@oW5IGEUM[g0A=mP=Jn`03DUQk]g^g009k]`I9T`9k
4`9oLP9RE0I9/`I=/`03FQ@Y4bdC00<]4`IAe0I5U0DeD`Da<`03>E=F=EHe00AF=@8]=@8@]0Hme`04
7ADH/QRb6;85@KH5NgH4DOD5?E<00c4c?I@mU002?I@5?E<6>E<2?ID00`0a;C@PdP048=84;ED00bdC
9?<Tl`02LmX4AK@3<C<2?ID5<C<39?@2?ID6=C<45=D00cFg@KE1]@0=Ool00dGFOomoo`0[Ool007Io
o`E[O0ENE@9oTPMVM09oL0IVM09ZM0Ak50EZL`Qfd`04GS@1>04h0CP5L]@7L[<4Ne@6M_<5Na<5FS@2
L[@5HU@5KY<3HS<7JW<00eGcKYA^U005KY@2FQ<00gKc:CDY=@03M_<2FQ<203<8FWP3LgX3KaL68Qd4
?ih3Jm`00eIGCOI=mP03COH2GbX2=KP01E9HNkMk]g^gDM<01TVC00=RE7mbHU@00f9D1TVc1Tfc00=J
52TC:A<00bdC1e7D1DFD1CEC1C4c1eHe0bde00<@]3gG?ML013gG0QdE0QRb146f1W]f157e1CeC0S4c
0cfD1SeC1CUC0cfE00<]=23B8=800b3B1BeE00@Tlg?JLmYcfPA5]0@a<`03?IDa<c4c00@a<`<Tm003
?IDe<cDc00@e<`<De@04Oole]d6e@KDkOol007Qoo`=[O0ENE@03Oi9VM6Id00EVM0=oL0MVM003JWAk
57/D009k50EZL`Ufd`03GS@1>04h00Ebe0Mb/`AkE003NeIflgKc009fl`Ek4`IJ=09b]0ERE0E^T`9R
<`QZL`03EO=^U6jD00E^U09J4`03M_<Y=GKc00=fl`=J4`0303=JN5Yh00EJN0=cNPE_5`8R7@DoWP=>
oPQ=mP9O:PHe^003DM=9TdVC00E9T`ERE0I9/`E=/`=J5004:A<]4bdC;A<7DM@5AI@6=E<4<C<7ESD4
;CD00a2d?MLme`03?ML37AD011Rb@KI1]T6f1W]f1E7e1CeC0S4c0cfD1SeC1CUC13fE1B3B22eE1DFd
134c00<mUC4c<C<0134c0bCd00<mUCDc=C<01CDc00DDeGooOomoocFg03aoo`00N7oo16]l0eiE0WnB
1fId0gm`1fId1G/D1FYc2GKC00AN=04h0CP1>0Abe0Ib/`EkE09kEP=fl`Ek4`IJ=09b]0ERE0E^T`9R
<`QZL`03EO=^U6jD00I^U003FQ=flgKc00=fl`AJ4`80<`EJN0AcNPE_5`=gE`03001>oTkn00A>oPQ=
mP=O:P@e^09Ad`M9T`IRE0E9/`E=/`=J508Y4`8]4`MAe0I5U0DeD`Da<`IF=@D]=@Hme`8M5@046;91
]T6f@KH5NgH00cDcDOEAm@03DOD5?E<3<C<2?I@6?E<6>E<5?ID48=86;ED00c4dAKA5]003AK@5<C<0
0cfE<C<a<`03<C<49?@00cfE=C<e<`04=C<00aCEOomoo`0nOol007Uoo`=[O0=NE@03Oi80000000IV
M09oL0QVM0=VM@03NaAZLfYc00AZL`Ufd`04GS@Q5@4h0CP3L]@7L[<4Ne@4NeH2M_<4Na<6FS@3L[@4
HU@6KY<2HS<8JW<9KY@00eXCM_=fl`03M_<5FQ<00`0cFWQJN002FWP4LgX6KaL3MeL20006C_h6COH4
GbX4=KP2DM<7BI<6HU@5BK<4CK<4FQ@2:A<2;A<7DM@6AI@5=E<5<C<7ESD4;CD2>GD4?ML37AD00aRb
@KIkMP04NgH2=C<5DOD5?E<3<C<2?I@6?E<6>E<6?ID38=85;ED2<C@5AK@5<C<00cfE<C<a<`03<C<4
9?@00cfE=C<e<`03=C=2Ool007Uoo`0307E[O6]l00=NE@03Oi9oo`0000EVM0=oL0QVM0AVM@IZL`Uf
d`9N=0038AD1>04h009be0Ib/`EkE0EkEPEk4`IJ=0=b]0ARE0M^T`03HS=ZLfYc00IZL`U^U003FQ=f
lgKc00=fl`IJ4`=JN0EcNPE_5`=gE`@000E>oPI=mPAO:P<e^0=Ad`M9T`IRE0I9/`==/`AJ508Y4`8]
4`MAe0I5U0DeD`Da<`MF=@@]=@<iM@<me`@M5@03@KIkMW]f009kMP<e<`EAm@HmD`<a<`03?I@mDceC
00@mD`HiD`PmU@038=8]EBeE008]E@03;A@a=34d00I5]0/a<`@Tm08e<dEoo`00NWoo00D0MF]lGUEN
EGnB009oo`03001VM6Id00=VM0=oL0MVM0EVM@EZL`Yfd`9N=08Q5@030CQbe7;D00Ib/`AkE0IkEPAR
M@MJ=0Ab]0=RE0M^T`03HS=ZLfYc00IZL`U^U0Efl`QJ4`03FWQcNW=j00=cNPI_5`=gE`=J=08000A>
oPE=mPIO:P03=KQAde7C009Ad`M9T`IRE0I9/`9=/`EJ50<Y4`03;A=Ae57D00AAe003EOA5U4FD00A5
U0DeD`Da<`MF=@D]=@@iM@03?MLM5AdE00DM5@03NgHe<cDc00<e<`AAm@HmD`<a<`8mU0DmD`HiD`Lm
U@8]4`038=8]EBeE00<]5003<CA5]4Fd00A5]0Da<`8eUP@a<`@Tm4Moo`00NWoo0P1e00=[O5iEOol0
0Woo00<006IdIW@00fId0Wm`26Id1FIe00=o<fYcJW<00VYc2WKC0Uhd0b4E0W;D1W:c17]D1W]F169e
1eXd17:d0f9D1fjC26Yc0VID26jD1GKc2UXC0g=j1VlG0gMG00=N=5XdFS@00eXd14kn1Dgf0eWc00AZ
U5lZGbXe^0AAd`Q9T`ERE0I9/`9=/`EJ50<Y4`8]4`AAe0=Em0E5U003:CDeDcEC008eD`Ha<`IF=@D]
=@DiM@03?MLM5AdE00<M5@03@G<e<cDc00@e<`EAm@DmD`@a<`03?I@mDceC00<mD`HiD`LmU@05Ool]
4bdC;ED]4`03;A@00c4dAKA5]004AK@5<C<3=IH3<C<39?A8Ool007]oo`0307EooeiE00Aoo`EVM09o
L0MVM0EVM@9o<`AZL`]fd`03GS@Q5B4E008Q5@Ib/`EkE0EkEPARM@03Oi5J=5Xd00AJ=0Eb]09RE0Q^
T`QZL`9VE0Q^U004EOAflgKcM_<<FQ<00`0@LgY_5`05KaL3MeL6FS@00eXDC_i>oP02C_h4COH2FO<3
JY@6DM<8BI<3HU@2BK@3AI@3BK<00dfcFQAJ5004FQ@4:A<012dCDMAAe57D15Gd1TFD00@Y=CEC=E<e
D`Ha<`IF=@D]=@HiM@8M5@9;W`03=E=1LcDc00@e<`03CQIAmE7e00=Am@DmD`@a<`03?I@mDceC00@m
D`DiD`HmU@9oo`@]4`@]5003<CA5]4Fd00=5]0Ha<`@eUP04<C<Tm2Cd9?A8Ool0089oo`04001VM6Id
IW@2Og02God6IW@5IWD2Oc<4JW<;M]<00ehdN_<Q5@028AD6L[<4Ne@5NeH5HWD00gnAFSAJ=004FS@5
L[@2HU@8KY<8JW<2IU@7KY@3EO@2M_<<FQ<00fYdKaM_5`04KaL3MeL7FS@2FQ@3C_h3COH3FO<3JY@7
DM<7BI<5BK@6AI@00dfcFQAJ5004FQ@4:A<00bdCDMAAe005EO@6AI@2:CD3=E<5<C<7ESD4;CD9>GD3
=E<2=C<4CQH00bDEDOEAm@02DOD5?E<5<C<6?E<6>E<5?ID3Ool3;A<4;A@00c4dAKA5]003AK@6<C<5
=IH00c4c9?Aoo`18Ool0089oo`04001VM6IdIW@2Og02God6IW@5IWD2Oc<4JW<;M]<2N_<48AD5L[<4
Ne@5NeH5HWD2Oi45FS@5L[@2HU@7KY<2MaD6JW<4IU@5KY@5EO@00gKcFQ=J4`09FQ<2JW@00`0@KaM_
5`02KaL4MeL8FS@2FQ@2C_h3COH3FO<3JY@7DM<7BI<6BK@5AI@8FQ@4:A<00e7DEOAEm004EO@6AI@3
:CD2=E<5<C<7ESD5;CD8>GD3=E<7CQH012DEDOEAmE7e1CeC1C4c1SeC1SUC1CfE0goo0bdC1BdD1DFd
1S4c13FF0Woo00<Tm7ooOol0Agoo0022Ool01P00IWAVM6IdOg1oo`9Oo@EVM0EVM@Ao<`9ZL`afd`9Z
U0@Q5@Ab/`AkE0EkEPERM@=oT@AJ=0Mb]003HUA^TfjC00E^T`9g5@IZL`AVE0A^U0IEm0aJ4`=ZM004
011_5flGKaL4MeL8FS@3FQ@00dknCOI=mP03FO<4JY@7DM<6BI<00g;EBKA9]004BK@5AI@8FQ@4:A<7
EO@6AI@4:CD00cEC<C<a<`03<C<7ESD5;CD8>GD3=E<7CQH012DEDOEAmE7e1SeC134c00<U=CeC?E<0
0ceC1SUC13fE1Goo0bdC12dD1TFd1S4c0cFFC7oo0023Ool3IW@00gm`Ool02`02God4IW@5IWD4Oc<2
JW<<M]<2JY@58AD3L[<4Ne@5NeH5HWD3Oi44FS@7L[@00f9DKY=^T`05KY<2MaD6JW<4IU@4KY@6EO@<
FQ<3JW@00eGcKaM_5`04MeL2HU@7FS@4FQ@00dknCOIIl`02FO<4JY@7DM<6BI<00g;EBKA9]004BK@6
AI@7FQ@4:A<7EO@7AI@4:CD6<C<5ESD00e8F;CD]=@03;CD7>GD5=E<6CQH29AD2DOD6?E<5<C<00bDe
?E<mD`02?E<6>E<4?ID6Ool2;A<4;A@00bTeAKA5]003AK@6<C<3=II<Ool008=oo`9VM004Og1oogoo
Ool2God3IW@6IWD4Oc<2JW<;M]<4JY@48AD2L[<4Ne@5NeH6HWD3Oi44FS@7L[@7KY<3MaD5JW<6IU@2
KY@7EO@<FQ<3JW@2EO<00flGMeMgE`02MeL2HU@7FS@5FQ@014gfFO=IleWc16ZD1e7C1TVC0W;E1DVd
1TFD1eXD1BTC1eGd1TFD12Te14WE0S4c0UHe1E8F12de1SUe1SEC1ThF0RDE0U7e1SeC1C4c0RDe0ceC
1SUC0cfE1goo0RdC1BdD00<Y=DFdAK@00TFd1S4c0SFFCGoo0023Ool00`00IWAoL003Ool00`0;GoeV
M002IW@6IWD4Oc<2JW<;M]<4JY@48AD2L[<4Ne@4NeH6HWD4Oi43FS@8L[@7KY<3MaD5JW<6IU@00fjD
EOAEm005EO@00gmAFQ=J4`09FQ<4JW@4EO<2MeL3HU@7FS@7FQ@00eWcJYAZU004JY@6DM<5BI<3L]D5
BK@6AI@7FQ@5:A<7EO@6AI@4:CD6BMD7DQH00`2E;CD]=@02;CD5>GD6=E<6CQH39AD2DOD5?E<5<C<3
9CD2?E<6>E<3?ID8Ool00bdC;A@]5003;A@00bTeAKA5]002AK@6<C<2=II=Ool008Aoo`03IWAoogoo
00=oo`03GoeVM6Id00IVM@Eo<`9ZL`]fd`=ZU09oDP=ZU@038AEb/g]D00=kE0AkEPIRM@AoT@=J=0Qb
]0M^T`Ag5@AZL`IVE0QEm09oD@YJ4`EZM0AEl`04MeMRE69DHU@7FS@7FQ@00eWcJYAZU004JY@6DM<5
BI<3L]D6BK@5AI@7FQ@5:A<7EO@6AI@5:CD6BMD7DQH0102E;CD]=Bde13Ue0U7e1SEC1ThF0bDE00=A
mCeC?E<00ceC1S4c0RDe0ceC1SUC00<mUGooOol01goo00<]4bdD;A@00bdD0RTe0dFd1c4c00<eUWoo
Ool0Bgoo0024Ool00gm`Oomoo`03Ool00`0;GoeVM006IWD6Oc<;M]<4JY@3Oe85JYD3GUD3KY<7HWD4
Oi43FS@7L[@2K]D5KY<5MaD3JW<7IU@8EO@2Oe4:FQ<5JW@5EO<3HU@7FS@7FQ@00eWcJYAZU004JY@6
DM<4BI<4L]D6BK@5AI@7FQ@5:A<7EO@6AI@5:CD6BMD7DQH209D2;CD4>GD2DOD6=E<6CQH39AD00e7e
?E<mD`03?E<6<C<39CD2?E<6>E<00cfEOomoo`08Ool00bdC;A@]5002;A@3:CD2AK@7<C=>Ool008]o
o`0300]VM6Ie00EVM@Io<`]fd`AZU0=oDPAZU@ENE@9^T`IRM@EoT@=J=0Mb]09^e@E^T`Eg5@=ZL`MV
E0QEm09oD@YJ4`EZM0AEl`ERE0MJ=0IJ50MZU0IAd`A9T`Abe@I9]0I5U0IJ50DY4`MEm0M5U0@Y=@I9
e@QB5P0309DiDbde00<iM@=Am@HeD`I>5P@U5@HmD`Da<`@U=@03?E<iDcUC00@iD`03?IEoogoo00Qo
o`03;A<]52dD00<]50<Y=@03AK@a<c4c00@a<dmoo`00Rgoo00<02fIeIWD016Ie1glc2WKC1FZD0gmB
0fZE1UiE0fjC1F9e1WnA00=J=7:dL[@01W:d0VkE1FjC1GLE0fYc1VID00=oT5GdEO@01UGd0WmA2UXC
1FYd15Gc1F9D1eXd1EXD00==e6ZDJY@01FZD1U7C14VC17;E1TVd1TFD1eXD1BTC1UGd1dFD1BTe1TWE
1e8F0cUC00<]=CUeDOD00e7e1cEC1DhF12DE1SeC1S4c0bDe00AoocUC>E<iD`moo`D]50<Y=@95]0@a
<e1oo`00Rgoo00<02fIeIWD016Ie1glc00=gNGKCM]<01gKC16ZD1GmB0VZE1UiE0VjC00=be69eHWD0
0f9e1WnA00=J=7:dL[@01G:d16kE0fjC1WLE0VYc1fID0Wn@1UGd0gmA2EXC1VYd15Gc1F9D1eXd0UXD
14gD1fZD1e7C0TVC1G;E1TVd1TFD1eXD1BTC1UGd1dFD1BTe1TWE1e8F13UC00<iME7eDOD00U7e1cEC
1DhF12DE00<U=SeC?E<00ceC1S4c0bDe57oo12dD12Te00A5]34c<C=;]e5oo`00S7oo00<02fIeIWD0
0fIe1Wlc0WMi2GKC16ZD1GmB00=ZUEiEGUD01EiE0VjC00=be69eHWD00V9e1gnA00=J=7:dL[@01G:d
16kE0fjC1gLE00=ZLfIDIU@01FID0Wn@1UGd0gmA2EXC1VYd0eGc1V9D1eXd1dgD1VZD1e7C0TVC1W;E
1TVd1DFD1eXD1BTC1eGd1TFD00=_5bTe:CD00RTe1TWE1U8F1DXG0Sed0e7e1SEC00=[_46f@KH014hF
12DE00<U=SeC?E<00SeC1S4c0RDe5Woo12dD12Te00<a<d^gBkL0DGoo002<Ool00`0;IWEVM@02IWD6
Oc<4MgT7M]<5JY@5Oe89GUD00fjCL]AM0`03HWD2Oi44?OP00gnAL[Ab]005L[@5K]D3KY<7MaD00fYc
IUAVE004IU@3Oi06EO@3Oe49FQ<6JW@3EO<6HU@6FS@00eHECMA=e005CM@7JY@6DM<00dVCL]Ebe@05
L]D6BK@6AI@6FQ@5:A<7EO@5AI@3KaL3:CD7BMD4DQH6BQL3?G@2DOD5=E<2Jk`4@KH2CQH49AD29CH3
?E<7<C<00bDeOomoo`0EOol3;A@6:CEBOol008eoo`AVM@Io<`AgN@Mfd`AZU0IoDPUNE@=be0=RM@9o
T@03IW@mn3gh008mn0Mb]0E^e@9^T`Mg5@03H_UVE6ID00EVE0=oT0IEm0=oD@UJ4`IZM0=El`IRE0EJ
=09F5@M=e0MZU0IAd`03BI=beG;E00Ebe@I9]0I5U0IJ50DY4`MEm0E5U0=_5`04018Y=BTe:CD6BMD4
DQH00dVdBQM:5`03BQL4?G@2DOD3=E<4Jk`5@KH49AD39CH2?E<7<C<00bDeOomoo`0FOol2;A@5:CEC
Ool008eoo`0400]VMFIeIWD5Oc<6MgT6M]<4JY@5Oe82J[H8GUD3L]@2HWD2Oi42IW@5?OP6L[@6K]D0
0fjCMaEg5@04MaD2H_T7IU@3Oi05EO@4Oe48FQ<8JW@00eGcHUARE006HU@3FS@4EQD7CM@6JY@6DM<0
0dVCL]Ebe@05L]D6BK@6AI@6FQ@00f:h:A<Y4`03:A<6EO@4AI@5KaL00`0B:CDY=@06BMD3DQH2BK@6
BQL4?G@00e7e=E<eD`05Jk`6@KH49AD39CH2?E<5<C<KOol00bdD:CDY=@02:CEDOol008eoo`0400]V
MFIeIWD4Oc<6MgT00e_NM]=fd`03M]<5JY@5Oe82J[H8GUD00gNHL]Abe002HWD017nAIWAVM6Id1Cgh
1G:d1fkE00=^TgLEMaD00gLE16;i1VID0gn@1EGd1GmA1eXC26Yd00=Elf9DHU@01V9D0UXd1EHE1dgD
1VZD1U7C27;E1TVd1TFD1EXD0V:h00<HmBTC:A<00RTC1UGd14FD1FlG0TgD00<Y=DWEBMD01DWE0U8F
0TVd1TXG1Ced00<eDf^lJk`016^l1T6f00AoobDE9ADU5@@U=P04?E<a<c4c<C<NOol00bdD:CDY=@1E
Ool008ioo`9VM@Eo<`AgN@AKgPAfd`EZU0AoDP=Z]PMNE@=gV09be003HWEoTFId00=VM0Dmn0Ab]0M^
e@9SS`=g5@ERn@EVE0AoT0EEm0EoD@MJ4`QZM003EO=RE69D00IRE003FSAF5EHE00AF5@M=e0IZU0IA
d`03MeQbeG;E00Ebe@M9]0E5U0AJ50=R^08Hm@<Y4`IEm0=5U0I_5`==e003:CE9eDWE00A9e@03DQI9
]4Vd0099]0E:5`PmM0A[_0E1]P=oo`8U5@@U=P03Oola<goo021oo`03:CEoogoo05Aoo`00SWoo0VIe
17lc0gMi1e_N0WKC1FZD1GmB16Zf1EiE17NH0W;D00=oTFIdIW@00fId1Sgh0W:d26kE0f>?00=g5F;i
H_T016;i1FID1Gn@15Gd1GmA1UXC0V^>1fYd2F9D1eHE24gD1FZD1E7C0gMH1W;E1dVd1TFD0UXD1F:h
0QSe0RTC1eGd0TFD1FlG14gD00DmDdWEBME9eCeC00M9]0E:5`PmM0A[_0E1]PAoo`049ADU=RDf9CIk
Ool008ioo`0400]VMGlcOc<:Ool2Fmh2M]<5JY@4Oe85J[H5GUD5MiP00g;DIWAVM004IW@6?OP2L[@7
K]D3Hhl00g:cJYERn@05H_T5IU@5Oi04EO@5Oe46FQ<2Jhh7JW@9HU@7EQD8CM@5JY@5DM<3MeP6L]D7
BK@6AI@00eXDH[QR^004H[P36?D00bTCEOAEm005EO@00dFDKaM_5`03KaL5CM@5?E<7BK@5BQL8?G@0
0gooJka[_002Jk`4@KH5Ool00bDE9CIoo`1kOol008moo`03Oc=oogoo00eoo`03M]=ZU6ZD00=ZU0=o
DPIZ]PANE@EgV003IgaVM6Id00IVM0Hmn003L[A^eFkE00A^e@9SS`9b/`=ZU@ERn@AVE0IoT0=Em0Io
D@EJ4`=[SPMZM0URE003Oi=F5EHE00AF5@Q=e08iM@=ZU0AAd`EgF0Ibe@E9]003Ime:>DXi00A:>@MR
^0@Hm@03:A=Em5Gd00AEm003AIA_5flG00=_5`E=e0DmD`Q9]0A:5`LmM0=oo`=[_0=1]PMoo`039CIo
ogoo07Yoo`00Wgoo1VZD0gmB1VZf0eiE1GNH0VMl26Id0W]e169C1fkE00ASSg:cL[=b/`=ZU@03IWAR
nF;i00=Rn@=VE0IoT0=Em0IoD@EJ4`=[SPIZM09kePMRE09oT`MF5@M=e0<iM@=ZU09Ad`IgF08Uf`Ab
e@A9]0=Wg@I:>@MR^0@Hm@=Em08mD`03:01_5flG00=_5`03GSA=e4gD00==e0DmD`Q9]0E:5`HmM0Ao
o`9[_0=1]XAoo`00X7oo16ZD0gmB26Zf0UiE17NH16Ml1VId0g]e1F9C1FkE00ASSg:cL[=b/`AZU@9V
M0ARn@=VE0IoT0=Em0IoD@AJ4`E[SPEZM09kePMRE09oT`MF5@I=e003000iMCUe008iM@9ZU09Ad`Ig
F004Kk/UfbGK9M/2L]D2BK@5Imd6BST7H[P46?D5?E<00ehd:01_5`02KaL3GS@4CM@6?E<7BK@5BQL5
?G@5Ool2Jk`3@KJ4Ool00:1oo`AZU0=oDPQZ]P03GUEgV7NH009gV0EWO0IVM0=kM@ERD`E^e@04Hhmb
/g:cL[<5JYD2IW@3H_T3IU@00gn@FSEoT003Oi03EO@6Oe44FQ<00eWcJhi[SP02Jhh4JW@3NmH7HU@2
Oi<7EQD6CM@20004>GD00fZDDM=gF005MeP2Kk/59M/00dVdImeWg@05Imd6BST6H[P36?D00eHD?E<m
D`03?E<2GS@3KaL3GS@4CM@6?E<7BK@00gooBQM:5`02BQL5?G@6Ool00f^l@KI1]P25Ool00:1oo`AZ
U09oDPUZ]PIRE0AWO0IVM0=kM@IRD`=^e@04Hhmb/g:cL[<6JYD2IW@00g;DH_URn@02IU@017n@L]AJ
=EXe0gn@0UGd1gmA15XC0UWc0f^>16Yd0g_F1V9D0gnC1eHE1DgD0`001CUe00=AdgMHMeP00gMH16nk
1bGK1FOM1TXi1f:h00<HmEHDEQ@01CeC0ehd00=_5ehdGS@00Uhd1DgD1CeC1TVd0goo0dXG13ed27oo
00=[_46fOol0Q7oo002QOol2JY@3Oe800fIDJ[IZ]P06J[H7HU@3Ig`5IW@4NgD6HU<2K]D00f>?Ni1b
/`02L[<6JYD2IW@2L]@016;iIUAVE7n@0V9E0UXe0Wn@0UGd0WmA00=ZLfIdOe400gmA0UXC15Wc0V^>
0fYd1G_F1F9D17nC1UHE1DgD0`001cUe0gMH1Fnk1RGK0eHD00=EdfOMImd01dXi0f:h00=N=5HDEQ@0
0eHD1CeC25hd1DgD1CeC1TVd17oo0TXG13ed2Goo00=1]WooOol0Pgoo002QOol2JY@2Oe82IU@7J[H8
HU@4Ig`4IW@4NgD6HU<00g^@K]EkT002Ni000g:cJYEZU@05JYD2IW@3L]@00f;iIUAbe002HUD2FSD3
Oi0015GdOe5oDFYc0VId0gmA0UXC15Wc00=be6^>JW@00VYd1G_F1F9D17nC1UHE14gD0UXD0P0023Ue
00=gF6nkKk/01Fnk0RGK00=RE5HDEQ@00eHD15GC0dXi1ehd1EHD1SeC1ehd00<0<TgDCM@00TgD1CeC
1TVd17oo0TXG0cedT7oo002QOol2JY@01GmBIUAVE6IDJ[D01FZf2F9D00AVE6MlIgaWO0=VM0IkM@AR
D`IkT003L[=ZUFZE00EZU@9VM0Abe004Oi1be69EHUD3FSD2Oi0015GdOe5J=FYc16Id00=oDEXCFO<0
15Wc0W;D00A[SVYdNmIJ50AkePERE0AoT`IF5@==e0=J508000PiM@03DM=VMFnk009_^`IRE0EF50IE
d`QN=0EF50HmD`IN=09gM`A=e0HmD`A9]0Ioo`9:5`8mM91oo`00XWoo00=ZU7mBIU@00VID0VZe0fZf
00=Z]F9DHU@01f9D0VID0VMl0fId1W]e169C1G^@00<006ZEJYD01fZE00=VM7;DL]@00g;D0f9E15Xe
00AoT5GdFSEJ=@IVM003FQ=IleWc00=Il`=be004JWAJ55XDFQ@3NmH4HU@5Oi<7EQD2CM@3FQ@30007
>GD5IWD6HU@00aTFEQAF5002EQ@5EM<2LcP8GS@4EQ@6?E<5GS@3MgL0100bCMA=e4gD1SeC14Vd1goo
00=:5cedOol0T7oo002ROol00gmBIUAVE002IU@2J[D3J[H00fZeHUARE007HU@017LDIUAVE6Ml0VId
1g]e169C0W^@00EZTeGdHUARE00000QZU@Ibe0=RE@EJ=@03Oe5J=EXe00MVM0AIl`Ebe0AJ509kePAR
E0EoT`MF5@03CMAJ55XD00=J508000HiM@IVM@ERE09gf0046AIF55HDEQ@5EM<2LcP8GS@4EQ@6?E<5
GS@3MgL0100bCMA=e4gD1SeC14Vd27oo00<mM7ooOol0Sgoo002SOol3IU@4J[D00fZfJ[E^]@08HU@2
Ma@3IU@00fMlIWAkM@06NgD3HU<01G^@JY=ZTfZCEO@00V9D00<006ZEJYD01FZE00=[FW;DL]@00g;D
1F9E1eXe1fId15Wc1G;D0eXD00AoE7_FNmIkeP=RE0IoT`IF5@03CMAJ55XD00=J508000DiM@03DM=V
MFIe00AVM@ARE0=gf08I5P9F50AEd`=c>0QN=0EF50DmD`AN=0EgM`03039=e4gD00HmD`=9]9]oo`00
Y7oo0VID1VZe0Vje1f9D0WLD16ID00AVM7]eL]Abe0AkM@=RD`04Ni1ZTfZCJY<4HU@00`00JYEZU@03
JYD3JeX4L]@5HUD6FSD2J]L6IW@4FO<5L]@3FQ@2Oe@2NmH3HU@6Oi<3EQD2DO@7FQ@00eXC000iM@04
>GD7IWD4HU@3MmP26AH3EQ@2EM<4LcP8GS@5EQ@5?E<4GS@5MgL00`0bCMA=e006?E<3BKBKOol00:Ao
o`03IUAZ]FZe00AZ]@=^]@MRE09g50EVE0Abe0=kM@=RD`AZT`ARE003001ZUFZE009ZU@E[FP9be0IR
E@EJ=@=Ze`IVM0=Il`Ibe0=J50=oE003NmIRE69D00EoT`9oL`EAm0MJ5003FQ<003Ue00<iM@03DM=V
MFIe00EVM@=RE0Egf08I5P9F509Ed`Ac>0QN=003OomF55HD009F50HmD`9N=0IgM`80<P03CM@mDceC
00@mD`=9]9]oo`00Y7oo00=VE6ZeJ[D016Ze0fje1V9D0gLD1FID17;D00=RE7]eNgD00V9C00=kT6ZC
JY<00VZC1F9D0fZE1V]J0W;D1V9E1EXe0f[G1VId0eWc1W;D0eXD0gmD00=keV9DHU@00WnC0eWc0Wmc
1E7d1eXD0UXC13Ue2FIe0V9D1GOH0aTF00=F55GCLcP01G<h1Uhd0Woo15HD1SeC00=N=7MgMgL01WMg
00<0<TgDCM@01SeC00=9]7ooOol0VWoo002TOol00fIDJ[EZ]@03J[D4K[D6HU@4Ma@3IU@6L]@0169D
NgEkMF9C16ZC0W/d1F9D00=ZUF]JJeX01V]J00=be69EHUD0169E15Xe16[G1fId0UWc1W;D0UXD1GmD
00=keV9DOi<00eWc0gmc1E7d1eXD0UXC00D003Ue>GEJ4g_E00QVM@03HUAgf7OH00Agf0@I5P03EM=c
>7<h00Ac>0EN=0Aoo`=F50HmD`03GSAgMgMg00IgM`03039oodgD00HmD`03BKAoogoo09Yoo`00Y7oo
1VZe16je1V9D17LD0fID1W;D00ARE6ZCNgERD`AZT`9k=0ERE09be0I[FP03001REF9E00IRE@9J=@EZ
e`MVM003FO=be7;D00Ibe003FQAoE7mD00AoE003Oi=IleWc009Il`=oL`IAm0IJ509J4`03000iMEXC
009ke@QVM@Eoo`=gf0DI5PEc>0EN=0Aoo`=F50HmD`9;K`IgM`=oo`03CM@mDceC00@mD`03BKAoogoo
09Yoo`00YGoo1FZe16je1F9D1GLD0fID1W;D00ARE6ZCJY=kT0AZT`9k=0ERE0=be09[FP=El`03001R
EF9E00IRE@9J=@IZe`IVM003FO=be7;D00Ibe003FQAoE7mD00AoE0EIl`=oL`IAm0IJ50=J4`04>GEJ
4g_ENmD8IWD8Ool66AH4LcP4GS@6Ool2EQ@6?E<3Bfl2MgL7Ool3?E>POol00:Eoo`AZ]@I^]@ARE0Eg
509VE0Mbe003HUAZTfZC00AZT`=k=0ERE0Abe0AEl`8000MRE@03FSEZef[G00EZe`IVM003FO=be7;D
00Ibe09oE003GSEoE7mD009oE0AIl`AoL`IAm0IJ50AJ4`Ake@IVMA5oo`9c>0AN=0Moo`03EQ@mDceC
00<mD`=;Kjeoo`00YWoo0fZe1Vje169D1GLD0VID1g;D1fZC0g/d1F9D17;D15Gc0P001f9E26[G1VId
2G;D0UXD0Uhe0gmD15Wc1Gmc1E7d1eXD0eXC17_E1FIe4goo0W<h0Uhd27oo0UHD0ceC00=;KgooOol0
[Woo002VOol2J[D7K[D3HU@7Ma@00fIDL]Abe005L]@7JY<4Nc@3HU@5L]@4EO<00g/c001RE@06HUD0
0eiEJ]MZe`05J]L6IW@8L]@3FQ@2GSD3Oe@4FO<5Og<5DO@7FQ@2FQ<5NmD4IWDEOol00g<hGSAoo`09
Ool00eHD?E<mD`2bOol00:Moo`03J[E^]Fje00E^]@=RE0Mg50Qbe0IZT`Ek=0=RE0Ebe0AEl`03Nc<0
069E00ERE@=NE@IZe`MVM0Ibe0AJ50=N=@9oE0=Il`IoL`EAm0MJ509J4`Ike@9VMAMoo`03GSAoogoo
00Qoo`03EQ@mDceC0;9oo`00Ygoo26je0f9D1gLD1g;D0V/H1FZC1G/d0f9D1G;D15Gc0W/c00<0069E
HUD00f9E15iE1V[G1fId17;D00=N=5XDFQ@00UXD0ehe0WmD0eWc1Wmc1U7d1UXD00=J4g_EOol017oo
00=keFIeOol08goo00<mDgooOol0/Goo002XOol7K[D2HU@7Ma@2Ool5L]@3JaP5JY<5Nc@2HU@6L]@4
EO<2Nc<00`00HUERE@02HUD5GUD4HS<2J]L7IW@3L]@00ehdFQAJ5004FQ@3GSD017mDFO=IleWc1Wmc
1U7d1UXD00=J4gooOol0gWoo002YOol7K[D00f9DMaAg5004Ma@4Ool3L]@4JaP5JY<5Nc@2HU@6L]@4
EO<3Nc<3HUD00eXDGUENE@03GUD6HS<2Lhl6IW@00g;DIWAJ5006FQ@3GSD2Oe@00eWcOg=oL`05Og<6
DO@3FQCTOol00:Uoo`M^]@03HUAg57LD00=g50Eoo`03DMAbe6/H00A[60AZT`Mk=003HUAbe7;D00Ab
e0=El`Ak<`=RE@INE@IR<`9cS`QVM0MJ50AN=@03OeAIlgmc00IoL`EAm09N=003FO=oogoo0>=oo`00
ZWoo1Vje1GLD1Woo0VZe1V/H0fZC1g/d00=RE7;DL]@017;D0eGc17/c00<0069ENc<01eiE1F8c0W>?
1fId00<00eXDFQ@01EXD0ehe00=gV7mDFO<027mc0e7d0ehdiWoo002[Ool3K[D5Ool00gLDOomoo`06
Ool2J[D5JaP3JY<7Nc@8L]@2EO<5Nc<00f9ENcA=m@06GUD4HS<3Lhl7IW@00`03FQAJ5005FQ@3GSD2
MiP2Og<4DO@3Og<2DO@4GSCVOol00;aoo`=Z]@A[609ZT`Mk=003M_Abe7;D00Ibe09El`Ek<`9k=003
COENEEiE00ANE@AR<`AcS`EVM0<00`MJ5003GSEgV7NH00=gV0IAm003GSAAm5hd00=N=>Moo`00_Goo
0fZe00=RMF/HJaP00VZC1G/d17Kd1g;D00=Elg/cNc<00g/c0g/d00==mEiEGUD015iE168c17>?1FId
00=oo`0300<01eXD00=N=GNHMiP00gNH1U7d1Uhdigoo002mOol2J[D4HWD00f/HJY=k=002Nc@00ehd
M_Afm003M_@00eHDL]Abe004L]@00eGcNc=k<`02Nc<4Nc@00dge92]NE@04GUD3HS<00g>?OomcS`02
Lhl4IW@2Ool200<7FQ@3Ool3MiP6DO@5GSCXOol00;ioo`03J[ERMF9e00=RM@9k=0=N=0Efm003EQAb
e7;D00Abe005EO=k<g/cNc==e004Nc@2COD5GUD3HS<00g>?Oomoo`02Lhl3IW@3Ool200<7FQ@4Ool3
MiP5DO@5GSCXOol00;ioo`MRM@AN=0Efm09F50Ebe003EO=k<dgD009=e0Ak=09=m@ENE@=R<`Aoo`04
LhmVM6IdIW@4Ool00`03FQAJ5004FQ@5Ool3MiP6DO@3GSCYOol00;ioo`MRM@=N=0Ifm0=F50Abe004
Nc==e4gDCM@5Nc@2COD6GUD00f8cLhmoo`04Ool00g>?IWAoo`04Ool00`03FQAJ5003FQ@6Ool3MiP6
DO@2GSCZOol00;moo`IRM@=N=0Ifm09F50Ibe0==e0Ik=09=m@ENE@03HS=oogoo00Eoo`03IWAoogoo
00=oo`0300=J55XD00=J50Moo`9gV0IAm09N=>Yoo`00_goo1f9e0Uhd1gKd00=F57;DL]@01G;D0TgD
1W/d0Tge1EiE00=R<gooOol037oo00@00eXDFQAJ50Qoo`9gV0IAm003GSAoogoo0>Uoo`00_goo1f9e
00=N=7KdM_@01WKd00=F57;DL]@01G;D00==e7/dNc@01G/d0Tge57oo00<00eXDFQ@02Woo00=gV57d
DO@0157d00=N=7ooOol0jGoo0030Ool6HWD00ehdM_Afm006M_@8L]@00dgDNcAk=005Nc@00dgeOomo
o`0COol00`03FQAJ500:Ool00gNHDOAAm004DOC/Ool00<1oo`IRM@03GSAfm7Kd00Efm003Oombe7;D
00Ibe003CMAk=7/d00Ak=1Qoo`03FQAoogoo00Yoo`03MiQAm57d009Am>eoo`00`7oo1V9e1WKd17oo
1g;D17/d:7oo00AgV57dDOAAm>ioo`00`Goo169e17oo0WKd1Woo1G;D;Goo00=gV57dDO@0kgoo0031
Ool00f9eOomoo`0>Ool00g;DOomoo`0_Ool00e7dOomoo`3^Ool00?moooIoo`00ogoomWoo003oOoof
Ool00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00
ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoof
Ool00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00
ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoof
Ool00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00
ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoof
Ool00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00
ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoofOol00?moooIoo`00ogoomWoo003oOoof
Ool00?moooIoo`00\
\>"],
  ImageRangeCache->{{{0, 500}, {410.062, 0}} -> {-0.0252648, 0.0397325, \
0.00200623, 0.00200623}}],

Cell["\<\
We will show that evolutionary algorithms can indeed cope with \
noisy situations like these ...\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "C. Jacob, ",
  StyleBox["Illustrating Evolutionary Computation with Mathematica.",
    FontWeight->"Bold"],
  " Morgan Kaufmann Publishers, San Fancisco, 2001. Chapter 2.\n"
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{757, 654},
WindowMargins->{{Automatic, 110}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Evolution Strategy - Introduction"}]]}, {Cell[ 
        TextData[ {"Evolutionary Algorithms"}]], Inherited, Cell[ 
        TextData[ {"Introduction"}]]}},
PageFooters->{{Cell[ 
        TextData[ {"Evolution Strategy - Introduction"}]], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}]]}, {Cell[ 
        TextData[ {"\[Copyright] C. Jacob"}]], Inherited, Cell[ 
        TextData[ 
          CounterBox[ "Page"]]]}},
PageFooterLines->{True, True},
PrintingOptions->{"FirstPageHeader"->False},
ShowCellBracket->True,
AnimationDisplayTime->1,
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[ParentDirectory[]], \
"IEC-Setup"}, "EvolvicaStyle.nb", CharacterEncoding -> "WindowsANSI"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Mutations"->{
    Cell[76487, 1066, 56, 1, 39, "Subsection",
      CellTags->"Mutations"]},
  "Preconditions"->{
    Cell[251799, 3306, 469, 12, 44, "Text",
      CellTags->"Preconditions"]},
  "Reproductive Plan"->{
    Cell[254924, 3425, 99, 1, 55, "Subsection",
      CellTags->"Reproductive Plan"]},
  "Evolution as Adaptation (Figure)"->{
    Cell[298623, 3987, 246, 5, 64, "NumberedFigure",
      CellTags->"Evolution as Adaptation (Figure)"]},
  "Figure: selection and variation"->{
    Cell[641082, 8323, 439, 12, 93, "NumberedFigure",
      CellTags->"Figure: selection and variation"]},
  "Adaptation definition"->{
    Cell[641807, 8352, 225, 9, 27, "Text",
      CellTags->"Adaptation definition"]},
  "Adaptation step animation"->{
    Cell[652704, 8726, 58, 1, 26, "Text",
      CellTags->"Adaptation step animation"]},
  "AdaptationStep"->{
    Cell[1008831, 13179, 218, 5, 75, "NumberedFigure",
      CellTags->"AdaptationStep"]},
  "Adaptation sequence animation"->{
    Cell[1009477, 13204, 62, 1, 26, "Text",
      CellTags->"Adaptation sequence animation"]},
  "Adaptation sequence (Figure)"->{
    Cell[1386884, 17913, 235, 5, 75, "NumberedFigure",
      CellTags->"Adaptation sequence (Figure)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Mutations", 2213626, 31230},
  {"Preconditions", 2213725, 31233},
  {"Reproductive Plan", 2213829, 31236},
  {"Evolution as Adaptation (Figure)", 2213956, 31239},
  {"Figure: selection and variation", 2214102, 31242},
  {"Adaptation definition", 2214238, 31245},
  {"Adaptation step animation", 2214357, 31248},
  {"AdaptationStep", 2214468, 31251},
  {"Adaptation sequence animation", 2214596, 31254},
  {"Adaptation sequence (Figure)", 2214727, 31257}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 47, 0, 96, "Title"],
Cell[1777, 54, 118, 3, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1920, 61, 49, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[1994, 65, 60, 0, 55, "Subsection"],
Cell[2057, 67, 501, 15, 63, "Text"],
Cell[2561, 84, 118, 3, 26, "Text"],

Cell[CellGroupData[{
Cell[2704, 91, 33, 0, 61, "Subsubsection"],
Cell[2740, 93, 121, 3, 26, "Text"],
Cell[2864, 98, 130, 3, 44, "Text"],
Cell[2997, 103, 70, 2, 26, "Text"],
Cell[3070, 107, 138, 3, 44, "Text"],
Cell[3211, 112, 418, 10, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3666, 127, 34, 0, 61, "Subsubsection"],
Cell[3703, 129, 110, 3, 26, "Text"],
Cell[3816, 134, 93, 3, 26, "Text"],
Cell[3912, 139, 161, 4, 44, "Text"],
Cell[4076, 145, 73, 0, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4186, 150, 75, 0, 61, "Subsubsection"],
Cell[4264, 152, 16, 0, 26, "Text"],
Cell[4283, 154, 71506, 886, 352, 71388, 882, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[75792, 1042, 277, 6, 81, "NumberedFigure"],
Cell[76072, 1050, 366, 10, 26, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[76487, 1066, 56, 1, 39, "Subsection",
  CellTags->"Mutations"],

Cell[CellGroupData[{
Cell[76568, 1071, 60, 0, 61, "Subsubsection"],
Cell[76631, 1073, 54, 0, 26, "Text"],
Cell[76688, 1075, 138, 3, 44, "Text"],
Cell[76829, 1080, 112, 3, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[76978, 1088, 53, 0, 61, "Subsubsection"],
Cell[77034, 1090, 17, 0, 26, "Text"],
Cell[77054, 1092, 87313, 1081, 557, 87195, 1077, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[164370, 2175, 493, 9, 115, "NumberedFigure"],
Cell[164866, 2186, 311, 9, 26, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[165226, 2201, 71, 0, 39, "Subsection"],
Cell[165300, 2203, 216, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[165541, 2211, 70, 0, 61, "Subsubsection"],
Cell[165614, 2213, 17, 0, 26, "Text"],
Cell[165634, 2215, 43484, 540, 460, 43366, 536, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[209121, 2757, 257, 5, 81, "NumberedFigure"]
}, Closed]],

Cell[CellGroupData[{
Cell[209415, 2767, 50, 0, 61, "Subsubsection"],
Cell[209468, 2769, 17, 0, 26, "Text"],
Cell[209488, 2771, 42115, 523, 355, 42001, 519, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[251606, 3296, 83, 1, 47, "NumberedFigure"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[251750, 3304, 46, 0, 62, "Section"],
Cell[251799, 3306, 469, 12, 44, "Text",
  CellTags->"Preconditions"],
Cell[252271, 3320, 123, 4, 27, "ListSquare"],
Cell[252397, 3326, 142, 4, 27, "ListSquare"],
Cell[252542, 3332, 102, 4, 27, "ListSquare"],
Cell[252647, 3338, 110, 4, 27, "ListSquare"],
Cell[252760, 3344, 516, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[253301, 3362, 59, 0, 55, "Subsection"],
Cell[253363, 3364, 197, 4, 44, "Text"],
Cell[253563, 3370, 43, 0, 26, "Text"],
Cell[253609, 3372, 164, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[253810, 3381, 56, 0, 55, "Subsection"],
Cell[253869, 3383, 110, 3, 26, "Text"],
Cell[253982, 3388, 243, 5, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[254262, 3398, 55, 0, 55, "Subsection"],
Cell[254320, 3400, 167, 4, 44, "Text"],
Cell[254490, 3406, 95, 3, 26, "Text"],
Cell[254588, 3411, 211, 4, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[254848, 3421, 51, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[254924, 3425, 99, 1, 55, "Subsection",
  CellTags->"Reproductive Plan"],

Cell[CellGroupData[{
Cell[255048, 3430, 72, 0, 61, "Subsubsection"],
Cell[255123, 3432, 393, 8, 62, "Text"],
Cell[255519, 3442, 146, 3, 26, "Text"],
Cell[255668, 3447, 149, 2, 26, "Text"],
Cell[255820, 3451, 17, 0, 26, "Text"],
Cell[255840, 3453, 42780, 532, 357, 42662, 528, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[298623, 3987, 246, 5, 64, "NumberedFigure",
  CellTags->"Evolution as Adaptation (Figure)"]
}, Closed]],

Cell[CellGroupData[{
Cell[298906, 3997, 49, 0, 61, "Subsubsection"],
Cell[298958, 3999, 238, 6, 44, "Text"],
Cell[299199, 4007, 211, 7, 45, "ListSquare"],
Cell[299413, 4016, 334, 8, 63, "ListSquare"],
Cell[299750, 4026, 453, 10, 81, "ListSquare"],
Cell[300206, 4038, 241, 7, 45, "ListSquare"],
Cell[300450, 4047, 17, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[300492, 4051, 43120, 538, 442, 42909, 531, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[343615, 4591, 29075, 364, 442, 28871, 357, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[372693, 4957, 31773, 398, 442, 31569, 391, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[404469, 5357, 35738, 447, 442, 35534, 440, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[440210, 5806, 38435, 480, 442, 38231, 473, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[478648, 6288, 42100, 525, 442, 41896, 518, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[520751, 6815, 42695, 532, 442, 42491, 525, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[563449, 7349, 34494, 431, 442, 34290, 424, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[597946, 7782, 43121, 538, 442, 42909, 531, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]],
Cell[641082, 8323, 439, 12, 93, "NumberedFigure",
  CellTags->"Figure: selection and variation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[641570, 8341, 58, 0, 55, "Subsection"],

Cell[CellGroupData[{
Cell[641653, 8345, 151, 5, 61, "Subsubsection"],
Cell[641807, 8352, 225, 9, 27, "Text",
  CellTags->"Adaptation definition"],
Cell[642035, 8363, 273, 8, 76, "Text"],
Cell[642311, 8373, 99, 3, 26, "Text"],
Cell[642413, 8378, 272, 6, 45, "Text"],
Cell[642688, 8386, 252, 5, 45, "Text"],
Cell[642943, 8393, 46, 0, 26, "Text"],
Cell[642992, 8395, 68, 0, 26, "Text"],
Cell[643063, 8397, 62, 0, 26, "Text"],
Cell[643128, 8399, 58, 0, 26, "Text"],
Cell[643189, 8401, 68, 0, 26, "Text"],
Cell[643260, 8403, 205, 8, 27, "Text"],
Cell[643468, 8413, 315, 8, 44, "Text"],
Cell[643786, 8423, 207, 6, 45, "ListSquare"],
Cell[643996, 8431, 292, 8, 63, "ListSquare"],
Cell[644291, 8441, 100, 1, 26, "NumberedEquation"],
Cell[644394, 8444, 211, 7, 45, "ListSquare"],
Cell[644608, 8453, 365, 10, 26, "NumberedEquation"],
Cell[644976, 8465, 969, 29, 81, "ListSquare"],
Cell[645948, 8496, 373, 9, 63, "ListSquare"],
Cell[646324, 8507, 147, 4, 62, "Text"],
Cell[646474, 8513, 2831, 87, 299, "Text"],
Cell[649308, 8602, 25, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[649370, 8610, 180, 6, 61, "Subsubsection"],
Cell[649553, 8618, 222, 6, 44, "Text"],
Cell[649778, 8626, 306, 10, 44, "Text"],
Cell[650087, 8638, 347, 11, 45, "ListNumbered"],
Cell[650437, 8651, 439, 11, 63, "ListNumbered"],
Cell[650879, 8664, 279, 6, 27, "NumberedEquation"],
Cell[651161, 8672, 268, 9, 27, "ListNumbered"],
Cell[651432, 8683, 241, 4, 24, "NumberedEquation"],
Cell[651676, 8689, 270, 8, 44, "ListNumbered"],
Cell[651949, 8699, 429, 12, 45, "ListNumbered"],
Cell[652381, 8713, 320, 11, 45, "ListNumbered"],
Cell[652704, 8726, 58, 1, 26, "Text",
  CellTags->"Adaptation step animation"],

Cell[CellGroupData[{
Cell[652787, 8731, 58455, 727, 492, 58185, 719, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[711245, 9460, 37937, 474, 358, 37733, 467, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[749185, 9936, 47462, 591, 358, 47258, 584, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[796650, 10529, 48451, 604, 358, 48247, 597, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[845104, 11135, 52152, 649, 358, 51948, 642, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[897259, 11786, 53157, 662, 358, 52953, 655, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[950419, 12450, 58397, 726, 358, 58185, 719, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]],
Cell[1008831, 13179, 218, 5, 75, "NumberedFigure",
  CellTags->"AdaptationStep"]
}, Closed]],

Cell[CellGroupData[{
Cell[1009086, 13189, 177, 6, 61, "Subsubsection"],
Cell[1009266, 13197, 208, 5, 44, "Text"],
Cell[1009477, 13204, 62, 1, 26, "Text",
  CellTags->"Adaptation sequence animation"],

Cell[CellGroupData[{
Cell[1009564, 13209, 53081, 661, 488, 52811, 653, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[1062648, 13872, 57385, 714, 488, 57181, 707, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[1120036, 14588, 60046, 747, 358, 59842, 740, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[1180085, 15337, 66092, 821, 358, 65888, 814, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[1246180, 16160, 69219, 860, 358, 69015, 853, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[1315402, 17022, 71467, 888, 358, 71255, 881, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]],
Cell[1386884, 17913, 235, 5, 75, "NumberedFigure",
  CellTags->"Adaptation sequence (Figure)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1387168, 17924, 83, 1, 55, "Subsection"],

Cell[CellGroupData[{
Cell[1387276, 17929, 66, 0, 61, "Subsubsection"],
Cell[1387345, 17931, 97, 4, 26, "ListNumbered"],
Cell[1387445, 17937, 120, 5, 27, "ListNumbered"],
Cell[1387568, 17944, 198, 3, 24, "NumberedEquation"],
Cell[1387769, 17949, 121, 5, 27, "ListNumbered"],
Cell[1387893, 17956, 269, 4, 25, "NumberedEquation"],
Cell[1388165, 17962, 256, 4, 24, "NumberedEquation"],
Cell[1388424, 17968, 102, 5, 27, "ListNumbered"],
Cell[1388529, 17975, 233, 8, 26, "ListNumbered"],
Cell[1388765, 17985, 100, 5, 27, "ListNumbered"],
Cell[1388868, 17992, 223, 4, 24, "NumberedEquation"],
Cell[1389094, 17998, 100, 5, 27, "ListNumbered"],
Cell[1389197, 18005, 169, 3, 24, "NumberedEquation"],
Cell[1389369, 18010, 101, 4, 26, "ListNumbered"],
Cell[1389473, 18016, 49, 0, 26, "ListNumbered"]
}, Closed]],

Cell[CellGroupData[{
Cell[1389559, 18021, 42, 0, 61, "Subsubsection"],
Cell[1389604, 18023, 17, 0, 26, "Text"],
Cell[1389624, 18025, 102770, 1272, 687, 102593, 1267, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1492455, 19304, 57, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[1492537, 19308, 58, 0, 55, "Subsection"],
Cell[1492598, 19310, 17, 0, 26, "Text"],
Cell[1492618, 19312, 221885, 2743, 373, 221708, 2738, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[1714506, 22057, 104, 3, 47, "NumberedFigure"],
Cell[1714613, 22062, 16, 0, 26, "Text"],
Cell[1714632, 22064, 121056, 1498, 266, 120883, 1493, "GraphicsData", \
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[1835691, 23564, 457, 8, 115, "NumberedFigure"]
}, Closed]],

Cell[CellGroupData[{
Cell[1836185, 23577, 56, 0, 55, "Subsection"],
Cell[1836244, 23579, 91, 3, 26, "Text"],
Cell[1836338, 23584, 66, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[1836429, 23588, 67, 0, 61, "Subsubsection"],
Cell[1836499, 23590, 71904, 891, 325, 71785, 887, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[1908440, 24486, 60, 0, 61, "Subsubsection"],
Cell[1908503, 24488, 303150, 6681, 482, 191431, 5297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2211656, 31171, 120, 3, 26, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2211837, 31181, 77, 2, 62, "Section",
  Evaluatable->False],
Cell[2211917, 31185, 204, 5, 63, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

